/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 52 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qgesture.sip"
#include <qgesture.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 98 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qgesture.sip"
#include <qgesture.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 62 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 77 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 83 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 86 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQPanGesture.cpp"


class sipQPanGesture : public ::QPanGesture
{
public:
    sipQPanGesture(::QObject*);
    virtual ~sipQPanGesture();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPanGesture(const sipQPanGesture &);
    sipQPanGesture &operator = (const sipQPanGesture &);

    char sipPyMethods[7];
};

sipQPanGesture::sipQPanGesture(::QObject*a0): ::QPanGesture(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPanGesture::~sipQPanGesture()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQPanGesture::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QPanGesture);

    return ::QPanGesture::metaObject();
}

int sipQPanGesture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QPanGesture::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QPanGesture, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQPanGesture::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QPanGesture, _clname, &sipCpp) ? sipCpp : ::QPanGesture::qt_metacast(_clname));
}

void sipQPanGesture::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QPanGesture::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPanGesture::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QPanGesture::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPanGesture::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QPanGesture::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPanGesture::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QPanGesture::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPanGesture::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QPanGesture::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPanGesture::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QPanGesture::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQPanGesture::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QPanGesture::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QPanGesture_lastOffset, "lastOffset(self) -> QPointF");

extern "C" {static PyObject *meth_QPanGesture_lastOffset(PyObject *, PyObject *);}
static PyObject *meth_QPanGesture_lastOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPanGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPanGesture, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->lastOffset());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPanGesture, sipName_lastOffset, doc_QPanGesture_lastOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPanGesture_offset, "offset(self) -> QPointF");

extern "C" {static PyObject *meth_QPanGesture_offset(PyObject *, PyObject *);}
static PyObject *meth_QPanGesture_offset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPanGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPanGesture, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->offset());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPanGesture, sipName_offset, doc_QPanGesture_offset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPanGesture_delta, "delta(self) -> QPointF");

extern "C" {static PyObject *meth_QPanGesture_delta(PyObject *, PyObject *);}
static PyObject *meth_QPanGesture_delta(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPanGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPanGesture, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->delta());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPanGesture, sipName_delta, doc_QPanGesture_delta);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPanGesture_acceleration, "acceleration(self) -> float");

extern "C" {static PyObject *meth_QPanGesture_acceleration(PyObject *, PyObject *);}
static PyObject *meth_QPanGesture_acceleration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPanGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPanGesture, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->acceleration();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPanGesture, sipName_acceleration, doc_QPanGesture_acceleration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPanGesture_setLastOffset, "setLastOffset(self, value: Union[QPointF, QPoint])");

extern "C" {static PyObject *meth_QPanGesture_setLastOffset(PyObject *, PyObject *);}
static PyObject *meth_QPanGesture_setLastOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QPanGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPanGesture, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->setLastOffset(*a0);
            sipReleaseType(const_cast<::QPointF *>(a0), sipType_QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPanGesture, sipName_setLastOffset, doc_QPanGesture_setLastOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPanGesture_setOffset, "setOffset(self, value: Union[QPointF, QPoint])");

extern "C" {static PyObject *meth_QPanGesture_setOffset(PyObject *, PyObject *);}
static PyObject *meth_QPanGesture_setOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QPanGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPanGesture, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->setOffset(*a0);
            sipReleaseType(const_cast<::QPointF *>(a0), sipType_QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPanGesture, sipName_setOffset, doc_QPanGesture_setOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPanGesture_setAcceleration, "setAcceleration(self, value: float)");

extern "C" {static PyObject *meth_QPanGesture_setAcceleration(PyObject *, PyObject *);}
static PyObject *meth_QPanGesture_setAcceleration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QPanGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QPanGesture, &sipCpp, &a0))
        {
            sipCpp->setAcceleration(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPanGesture, sipName_setAcceleration, doc_QPanGesture_setAcceleration);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPanGesture(void *, const sipTypeDef *);}
static void *cast_QPanGesture(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPanGesture *sipCpp = reinterpret_cast<::QPanGesture *>(sipCppV);

    if (targetType == sipType_QPanGesture)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGesture)->ctd_cast(static_cast<::QGesture *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPanGesture(void *, int);}
static void release_QPanGesture(void *sipCppV, int)
{
    ::QPanGesture *sipCpp = reinterpret_cast<::QPanGesture *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QPanGesture(Py_ssize_t);}
static void *array_QPanGesture(Py_ssize_t sipNrElem)
{
    return new ::QPanGesture[sipNrElem];
}


extern "C" {static void array_delete_QPanGesture(void *);}
static void array_delete_QPanGesture(void *sipCpp)
{
    delete[] reinterpret_cast<::QPanGesture *>(sipCpp);
}


extern "C" {static void dealloc_QPanGesture(sipSimpleWrapper *);}
static void dealloc_QPanGesture(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPanGesture *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPanGesture(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPanGesture(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPanGesture(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQPanGesture *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQPanGesture(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPanGesture[] = {{107, 255, 1}};


static PyMethodDef methods_QPanGesture[] = {
    {sipName_acceleration, meth_QPanGesture_acceleration, METH_VARARGS, doc_QPanGesture_acceleration},
    {sipName_delta, meth_QPanGesture_delta, METH_VARARGS, doc_QPanGesture_delta},
    {sipName_lastOffset, meth_QPanGesture_lastOffset, METH_VARARGS, doc_QPanGesture_lastOffset},
    {sipName_offset, meth_QPanGesture_offset, METH_VARARGS, doc_QPanGesture_offset},
    {sipName_setAcceleration, meth_QPanGesture_setAcceleration, METH_VARARGS, doc_QPanGesture_setAcceleration},
    {sipName_setLastOffset, meth_QPanGesture_setLastOffset, METH_VARARGS, doc_QPanGesture_setLastOffset},
    {sipName_setOffset, meth_QPanGesture_setOffset, METH_VARARGS, doc_QPanGesture_setOffset}
};

PyDoc_STRVAR(doc_QPanGesture, "\1QPanGesture(parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QPanGesture = {
    &::QPanGesture::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QPanGesture = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPanGesture,
        SIP_NULLPTR,
        &plugin_QPanGesture,
    },
    {
        sipNameNr_QPanGesture,
        {0, 0, 1},
        7, methods_QPanGesture,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPanGesture,
    -1,
    -1,
    supers_QPanGesture,
    SIP_NULLPTR,
    init_type_QPanGesture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPanGesture,
    SIP_NULLPTR,
    array_QPanGesture,
    SIP_NULLPTR,
    release_QPanGesture,
    cast_QPanGesture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPanGesture,
    sizeof (::QPanGesture),
};
