/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qopenglwindow.sip"
#include <qopenglwindow.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 46 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qopenglcontext.sip"
#include <qopenglcontext.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 425 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 398 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qimage.sip"
#include <qimage.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 795 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 54 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 57 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 60 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 63 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 66 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 69 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 195 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 72 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 302 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 75 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 726 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 78 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 253 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 81 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 205 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 84 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 363 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 87 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 471 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 90 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 460 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 93 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 384 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 96 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 412 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 99 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 102 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 105 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 108 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 111 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 114 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 117 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 120 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 123 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 126 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 129 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qsurface.sip"
#include <qsurface.h>
#line 132 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 137 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 140 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 143 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 152 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 155 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 158 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 161 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 164 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 167 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 170 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 173 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"
#line 52 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 176 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLWindow.cpp"


class sipQOpenGLWindow : public ::QOpenGLWindow
{
public:
    sipQOpenGLWindow(::QOpenGLWindow::UpdateBehavior, ::QWindow*);
    sipQOpenGLWindow(::QOpenGLContext*, ::QOpenGLWindow::UpdateBehavior, ::QWindow*);
    virtual ~sipQOpenGLWindow();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void paintOverGL() SIP_OVERRIDE;
    void paintUnderGL() SIP_OVERRIDE;
    void paintGL() SIP_OVERRIDE;
    void resizeGL(int, int) SIP_OVERRIDE;
    void initializeGL() SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void exposeEvent(::QExposeEvent*) SIP_OVERRIDE;
    ::QObject* focusObject() const SIP_OVERRIDE;
    ::QSurfaceFormat format() const SIP_OVERRIDE;
    ::QSurface::SurfaceType surfaceType() const SIP_OVERRIDE;
    ::QSize size() const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQOpenGLWindow(const sipQOpenGLWindow &);
    sipQOpenGLWindow &operator = (const sipQOpenGLWindow &);

    char sipPyMethods[35];
};

sipQOpenGLWindow::sipQOpenGLWindow(::QOpenGLWindow::UpdateBehavior a0, ::QWindow*a1): ::QOpenGLWindow(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQOpenGLWindow::sipQOpenGLWindow(::QOpenGLContext*a0, ::QOpenGLWindow::UpdateBehavior a1, ::QWindow*a2): ::QOpenGLWindow(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQOpenGLWindow::~sipQOpenGLWindow()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQOpenGLWindow::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtGui_qt_metaobject(sipPySelf, sipType_QOpenGLWindow);

    return ::QOpenGLWindow::metaObject();
}

int sipQOpenGLWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QOpenGLWindow::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtGui_qt_metacall(sipPySelf, sipType_QOpenGLWindow, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQOpenGLWindow::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtGui_qt_metacast(sipPySelf, sipType_QOpenGLWindow, _clname, &sipCpp) ? sipCpp : ::QOpenGLWindow::qt_metacast(_clname));
}

void sipQOpenGLWindow::paintOverGL()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_paintOverGL);

    if (!sipMeth)
    {
        ::QOpenGLWindow::paintOverGL();
        return;
    }

    extern void sipVH_QtGui_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtGui_39(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQOpenGLWindow::paintUnderGL()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_paintUnderGL);

    if (!sipMeth)
    {
        ::QOpenGLWindow::paintUnderGL();
        return;
    }

    extern void sipVH_QtGui_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtGui_39(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQOpenGLWindow::paintGL()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_paintGL);

    if (!sipMeth)
    {
        ::QOpenGLWindow::paintGL();
        return;
    }

    extern void sipVH_QtGui_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtGui_39(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQOpenGLWindow::resizeGL(int a0, int a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_resizeGL);

    if (!sipMeth)
    {
        ::QOpenGLWindow::resizeGL(a0, a1);
        return;
    }

    extern void sipVH_QtGui_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int);

    sipVH_QtGui_53(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQOpenGLWindow::initializeGL()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_initializeGL);

    if (!sipMeth)
    {
        ::QOpenGLWindow::initializeGL();
        return;
    }

    extern void sipVH_QtGui_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtGui_39(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQOpenGLWindow::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtGui_51(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtGui_51(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::touchEvent(::QTouchEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_touchEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::touchEvent(a0);
        return;
    }

    extern void sipVH_QtGui_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTouchEvent*);

    sipVH_QtGui_50(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtGui_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtGui_49(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtGui_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtGui_48(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtGui_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtGui_48(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtGui_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtGui_48(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtGui_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtGui_48(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtGui_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtGui_47(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtGui_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtGui_47(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::hideEvent(a0);
        return;
    }

    extern void sipVH_QtGui_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtGui_46(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::showEvent(a0);
        return;
    }

    extern void sipVH_QtGui_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtGui_45(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtGui_44(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtGui_44(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtGui_44(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtGui_44(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::moveEvent(a0);
        return;
    }

    extern void sipVH_QtGui_43(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtGui_43(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtGui_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtGui_42(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::exposeEvent(::QExposeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_exposeEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::exposeEvent(a0);
        return;
    }

    extern void sipVH_QtGui_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QExposeEvent*);

    sipVH_QtGui_41(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QObject* sipQOpenGLWindow::focusObject() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_focusObject);

    if (!sipMeth)
        return ::QOpenGLWindow::focusObject();

    extern ::QObject* sipVH_QtGui_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_40(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSurfaceFormat sipQOpenGLWindow::format() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[22]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_format);

    if (!sipMeth)
        return ::QOpenGLWindow::format();

    extern ::QSurfaceFormat sipVH_QtGui_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_36(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSurface::SurfaceType sipQOpenGLWindow::surfaceType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[23]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_surfaceType);

    if (!sipMeth)
        return ::QOpenGLWindow::surfaceType();

    extern ::QSurface::SurfaceType sipVH_QtGui_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_37(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQOpenGLWindow::size() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[24]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_size);

    if (!sipMeth)
        return ::QOpenGLWindow::size();

    extern ::QSize sipVH_QtGui_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_38(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQOpenGLWindow::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QOpenGLWindow::event(a0);

    extern bool sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQOpenGLWindow::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QOpenGLWindow::eventFilter(a0, a1);

    extern bool sipVH_QtGui_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtGui_4(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQOpenGLWindow::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::timerEvent(a0);
        return;
    }

    extern void sipVH_QtGui_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtGui_3(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::childEvent(a0);
        return;
    }

    extern void sipVH_QtGui_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtGui_2(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::customEvent(a0);
        return;
    }

    extern void sipVH_QtGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtGui_1(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QOpenGLWindow::connectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLWindow::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QOpenGLWindow::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQOpenGLWindow::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[32]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QOpenGLWindow::metric(a0);

    extern int sipVH_QtGui_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtGui_18(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQOpenGLWindow::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[33]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QOpenGLWindow, sipName_paintEngine);

    if (!sipMeth)
        return 0;

    extern ::QPaintEngine* sipVH_QtGui_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_17(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQOpenGLWindow::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QOpenGLWindow::paintEvent(a0);
        return;
    }

    extern void sipVH_QtGui_52(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtGui_52(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QOpenGLWindow_updateBehavior, "updateBehavior(self) -> QOpenGLWindow.UpdateBehavior");

extern "C" {static PyObject *meth_QOpenGLWindow_updateBehavior(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_updateBehavior(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            ::QOpenGLWindow::UpdateBehavior sipRes;

            sipRes = sipCpp->updateBehavior();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QOpenGLWindow_UpdateBehavior);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_updateBehavior, doc_QOpenGLWindow_updateBehavior);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QOpenGLWindow_isValid(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_isValid, doc_QOpenGLWindow_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_makeCurrent, "makeCurrent(self)");

extern "C" {static PyObject *meth_QOpenGLWindow_makeCurrent(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_makeCurrent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            sipCpp->makeCurrent();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_makeCurrent, doc_QOpenGLWindow_makeCurrent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_doneCurrent, "doneCurrent(self)");

extern "C" {static PyObject *meth_QOpenGLWindow_doneCurrent(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_doneCurrent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            sipCpp->doneCurrent();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_doneCurrent, doc_QOpenGLWindow_doneCurrent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_context, "context(self) -> Optional[QOpenGLContext]");

extern "C" {static PyObject *meth_QOpenGLWindow_context(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_context(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            ::QOpenGLContext*sipRes;

            sipRes = sipCpp->context();

            return sipConvertFromType(sipRes, sipType_QOpenGLContext, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_context, doc_QOpenGLWindow_context);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_defaultFramebufferObject, "defaultFramebufferObject(self) -> int");

extern "C" {static PyObject *meth_QOpenGLWindow_defaultFramebufferObject(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_defaultFramebufferObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            ::GLuint sipRes;

            sipRes = sipCpp->defaultFramebufferObject();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_defaultFramebufferObject, doc_QOpenGLWindow_defaultFramebufferObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_grabFramebuffer, "grabFramebuffer(self) -> QImage");

extern "C" {static PyObject *meth_QOpenGLWindow_grabFramebuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_grabFramebuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            ::QImage*sipRes;

            sipRes = new ::QImage(sipCpp->grabFramebuffer());

            return sipConvertFromNewType(sipRes, sipType_QImage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_grabFramebuffer, doc_QOpenGLWindow_grabFramebuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_shareContext, "shareContext(self) -> Optional[QOpenGLContext]");

extern "C" {static PyObject *meth_QOpenGLWindow_shareContext(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_shareContext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            ::QOpenGLContext*sipRes;

            sipRes = sipCpp->shareContext();

            return sipConvertFromType(sipRes, sipType_QOpenGLContext, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_shareContext, doc_QOpenGLWindow_shareContext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_initializeGL, "initializeGL(self)");

extern "C" {static PyObject *meth_QOpenGLWindow_initializeGL(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_initializeGL(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QOpenGLWindow::initializeGL() : sipCpp->initializeGL());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_initializeGL, doc_QOpenGLWindow_initializeGL);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_resizeGL, "resizeGL(self, w: int, h: int)");

extern "C" {static PyObject *meth_QOpenGLWindow_resizeGL(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_resizeGL(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pii", &sipSelf, sipType_QOpenGLWindow, &sipCpp, &a0, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QOpenGLWindow::resizeGL(a0, a1) : sipCpp->resizeGL(a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_resizeGL, doc_QOpenGLWindow_resizeGL);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_paintGL, "paintGL(self)");

extern "C" {static PyObject *meth_QOpenGLWindow_paintGL(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_paintGL(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QOpenGLWindow::paintGL() : sipCpp->paintGL());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_paintGL, doc_QOpenGLWindow_paintGL);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_paintUnderGL, "paintUnderGL(self)");

extern "C" {static PyObject *meth_QOpenGLWindow_paintUnderGL(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_paintUnderGL(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QOpenGLWindow::paintUnderGL() : sipCpp->paintUnderGL());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_paintUnderGL, doc_QOpenGLWindow_paintUnderGL);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_paintOverGL, "paintOverGL(self)");

extern "C" {static PyObject *meth_QOpenGLWindow_paintOverGL(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_paintOverGL(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QOpenGLWindow, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QOpenGLWindow::paintOverGL() : sipCpp->paintOverGL());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_paintOverGL, doc_QOpenGLWindow_paintOverGL);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_paintEvent, "paintEvent(self, event: Optional[QPaintEvent])");

extern "C" {static PyObject *meth_QOpenGLWindow_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QOpenGLWindow, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QOpenGLWindow::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_paintEvent, doc_QOpenGLWindow_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_resizeEvent, "resizeEvent(self, event: Optional[QResizeEvent])");

extern "C" {static PyObject *meth_QOpenGLWindow_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QOpenGLWindow, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QOpenGLWindow::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_resizeEvent, doc_QOpenGLWindow_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLWindow_metric, "metric(self, metric: QPaintDevice.PaintDeviceMetric) -> int");

extern "C" {static PyObject *meth_QOpenGLWindow_metric(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLWindow_metric(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintDevice::PaintDeviceMetric a0;
        const ::QOpenGLWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QOpenGLWindow, &sipCpp, sipType_QPaintDevice_PaintDeviceMetric, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QOpenGLWindow::metric(a0) : sipCpp->metric(a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLWindow, sipName_metric, doc_QOpenGLWindow_metric);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QOpenGLWindow(void *, const sipTypeDef *);}
static void *cast_QOpenGLWindow(void *sipCppV, const sipTypeDef *targetType)
{
    ::QOpenGLWindow *sipCpp = reinterpret_cast<::QOpenGLWindow *>(sipCppV);

    if (targetType == sipType_QOpenGLWindow)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QPaintDeviceWindow)->ctd_cast(static_cast<::QPaintDeviceWindow *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QOpenGLWindow(void *, int);}
static void release_QOpenGLWindow(void *sipCppV, int)
{
    ::QOpenGLWindow *sipCpp = reinterpret_cast<::QOpenGLWindow *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QOpenGLWindow(sipSimpleWrapper *);}
static void dealloc_QOpenGLWindow(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQOpenGLWindow *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOpenGLWindow(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QOpenGLWindow(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOpenGLWindow(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQOpenGLWindow *sipCpp = SIP_NULLPTR;

    {
        ::QOpenGLWindow::UpdateBehavior a0 = QOpenGLWindow::NoPartialUpdate;
        ::QWindow* a1 = 0;

        static const char *sipKwdList[] = {
            sipName_updateBehavior,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|EJH", sipType_QOpenGLWindow_UpdateBehavior, &a0, sipType_QWindow, &a1, sipOwner))
        {
            sipCpp = new sipQOpenGLWindow(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QOpenGLContext* a0;
        ::QOpenGLWindow::UpdateBehavior a1 = QOpenGLWindow::NoPartialUpdate;
        ::QWindow* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_updateBehavior,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|EJH", sipType_QOpenGLContext, &a0, sipType_QOpenGLWindow_UpdateBehavior, &a1, sipType_QWindow, &a2, sipOwner))
        {
            sipCpp = new sipQOpenGLWindow(a0, a1, a2);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QOpenGLWindow[] = {{200, 255, 1}};


static PyMethodDef methods_QOpenGLWindow[] = {
    {sipName_context, meth_QOpenGLWindow_context, METH_VARARGS, doc_QOpenGLWindow_context},
    {sipName_defaultFramebufferObject, meth_QOpenGLWindow_defaultFramebufferObject, METH_VARARGS, doc_QOpenGLWindow_defaultFramebufferObject},
    {sipName_doneCurrent, meth_QOpenGLWindow_doneCurrent, METH_VARARGS, doc_QOpenGLWindow_doneCurrent},
    {sipName_grabFramebuffer, meth_QOpenGLWindow_grabFramebuffer, METH_VARARGS, doc_QOpenGLWindow_grabFramebuffer},
    {sipName_initializeGL, meth_QOpenGLWindow_initializeGL, METH_VARARGS, doc_QOpenGLWindow_initializeGL},
    {sipName_isValid, meth_QOpenGLWindow_isValid, METH_VARARGS, doc_QOpenGLWindow_isValid},
    {sipName_makeCurrent, meth_QOpenGLWindow_makeCurrent, METH_VARARGS, doc_QOpenGLWindow_makeCurrent},
    {sipName_metric, meth_QOpenGLWindow_metric, METH_VARARGS, doc_QOpenGLWindow_metric},
    {sipName_paintEvent, meth_QOpenGLWindow_paintEvent, METH_VARARGS, doc_QOpenGLWindow_paintEvent},
    {sipName_paintGL, meth_QOpenGLWindow_paintGL, METH_VARARGS, doc_QOpenGLWindow_paintGL},
    {sipName_paintOverGL, meth_QOpenGLWindow_paintOverGL, METH_VARARGS, doc_QOpenGLWindow_paintOverGL},
    {sipName_paintUnderGL, meth_QOpenGLWindow_paintUnderGL, METH_VARARGS, doc_QOpenGLWindow_paintUnderGL},
    {sipName_resizeEvent, meth_QOpenGLWindow_resizeEvent, METH_VARARGS, doc_QOpenGLWindow_resizeEvent},
    {sipName_resizeGL, meth_QOpenGLWindow_resizeGL, METH_VARARGS, doc_QOpenGLWindow_resizeGL},
    {sipName_shareContext, meth_QOpenGLWindow_shareContext, METH_VARARGS, doc_QOpenGLWindow_shareContext},
    {sipName_updateBehavior, meth_QOpenGLWindow_updateBehavior, METH_VARARGS, doc_QOpenGLWindow_updateBehavior}
};

static sipEnumMemberDef enummembers_QOpenGLWindow[] = {
    {sipName_NoPartialUpdate, static_cast<int>(::QOpenGLWindow::NoPartialUpdate), 185},
    {sipName_PartialUpdateBlend, static_cast<int>(::QOpenGLWindow::PartialUpdateBlend), 185},
    {sipName_PartialUpdateBlit, static_cast<int>(::QOpenGLWindow::PartialUpdateBlit), 185},
};

PyDoc_STRVAR(doc_QOpenGLWindow, "\1QOpenGLWindow(updateBehavior: QOpenGLWindow.UpdateBehavior = QOpenGLWindow.NoPartialUpdate, parent: Optional[QWindow] = None)\n"
"QOpenGLWindow(shareContext: Optional[QOpenGLContext], updateBehavior: QOpenGLWindow.UpdateBehavior = QOpenGLWindow.NoPartialUpdate, parent: Optional[QWindow] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QOpenGLWindow[] = {
    {"frameSwapped()", "\1frameSwapped(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QOpenGLWindow = {
    &::QOpenGLWindow::staticMetaObject,
    0,
    signals_QOpenGLWindow,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QOpenGLWindow = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOpenGLWindow,
        SIP_NULLPTR,
        &plugin_QOpenGLWindow,
    },
    {
        sipNameNr_QOpenGLWindow,
        {0, 0, 1},
        16, methods_QOpenGLWindow,
        3, enummembers_QOpenGLWindow,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOpenGLWindow,
    -1,
    -1,
    supers_QOpenGLWindow,
    SIP_NULLPTR,
    init_type_QOpenGLWindow,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QOpenGLWindow,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QOpenGLWindow,
    cast_QOpenGLWindow,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QOpenGLWindow),
};
