/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qopenglvertexarrayobject.sip"
#include <qopenglvertexarrayobject.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 41 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 53 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 56 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 62 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 68 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 71 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 77 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 80 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 83 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQOpenGLVertexArrayObject.cpp"


class sipQOpenGLVertexArrayObject : public ::QOpenGLVertexArrayObject
{
public:
    sipQOpenGLVertexArrayObject(::QObject*);
    virtual ~sipQOpenGLVertexArrayObject();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQOpenGLVertexArrayObject(const sipQOpenGLVertexArrayObject &);
    sipQOpenGLVertexArrayObject &operator = (const sipQOpenGLVertexArrayObject &);

    char sipPyMethods[7];
};

sipQOpenGLVertexArrayObject::sipQOpenGLVertexArrayObject(::QObject*a0): ::QOpenGLVertexArrayObject(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQOpenGLVertexArrayObject::~sipQOpenGLVertexArrayObject()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQOpenGLVertexArrayObject::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtGui_qt_metaobject(sipPySelf, sipType_QOpenGLVertexArrayObject);

    return ::QOpenGLVertexArrayObject::metaObject();
}

int sipQOpenGLVertexArrayObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QOpenGLVertexArrayObject::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtGui_qt_metacall(sipPySelf, sipType_QOpenGLVertexArrayObject, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQOpenGLVertexArrayObject::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtGui_qt_metacast(sipPySelf, sipType_QOpenGLVertexArrayObject, _clname, &sipCpp) ? sipCpp : ::QOpenGLVertexArrayObject::qt_metacast(_clname));
}

bool sipQOpenGLVertexArrayObject::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QOpenGLVertexArrayObject::event(a0);

    extern bool sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQOpenGLVertexArrayObject::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QOpenGLVertexArrayObject::eventFilter(a0, a1);

    extern bool sipVH_QtGui_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtGui_4(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQOpenGLVertexArrayObject::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QOpenGLVertexArrayObject::timerEvent(a0);
        return;
    }

    extern void sipVH_QtGui_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtGui_3(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLVertexArrayObject::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QOpenGLVertexArrayObject::childEvent(a0);
        return;
    }

    extern void sipVH_QtGui_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtGui_2(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLVertexArrayObject::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QOpenGLVertexArrayObject::customEvent(a0);
        return;
    }

    extern void sipVH_QtGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtGui_1(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLVertexArrayObject::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QOpenGLVertexArrayObject::connectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLVertexArrayObject::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QOpenGLVertexArrayObject::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_create, "create(self) -> bool");

extern "C" {static PyObject *meth_QOpenGLVertexArrayObject_create(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLVertexArrayObject_create(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLVertexArrayObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLVertexArrayObject, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->create();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLVertexArrayObject, sipName_create, doc_QOpenGLVertexArrayObject_create);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_destroy, "destroy(self)");

extern "C" {static PyObject *meth_QOpenGLVertexArrayObject_destroy(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLVertexArrayObject_destroy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLVertexArrayObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLVertexArrayObject, &sipCpp))
        {
            sipCpp->destroy();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLVertexArrayObject, sipName_destroy, doc_QOpenGLVertexArrayObject_destroy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_isCreated, "isCreated(self) -> bool");

extern "C" {static PyObject *meth_QOpenGLVertexArrayObject_isCreated(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLVertexArrayObject_isCreated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLVertexArrayObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLVertexArrayObject, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isCreated();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLVertexArrayObject, sipName_isCreated, doc_QOpenGLVertexArrayObject_isCreated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_objectId, "objectId(self) -> int");

extern "C" {static PyObject *meth_QOpenGLVertexArrayObject_objectId(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLVertexArrayObject_objectId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLVertexArrayObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLVertexArrayObject, &sipCpp))
        {
            ::GLuint sipRes;

            sipRes = sipCpp->objectId();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLVertexArrayObject, sipName_objectId, doc_QOpenGLVertexArrayObject_objectId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_bind, "bind(self)");

extern "C" {static PyObject *meth_QOpenGLVertexArrayObject_bind(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLVertexArrayObject_bind(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLVertexArrayObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLVertexArrayObject, &sipCpp))
        {
            sipCpp->bind();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLVertexArrayObject, sipName_bind, doc_QOpenGLVertexArrayObject_bind);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_release, "release(self)");

extern "C" {static PyObject *meth_QOpenGLVertexArrayObject_release(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLVertexArrayObject_release(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLVertexArrayObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLVertexArrayObject, &sipCpp))
        {
            sipCpp->release();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLVertexArrayObject, sipName_release, doc_QOpenGLVertexArrayObject_release);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QOpenGLVertexArrayObject(void *, const sipTypeDef *);}
static void *cast_QOpenGLVertexArrayObject(void *sipCppV, const sipTypeDef *targetType)
{
    ::QOpenGLVertexArrayObject *sipCpp = reinterpret_cast<::QOpenGLVertexArrayObject *>(sipCppV);

    if (targetType == sipType_QOpenGLVertexArrayObject)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast<::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QOpenGLVertexArrayObject(void *, int);}
static void release_QOpenGLVertexArrayObject(void *sipCppV, int)
{
    ::QOpenGLVertexArrayObject *sipCpp = reinterpret_cast<::QOpenGLVertexArrayObject *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QOpenGLVertexArrayObject(Py_ssize_t);}
static void *array_QOpenGLVertexArrayObject(Py_ssize_t sipNrElem)
{
    return new ::QOpenGLVertexArrayObject[sipNrElem];
}


extern "C" {static void array_delete_QOpenGLVertexArrayObject(void *);}
static void array_delete_QOpenGLVertexArrayObject(void *sipCpp)
{
    delete[] reinterpret_cast<::QOpenGLVertexArrayObject *>(sipCpp);
}


extern "C" {static void dealloc_QOpenGLVertexArrayObject(sipSimpleWrapper *);}
static void dealloc_QOpenGLVertexArrayObject(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQOpenGLVertexArrayObject *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOpenGLVertexArrayObject(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QOpenGLVertexArrayObject(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOpenGLVertexArrayObject(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQOpenGLVertexArrayObject *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQOpenGLVertexArrayObject(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QOpenGLVertexArrayObject[] = {{25, 0, 1}};


static PyMethodDef methods_QOpenGLVertexArrayObject[] = {
    {sipName_bind, meth_QOpenGLVertexArrayObject_bind, METH_VARARGS, doc_QOpenGLVertexArrayObject_bind},
    {sipName_create, meth_QOpenGLVertexArrayObject_create, METH_VARARGS, doc_QOpenGLVertexArrayObject_create},
    {sipName_destroy, meth_QOpenGLVertexArrayObject_destroy, METH_VARARGS, doc_QOpenGLVertexArrayObject_destroy},
    {sipName_isCreated, meth_QOpenGLVertexArrayObject_isCreated, METH_VARARGS, doc_QOpenGLVertexArrayObject_isCreated},
    {sipName_objectId, meth_QOpenGLVertexArrayObject_objectId, METH_VARARGS, doc_QOpenGLVertexArrayObject_objectId},
    {sipName_release, meth_QOpenGLVertexArrayObject_release, METH_VARARGS, doc_QOpenGLVertexArrayObject_release}
};

PyDoc_STRVAR(doc_QOpenGLVertexArrayObject, "\1QOpenGLVertexArrayObject(parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QOpenGLVertexArrayObject = {
    &::QOpenGLVertexArrayObject::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QOpenGLVertexArrayObject = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOpenGLVertexArrayObject,
        SIP_NULLPTR,
        &plugin_QOpenGLVertexArrayObject,
    },
    {
        sipNameNr_QOpenGLVertexArrayObject,
        {0, 0, 1},
        6, methods_QOpenGLVertexArrayObject,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOpenGLVertexArrayObject,
    -1,
    -1,
    supers_QOpenGLVertexArrayObject,
    SIP_NULLPTR,
    init_type_QOpenGLVertexArrayObject,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QOpenGLVertexArrayObject,
    SIP_NULLPTR,
    array_QOpenGLVertexArrayObject,
    SIP_NULLPTR,
    release_QOpenGLVertexArrayObject,
    cast_QOpenGLVertexArrayObject,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QOpenGLVertexArrayObject,
    sizeof (::QOpenGLVertexArrayObject),
};
