/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQml/qqmlexpression.sip"
#include <qqmlexpression.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQml/qqmlcontext.sip"
#include <qqmlcontext.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQml/qqmlscriptstring.sip"
#include <qqmlscriptstring.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQml/qqmlerror.sip"
#include <qqmlerror.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 83 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 86 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 89 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 92 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 95 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlExpression.cpp"


class sipQQmlExpression : public ::QQmlExpression
{
public:
    sipQQmlExpression();
    sipQQmlExpression(::QQmlContext*, ::QObject*, const ::QString&, ::QObject*);
    sipQQmlExpression(const ::QQmlScriptString&, ::QQmlContext*, ::QObject*, ::QObject*);
    virtual ~sipQQmlExpression();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQmlExpression(const sipQQmlExpression &);
    sipQQmlExpression &operator = (const sipQQmlExpression &);

    char sipPyMethods[7];
};

sipQQmlExpression::sipQQmlExpression(): ::QQmlExpression(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlExpression::sipQQmlExpression(::QQmlContext*a0, ::QObject*a1, const ::QString& a2, ::QObject*a3): ::QQmlExpression(a0, a1, a2, a3), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlExpression::sipQQmlExpression(const ::QQmlScriptString& a0, ::QQmlContext*a1, ::QObject*a2, ::QObject*a3): ::QQmlExpression(a0, a1, a2, a3), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlExpression::~sipQQmlExpression()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQQmlExpression::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtQml_qt_metaobject(sipPySelf, sipType_QQmlExpression);

    return ::QQmlExpression::metaObject();
}

int sipQQmlExpression::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QQmlExpression::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtQml_qt_metacall(sipPySelf, sipType_QQmlExpression, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQQmlExpression::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtQml_qt_metacast(sipPySelf, sipType_QQmlExpression, _clname, &sipCpp) ? sipCpp : ::QQmlExpression::qt_metacast(_clname));
}

bool sipQQmlExpression::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QQmlExpression::event(a0);

    extern bool sipVH_QtQml_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtQml_5(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQmlExpression::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QQmlExpression::eventFilter(a0, a1);

    extern bool sipVH_QtQml_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtQml_4(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQQmlExpression::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QQmlExpression::timerEvent(a0);
        return;
    }

    extern void sipVH_QtQml_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtQml_3(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlExpression::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QQmlExpression::childEvent(a0);
        return;
    }

    extern void sipVH_QtQml_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtQml_2(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlExpression::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QQmlExpression::customEvent(a0);
        return;
    }

    extern void sipVH_QtQml_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtQml_1(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlExpression::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QQmlExpression::connectNotify(a0);
        return;
    }

    extern void sipVH_QtQml_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQml_0(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlExpression::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QQmlExpression::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtQml_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQml_0(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QQmlExpression_engine, "engine(self) -> Optional[QQmlEngine]");

extern "C" {static PyObject *meth_QQmlExpression_engine(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_engine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            ::QQmlEngine*sipRes;

            sipRes = sipCpp->engine();

            return sipConvertFromType(sipRes, sipType_QQmlEngine, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_engine, doc_QQmlExpression_engine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_context, "context(self) -> Optional[QQmlContext]");

extern "C" {static PyObject *meth_QQmlExpression_context(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_context(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            ::QQmlContext*sipRes;

            sipRes = sipCpp->context();

            return sipConvertFromType(sipRes, sipType_QQmlContext, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_context, doc_QQmlExpression_context);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_expression, "expression(self) -> str");

extern "C" {static PyObject *meth_QQmlExpression_expression(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_expression(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->expression());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_expression, doc_QQmlExpression_expression);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_setExpression, "setExpression(self, a0: Optional[str])");

extern "C" {static PyObject *meth_QQmlExpression_setExpression(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_setExpression(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQmlExpression, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setExpression(*a0);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_setExpression, doc_QQmlExpression_setExpression);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_notifyOnValueChanged, "notifyOnValueChanged(self) -> bool");

extern "C" {static PyObject *meth_QQmlExpression_notifyOnValueChanged(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_notifyOnValueChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->notifyOnValueChanged();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_notifyOnValueChanged, doc_QQmlExpression_notifyOnValueChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_setNotifyOnValueChanged, "setNotifyOnValueChanged(self, a0: bool)");

extern "C" {static PyObject *meth_QQmlExpression_setNotifyOnValueChanged(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_setNotifyOnValueChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQmlExpression, &sipCpp, &a0))
        {
            sipCpp->setNotifyOnValueChanged(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_setNotifyOnValueChanged, doc_QQmlExpression_setNotifyOnValueChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_sourceFile, "sourceFile(self) -> str");

extern "C" {static PyObject *meth_QQmlExpression_sourceFile(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_sourceFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->sourceFile());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_sourceFile, doc_QQmlExpression_sourceFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_lineNumber, "lineNumber(self) -> int");

extern "C" {static PyObject *meth_QQmlExpression_lineNumber(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_lineNumber(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->lineNumber();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_lineNumber, doc_QQmlExpression_lineNumber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_columnNumber, "columnNumber(self) -> int");

extern "C" {static PyObject *meth_QQmlExpression_columnNumber(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_columnNumber(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->columnNumber();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_columnNumber, doc_QQmlExpression_columnNumber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_setSourceLocation, "setSourceLocation(self, fileName: Optional[str], line: int, column: int = 0)");

extern "C" {static PyObject *meth_QQmlExpression_setSourceLocation(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_setSourceLocation(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        int a1;
        int a2 = 0;
        ::QQmlExpression *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1i|i", &sipSelf, sipType_QQmlExpression, &sipCpp, sipType_QString, &a0, &a0State, &a1, &a2))
        {
            sipCpp->setSourceLocation(*a0, a1, a2);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_setSourceLocation, doc_QQmlExpression_setSourceLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_scopeObject, "scopeObject(self) -> Optional[QObject]");

extern "C" {static PyObject *meth_QQmlExpression_scopeObject(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_scopeObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            ::QObject*sipRes;

            sipRes = sipCpp->scopeObject();

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_scopeObject, doc_QQmlExpression_scopeObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_hasError, "hasError(self) -> bool");

extern "C" {static PyObject *meth_QQmlExpression_hasError(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_hasError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasError();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_hasError, doc_QQmlExpression_hasError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_clearError, "clearError(self)");

extern "C" {static PyObject *meth_QQmlExpression_clearError(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_clearError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            sipCpp->clearError();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_clearError, doc_QQmlExpression_clearError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_error, "error(self) -> QQmlError");

extern "C" {static PyObject *meth_QQmlExpression_error(PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlExpression *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            ::QQmlError*sipRes;

            sipRes = new ::QQmlError(sipCpp->error());

            return sipConvertFromNewType(sipRes, sipType_QQmlError, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_error, doc_QQmlExpression_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlExpression_evaluate, "evaluate(self) -> (Any, Optional[bool])");

extern "C" {static PyObject *meth_QQmlExpression_evaluate(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QQmlExpression_evaluate(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QQmlExpression *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "B", &sipSelf, sipType_QQmlExpression, &sipCpp))
        {
            ::QVariant*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = new ::QVariant(sipCpp->evaluate(&a0));
            Py_END_ALLOW_THREADS

            PyObject *sipResObj = sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
            return sipBuildResult(0, "(Rb)", sipResObj, a0);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlExpression, sipName_evaluate, doc_QQmlExpression_evaluate);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQmlExpression(void *, const sipTypeDef *);}
static void *cast_QQmlExpression(void *sipCppV, const sipTypeDef *targetType)
{
    ::QQmlExpression *sipCpp = reinterpret_cast<::QQmlExpression *>(sipCppV);

    if (targetType == sipType_QQmlExpression)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast<::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlExpression(void *, int);}
static void release_QQmlExpression(void *sipCppV, int)
{
    ::QQmlExpression *sipCpp = reinterpret_cast<::QQmlExpression *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QQmlExpression(Py_ssize_t);}
static void *array_QQmlExpression(Py_ssize_t sipNrElem)
{
    return new ::QQmlExpression[sipNrElem];
}


extern "C" {static void array_delete_QQmlExpression(void *);}
static void array_delete_QQmlExpression(void *sipCpp)
{
    delete[] reinterpret_cast<::QQmlExpression *>(sipCpp);
}


extern "C" {static void dealloc_QQmlExpression(sipSimpleWrapper *);}
static void dealloc_QQmlExpression(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQmlExpression *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlExpression(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQmlExpression(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQmlExpression(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQQmlExpression *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQQmlExpression();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QQmlContext* a0;
        ::QObject* a1;
        const ::QString* a2;
        int a2State = 0;
        ::QObject* a3 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8J8J1|JH", sipType_QQmlContext, &a0, sipType_QObject, &a1, sipType_QString, &a2, &a2State, sipType_QObject, &a3, sipOwner))
        {
            sipCpp = new sipQQmlExpression(a0, a1, *a2, a3);
            sipReleaseType(const_cast<::QString *>(a2), sipType_QString, a2State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QQmlScriptString* a0;
        ::QQmlContext* a1 = 0;
        ::QObject* a2 = 0;
        ::QObject* a3 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_context,
            sipName_scope,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|J8J8JH", sipType_QQmlScriptString, &a0, sipType_QQmlContext, &a1, sipType_QObject, &a2, sipType_QObject, &a3, sipOwner))
        {
            sipCpp = new sipQQmlExpression(*a0, a1, a2, a3);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQmlExpression[] = {{9, 0, 1}};


static PyMethodDef methods_QQmlExpression[] = {
    {sipName_clearError, meth_QQmlExpression_clearError, METH_VARARGS, doc_QQmlExpression_clearError},
    {sipName_columnNumber, meth_QQmlExpression_columnNumber, METH_VARARGS, doc_QQmlExpression_columnNumber},
    {sipName_context, meth_QQmlExpression_context, METH_VARARGS, doc_QQmlExpression_context},
    {sipName_engine, meth_QQmlExpression_engine, METH_VARARGS, doc_QQmlExpression_engine},
    {sipName_error, meth_QQmlExpression_error, METH_VARARGS, doc_QQmlExpression_error},
    {sipName_evaluate, SIP_MLMETH_CAST(meth_QQmlExpression_evaluate), METH_VARARGS|METH_KEYWORDS, doc_QQmlExpression_evaluate},
    {sipName_expression, meth_QQmlExpression_expression, METH_VARARGS, doc_QQmlExpression_expression},
    {sipName_hasError, meth_QQmlExpression_hasError, METH_VARARGS, doc_QQmlExpression_hasError},
    {sipName_lineNumber, meth_QQmlExpression_lineNumber, METH_VARARGS, doc_QQmlExpression_lineNumber},
    {sipName_notifyOnValueChanged, meth_QQmlExpression_notifyOnValueChanged, METH_VARARGS, doc_QQmlExpression_notifyOnValueChanged},
    {sipName_scopeObject, meth_QQmlExpression_scopeObject, METH_VARARGS, doc_QQmlExpression_scopeObject},
    {sipName_setExpression, meth_QQmlExpression_setExpression, METH_VARARGS, doc_QQmlExpression_setExpression},
    {sipName_setNotifyOnValueChanged, meth_QQmlExpression_setNotifyOnValueChanged, METH_VARARGS, doc_QQmlExpression_setNotifyOnValueChanged},
    {sipName_setSourceLocation, SIP_MLMETH_CAST(meth_QQmlExpression_setSourceLocation), METH_VARARGS|METH_KEYWORDS, doc_QQmlExpression_setSourceLocation},
    {sipName_sourceFile, meth_QQmlExpression_sourceFile, METH_VARARGS, doc_QQmlExpression_sourceFile}
};

PyDoc_STRVAR(doc_QQmlExpression, "\1QQmlExpression()\n"
"QQmlExpression(a0: Optional[QQmlContext], a1: Optional[QObject], a2: Optional[str], parent: Optional[QObject] = None)\n"
"QQmlExpression(a0: QQmlScriptString, context: Optional[QQmlContext] = None, scope: Optional[QObject] = None, parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QQmlExpression[] = {
    {"valueChanged()", "\1valueChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QQmlExpression = {
    &::QQmlExpression::staticMetaObject,
    0,
    signals_QQmlExpression,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QQmlExpression = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlExpression,
        SIP_NULLPTR,
        &plugin_QQmlExpression,
    },
    {
        sipNameNr_QQmlExpression,
        {0, 0, 1},
        15, methods_QQmlExpression,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQmlExpression,
    -1,
    -1,
    supers_QQmlExpression,
    SIP_NULLPTR,
    init_type_QQmlExpression,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQmlExpression,
    SIP_NULLPTR,
    array_QQmlExpression,
    SIP_NULLPTR,
    release_QQmlExpression,
    cast_QQmlExpression,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QQmlExpression,
    sizeof (::QQmlExpression),
};
