/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 58 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 31 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQSGMaterialRhiShaderGraphicsPipelineState.cpp"



/* Call the instance's destructor. */
extern "C" {static void release_QSGMaterialRhiShader_GraphicsPipelineState(void *, int);}
static void release_QSGMaterialRhiShader_GraphicsPipelineState(void *sipCppV, int)
{
    delete reinterpret_cast<::QSGMaterialRhiShader::GraphicsPipelineState *>(sipCppV);
}


extern "C" {static void *array_QSGMaterialRhiShader_GraphicsPipelineState(Py_ssize_t);}
static void *array_QSGMaterialRhiShader_GraphicsPipelineState(Py_ssize_t sipNrElem)
{
    return new ::QSGMaterialRhiShader::GraphicsPipelineState[sipNrElem];
}


extern "C" {static void array_delete_QSGMaterialRhiShader_GraphicsPipelineState(void *);}
static void array_delete_QSGMaterialRhiShader_GraphicsPipelineState(void *sipCpp)
{
    delete[] reinterpret_cast<::QSGMaterialRhiShader::GraphicsPipelineState *>(sipCpp);
}


extern "C" {static void assign_QSGMaterialRhiShader_GraphicsPipelineState(void *, Py_ssize_t, void *);}
static void assign_QSGMaterialRhiShader_GraphicsPipelineState(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast<::QSGMaterialRhiShader::GraphicsPipelineState *>(sipDst)[sipDstIdx] = *reinterpret_cast<::QSGMaterialRhiShader::GraphicsPipelineState *>(sipSrc);
}


extern "C" {static void *copy_QSGMaterialRhiShader_GraphicsPipelineState(const void *, Py_ssize_t);}
static void *copy_QSGMaterialRhiShader_GraphicsPipelineState(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QSGMaterialRhiShader::GraphicsPipelineState(reinterpret_cast<const ::QSGMaterialRhiShader::GraphicsPipelineState *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QSGMaterialRhiShader_GraphicsPipelineState(sipSimpleWrapper *);}
static void dealloc_QSGMaterialRhiShader_GraphicsPipelineState(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGMaterialRhiShader_GraphicsPipelineState(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QSGMaterialRhiShader_GraphicsPipelineState(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSGMaterialRhiShader_GraphicsPipelineState(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QSGMaterialRhiShader::GraphicsPipelineState *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QSGMaterialRhiShader::GraphicsPipelineState();

            return sipCpp;
        }
    }

    {
        const ::QSGMaterialRhiShader::GraphicsPipelineState* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QSGMaterialRhiShader_GraphicsPipelineState, &a0))
        {
            sipCpp = new ::QSGMaterialRhiShader::GraphicsPipelineState(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}

static sipEnumMemberDef enummembers_QSGMaterialRhiShader_GraphicsPipelineState[] = {
    {sipName_A, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::A), 67},
    {sipName_B, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::B), 67},
    {sipName_ConstantAlpha, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::ConstantAlpha), 65},
    {sipName_ConstantColor, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::ConstantColor), 65},
    {sipName_CullBack, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::CullBack), 68},
    {sipName_CullFront, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::CullFront), 68},
    {sipName_CullNone, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::CullNone), 68},
    {sipName_DstAlpha, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::DstAlpha), 65},
    {sipName_DstColor, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::DstColor), 65},
    {sipName_G, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::G), 67},
    {sipName_One, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::One), 65},
    {sipName_OneMinusConstantAlpha, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::OneMinusConstantAlpha), 65},
    {sipName_OneMinusConstantColor, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::OneMinusConstantColor), 65},
    {sipName_OneMinusDstAlpha, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::OneMinusDstAlpha), 65},
    {sipName_OneMinusDstColor, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::OneMinusDstColor), 65},
    {sipName_OneMinusSrc1Alpha, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::OneMinusSrc1Alpha), 65},
    {sipName_OneMinusSrc1Color, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::OneMinusSrc1Color), 65},
    {sipName_OneMinusSrcAlpha, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::OneMinusSrcAlpha), 65},
    {sipName_OneMinusSrcColor, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::OneMinusSrcColor), 65},
    {sipName_R, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::R), 67},
    {sipName_Src1Alpha, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::Src1Alpha), 65},
    {sipName_Src1Color, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::Src1Color), 65},
    {sipName_SrcAlpha, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::SrcAlpha), 65},
    {sipName_SrcAlphaSaturate, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::SrcAlphaSaturate), 65},
    {sipName_SrcColor, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::SrcColor), 65},
    {sipName_Zero, static_cast<int>(::QSGMaterialRhiShader::GraphicsPipelineState::Zero), 65},
};

PyDoc_STRVAR(doc_QSGMaterialRhiShader_GraphicsPipelineState, "\1QSGMaterialRhiShader.GraphicsPipelineState()\n"
"QSGMaterialRhiShader.GraphicsPipelineState(a0: QSGMaterialRhiShader.GraphicsPipelineState)");


static pyqt5ClassPluginDef plugin_QSGMaterialRhiShader_GraphicsPipelineState = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialRhiShader_GraphicsPipelineState = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGMaterialRhiShader__GraphicsPipelineState,
        SIP_NULLPTR,
        &plugin_QSGMaterialRhiShader_GraphicsPipelineState,
    },
    {
        sipNameNr_GraphicsPipelineState,
        {61, 255, 0},
        0, SIP_NULLPTR,
        26, enummembers_QSGMaterialRhiShader_GraphicsPipelineState,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSGMaterialRhiShader_GraphicsPipelineState,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QSGMaterialRhiShader_GraphicsPipelineState,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSGMaterialRhiShader_GraphicsPipelineState,
    assign_QSGMaterialRhiShader_GraphicsPipelineState,
    array_QSGMaterialRhiShader_GraphicsPipelineState,
    copy_QSGMaterialRhiShader_GraphicsPipelineState,
    release_QSGMaterialRhiShader_GraphicsPipelineState,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSGMaterialRhiShader_GraphicsPipelineState,
    sizeof (::QSGMaterialRhiShader::GraphicsPipelineState),
};
