/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 50 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qtexttable.sip"
#include <qtexttable.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"

#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qtextdocument.sip"
#include <qtextdocument.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 618 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qtextcursor.sip"
#include <qtextcursor.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qtexttable.sip"
#include <qtexttable.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 555 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 76 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 50 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 53 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 56 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 61 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 64 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 67 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 70 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 73 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 76 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 79 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 82 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 85 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 88 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 91 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 94 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 97 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 100 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 103 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 106 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 109 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQTextTable.cpp"


class sipQTextTable : public ::QTextTable
{
public:
    sipQTextTable(::QTextDocument*);
    virtual ~sipQTextTable();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQTextTable(const sipQTextTable &);
    sipQTextTable &operator = (const sipQTextTable &);

    char sipPyMethods[7];
};

sipQTextTable::sipQTextTable(::QTextDocument*a0): ::QTextTable(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTextTable::~sipQTextTable()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQTextTable::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtGui_qt_metaobject(sipPySelf, sipType_QTextTable);

    return ::QTextTable::metaObject();
}

int sipQTextTable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QTextTable::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtGui_qt_metacall(sipPySelf, sipType_QTextTable, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQTextTable::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtGui_qt_metacast(sipPySelf, sipType_QTextTable, _clname, &sipCpp) ? sipCpp : ::QTextTable::qt_metacast(_clname));
}

bool sipQTextTable::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QTextTable::event(a0);

    extern bool sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQTextTable::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QTextTable::eventFilter(a0, a1);

    extern bool sipVH_QtGui_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtGui_4(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQTextTable::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QTextTable::timerEvent(a0);
        return;
    }

    extern void sipVH_QtGui_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtGui_3(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTextTable::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QTextTable::childEvent(a0);
        return;
    }

    extern void sipVH_QtGui_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtGui_2(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTextTable::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QTextTable::customEvent(a0);
        return;
    }

    extern void sipVH_QtGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtGui_1(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTextTable::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QTextTable::connectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTextTable::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QTextTable::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QTextTable_resize, "resize(self, rows: int, cols: int)");

extern "C" {static PyObject *meth_QTextTable_resize(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_resize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QTextTable, &sipCpp, &a0, &a1))
        {
            sipCpp->resize(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_resize, doc_QTextTable_resize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_insertRows, "insertRows(self, pos: int, num: int)");

extern "C" {static PyObject *meth_QTextTable_insertRows(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_insertRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QTextTable, &sipCpp, &a0, &a1))
        {
            sipCpp->insertRows(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_insertRows, doc_QTextTable_insertRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_insertColumns, "insertColumns(self, pos: int, num: int)");

extern "C" {static PyObject *meth_QTextTable_insertColumns(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_insertColumns(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QTextTable, &sipCpp, &a0, &a1))
        {
            sipCpp->insertColumns(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_insertColumns, doc_QTextTable_insertColumns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_removeRows, "removeRows(self, pos: int, num: int)");

extern "C" {static PyObject *meth_QTextTable_removeRows(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_removeRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QTextTable, &sipCpp, &a0, &a1))
        {
            sipCpp->removeRows(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_removeRows, doc_QTextTable_removeRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_removeColumns, "removeColumns(self, pos: int, num: int)");

extern "C" {static PyObject *meth_QTextTable_removeColumns(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_removeColumns(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QTextTable, &sipCpp, &a0, &a1))
        {
            sipCpp->removeColumns(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_removeColumns, doc_QTextTable_removeColumns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_mergeCells, "mergeCells(self, row: int, col: int, numRows: int, numCols: int)\n"
"mergeCells(self, cursor: QTextCursor)");

extern "C" {static PyObject *meth_QTextTable_mergeCells(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_mergeCells(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QTextTable, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->mergeCells(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QTextCursor* a0;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTextTable, &sipCpp, sipType_QTextCursor, &a0))
        {
            sipCpp->mergeCells(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_mergeCells, doc_QTextTable_mergeCells);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_splitCell, "splitCell(self, row: int, col: int, numRows: int, numCols: int)");

extern "C" {static PyObject *meth_QTextTable_splitCell(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_splitCell(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QTextTable, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->splitCell(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_splitCell, doc_QTextTable_splitCell);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_rows, "rows(self) -> int");

extern "C" {static PyObject *meth_QTextTable_rows(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_rows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTable, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->rows();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_rows, doc_QTextTable_rows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_columns, "columns(self) -> int");

extern "C" {static PyObject *meth_QTextTable_columns(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_columns(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTable, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->columns();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_columns, doc_QTextTable_columns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_cellAt, "cellAt(self, row: int, col: int) -> QTextTableCell\n"
"cellAt(self, position: int) -> QTextTableCell\n"
"cellAt(self, c: QTextCursor) -> QTextTableCell");

extern "C" {static PyObject *meth_QTextTable_cellAt(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_cellAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QTextTable, &sipCpp, &a0, &a1))
        {
            ::QTextTableCell*sipRes;

            sipRes = new ::QTextTableCell(sipCpp->cellAt(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QTextTableCell, SIP_NULLPTR);
        }
    }

    {
        int a0;
        const ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTextTable, &sipCpp, &a0))
        {
            ::QTextTableCell*sipRes;

            sipRes = new ::QTextTableCell(sipCpp->cellAt(a0));

            return sipConvertFromNewType(sipRes, sipType_QTextTableCell, SIP_NULLPTR);
        }
    }

    {
        const ::QTextCursor* a0;
        const ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTextTable, &sipCpp, sipType_QTextCursor, &a0))
        {
            ::QTextTableCell*sipRes;

            sipRes = new ::QTextTableCell(sipCpp->cellAt(*a0));

            return sipConvertFromNewType(sipRes, sipType_QTextTableCell, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_cellAt, doc_QTextTable_cellAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_rowStart, "rowStart(self, c: QTextCursor) -> QTextCursor");

extern "C" {static PyObject *meth_QTextTable_rowStart(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_rowStart(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextCursor* a0;
        const ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTextTable, &sipCpp, sipType_QTextCursor, &a0))
        {
            ::QTextCursor*sipRes;

            sipRes = new ::QTextCursor(sipCpp->rowStart(*a0));

            return sipConvertFromNewType(sipRes, sipType_QTextCursor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_rowStart, doc_QTextTable_rowStart);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_rowEnd, "rowEnd(self, c: QTextCursor) -> QTextCursor");

extern "C" {static PyObject *meth_QTextTable_rowEnd(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_rowEnd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextCursor* a0;
        const ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTextTable, &sipCpp, sipType_QTextCursor, &a0))
        {
            ::QTextCursor*sipRes;

            sipRes = new ::QTextCursor(sipCpp->rowEnd(*a0));

            return sipConvertFromNewType(sipRes, sipType_QTextCursor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_rowEnd, doc_QTextTable_rowEnd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_format, "format(self) -> QTextTableFormat");

extern "C" {static PyObject *meth_QTextTable_format(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_format(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTable, &sipCpp))
        {
            ::QTextTableFormat*sipRes;

            sipRes = new ::QTextTableFormat(sipCpp->format());

            return sipConvertFromNewType(sipRes, sipType_QTextTableFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_format, doc_QTextTable_format);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_setFormat, "setFormat(self, aformat: QTextTableFormat)");

extern "C" {static PyObject *meth_QTextTable_setFormat(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_setFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextTableFormat* a0;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTextTable, &sipCpp, sipType_QTextTableFormat, &a0))
        {
            sipCpp->setFormat(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_setFormat, doc_QTextTable_setFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_appendRows, "appendRows(self, count: int)");

extern "C" {static PyObject *meth_QTextTable_appendRows(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_appendRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTextTable, &sipCpp, &a0))
        {
            sipCpp->appendRows(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_appendRows, doc_QTextTable_appendRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTable_appendColumns, "appendColumns(self, count: int)");

extern "C" {static PyObject *meth_QTextTable_appendColumns(PyObject *, PyObject *);}
static PyObject *meth_QTextTable_appendColumns(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QTextTable *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTextTable, &sipCpp, &a0))
        {
            sipCpp->appendColumns(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTable, sipName_appendColumns, doc_QTextTable_appendColumns);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QTextTable(void *, const sipTypeDef *);}
static void *cast_QTextTable(void *sipCppV, const sipTypeDef *targetType)
{
    ::QTextTable *sipCpp = reinterpret_cast<::QTextTable *>(sipCppV);

    if (targetType == sipType_QTextTable)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QTextFrame)->ctd_cast(static_cast<::QTextFrame *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QTextTable(void *, int);}
static void release_QTextTable(void *sipCppV, int)
{
    ::QTextTable *sipCpp = reinterpret_cast<::QTextTable *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QTextTable(sipSimpleWrapper *);}
static void dealloc_QTextTable(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQTextTable *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QTextTable(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QTextTable(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QTextTable(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQTextTable *sipCpp = SIP_NULLPTR;

    {
        ::QTextDocument* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QTextDocument, &a0))
        {
            sipCpp = new sipQTextTable(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QTextTable[] = {{319, 255, 1}};


static PyMethodDef methods_QTextTable[] = {
    {sipName_appendColumns, meth_QTextTable_appendColumns, METH_VARARGS, doc_QTextTable_appendColumns},
    {sipName_appendRows, meth_QTextTable_appendRows, METH_VARARGS, doc_QTextTable_appendRows},
    {sipName_cellAt, meth_QTextTable_cellAt, METH_VARARGS, doc_QTextTable_cellAt},
    {sipName_columns, meth_QTextTable_columns, METH_VARARGS, doc_QTextTable_columns},
    {sipName_format, meth_QTextTable_format, METH_VARARGS, doc_QTextTable_format},
    {sipName_insertColumns, meth_QTextTable_insertColumns, METH_VARARGS, doc_QTextTable_insertColumns},
    {sipName_insertRows, meth_QTextTable_insertRows, METH_VARARGS, doc_QTextTable_insertRows},
    {sipName_mergeCells, meth_QTextTable_mergeCells, METH_VARARGS, doc_QTextTable_mergeCells},
    {sipName_removeColumns, meth_QTextTable_removeColumns, METH_VARARGS, doc_QTextTable_removeColumns},
    {sipName_removeRows, meth_QTextTable_removeRows, METH_VARARGS, doc_QTextTable_removeRows},
    {sipName_resize, meth_QTextTable_resize, METH_VARARGS, doc_QTextTable_resize},
    {sipName_rowEnd, meth_QTextTable_rowEnd, METH_VARARGS, doc_QTextTable_rowEnd},
    {sipName_rowStart, meth_QTextTable_rowStart, METH_VARARGS, doc_QTextTable_rowStart},
    {sipName_rows, meth_QTextTable_rows, METH_VARARGS, doc_QTextTable_rows},
    {sipName_setFormat, meth_QTextTable_setFormat, METH_VARARGS, doc_QTextTable_setFormat},
    {sipName_splitCell, meth_QTextTable_splitCell, METH_VARARGS, doc_QTextTable_splitCell}
};

PyDoc_STRVAR(doc_QTextTable, "\1QTextTable(doc: Optional[QTextDocument])");


static pyqt5ClassPluginDef plugin_QTextTable = {
    &::QTextTable::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QTextTable = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QTextTable,
        SIP_NULLPTR,
        &plugin_QTextTable,
    },
    {
        sipNameNr_QTextTable,
        {0, 0, 1},
        16, methods_QTextTable,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QTextTable,
    -1,
    -1,
    supers_QTextTable,
    SIP_NULLPTR,
    init_type_QTextTable,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QTextTable,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QTextTable,
    cast_QTextTable,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QTextTable),
};
