/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQuick/qquickimageprovider.sip"
#include <qquickimageprovider.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qimage.sip"
#include <qimage.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQuick/qsgtexture.sip"
#include <qsgtexture.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQuick/qquickwindow.sip"
#include <qquickwindow.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 62 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 65 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 83 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 86 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 89 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 92 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 95 "/usr/src/debug/python3-pyqt5/5.15.10/QtQuick/sipQtQuickQQuickTextureFactory.cpp"


class sipQQuickTextureFactory : public ::QQuickTextureFactory
{
public:
    sipQQuickTextureFactory();
    virtual ~sipQQuickTextureFactory();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QImage image() const SIP_OVERRIDE;
    int textureByteCount() const SIP_OVERRIDE;
    ::QSize textureSize() const SIP_OVERRIDE;
    ::QSGTexture* createTexture(::QQuickWindow*) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickTextureFactory(const sipQQuickTextureFactory &);
    sipQQuickTextureFactory &operator = (const sipQQuickTextureFactory &);

    char sipPyMethods[11];
};

sipQQuickTextureFactory::sipQQuickTextureFactory(): ::QQuickTextureFactory(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQuickTextureFactory::~sipQQuickTextureFactory()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQQuickTextureFactory::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtQuick_qt_metaobject(sipPySelf, sipType_QQuickTextureFactory);

    return ::QQuickTextureFactory::metaObject();
}

int sipQQuickTextureFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QQuickTextureFactory::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtQuick_qt_metacall(sipPySelf, sipType_QQuickTextureFactory, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQQuickTextureFactory::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtQuick_qt_metacast(sipPySelf, sipType_QQuickTextureFactory, _clname, &sipCpp) ? sipCpp : ::QQuickTextureFactory::qt_metacast(_clname));
}

::QImage sipQQuickTextureFactory::image() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_image);

    if (!sipMeth)
        return ::QQuickTextureFactory::image();

    extern ::QImage sipVH_QtQuick_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_32(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQQuickTextureFactory::textureByteCount() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QQuickTextureFactory, sipName_textureByteCount);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtQuick_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_31(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQQuickTextureFactory::textureSize() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QQuickTextureFactory, sipName_textureSize);

    if (!sipMeth)
        return ::QSize();

    extern ::QSize sipVH_QtQuick_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_30(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSGTexture* sipQQuickTextureFactory::createTexture(::QQuickWindow*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QQuickTextureFactory, sipName_createTexture);

    if (!sipMeth)
        return 0;

    extern ::QSGTexture* sipVH_QtQuick_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QQuickWindow*);

    return sipVH_QtQuick_29(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQuickTextureFactory::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QQuickTextureFactory::event(a0);

    extern bool sipVH_QtQuick_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtQuick_5(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQuickTextureFactory::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QQuickTextureFactory::eventFilter(a0, a1);

    extern bool sipVH_QtQuick_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtQuick_4(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQQuickTextureFactory::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QQuickTextureFactory::timerEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtQuick_3(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickTextureFactory::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QQuickTextureFactory::childEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtQuick_2(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickTextureFactory::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QQuickTextureFactory::customEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtQuick_1(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickTextureFactory::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QQuickTextureFactory::connectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQuick_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickTextureFactory::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QQuickTextureFactory::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQuick_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QQuickTextureFactory_createTexture, "createTexture(self, window: Optional[QQuickWindow]) -> Optional[QSGTexture]");

extern "C" {static PyObject *meth_QQuickTextureFactory_createTexture(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextureFactory_createTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QQuickWindow* a0;
        const ::QQuickTextureFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QQuickTextureFactory, &sipCpp, sipType_QQuickWindow, &a0))
        {
            ::QSGTexture*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQuickTextureFactory, sipName_createTexture);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->createTexture(a0);

            return sipConvertFromNewType(sipRes, sipType_QSGTexture, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextureFactory, sipName_createTexture, doc_QQuickTextureFactory_createTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextureFactory_textureSize, "textureSize(self) -> QSize");

extern "C" {static PyObject *meth_QQuickTextureFactory_textureSize(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextureFactory_textureSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QQuickTextureFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickTextureFactory, &sipCpp))
        {
            ::QSize*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQuickTextureFactory, sipName_textureSize);
                return SIP_NULLPTR;
            }

            sipRes = new ::QSize(sipCpp->textureSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextureFactory, sipName_textureSize, doc_QQuickTextureFactory_textureSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextureFactory_textureByteCount, "textureByteCount(self) -> int");

extern "C" {static PyObject *meth_QQuickTextureFactory_textureByteCount(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextureFactory_textureByteCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QQuickTextureFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickTextureFactory, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQuickTextureFactory, sipName_textureByteCount);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->textureByteCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextureFactory, sipName_textureByteCount, doc_QQuickTextureFactory_textureByteCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextureFactory_image, "image(self) -> QImage");

extern "C" {static PyObject *meth_QQuickTextureFactory_image(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextureFactory_image(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QQuickTextureFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickTextureFactory, &sipCpp))
        {
            ::QImage*sipRes;

            sipRes = new ::QImage((sipSelfWasArg ? sipCpp->::QQuickTextureFactory::image() : sipCpp->image()));

            return sipConvertFromNewType(sipRes, sipType_QImage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextureFactory, sipName_image, doc_QQuickTextureFactory_image);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextureFactory_textureFactoryForImage, "textureFactoryForImage(image: QImage) -> Optional[QQuickTextureFactory]");

extern "C" {static PyObject *meth_QQuickTextureFactory_textureFactoryForImage(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextureFactory_textureFactoryForImage(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImage* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QImage, &a0))
        {
            ::QQuickTextureFactory*sipRes;

            sipRes = ::QQuickTextureFactory::textureFactoryForImage(*a0);

            return sipConvertFromNewType(sipRes, sipType_QQuickTextureFactory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextureFactory, sipName_textureFactoryForImage, doc_QQuickTextureFactory_textureFactoryForImage);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQuickTextureFactory(void *, const sipTypeDef *);}
static void *cast_QQuickTextureFactory(void *sipCppV, const sipTypeDef *targetType)
{
    ::QQuickTextureFactory *sipCpp = reinterpret_cast<::QQuickTextureFactory *>(sipCppV);

    if (targetType == sipType_QQuickTextureFactory)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast<::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuickTextureFactory(void *, int);}
static void release_QQuickTextureFactory(void *sipCppV, int)
{
    ::QQuickTextureFactory *sipCpp = reinterpret_cast<::QQuickTextureFactory *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QQuickTextureFactory(sipSimpleWrapper *);}
static void dealloc_QQuickTextureFactory(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQuickTextureFactory *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuickTextureFactory(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQuickTextureFactory(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuickTextureFactory(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQQuickTextureFactory *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQQuickTextureFactory();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQuickTextureFactory[] = {{4, 0, 1}};


static PyMethodDef methods_QQuickTextureFactory[] = {
    {sipName_createTexture, meth_QQuickTextureFactory_createTexture, METH_VARARGS, doc_QQuickTextureFactory_createTexture},
    {sipName_image, meth_QQuickTextureFactory_image, METH_VARARGS, doc_QQuickTextureFactory_image},
    {sipName_textureByteCount, meth_QQuickTextureFactory_textureByteCount, METH_VARARGS, doc_QQuickTextureFactory_textureByteCount},
    {sipName_textureFactoryForImage, meth_QQuickTextureFactory_textureFactoryForImage, METH_VARARGS, doc_QQuickTextureFactory_textureFactoryForImage},
    {sipName_textureSize, meth_QQuickTextureFactory_textureSize, METH_VARARGS, doc_QQuickTextureFactory_textureSize}
};

PyDoc_STRVAR(doc_QQuickTextureFactory, "\1QQuickTextureFactory()");


static pyqt5ClassPluginDef plugin_QQuickTextureFactory = {
    &::QQuickTextureFactory::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QQuickTextureFactory = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuickTextureFactory,
        SIP_NULLPTR,
        &plugin_QQuickTextureFactory,
    },
    {
        sipNameNr_QQuickTextureFactory,
        {0, 0, 1},
        5, methods_QQuickTextureFactory,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuickTextureFactory,
    -1,
    -1,
    supers_QQuickTextureFactory,
    SIP_NULLPTR,
    init_type_QQuickTextureFactory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuickTextureFactory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQuickTextureFactory,
    cast_QQuickTextureFactory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QQuickTextureFactory),
};
