/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 109 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 53 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 56 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 68 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 80 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 86 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 89 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 92 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMimeData.cpp"


class sipQMimeData : public ::QMimeData
{
public:
    sipQMimeData();
    virtual ~sipQMimeData();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QVariant retrieveData(const ::QString&, ::QVariant::Type) const SIP_OVERRIDE;
    ::QStringList formats() const SIP_OVERRIDE;
    bool hasFormat(const ::QString&) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQMimeData(const sipQMimeData &);
    sipQMimeData &operator = (const sipQMimeData &);

    char sipPyMethods[10];
};

sipQMimeData::sipQMimeData(): ::QMimeData(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQMimeData::~sipQMimeData()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQMimeData::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtCore_qt_metaobject(sipPySelf, sipType_QMimeData);

    return ::QMimeData::metaObject();
}

int sipQMimeData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QMimeData::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtCore_qt_metacall(sipPySelf, sipType_QMimeData, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQMimeData::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtCore_qt_metacast(sipPySelf, sipType_QMimeData, _clname, &sipCpp) ? sipCpp : ::QMimeData::qt_metacast(_clname));
}

::QVariant sipQMimeData::retrieveData(const ::QString& a0, ::QVariant::Type a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_retrieveData);

    if (!sipMeth)
        return ::QMimeData::retrieveData(a0, a1);

    extern ::QVariant sipVH_QtCore_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, ::QVariant::Type);

    return sipVH_QtCore_56(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

::QStringList sipQMimeData::formats() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_formats);

    if (!sipMeth)
        return ::QMimeData::formats();

    extern ::QStringList sipVH_QtCore_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_29(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

bool sipQMimeData::hasFormat(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasFormat);

    if (!sipMeth)
        return ::QMimeData::hasFormat(a0);

    extern bool sipVH_QtCore_55(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtCore_55(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQMimeData::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QMimeData::event(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQMimeData::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QMimeData::eventFilter(a0, a1);

    extern bool sipVH_QtCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtCore_1(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

void sipQMimeData::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QMimeData::timerEvent(a0);
        return;
    }

    extern void sipVH_QtCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtCore_2(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQMimeData::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QMimeData::childEvent(a0);
        return;
    }

    extern void sipVH_QtCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtCore_3(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQMimeData::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QMimeData::customEvent(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQMimeData::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QMimeData::connectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQMimeData::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QMimeData::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QMimeData_urls, "urls(self) -> List[QUrl]");

extern "C" {static PyObject *meth_QMimeData_urls(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_urls(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            QList<::QUrl>*sipRes;

            sipRes = new QList<::QUrl>(sipCpp->urls());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_urls, doc_QMimeData_urls);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_setUrls, "setUrls(self, urls: Iterable[QUrl])");

extern "C" {static PyObject *meth_QMimeData_setUrls(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_setUrls(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList<::QUrl>* a0;
        int a0State = 0;
        ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMimeData, &sipCpp, sipType_QList_0100QUrl, &a0, &a0State))
        {
            sipCpp->setUrls(*a0);
            sipReleaseType(const_cast<QList<::QUrl> *>(a0), sipType_QList_0100QUrl, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_setUrls, doc_QMimeData_setUrls);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_hasUrls, "hasUrls(self) -> bool");

extern "C" {static PyObject *meth_QMimeData_hasUrls(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_hasUrls(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasUrls();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_hasUrls, doc_QMimeData_hasUrls);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_text, "text(self) -> str");

extern "C" {static PyObject *meth_QMimeData_text(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_text, doc_QMimeData_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_setText, "setText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QMimeData_setText(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_setText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMimeData, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setText(*a0);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_setText, doc_QMimeData_setText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_hasText, "hasText(self) -> bool");

extern "C" {static PyObject *meth_QMimeData_hasText(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_hasText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasText();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_hasText, doc_QMimeData_hasText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_html, "html(self) -> str");

extern "C" {static PyObject *meth_QMimeData_html(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_html(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->html());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_html, doc_QMimeData_html);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_setHtml, "setHtml(self, html: Optional[str])");

extern "C" {static PyObject *meth_QMimeData_setHtml(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_setHtml(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMimeData, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setHtml(*a0);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_setHtml, doc_QMimeData_setHtml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_hasHtml, "hasHtml(self) -> bool");

extern "C" {static PyObject *meth_QMimeData_hasHtml(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_hasHtml(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasHtml();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_hasHtml, doc_QMimeData_hasHtml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_imageData, "imageData(self) -> Any");

extern "C" {static PyObject *meth_QMimeData_imageData(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_imageData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->imageData());

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_imageData, doc_QMimeData_imageData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_setImageData, "setImageData(self, image: Any)");

extern "C" {static PyObject *meth_QMimeData_setImageData(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_setImageData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariant* a0;
        int a0State = 0;
        ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMimeData, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            sipCpp->setImageData(*a0);
            sipReleaseType(const_cast<::QVariant *>(a0), sipType_QVariant, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_setImageData, doc_QMimeData_setImageData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_hasImage, "hasImage(self) -> bool");

extern "C" {static PyObject *meth_QMimeData_hasImage(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_hasImage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasImage();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_hasImage, doc_QMimeData_hasImage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_colorData, "colorData(self) -> Any");

extern "C" {static PyObject *meth_QMimeData_colorData(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_colorData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->colorData());

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_colorData, doc_QMimeData_colorData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_setColorData, "setColorData(self, color: Any)");

extern "C" {static PyObject *meth_QMimeData_setColorData(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_setColorData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariant* a0;
        int a0State = 0;
        ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMimeData, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            sipCpp->setColorData(*a0);
            sipReleaseType(const_cast<::QVariant *>(a0), sipType_QVariant, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_setColorData, doc_QMimeData_setColorData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_hasColor, "hasColor(self) -> bool");

extern "C" {static PyObject *meth_QMimeData_hasColor(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_hasColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasColor();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_hasColor, doc_QMimeData_hasColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_data, "data(self, mimetype: Optional[str]) -> QByteArray");

extern "C" {static PyObject *meth_QMimeData_data(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_data(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMimeData, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->data(*a0));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_data, doc_QMimeData_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_setData, "setData(self, mimetype: Optional[str], data: Union[QByteArray, bytes, bytearray])");

extern "C" {static PyObject *meth_QMimeData_setData(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_setData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QMimeData, &sipCpp, sipType_QString, &a0, &a0State, sipType_QByteArray, &a1, &a1State))
        {
            sipCpp->setData(*a0, *a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast<::QByteArray *>(a1), sipType_QByteArray, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_setData, doc_QMimeData_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_hasFormat, "hasFormat(self, mimetype: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QMimeData_hasFormat(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_hasFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMimeData, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QMimeData::hasFormat(*a0) : sipCpp->hasFormat(*a0));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_hasFormat, doc_QMimeData_hasFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_formats, "formats(self) -> List[str]");

extern "C" {static PyObject *meth_QMimeData_formats(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_formats(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList((sipSelfWasArg ? sipCpp->::QMimeData::formats() : sipCpp->formats()));

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_formats, doc_QMimeData_formats);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_clear, "clear(self)");

extern "C" {static PyObject *meth_QMimeData_clear(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMimeData, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_clear, doc_QMimeData_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_removeFormat, "removeFormat(self, mimetype: Optional[str])");

extern "C" {static PyObject *meth_QMimeData_removeFormat(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_removeFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMimeData, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->removeFormat(*a0);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_removeFormat, doc_QMimeData_removeFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMimeData_retrieveData, "retrieveData(self, mimetype: Optional[str], preferredType: QVariant.Type) -> Any");

extern "C" {static PyObject *meth_QMimeData_retrieveData(PyObject *, PyObject *);}
static PyObject *meth_QMimeData_retrieveData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        ::QVariant::Type a1;
        const ::QMimeData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1E", &sipSelf, sipType_QMimeData, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant_Type, &a1))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QMimeData::retrieveData(*a0, a1) : sipCpp->retrieveData(*a0, a1)));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMimeData, sipName_retrieveData, doc_QMimeData_retrieveData);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QMimeData(void *, const sipTypeDef *);}
static void *cast_QMimeData(void *sipCppV, const sipTypeDef *targetType)
{
    ::QMimeData *sipCpp = reinterpret_cast<::QMimeData *>(sipCppV);

    if (targetType == sipType_QMimeData)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast<::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QMimeData(void *, int);}
static void release_QMimeData(void *sipCppV, int)
{
    ::QMimeData *sipCpp = reinterpret_cast<::QMimeData *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QMimeData(Py_ssize_t);}
static void *array_QMimeData(Py_ssize_t sipNrElem)
{
    return new ::QMimeData[sipNrElem];
}


extern "C" {static void array_delete_QMimeData(void *);}
static void array_delete_QMimeData(void *sipCpp)
{
    delete[] reinterpret_cast<::QMimeData *>(sipCpp);
}


extern "C" {static void dealloc_QMimeData(sipSimpleWrapper *);}
static void dealloc_QMimeData(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQMimeData *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMimeData(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QMimeData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMimeData(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQMimeData *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQMimeData();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QMimeData[] = {{191, 255, 1}};


static PyMethodDef methods_QMimeData[] = {
    {sipName_clear, meth_QMimeData_clear, METH_VARARGS, doc_QMimeData_clear},
    {sipName_colorData, meth_QMimeData_colorData, METH_VARARGS, doc_QMimeData_colorData},
    {sipName_data, meth_QMimeData_data, METH_VARARGS, doc_QMimeData_data},
    {sipName_formats, meth_QMimeData_formats, METH_VARARGS, doc_QMimeData_formats},
    {sipName_hasColor, meth_QMimeData_hasColor, METH_VARARGS, doc_QMimeData_hasColor},
    {sipName_hasFormat, meth_QMimeData_hasFormat, METH_VARARGS, doc_QMimeData_hasFormat},
    {sipName_hasHtml, meth_QMimeData_hasHtml, METH_VARARGS, doc_QMimeData_hasHtml},
    {sipName_hasImage, meth_QMimeData_hasImage, METH_VARARGS, doc_QMimeData_hasImage},
    {sipName_hasText, meth_QMimeData_hasText, METH_VARARGS, doc_QMimeData_hasText},
    {sipName_hasUrls, meth_QMimeData_hasUrls, METH_VARARGS, doc_QMimeData_hasUrls},
    {sipName_html, meth_QMimeData_html, METH_VARARGS, doc_QMimeData_html},
    {sipName_imageData, meth_QMimeData_imageData, METH_VARARGS, doc_QMimeData_imageData},
    {sipName_removeFormat, meth_QMimeData_removeFormat, METH_VARARGS, doc_QMimeData_removeFormat},
    {sipName_retrieveData, meth_QMimeData_retrieveData, METH_VARARGS, doc_QMimeData_retrieveData},
    {sipName_setColorData, meth_QMimeData_setColorData, METH_VARARGS, doc_QMimeData_setColorData},
    {sipName_setData, meth_QMimeData_setData, METH_VARARGS, doc_QMimeData_setData},
    {sipName_setHtml, meth_QMimeData_setHtml, METH_VARARGS, doc_QMimeData_setHtml},
    {sipName_setImageData, meth_QMimeData_setImageData, METH_VARARGS, doc_QMimeData_setImageData},
    {sipName_setText, meth_QMimeData_setText, METH_VARARGS, doc_QMimeData_setText},
    {sipName_setUrls, meth_QMimeData_setUrls, METH_VARARGS, doc_QMimeData_setUrls},
    {sipName_text, meth_QMimeData_text, METH_VARARGS, doc_QMimeData_text},
    {sipName_urls, meth_QMimeData_urls, METH_VARARGS, doc_QMimeData_urls}
};

PyDoc_STRVAR(doc_QMimeData, "\1QMimeData()");


static pyqt5ClassPluginDef plugin_QMimeData = {
    &::QMimeData::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QMimeData = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMimeData,
        SIP_NULLPTR,
        &plugin_QMimeData,
    },
    {
        sipNameNr_QMimeData,
        {0, 0, 1},
        22, methods_QMimeData,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMimeData,
    -1,
    -1,
    supers_QMimeData,
    SIP_NULLPTR,
    init_type_QMimeData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMimeData,
    SIP_NULLPTR,
    array_QMimeData,
    SIP_NULLPTR,
    release_QMimeData,
    cast_QMimeData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QMimeData,
    sizeof (::QMimeData),
};
