/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQXmlStreamAttribute.cpp"

#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQXmlStreamAttribute.cpp"
#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQXmlStreamAttribute.cpp"


PyDoc_STRVAR(doc_QXmlStreamAttribute_namespaceUri, "namespaceUri(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamAttribute_namespaceUri(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamAttribute_namespaceUri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamAttribute, &sipCpp))
        {
            ::QStringRef*sipRes;

            sipRes = new ::QStringRef(sipCpp->namespaceUri());

            return sipConvertFromNewType(sipRes, sipType_QStringRef, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamAttribute, sipName_namespaceUri, doc_QXmlStreamAttribute_namespaceUri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamAttribute_name, "name(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamAttribute_name(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamAttribute_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamAttribute, &sipCpp))
        {
            ::QStringRef*sipRes;

            sipRes = new ::QStringRef(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QStringRef, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamAttribute, sipName_name, doc_QXmlStreamAttribute_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamAttribute_qualifiedName, "qualifiedName(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamAttribute_qualifiedName(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamAttribute_qualifiedName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamAttribute, &sipCpp))
        {
            ::QStringRef*sipRes;

            sipRes = new ::QStringRef(sipCpp->qualifiedName());

            return sipConvertFromNewType(sipRes, sipType_QStringRef, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamAttribute, sipName_qualifiedName, doc_QXmlStreamAttribute_qualifiedName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamAttribute_prefix, "prefix(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamAttribute_prefix(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamAttribute_prefix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamAttribute, &sipCpp))
        {
            ::QStringRef*sipRes;

            sipRes = new ::QStringRef(sipCpp->prefix());

            return sipConvertFromNewType(sipRes, sipType_QStringRef, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamAttribute, sipName_prefix, doc_QXmlStreamAttribute_prefix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamAttribute_value, "value(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamAttribute_value(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamAttribute_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamAttribute, &sipCpp))
        {
            ::QStringRef*sipRes;

            sipRes = new ::QStringRef(sipCpp->value());

            return sipConvertFromNewType(sipRes, sipType_QStringRef, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamAttribute, sipName_value, doc_QXmlStreamAttribute_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamAttribute_isDefault, "isDefault(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamAttribute_isDefault(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamAttribute_isDefault(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamAttribute, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDefault();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamAttribute, sipName_isDefault, doc_QXmlStreamAttribute_isDefault);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QXmlStreamAttribute___ne__(PyObject *, PyObject *);}
static PyObject *slot_QXmlStreamAttribute___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QXmlStreamAttribute *sipCpp = reinterpret_cast<::QXmlStreamAttribute *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QXmlStreamAttribute));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamAttribute* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QXmlStreamAttribute, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QXmlStreamAttribute::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QXmlStreamAttribute, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QXmlStreamAttribute___eq__(PyObject *, PyObject *);}
static PyObject *slot_QXmlStreamAttribute___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QXmlStreamAttribute *sipCpp = reinterpret_cast<::QXmlStreamAttribute *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QXmlStreamAttribute));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamAttribute* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QXmlStreamAttribute, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QXmlStreamAttribute::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QXmlStreamAttribute, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QXmlStreamAttribute(void *, int);}
static void release_QXmlStreamAttribute(void *sipCppV, int)
{
    delete reinterpret_cast<::QXmlStreamAttribute *>(sipCppV);
}


extern "C" {static void *array_QXmlStreamAttribute(Py_ssize_t);}
static void *array_QXmlStreamAttribute(Py_ssize_t sipNrElem)
{
    return new ::QXmlStreamAttribute[sipNrElem];
}


extern "C" {static void array_delete_QXmlStreamAttribute(void *);}
static void array_delete_QXmlStreamAttribute(void *sipCpp)
{
    delete[] reinterpret_cast<::QXmlStreamAttribute *>(sipCpp);
}


extern "C" {static void assign_QXmlStreamAttribute(void *, Py_ssize_t, void *);}
static void assign_QXmlStreamAttribute(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast<::QXmlStreamAttribute *>(sipDst)[sipDstIdx] = *reinterpret_cast<::QXmlStreamAttribute *>(sipSrc);
}


extern "C" {static void *copy_QXmlStreamAttribute(const void *, Py_ssize_t);}
static void *copy_QXmlStreamAttribute(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QXmlStreamAttribute(reinterpret_cast<const ::QXmlStreamAttribute *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QXmlStreamAttribute(sipSimpleWrapper *);}
static void dealloc_QXmlStreamAttribute(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QXmlStreamAttribute(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QXmlStreamAttribute(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QXmlStreamAttribute(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QXmlStreamAttribute *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QXmlStreamAttribute();

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1J1", sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            sipCpp = new ::QXmlStreamAttribute(*a0, *a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1J1J1", sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            sipCpp = new ::QXmlStreamAttribute(*a0, *a1, *a2);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast<::QString *>(a2), sipType_QString, a2State);

            return sipCpp;
        }
    }

    {
        const ::QXmlStreamAttribute* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QXmlStreamAttribute, &a0))
        {
            sipCpp = new ::QXmlStreamAttribute(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QXmlStreamAttribute[] = {
    {(void *)slot_QXmlStreamAttribute___ne__, ne_slot},
    {(void *)slot_QXmlStreamAttribute___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QXmlStreamAttribute[] = {
    {sipName_isDefault, meth_QXmlStreamAttribute_isDefault, METH_VARARGS, doc_QXmlStreamAttribute_isDefault},
    {sipName_name, meth_QXmlStreamAttribute_name, METH_VARARGS, doc_QXmlStreamAttribute_name},
    {sipName_namespaceUri, meth_QXmlStreamAttribute_namespaceUri, METH_VARARGS, doc_QXmlStreamAttribute_namespaceUri},
    {sipName_prefix, meth_QXmlStreamAttribute_prefix, METH_VARARGS, doc_QXmlStreamAttribute_prefix},
    {sipName_qualifiedName, meth_QXmlStreamAttribute_qualifiedName, METH_VARARGS, doc_QXmlStreamAttribute_qualifiedName},
    {sipName_value, meth_QXmlStreamAttribute_value, METH_VARARGS, doc_QXmlStreamAttribute_value}
};

PyDoc_STRVAR(doc_QXmlStreamAttribute, "\1QXmlStreamAttribute()\n"
"QXmlStreamAttribute(qualifiedName: Optional[str], value: Optional[str])\n"
"QXmlStreamAttribute(namespaceUri: Optional[str], name: Optional[str], value: Optional[str])\n"
"QXmlStreamAttribute(a0: QXmlStreamAttribute)");


static pyqt5ClassPluginDef plugin_QXmlStreamAttribute = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QXmlStreamAttribute = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QXmlStreamAttribute,
        SIP_NULLPTR,
        &plugin_QXmlStreamAttribute,
    },
    {
        sipNameNr_QXmlStreamAttribute,
        {0, 0, 1},
        6, methods_QXmlStreamAttribute,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QXmlStreamAttribute,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QXmlStreamAttribute,
    init_type_QXmlStreamAttribute,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QXmlStreamAttribute,
    assign_QXmlStreamAttribute,
    array_QXmlStreamAttribute,
    copy_QXmlStreamAttribute,
    release_QXmlStreamAttribute,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QXmlStreamAttribute,
    sizeof (::QXmlStreamAttribute),
};
