/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintdevicewindow.sip"
#include <qpaintdevicewindow.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 795 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 398 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 54 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 57 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 60 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 195 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 63 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 302 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 66 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 726 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 69 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 253 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 72 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 205 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 75 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 363 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 78 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 471 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 81 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 460 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 84 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 384 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 87 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 412 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 90 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 425 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 93 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 96 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 99 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 102 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 105 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 108 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 111 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 114 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 117 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 120 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 123 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qsurface.sip"
#include <qsurface.h>
#line 126 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 131 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 134 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 137 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 140 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 143 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 152 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 155 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 158 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 161 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 164 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 167 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"
#line 52 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 170 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPaintDeviceWindow.cpp"


PyDoc_STRVAR(doc_QPaintDeviceWindow_update, "update(self, rect: QRect)\n"
"update(self, region: QRegion)\n"
"update(self)");

extern "C" {static PyObject *meth_QPaintDeviceWindow_update(PyObject *, PyObject *);}
static PyObject *meth_QPaintDeviceWindow_update(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRect* a0;
        ::QPaintDeviceWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPaintDeviceWindow, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->update(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QRegion* a0;
        ::QPaintDeviceWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPaintDeviceWindow, &sipCpp, sipType_QRegion, &a0))
        {
            sipCpp->update(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QPaintDeviceWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPaintDeviceWindow, &sipCpp))
        {
            sipCpp->update();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPaintDeviceWindow, sipName_update, doc_QPaintDeviceWindow_update);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPaintDeviceWindow_paintEvent, "paintEvent(self, event: Optional[QPaintEvent])");

extern "C" {static PyObject *meth_QPaintDeviceWindow_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QPaintDeviceWindow_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QPaintDeviceWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QPaintDeviceWindow, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QPaintDeviceWindow::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPaintDeviceWindow, sipName_paintEvent, doc_QPaintDeviceWindow_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPaintDeviceWindow_metric, "metric(self, metric: QPaintDevice.PaintDeviceMetric) -> int");

extern "C" {static PyObject *meth_QPaintDeviceWindow_metric(PyObject *, PyObject *);}
static PyObject *meth_QPaintDeviceWindow_metric(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintDevice::PaintDeviceMetric a0;
        const ::QPaintDeviceWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QPaintDeviceWindow, &sipCpp, sipType_QPaintDevice_PaintDeviceMetric, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPaintDeviceWindow::metric(a0) : sipCpp->metric(a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPaintDeviceWindow, sipName_metric, doc_QPaintDeviceWindow_metric);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPaintDeviceWindow_exposeEvent, "exposeEvent(self, a0: Optional[QExposeEvent])");

extern "C" {static PyObject *meth_QPaintDeviceWindow_exposeEvent(PyObject *, PyObject *);}
static PyObject *meth_QPaintDeviceWindow_exposeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QExposeEvent* a0;
        ::QPaintDeviceWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QPaintDeviceWindow, &sipCpp, sipType_QExposeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QPaintDeviceWindow::exposeEvent(a0) : sipCpp->exposeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPaintDeviceWindow, sipName_exposeEvent, doc_QPaintDeviceWindow_exposeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPaintDeviceWindow_event, "event(self, event: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QPaintDeviceWindow_event(PyObject *, PyObject *);}
static PyObject *meth_QPaintDeviceWindow_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QPaintDeviceWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QPaintDeviceWindow, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPaintDeviceWindow::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPaintDeviceWindow, sipName_event, doc_QPaintDeviceWindow_event);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPaintDeviceWindow(void *, const sipTypeDef *);}
static void *cast_QPaintDeviceWindow(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPaintDeviceWindow *sipCpp = reinterpret_cast<::QPaintDeviceWindow *>(sipCppV);

    if (targetType == sipType_QPaintDeviceWindow)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWindow)->ctd_cast(static_cast<::QWindow *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    if (targetType == sipType_QPaintDevice)
        return static_cast<::QPaintDevice *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPaintDeviceWindow(void *, int);}
static void release_QPaintDeviceWindow(void *sipCppV, int)
{
    ::QPaintDeviceWindow *sipCpp = reinterpret_cast<::QPaintDeviceWindow *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QPaintDeviceWindow(sipSimpleWrapper *);}
static void dealloc_QPaintDeviceWindow(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPaintDeviceWindow(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPaintDeviceWindow[] = {{380, 255, 0}, {198, 255, 1}};


static PyMethodDef methods_QPaintDeviceWindow[] = {
    {sipName_event, meth_QPaintDeviceWindow_event, METH_VARARGS, doc_QPaintDeviceWindow_event},
    {sipName_exposeEvent, meth_QPaintDeviceWindow_exposeEvent, METH_VARARGS, doc_QPaintDeviceWindow_exposeEvent},
    {sipName_metric, meth_QPaintDeviceWindow_metric, METH_VARARGS, doc_QPaintDeviceWindow_metric},
    {sipName_paintEvent, meth_QPaintDeviceWindow_paintEvent, METH_VARARGS, doc_QPaintDeviceWindow_paintEvent},
    {sipName_update, meth_QPaintDeviceWindow_update, METH_VARARGS, doc_QPaintDeviceWindow_update}
};


static pyqt5ClassPluginDef plugin_QPaintDeviceWindow = {
    &::QPaintDeviceWindow::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QPaintDeviceWindow = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPaintDeviceWindow,
        SIP_NULLPTR,
        &plugin_QPaintDeviceWindow,
    },
    {
        sipNameNr_QPaintDeviceWindow,
        {0, 0, 1},
        5, methods_QPaintDeviceWindow,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QPaintDeviceWindow,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPaintDeviceWindow,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QPaintDeviceWindow,
    cast_QPaintDeviceWindow,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
