/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQml/qqmlfileselector.sip"
#include <qqmlfileselector.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"

#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qfileselector.sip"
#include <qfileselector.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 62 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 80 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 86 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 89 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 92 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlFileSelector.cpp"


class sipQQmlFileSelector : public ::QQmlFileSelector
{
public:
    sipQQmlFileSelector(::QQmlEngine*, ::QObject*);
    virtual ~sipQQmlFileSelector();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQmlFileSelector(const sipQQmlFileSelector &);
    sipQQmlFileSelector &operator = (const sipQQmlFileSelector &);

    char sipPyMethods[7];
};

sipQQmlFileSelector::sipQQmlFileSelector(::QQmlEngine*a0, ::QObject*a1): ::QQmlFileSelector(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlFileSelector::~sipQQmlFileSelector()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQQmlFileSelector::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtQml_qt_metaobject(sipPySelf, sipType_QQmlFileSelector);

    return ::QQmlFileSelector::metaObject();
}

int sipQQmlFileSelector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QQmlFileSelector::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtQml_qt_metacall(sipPySelf, sipType_QQmlFileSelector, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQQmlFileSelector::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtQml_qt_metacast(sipPySelf, sipType_QQmlFileSelector, _clname, &sipCpp) ? sipCpp : ::QQmlFileSelector::qt_metacast(_clname));
}

bool sipQQmlFileSelector::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QQmlFileSelector::event(a0);

    extern bool sipVH_QtQml_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtQml_5(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQmlFileSelector::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QQmlFileSelector::eventFilter(a0, a1);

    extern bool sipVH_QtQml_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtQml_4(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQQmlFileSelector::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QQmlFileSelector::timerEvent(a0);
        return;
    }

    extern void sipVH_QtQml_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtQml_3(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlFileSelector::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QQmlFileSelector::childEvent(a0);
        return;
    }

    extern void sipVH_QtQml_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtQml_2(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlFileSelector::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QQmlFileSelector::customEvent(a0);
        return;
    }

    extern void sipVH_QtQml_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtQml_1(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlFileSelector::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QQmlFileSelector::connectNotify(a0);
        return;
    }

    extern void sipVH_QtQml_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQml_0(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlFileSelector::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QQmlFileSelector::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtQml_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQml_0(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QQmlFileSelector_setSelector, "setSelector(self, selector: Optional[QFileSelector])");

extern "C" {static PyObject *meth_QQmlFileSelector_setSelector(PyObject *, PyObject *);}
static PyObject *meth_QQmlFileSelector_setSelector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QFileSelector* a0;
        ::QQmlFileSelector *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QQmlFileSelector, &sipCpp, sipType_QFileSelector, &a0))
        {
            sipCpp->setSelector(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlFileSelector, sipName_setSelector, doc_QQmlFileSelector_setSelector);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlFileSelector_setExtraSelectors, "setExtraSelectors(self, strings: Iterable[Optional[str]])");

extern "C" {static PyObject *meth_QQmlFileSelector_setExtraSelectors(PyObject *, PyObject *);}
static PyObject *meth_QQmlFileSelector_setExtraSelectors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QQmlFileSelector *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQmlFileSelector, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setExtraSelectors(*a0);
            sipReleaseType(const_cast<::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlFileSelector, sipName_setExtraSelectors, doc_QQmlFileSelector_setExtraSelectors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlFileSelector_get, "get(a0: Optional[QQmlEngine]) -> Optional[QQmlFileSelector]");

extern "C" {static PyObject *meth_QQmlFileSelector_get(PyObject *, PyObject *);}
static PyObject *meth_QQmlFileSelector_get(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QQmlEngine* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8", sipType_QQmlEngine, &a0))
        {
            ::QQmlFileSelector*sipRes;

            sipRes = ::QQmlFileSelector::get(a0);

            return sipConvertFromType(sipRes, sipType_QQmlFileSelector, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlFileSelector, sipName_get, doc_QQmlFileSelector_get);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlFileSelector_selector, "selector(self) -> Optional[QFileSelector]");

extern "C" {static PyObject *meth_QQmlFileSelector_selector(PyObject *, PyObject *);}
static PyObject *meth_QQmlFileSelector_selector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlFileSelector *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlFileSelector, &sipCpp))
        {
            ::QFileSelector*sipRes;

            sipRes = sipCpp->selector();

            return sipConvertFromType(sipRes, sipType_QFileSelector, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlFileSelector, sipName_selector, doc_QQmlFileSelector_selector);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQmlFileSelector(void *, const sipTypeDef *);}
static void *cast_QQmlFileSelector(void *sipCppV, const sipTypeDef *targetType)
{
    ::QQmlFileSelector *sipCpp = reinterpret_cast<::QQmlFileSelector *>(sipCppV);

    if (targetType == sipType_QQmlFileSelector)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast<::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlFileSelector(void *, int);}
static void release_QQmlFileSelector(void *sipCppV, int)
{
    ::QQmlFileSelector *sipCpp = reinterpret_cast<::QQmlFileSelector *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QQmlFileSelector(sipSimpleWrapper *);}
static void dealloc_QQmlFileSelector(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQmlFileSelector *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlFileSelector(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQmlFileSelector(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQmlFileSelector(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQQmlFileSelector *sipCpp = SIP_NULLPTR;

    {
        ::QQmlEngine* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QQmlEngine, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQQmlFileSelector(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQmlFileSelector[] = {{9, 0, 1}};


static PyMethodDef methods_QQmlFileSelector[] = {
    {sipName_get, meth_QQmlFileSelector_get, METH_VARARGS, doc_QQmlFileSelector_get},
    {sipName_selector, meth_QQmlFileSelector_selector, METH_VARARGS, doc_QQmlFileSelector_selector},
    {sipName_setExtraSelectors, meth_QQmlFileSelector_setExtraSelectors, METH_VARARGS, doc_QQmlFileSelector_setExtraSelectors},
    {sipName_setSelector, meth_QQmlFileSelector_setSelector, METH_VARARGS, doc_QQmlFileSelector_setSelector}
};

PyDoc_STRVAR(doc_QQmlFileSelector, "\1QQmlFileSelector(engine: Optional[QQmlEngine], parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QQmlFileSelector = {
    &::QQmlFileSelector::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QQmlFileSelector = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlFileSelector,
        SIP_NULLPTR,
        &plugin_QQmlFileSelector,
    },
    {
        sipNameNr_QQmlFileSelector,
        {0, 0, 1},
        4, methods_QQmlFileSelector,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQmlFileSelector,
    -1,
    -1,
    supers_QQmlFileSelector,
    SIP_NULLPTR,
    init_type_QQmlFileSelector,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQmlFileSelector,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQmlFileSelector,
    cast_QQmlFileSelector,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QQmlFileSelector),
};
