/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtXml.h"

#line 174 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"

#line 54 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 237 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 312 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 364 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 275 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 429 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 54 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 388 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 57 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 402 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 60 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 351 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 63 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 417 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 66 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 192 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 69 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 263 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 72 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 376 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 75 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 295 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 78 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"
#line 154 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 81 "/usr/src/debug/python3-pyqt5/5.15.10/QtXml/sipQtXmlQDomDocumentType.cpp"


PyDoc_STRVAR(doc_QDomDocumentType_name, "name(self) -> str");

extern "C" {static PyObject *meth_QDomDocumentType_name(PyObject *, PyObject *);}
static PyObject *meth_QDomDocumentType_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomDocumentType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomDocumentType, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomDocumentType, sipName_name, doc_QDomDocumentType_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomDocumentType_entities, "entities(self) -> QDomNamedNodeMap");

extern "C" {static PyObject *meth_QDomDocumentType_entities(PyObject *, PyObject *);}
static PyObject *meth_QDomDocumentType_entities(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomDocumentType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomDocumentType, &sipCpp))
        {
            ::QDomNamedNodeMap*sipRes;

            sipRes = new ::QDomNamedNodeMap(sipCpp->entities());

            return sipConvertFromNewType(sipRes, sipType_QDomNamedNodeMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomDocumentType, sipName_entities, doc_QDomDocumentType_entities);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomDocumentType_notations, "notations(self) -> QDomNamedNodeMap");

extern "C" {static PyObject *meth_QDomDocumentType_notations(PyObject *, PyObject *);}
static PyObject *meth_QDomDocumentType_notations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomDocumentType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomDocumentType, &sipCpp))
        {
            ::QDomNamedNodeMap*sipRes;

            sipRes = new ::QDomNamedNodeMap(sipCpp->notations());

            return sipConvertFromNewType(sipRes, sipType_QDomNamedNodeMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomDocumentType, sipName_notations, doc_QDomDocumentType_notations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomDocumentType_publicId, "publicId(self) -> str");

extern "C" {static PyObject *meth_QDomDocumentType_publicId(PyObject *, PyObject *);}
static PyObject *meth_QDomDocumentType_publicId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomDocumentType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomDocumentType, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->publicId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomDocumentType, sipName_publicId, doc_QDomDocumentType_publicId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomDocumentType_systemId, "systemId(self) -> str");

extern "C" {static PyObject *meth_QDomDocumentType_systemId(PyObject *, PyObject *);}
static PyObject *meth_QDomDocumentType_systemId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomDocumentType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomDocumentType, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->systemId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomDocumentType, sipName_systemId, doc_QDomDocumentType_systemId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomDocumentType_internalSubset, "internalSubset(self) -> str");

extern "C" {static PyObject *meth_QDomDocumentType_internalSubset(PyObject *, PyObject *);}
static PyObject *meth_QDomDocumentType_internalSubset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomDocumentType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomDocumentType, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->internalSubset());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomDocumentType, sipName_internalSubset, doc_QDomDocumentType_internalSubset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomDocumentType_nodeType, "nodeType(self) -> QDomNode.NodeType");

extern "C" {static PyObject *meth_QDomDocumentType_nodeType(PyObject *, PyObject *);}
static PyObject *meth_QDomDocumentType_nodeType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomDocumentType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomDocumentType, &sipCpp))
        {
            ::QDomNode::NodeType sipRes;

            sipRes = sipCpp->nodeType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QDomNode_NodeType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomDocumentType, sipName_nodeType, doc_QDomDocumentType_nodeType);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QDomDocumentType(void *, const sipTypeDef *);}
static void *cast_QDomDocumentType(void *sipCppV, const sipTypeDef *targetType)
{
    ::QDomDocumentType *sipCpp = reinterpret_cast<::QDomDocumentType *>(sipCppV);

    if (targetType == sipType_QDomDocumentType)
        return sipCppV;

    if (targetType == sipType_QDomNode)
        return static_cast<::QDomNode *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDomDocumentType(void *, int);}
static void release_QDomDocumentType(void *sipCppV, int)
{
    delete reinterpret_cast<::QDomDocumentType *>(sipCppV);
}


extern "C" {static void *array_QDomDocumentType(Py_ssize_t);}
static void *array_QDomDocumentType(Py_ssize_t sipNrElem)
{
    return new ::QDomDocumentType[sipNrElem];
}


extern "C" {static void array_delete_QDomDocumentType(void *);}
static void array_delete_QDomDocumentType(void *sipCpp)
{
    delete[] reinterpret_cast<::QDomDocumentType *>(sipCpp);
}


extern "C" {static void assign_QDomDocumentType(void *, Py_ssize_t, void *);}
static void assign_QDomDocumentType(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast<::QDomDocumentType *>(sipDst)[sipDstIdx] = *reinterpret_cast<::QDomDocumentType *>(sipSrc);
}


extern "C" {static void *copy_QDomDocumentType(const void *, Py_ssize_t);}
static void *copy_QDomDocumentType(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QDomDocumentType(reinterpret_cast<const ::QDomDocumentType *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QDomDocumentType(sipSimpleWrapper *);}
static void dealloc_QDomDocumentType(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDomDocumentType(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QDomDocumentType(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDomDocumentType(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QDomDocumentType *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QDomDocumentType();

            return sipCpp;
        }
    }

    {
        const ::QDomDocumentType* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDomDocumentType, &a0))
        {
            sipCpp = new ::QDomDocumentType(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QDomDocumentType[] = {{13, 255, 1}};


static PyMethodDef methods_QDomDocumentType[] = {
    {sipName_entities, meth_QDomDocumentType_entities, METH_VARARGS, doc_QDomDocumentType_entities},
    {sipName_internalSubset, meth_QDomDocumentType_internalSubset, METH_VARARGS, doc_QDomDocumentType_internalSubset},
    {sipName_name, meth_QDomDocumentType_name, METH_VARARGS, doc_QDomDocumentType_name},
    {sipName_nodeType, meth_QDomDocumentType_nodeType, METH_VARARGS, doc_QDomDocumentType_nodeType},
    {sipName_notations, meth_QDomDocumentType_notations, METH_VARARGS, doc_QDomDocumentType_notations},
    {sipName_publicId, meth_QDomDocumentType_publicId, METH_VARARGS, doc_QDomDocumentType_publicId},
    {sipName_systemId, meth_QDomDocumentType_systemId, METH_VARARGS, doc_QDomDocumentType_systemId}
};

PyDoc_STRVAR(doc_QDomDocumentType, "\1QDomDocumentType()\n"
"QDomDocumentType(x: QDomDocumentType)");


static pyqt5ClassPluginDef plugin_QDomDocumentType = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtXml_QDomDocumentType = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDomDocumentType,
        SIP_NULLPTR,
        &plugin_QDomDocumentType,
    },
    {
        sipNameNr_QDomDocumentType,
        {0, 0, 1},
        7, methods_QDomDocumentType,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDomDocumentType,
    -1,
    -1,
    supers_QDomDocumentType,
    SIP_NULLPTR,
    init_type_QDomDocumentType,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDomDocumentType,
    assign_QDomDocumentType,
    array_QDomDocumentType,
    copy_QDomDocumentType,
    release_QDomDocumentType,
    cast_QDomDocumentType,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QDomDocumentType,
    sizeof (::QDomDocumentType),
};
