/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 24 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQml/qpyqmllistproperty.sip"
#include "qpyqmllistpropertywrapper.h"
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlListProperty0100QObject.cpp"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlListProperty0100QObject.cpp"


extern "C" {static void assign_QQmlListProperty_0100QObject(void *, Py_ssize_t, void *);}
static void assign_QQmlListProperty_0100QObject(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast<::QQmlListProperty<::QObject> *>(sipDst)[sipDstIdx] = *reinterpret_cast<::QQmlListProperty<::QObject> *>(sipSrc);
}


extern "C" {static void *array_QQmlListProperty_0100QObject(Py_ssize_t);}
static void *array_QQmlListProperty_0100QObject(Py_ssize_t sipNrElem)
{
    return new ::QQmlListProperty<::QObject>[sipNrElem];
}


extern "C" {static void *copy_QQmlListProperty_0100QObject(const void *, Py_ssize_t);}
static void *copy_QQmlListProperty_0100QObject(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QQmlListProperty<::QObject>(reinterpret_cast<const ::QQmlListProperty<::QObject> *>(sipSrc)[sipSrcIdx]);
}


/* Call the mapped type's destructor. */
extern "C" {static void release_QQmlListProperty_0100QObject(void *, int);}
static void release_QQmlListProperty_0100QObject(void *sipCppV, int)
{
    ::QQmlListProperty<::QObject> *sipCpp = reinterpret_cast<::QQmlListProperty<::QObject> *>(sipCppV);
    delete sipCpp;
}



extern "C" {static int convertTo_QQmlListProperty_0100QObject(PyObject *, void **, int *, PyObject *);}
static int convertTo_QQmlListProperty_0100QObject(PyObject *sipPy, void **sipCppPtrV, int *sipIsErr, PyObject *)
{
    ::QQmlListProperty<::QObject> **sipCppPtr = reinterpret_cast<::QQmlListProperty<::QObject> **>(sipCppPtrV);

#line 32 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQml/qpyqmllistproperty.sip"
    if (sipIsErr == NULL)
        return PyObject_IsInstance(sipPy, (PyObject *)qpyqml_QQmlListPropertyWrapper_TypeObject);

    *sipCppPtr = ((qpyqml_QQmlListPropertyWrapper *)sipPy)->qml_list_property;

    // It isn't a temporary copy.
    return 0;
#line 80 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlListProperty0100QObject.cpp"
}


extern "C" {static PyObject *convertFrom_QQmlListProperty_0100QObject(void *, PyObject *);}
static PyObject *convertFrom_QQmlListProperty_0100QObject(void *sipCppV, PyObject *)
{
    ::QQmlListProperty<::QObject> *sipCpp = reinterpret_cast<::QQmlListProperty<::QObject> *>(sipCppV);

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtQml/qpyqmllistproperty.sip"
    return qpyqml_QQmlListPropertyWrapper_New(sipCpp, 0);
#line 91 "/usr/src/debug/python3-pyqt5/5.15.10/QtQml/sipQtQmlQQmlListProperty0100QObject.cpp"
}


sipMappedTypeDef sipTypeDef_QtQml_QQmlListProperty_0100QObject = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_MAPPED,
        sipNameNr_746,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        -1,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
    },
    assign_QQmlListProperty_0100QObject,
    array_QQmlListProperty_0100QObject,
    copy_QQmlListProperty_0100QObject,
    release_QQmlListProperty_0100QObject,
    convertTo_QQmlListProperty_0100QObject,
    convertFrom_QQmlListProperty_0100QObject
};
