/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qeventtransition.sip"
#include <qeventtransition.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstate.sip"
#include <qstate.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstracttransition.sip"
#include <qabstracttransition.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstatemachine.sip"
#include <qstatemachine.h>
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstractstate.sip"
#include <qabstractstate.h>
#line 57 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 62 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 65 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 74 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 77 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 83 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 89 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 92 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 95 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 98 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 101 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 104 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQEventTransition.cpp"


class sipQEventTransition : public ::QEventTransition
{
public:
    sipQEventTransition(::QState*);
    sipQEventTransition(::QObject*, ::QEvent::Type, ::QState*);
    virtual ~sipQEventTransition();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventTest(::QEvent*) SIP_OVERRIDE;
    void onTransition(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQEventTransition(const sipQEventTransition &);
    sipQEventTransition &operator = (const sipQEventTransition &);

    char sipPyMethods[9];
};

sipQEventTransition::sipQEventTransition(::QState*a0): ::QEventTransition(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQEventTransition::sipQEventTransition(::QObject*a0, ::QEvent::Type a1, ::QState*a2): ::QEventTransition(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQEventTransition::~sipQEventTransition()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQEventTransition::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtCore_qt_metaobject(sipPySelf, sipType_QEventTransition);

    return ::QEventTransition::metaObject();
}

int sipQEventTransition::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QEventTransition::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtCore_qt_metacall(sipPySelf, sipType_QEventTransition, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQEventTransition::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtCore_qt_metacast(sipPySelf, sipType_QEventTransition, _clname, &sipCpp) ? sipCpp : ::QEventTransition::qt_metacast(_clname));
}

void sipQEventTransition::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QEventTransition::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQEventTransition::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QEventTransition::connectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQEventTransition::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QEventTransition::customEvent(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQEventTransition::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QEventTransition::childEvent(a0);
        return;
    }

    extern void sipVH_QtCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtCore_3(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQEventTransition::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QEventTransition::timerEvent(a0);
        return;
    }

    extern void sipVH_QtCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtCore_2(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQEventTransition::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QEventTransition::eventFilter(a0, a1);

    extern bool sipVH_QtCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtCore_1(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

bool sipQEventTransition::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QEventTransition::event(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQEventTransition::eventTest(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_eventTest);

    if (!sipMeth)
        return ::QEventTransition::eventTest(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQEventTransition::onTransition(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_onTransition);

    if (!sipMeth)
    {
        ::QEventTransition::onTransition(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QEventTransition_eventSource, "eventSource(self) -> Optional[QObject]");

extern "C" {static PyObject *meth_QEventTransition_eventSource(PyObject *, PyObject *);}
static PyObject *meth_QEventTransition_eventSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventTransition, &sipCpp))
        {
            ::QObject*sipRes;

            sipRes = sipCpp->eventSource();

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventTransition, sipName_eventSource, doc_QEventTransition_eventSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventTransition_setEventSource, "setEventSource(self, object: Optional[QObject])");

extern "C" {static PyObject *meth_QEventTransition_setEventSource(PyObject *, PyObject *);}
static PyObject *meth_QEventTransition_setEventSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        PyObject *a0Keep;
        ::QEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QEventTransition, &sipCpp, &a0Keep, sipType_QObject, &a0))
        {
            sipCpp->setEventSource(a0);

            sipKeepReference(sipSelf, 10, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventTransition, sipName_setEventSource, doc_QEventTransition_setEventSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventTransition_eventType, "eventType(self) -> QEvent.Type");

extern "C" {static PyObject *meth_QEventTransition_eventType(PyObject *, PyObject *);}
static PyObject *meth_QEventTransition_eventType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventTransition, &sipCpp))
        {
            ::QEvent::Type sipRes;

            sipRes = sipCpp->eventType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QEvent_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventTransition, sipName_eventType, doc_QEventTransition_eventType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventTransition_setEventType, "setEventType(self, type: QEvent.Type)");

extern "C" {static PyObject *meth_QEventTransition_setEventType(PyObject *, PyObject *);}
static PyObject *meth_QEventTransition_setEventType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QEvent::Type a0;
        ::QEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QEventTransition, &sipCpp, sipType_QEvent_Type, &a0))
        {
            sipCpp->setEventType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventTransition, sipName_setEventType, doc_QEventTransition_setEventType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventTransition_eventTest, "eventTest(self, event: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QEventTransition_eventTest(PyObject *, PyObject *);}
static PyObject *meth_QEventTransition_eventTest(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QEventTransition, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QEventTransition::eventTest(a0) : sipCpp->eventTest(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventTransition, sipName_eventTest, doc_QEventTransition_eventTest);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventTransition_onTransition, "onTransition(self, event: Optional[QEvent])");

extern "C" {static PyObject *meth_QEventTransition_onTransition(PyObject *, PyObject *);}
static PyObject *meth_QEventTransition_onTransition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QEventTransition, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QEventTransition::onTransition(a0) : sipCpp->onTransition(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventTransition, sipName_onTransition, doc_QEventTransition_onTransition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventTransition_event, "event(self, e: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QEventTransition_event(PyObject *, PyObject *);}
static PyObject *meth_QEventTransition_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QEventTransition, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QEventTransition::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventTransition, sipName_event, doc_QEventTransition_event);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QEventTransition(void *, const sipTypeDef *);}
static void *cast_QEventTransition(void *sipCppV, const sipTypeDef *targetType)
{
    ::QEventTransition *sipCpp = reinterpret_cast<::QEventTransition *>(sipCppV);

    if (targetType == sipType_QEventTransition)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstractTransition)->ctd_cast(static_cast<::QAbstractTransition *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QEventTransition(void *, int);}
static void release_QEventTransition(void *sipCppV, int)
{
    ::QEventTransition *sipCpp = reinterpret_cast<::QEventTransition *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QEventTransition(Py_ssize_t);}
static void *array_QEventTransition(Py_ssize_t sipNrElem)
{
    return new ::QEventTransition[sipNrElem];
}


extern "C" {static void array_delete_QEventTransition(void *);}
static void array_delete_QEventTransition(void *sipCpp)
{
    delete[] reinterpret_cast<::QEventTransition *>(sipCpp);
}


extern "C" {static void dealloc_QEventTransition(sipSimpleWrapper *);}
static void dealloc_QEventTransition(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQEventTransition *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QEventTransition(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QEventTransition(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QEventTransition(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQEventTransition *sipCpp = SIP_NULLPTR;

    {
        ::QState* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_sourceState,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QState, &a0, sipOwner))
        {
            sipCpp = new sipQEventTransition(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0;
        PyObject *a0Keep;
        ::QEvent::Type a1;
        ::QState* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_sourceState,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8E|JH", &a0Keep, sipType_QObject, &a0, sipType_QEvent_Type, &a1, sipType_QState, &a2, sipOwner))
        {
            sipCpp = new sipQEventTransition(a0, a1, a2);

            sipKeepReference((PyObject *)sipSelf, 10, a0Keep);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QEventTransition[] = {{15, 255, 1}};


static PyMethodDef methods_QEventTransition[] = {
    {sipName_event, meth_QEventTransition_event, METH_VARARGS, doc_QEventTransition_event},
    {sipName_eventSource, meth_QEventTransition_eventSource, METH_VARARGS, doc_QEventTransition_eventSource},
    {sipName_eventTest, meth_QEventTransition_eventTest, METH_VARARGS, doc_QEventTransition_eventTest},
    {sipName_eventType, meth_QEventTransition_eventType, METH_VARARGS, doc_QEventTransition_eventType},
    {sipName_onTransition, meth_QEventTransition_onTransition, METH_VARARGS, doc_QEventTransition_onTransition},
    {sipName_setEventSource, meth_QEventTransition_setEventSource, METH_VARARGS, doc_QEventTransition_setEventSource},
    {sipName_setEventType, meth_QEventTransition_setEventType, METH_VARARGS, doc_QEventTransition_setEventType}
};

PyDoc_STRVAR(doc_QEventTransition, "\1QEventTransition(sourceState: Optional[QState] = None)\n"
"QEventTransition(object: Optional[QObject], type: QEvent.Type, sourceState: Optional[QState] = None)");


static pyqt5ClassPluginDef plugin_QEventTransition = {
    &::QEventTransition::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QEventTransition = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QEventTransition,
        SIP_NULLPTR,
        &plugin_QEventTransition,
    },
    {
        sipNameNr_QEventTransition,
        {0, 0, 1},
        7, methods_QEventTransition,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QEventTransition,
    -1,
    -1,
    supers_QEventTransition,
    SIP_NULLPTR,
    init_type_QEventTransition,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QEventTransition,
    SIP_NULLPTR,
    array_QEventTransition,
    SIP_NULLPTR,
    release_QEventTransition,
    cast_QEventTransition,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QEventTransition,
    sizeof (::QEventTransition),
};
