/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPainterPixmapFragmentHints.cpp"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPainterPixmapFragmentHints.cpp"


extern "C" {static long slot_QPainter_PixmapFragmentHints___hash__(PyObject *);}
static long slot_QPainter_PixmapFragmentHints___hash__(PyObject *sipSelf)
{
    ::QPainter::PixmapFragmentHints *sipCpp = reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPainter_PixmapFragmentHints));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 122 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QPainter::PixmapFragmentHints::Int();
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPainterPixmapFragmentHints.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static int slot_QPainter_PixmapFragmentHints___bool__(PyObject *);}
static int slot_QPainter_PixmapFragmentHints___bool__(PyObject *sipSelf)
{
    ::QPainter::PixmapFragmentHints *sipCpp = reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPainter_PixmapFragmentHints));

    if (!sipCpp)
        return -1;


    {
        {
            int sipRes = 0;

#line 117 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QPainter::PixmapFragmentHints::Int() != 0);
#line 76 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPainterPixmapFragmentHints.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPainter::PixmapFragmentHints *sipCpp = reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPainter_PixmapFragmentHints));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPainter::PixmapFragmentHints* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QPainter_PixmapFragmentHints, &a0, &a0State))
        {
            bool sipRes = 0;

#line 112 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QPainter::PixmapFragmentHints::Int() != a0->operator QPainter::PixmapFragmentHints::Int());
#line 106 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPainterPixmapFragmentHints.cpp"
            sipReleaseType(const_cast<::QPainter::PixmapFragmentHints *>(a0), sipType_QPainter_PixmapFragmentHints, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, ne_slot, sipType_QPainter_PixmapFragmentHints, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPainter::PixmapFragmentHints *sipCpp = reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPainter_PixmapFragmentHints));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPainter::PixmapFragmentHints* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QPainter_PixmapFragmentHints, &a0, &a0State))
        {
            bool sipRes = 0;

#line 107 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QPainter::PixmapFragmentHints::Int() == a0->operator QPainter::PixmapFragmentHints::Int());
#line 139 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPainterPixmapFragmentHints.cpp"
            sipReleaseType(const_cast<::QPainter::PixmapFragmentHints *>(a0), sipType_QPainter_PixmapFragmentHints, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, eq_slot, sipType_QPainter_PixmapFragmentHints, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___ixor__(PyObject *, PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___ixor__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPainter_PixmapFragmentHints)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QPainter::PixmapFragmentHints *sipCpp = reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPainter_PixmapFragmentHints));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 101 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
        *sipCpp = QPainter::PixmapFragmentHints(*sipCpp ^ a0);
#line 175 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPainterPixmapFragmentHints.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___xor__(PyObject *, PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___xor__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter::PixmapFragmentHints* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QPainter_PixmapFragmentHints, &a0, &a0State, &a1))
        {
            ::QPainter::PixmapFragmentHints*sipRes;

            sipRes = new ::QPainter::PixmapFragmentHints((*a0 ^ a1));
            sipReleaseType(a0, sipType_QPainter_PixmapFragmentHints, a0State);

            return sipConvertFromNewType(sipRes, sipType_QPainter_PixmapFragmentHints, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, xor_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___ior__(PyObject *, PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___ior__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPainter_PixmapFragmentHints)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QPainter::PixmapFragmentHints *sipCpp = reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPainter_PixmapFragmentHints));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 95 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
        *sipCpp = QPainter::PixmapFragmentHints(*sipCpp | a0);
#line 247 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPainterPixmapFragmentHints.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___or__(PyObject *, PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter::PixmapFragmentHints* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QPainter_PixmapFragmentHints, &a0, &a0State, &a1))
        {
            ::QPainter::PixmapFragmentHints*sipRes;

            sipRes = new ::QPainter::PixmapFragmentHints((*a0 | a1));
            sipReleaseType(a0, sipType_QPainter_PixmapFragmentHints, a0State);

            return sipConvertFromNewType(sipRes, sipType_QPainter_PixmapFragmentHints, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, or_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___iand__(PyObject *, PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___iand__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPainter_PixmapFragmentHints)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QPainter::PixmapFragmentHints *sipCpp = reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPainter_PixmapFragmentHints));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
            sipCpp->::QPainter::PixmapFragmentHints::operator&=(a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___and__(PyObject *, PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___and__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter::PixmapFragmentHints* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QPainter_PixmapFragmentHints, &a0, &a0State, &a1))
        {
            ::QPainter::PixmapFragmentHints*sipRes;

            sipRes = new ::QPainter::PixmapFragmentHints((*a0 & a1));
            sipReleaseType(a0, sipType_QPainter_PixmapFragmentHints, a0State);

            return sipConvertFromNewType(sipRes, sipType_QPainter_PixmapFragmentHints, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, and_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___invert__(PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___invert__(PyObject *sipSelf)
{
    ::QPainter::PixmapFragmentHints *sipCpp = reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPainter_PixmapFragmentHints));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            ::QPainter::PixmapFragmentHints*sipRes;

            sipRes = new ::QPainter::PixmapFragmentHints(~(*sipCpp));

            return sipConvertFromNewType(sipRes, sipType_QPainter_PixmapFragmentHints, SIP_NULLPTR);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___index__(PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___index__(PyObject *sipSelf)
{
    ::QPainter::PixmapFragmentHints *sipCpp = reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPainter_PixmapFragmentHints));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes = 0;

#line 84 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QPainter::PixmapFragmentHints::Int();
#line 404 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPainterPixmapFragmentHints.cpp"

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QPainter_PixmapFragmentHints___int__(PyObject *);}
static PyObject *slot_QPainter_PixmapFragmentHints___int__(PyObject *sipSelf)
{
    ::QPainter::PixmapFragmentHints *sipCpp = reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPainter_PixmapFragmentHints));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes;

            sipRes = *sipCpp;

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPainter_PixmapFragmentHints(void *, int);}
static void release_QPainter_PixmapFragmentHints(void *sipCppV, int)
{
    delete reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipCppV);
}


extern "C" {static void *array_QPainter_PixmapFragmentHints(Py_ssize_t);}
static void *array_QPainter_PixmapFragmentHints(Py_ssize_t sipNrElem)
{
    return new ::QPainter::PixmapFragmentHints[sipNrElem];
}


extern "C" {static void array_delete_QPainter_PixmapFragmentHints(void *);}
static void array_delete_QPainter_PixmapFragmentHints(void *sipCpp)
{
    delete[] reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipCpp);
}


extern "C" {static void assign_QPainter_PixmapFragmentHints(void *, Py_ssize_t, void *);}
static void assign_QPainter_PixmapFragmentHints(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipDst)[sipDstIdx] = *reinterpret_cast<::QPainter::PixmapFragmentHints *>(sipSrc);
}


extern "C" {static void *copy_QPainter_PixmapFragmentHints(const void *, Py_ssize_t);}
static void *copy_QPainter_PixmapFragmentHints(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPainter::PixmapFragmentHints(reinterpret_cast<const ::QPainter::PixmapFragmentHints *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPainter_PixmapFragmentHints(sipSimpleWrapper *);}
static void dealloc_QPainter_PixmapFragmentHints(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPainter_PixmapFragmentHints(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QPainter_PixmapFragmentHints(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPainter_PixmapFragmentHints(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QPainter::PixmapFragmentHints *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QPainter::PixmapFragmentHints();

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "i", &a0))
        {
            sipCpp = new ::QPainter::PixmapFragmentHints(a0);

            return sipCpp;
        }
    }

    {
        const ::QPainter::PixmapFragmentHints* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QPainter_PixmapFragmentHints, &a0, &a0State))
        {
            sipCpp = new ::QPainter::PixmapFragmentHints(*a0);
            sipReleaseType(const_cast<::QPainter::PixmapFragmentHints *>(a0), sipType_QPainter_PixmapFragmentHints, a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static int convertTo_QPainter_PixmapFragmentHints(PyObject *, void **, int *, PyObject *);}
static int convertTo_QPainter_PixmapFragmentHints(PyObject *sipPy, void **sipCppPtrV, int *sipIsErr, PyObject *sipTransferObj)
{
    ::QPainter::PixmapFragmentHints **sipCppPtr = reinterpret_cast<::QPainter::PixmapFragmentHints **>(sipCppPtrV);

#line 127 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
// Allow an instance of the base enum whenever a QPainter::PixmapFragmentHints is expected.

if (sipIsErr == NULL)
    return (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QPainter_PixmapFragmentHint)) ||
            sipCanConvertToType(sipPy, sipType_QPainter_PixmapFragmentHints, SIP_NO_CONVERTORS));

if (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QPainter_PixmapFragmentHint)))
{
    *sipCppPtr = new QPainter::PixmapFragmentHints(int(SIPLong_AsLong(sipPy)));

    return sipGetState(sipTransferObj);
}

*sipCppPtr = reinterpret_cast<QPainter::PixmapFragmentHints *>(sipConvertToType(sipPy, sipType_QPainter_PixmapFragmentHints, sipTransferObj, SIP_NO_CONVERTORS, 0, sipIsErr));

return 0;
#line 547 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQPainterPixmapFragmentHints.cpp"
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPainter_PixmapFragmentHints[] = {
    {(void *)slot_QPainter_PixmapFragmentHints___hash__, hash_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___bool__, bool_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___ne__, ne_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___eq__, eq_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___ixor__, ixor_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___xor__, xor_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___ior__, ior_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___or__, or_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___iand__, iand_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___and__, and_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___invert__, invert_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___index__, index_slot},
    {(void *)slot_QPainter_PixmapFragmentHints___int__, int_slot},
    {0, (sipPySlotType)0}
};

PyDoc_STRVAR(doc_QPainter_PixmapFragmentHints, "\1QPainter.PixmapFragmentHints()\n"
"QPainter.PixmapFragmentHints(f: Union[QPainter.PixmapFragmentHints, QPainter.PixmapFragmentHint])\n"
"QPainter.PixmapFragmentHints(a0: QPainter.PixmapFragmentHints)");


static pyqt5ClassPluginDef plugin_QPainter_PixmapFragmentHints = {
    SIP_NULLPTR,
    1,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QPainter_PixmapFragmentHints = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPainter__PixmapFragmentHints,
        SIP_NULLPTR,
        &plugin_QPainter_PixmapFragmentHints,
    },
    {
        sipNameNr_PixmapFragmentHints,
        {210, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPainter_PixmapFragmentHints,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPainter_PixmapFragmentHints,
    init_type_QPainter_PixmapFragmentHints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPainter_PixmapFragmentHints,
    assign_QPainter_PixmapFragmentHints,
    array_QPainter_PixmapFragmentHints,
    copy_QPainter_PixmapFragmentHints,
    release_QPainter_PixmapFragmentHints,
    SIP_NULLPTR,
    convertTo_QPainter_PixmapFragmentHints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPainter_PixmapFragmentHints,
    sizeof (::QPainter::PixmapFragmentHints),
};
