/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 62 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 31 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQIconEngineAvailableSizesArgument.cpp"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 35 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQIconEngineAvailableSizesArgument.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQIconEngineAvailableSizesArgument.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 41 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipQtGuiQIconEngineAvailableSizesArgument.cpp"


/* Call the instance's destructor. */
extern "C" {static void release_QIconEngine_AvailableSizesArgument(void *, int);}
static void release_QIconEngine_AvailableSizesArgument(void *sipCppV, int)
{
    delete reinterpret_cast<::QIconEngine::AvailableSizesArgument *>(sipCppV);
}


extern "C" {static void *array_QIconEngine_AvailableSizesArgument(Py_ssize_t);}
static void *array_QIconEngine_AvailableSizesArgument(Py_ssize_t sipNrElem)
{
    return new ::QIconEngine::AvailableSizesArgument[sipNrElem];
}


extern "C" {static void array_delete_QIconEngine_AvailableSizesArgument(void *);}
static void array_delete_QIconEngine_AvailableSizesArgument(void *sipCpp)
{
    delete[] reinterpret_cast<::QIconEngine::AvailableSizesArgument *>(sipCpp);
}


extern "C" {static void assign_QIconEngine_AvailableSizesArgument(void *, Py_ssize_t, void *);}
static void assign_QIconEngine_AvailableSizesArgument(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast<::QIconEngine::AvailableSizesArgument *>(sipDst)[sipDstIdx] = *reinterpret_cast<::QIconEngine::AvailableSizesArgument *>(sipSrc);
}


extern "C" {static void *copy_QIconEngine_AvailableSizesArgument(const void *, Py_ssize_t);}
static void *copy_QIconEngine_AvailableSizesArgument(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QIconEngine::AvailableSizesArgument(reinterpret_cast<const ::QIconEngine::AvailableSizesArgument *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QIconEngine_AvailableSizesArgument(sipSimpleWrapper *);}
static void dealloc_QIconEngine_AvailableSizesArgument(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QIconEngine_AvailableSizesArgument(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QIconEngine_AvailableSizesArgument(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QIconEngine_AvailableSizesArgument(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QIconEngine::AvailableSizesArgument *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QIconEngine::AvailableSizesArgument();

            return sipCpp;
        }
    }

    {
        const ::QIconEngine::AvailableSizesArgument* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QIconEngine_AvailableSizesArgument, &a0))
        {
            sipCpp = new ::QIconEngine::AvailableSizesArgument(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static PyObject *varget_QIconEngine_AvailableSizesArgument_mode(void *, PyObject *, PyObject *);}
static PyObject *varget_QIconEngine_AvailableSizesArgument_mode(void *sipSelf, PyObject *, PyObject *)
{
    ::QIcon::Mode sipVal;
    ::QIconEngine::AvailableSizesArgument *sipCpp = reinterpret_cast<::QIconEngine::AvailableSizesArgument *>(sipSelf);

    sipVal = sipCpp->mode;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QIcon_Mode);
}


extern "C" {static int varset_QIconEngine_AvailableSizesArgument_mode(void *, PyObject *, PyObject *);}
static int varset_QIconEngine_AvailableSizesArgument_mode(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QIcon::Mode sipVal;
    ::QIconEngine::AvailableSizesArgument *sipCpp = reinterpret_cast<::QIconEngine::AvailableSizesArgument *>(sipSelf);

    sipVal = (::QIcon::Mode)sipConvertToEnum(sipPy, sipType_QIcon_Mode);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->mode = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QIconEngine_AvailableSizesArgument_sizes(void *, PyObject *, PyObject *);}
static PyObject *varget_QIconEngine_AvailableSizesArgument_sizes(void *sipSelf, PyObject *, PyObject *)
{
    QList<::QSize>*sipVal;
    ::QIconEngine::AvailableSizesArgument *sipCpp = reinterpret_cast<::QIconEngine::AvailableSizesArgument *>(sipSelf);

    sipVal = &sipCpp->sizes;

    return sipConvertFromType(sipVal, sipType_QList_0100QSize, SIP_NULLPTR);
}


extern "C" {static int varset_QIconEngine_AvailableSizesArgument_sizes(void *, PyObject *, PyObject *);}
static int varset_QIconEngine_AvailableSizesArgument_sizes(void *sipSelf, PyObject *sipPy, PyObject *)
{
    QList<::QSize>*sipVal;
    ::QIconEngine::AvailableSizesArgument *sipCpp = reinterpret_cast<::QIconEngine::AvailableSizesArgument *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast<QList<::QSize> *>(sipForceConvertToType(sipPy, sipType_QList_0100QSize, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->sizes = *sipVal;

    sipReleaseType(sipVal, sipType_QList_0100QSize, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_QIconEngine_AvailableSizesArgument_state(void *, PyObject *, PyObject *);}
static PyObject *varget_QIconEngine_AvailableSizesArgument_state(void *sipSelf, PyObject *, PyObject *)
{
    ::QIcon::State sipVal;
    ::QIconEngine::AvailableSizesArgument *sipCpp = reinterpret_cast<::QIconEngine::AvailableSizesArgument *>(sipSelf);

    sipVal = sipCpp->state;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QIcon_State);
}


extern "C" {static int varset_QIconEngine_AvailableSizesArgument_state(void *, PyObject *, PyObject *);}
static int varset_QIconEngine_AvailableSizesArgument_state(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QIcon::State sipVal;
    ::QIconEngine::AvailableSizesArgument *sipCpp = reinterpret_cast<::QIconEngine::AvailableSizesArgument *>(sipSelf);

    sipVal = (::QIcon::State)sipConvertToEnum(sipPy, sipType_QIcon_State);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->state = sipVal;

    return 0;
}

sipVariableDef variables_QIconEngine_AvailableSizesArgument[] = {
    {InstanceVariable, sipName_mode, (PyMethodDef *)varget_QIconEngine_AvailableSizesArgument_mode, (PyMethodDef *)varset_QIconEngine_AvailableSizesArgument_mode, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_sizes, (PyMethodDef *)varget_QIconEngine_AvailableSizesArgument_sizes, (PyMethodDef *)varset_QIconEngine_AvailableSizesArgument_sizes, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_state, (PyMethodDef *)varget_QIconEngine_AvailableSizesArgument_state, (PyMethodDef *)varset_QIconEngine_AvailableSizesArgument_state, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QIconEngine_AvailableSizesArgument, "\1QIconEngine.AvailableSizesArgument()\n"
"QIconEngine.AvailableSizesArgument(a0: QIconEngine.AvailableSizesArgument)");


static pyqt5ClassPluginDef plugin_QIconEngine_AvailableSizesArgument = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QIconEngine_AvailableSizesArgument = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QIconEngine__AvailableSizesArgument,
        SIP_NULLPTR,
        &plugin_QIconEngine_AvailableSizesArgument,
    },
    {
        sipNameNr_AvailableSizesArgument,
        {69, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        3, variables_QIconEngine_AvailableSizesArgument,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QIconEngine_AvailableSizesArgument,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QIconEngine_AvailableSizesArgument,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QIconEngine_AvailableSizesArgument,
    assign_QIconEngine_AvailableSizesArgument,
    array_QIconEngine_AvailableSizesArgument,
    copy_QIconEngine_AvailableSizesArgument,
    release_QIconEngine_AvailableSizesArgument,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QIconEngine_AvailableSizesArgument,
    sizeof (::QIconEngine::AvailableSizesArgument),
};
