/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qabstractslider.sip"
#include <qabstractslider.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 253 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 363 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 54 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 57 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 60 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 63 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 66 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 69 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 72 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 75 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 78 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 81 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 84 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 87 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 90 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 195 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 93 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 96 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 99 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 102 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 105 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 108 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 111 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 114 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 117 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 120 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 123 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 509 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 126 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 471 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 129 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 460 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 132 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 570 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 135 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 619 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 138 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 592 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 141 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 608 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 144 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 675 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 147 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 302 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 150 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 482 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 153 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 438 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 156 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 425 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 159 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 412 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 162 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 398 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 165 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 384 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 168 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 205 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 171 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 52 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 174 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 177 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 180 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 183 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 186 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 189 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 192 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 195 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 198 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 201 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 204 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 209 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 212 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 215 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 218 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 221 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 224 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 227 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 230 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 233 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 236 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 239 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQAbstractSlider.cpp"


class sipQAbstractSlider : public ::QAbstractSlider
{
public:
    sipQAbstractSlider(::QWidget*);
    virtual ~sipQAbstractSlider();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void sliderChange(::QAbstractSlider::SliderChange) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, long*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAbstractSlider(const sipQAbstractSlider &);
    sipQAbstractSlider &operator = (const sipQAbstractSlider &);

    char sipPyMethods[47];
};

sipQAbstractSlider::sipQAbstractSlider(::QWidget*a0): ::QAbstractSlider(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAbstractSlider::~sipQAbstractSlider()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAbstractSlider::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QAbstractSlider);

    return ::QAbstractSlider::metaObject();
}

int sipQAbstractSlider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAbstractSlider::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QAbstractSlider, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAbstractSlider::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QAbstractSlider, _clname, &sipCpp) ? sipCpp : ::QAbstractSlider::qt_metacast(_clname));
}

void sipQAbstractSlider::sliderChange(::QAbstractSlider::SliderChange a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_sliderChange);

    if (!sipMeth)
    {
        ::QAbstractSlider::sliderChange(a0);
        return;
    }

    extern void sipVH_QtWidgets_71(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractSlider::SliderChange);

    sipVH_QtWidgets_71(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAbstractSlider::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAbstractSlider::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSlider::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAbstractSlider::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQAbstractSlider::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAbstractSlider::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQAbstractSlider::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QAbstractSlider::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQAbstractSlider::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QAbstractSlider::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQAbstractSlider::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QAbstractSlider::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractSlider::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QAbstractSlider::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQAbstractSlider::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QAbstractSlider::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQAbstractSlider::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QAbstractSlider::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQAbstractSlider::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QAbstractSlider::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::enterEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSlider::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QAbstractSlider::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQAbstractSlider::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QAbstractSlider::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSlider::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QAbstractSlider::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSlider::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[43]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QAbstractSlider::hasHeightForWidth();

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractSlider::nativeEvent(const ::QByteArray& a0, void*a1, long*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QAbstractSlider::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, long*);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQAbstractSlider::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[45]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QAbstractSlider::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractSlider::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QAbstractSlider::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAbstractSlider_orientation, "orientation(self) -> Qt.Orientation");

extern "C" {static PyObject *meth_QAbstractSlider_orientation(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_orientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            ::Qt::Orientation sipRes;

            sipRes = sipCpp->orientation();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_Orientation);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_orientation, doc_QAbstractSlider_orientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setMinimum, "setMinimum(self, a0: int)");

extern "C" {static PyObject *meth_QAbstractSlider_setMinimum(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setMinimum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0))
        {
            sipCpp->setMinimum(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setMinimum, doc_QAbstractSlider_setMinimum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_minimum, "minimum(self) -> int");

extern "C" {static PyObject *meth_QAbstractSlider_minimum(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_minimum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minimum();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_minimum, doc_QAbstractSlider_minimum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setMaximum, "setMaximum(self, a0: int)");

extern "C" {static PyObject *meth_QAbstractSlider_setMaximum(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setMaximum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0))
        {
            sipCpp->setMaximum(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setMaximum, doc_QAbstractSlider_setMaximum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_maximum, "maximum(self) -> int");

extern "C" {static PyObject *meth_QAbstractSlider_maximum(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_maximum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maximum();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_maximum, doc_QAbstractSlider_maximum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setRange, "setRange(self, min: int, max: int)");

extern "C" {static PyObject *meth_QAbstractSlider_setRange(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0, &a1))
        {
            sipCpp->setRange(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setRange, doc_QAbstractSlider_setRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setSingleStep, "setSingleStep(self, a0: int)");

extern "C" {static PyObject *meth_QAbstractSlider_setSingleStep(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setSingleStep(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0))
        {
            sipCpp->setSingleStep(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setSingleStep, doc_QAbstractSlider_setSingleStep);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_singleStep, "singleStep(self) -> int");

extern "C" {static PyObject *meth_QAbstractSlider_singleStep(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_singleStep(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->singleStep();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_singleStep, doc_QAbstractSlider_singleStep);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setPageStep, "setPageStep(self, a0: int)");

extern "C" {static PyObject *meth_QAbstractSlider_setPageStep(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setPageStep(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0))
        {
            sipCpp->setPageStep(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setPageStep, doc_QAbstractSlider_setPageStep);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_pageStep, "pageStep(self) -> int");

extern "C" {static PyObject *meth_QAbstractSlider_pageStep(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_pageStep(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->pageStep();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_pageStep, doc_QAbstractSlider_pageStep);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setTracking, "setTracking(self, enable: bool)");

extern "C" {static PyObject *meth_QAbstractSlider_setTracking(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0))
        {
            sipCpp->setTracking(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setTracking, doc_QAbstractSlider_setTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_hasTracking, "hasTracking(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSlider_hasTracking(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_hasTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasTracking();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_hasTracking, doc_QAbstractSlider_hasTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setSliderDown, "setSliderDown(self, a0: bool)");

extern "C" {static PyObject *meth_QAbstractSlider_setSliderDown(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setSliderDown(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0))
        {
            sipCpp->setSliderDown(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setSliderDown, doc_QAbstractSlider_setSliderDown);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_isSliderDown, "isSliderDown(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSlider_isSliderDown(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_isSliderDown(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSliderDown();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_isSliderDown, doc_QAbstractSlider_isSliderDown);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setSliderPosition, "setSliderPosition(self, a0: int)");

extern "C" {static PyObject *meth_QAbstractSlider_setSliderPosition(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setSliderPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0))
        {
            sipCpp->setSliderPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setSliderPosition, doc_QAbstractSlider_setSliderPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_sliderPosition, "sliderPosition(self) -> int");

extern "C" {static PyObject *meth_QAbstractSlider_sliderPosition(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_sliderPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sliderPosition();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_sliderPosition, doc_QAbstractSlider_sliderPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setInvertedAppearance, "setInvertedAppearance(self, a0: bool)");

extern "C" {static PyObject *meth_QAbstractSlider_setInvertedAppearance(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setInvertedAppearance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0))
        {
            sipCpp->setInvertedAppearance(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setInvertedAppearance, doc_QAbstractSlider_setInvertedAppearance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_invertedAppearance, "invertedAppearance(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSlider_invertedAppearance(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_invertedAppearance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->invertedAppearance();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_invertedAppearance, doc_QAbstractSlider_invertedAppearance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setInvertedControls, "setInvertedControls(self, a0: bool)");

extern "C" {static PyObject *meth_QAbstractSlider_setInvertedControls(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setInvertedControls(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0))
        {
            sipCpp->setInvertedControls(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setInvertedControls, doc_QAbstractSlider_setInvertedControls);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_invertedControls, "invertedControls(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSlider_invertedControls(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_invertedControls(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->invertedControls();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_invertedControls, doc_QAbstractSlider_invertedControls);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_value, "value(self) -> int");

extern "C" {static PyObject *meth_QAbstractSlider_value(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->value();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_value, doc_QAbstractSlider_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_triggerAction, "triggerAction(self, action: QAbstractSlider.SliderAction)");

extern "C" {static PyObject *meth_QAbstractSlider_triggerAction(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_triggerAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractSlider::SliderAction a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractSlider, &sipCpp, sipType_QAbstractSlider_SliderAction, &a0))
        {
            sipCpp->triggerAction(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_triggerAction, doc_QAbstractSlider_triggerAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setValue, "setValue(self, a0: int)");

extern "C" {static PyObject *meth_QAbstractSlider_setValue(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAbstractSlider, &sipCpp, &a0))
        {
            sipCpp->setValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setValue, doc_QAbstractSlider_setValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setOrientation, "setOrientation(self, a0: Qt.Orientation)");

extern "C" {static PyObject *meth_QAbstractSlider_setOrientation(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setOrientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Orientation a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractSlider, &sipCpp, sipType_Qt_Orientation, &a0))
        {
            sipCpp->setOrientation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setOrientation, doc_QAbstractSlider_setOrientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_setRepeatAction, "setRepeatAction(self, action: QAbstractSlider.SliderAction, thresholdTime: int = 500, repeatTime: int = 50)");

extern "C" {static PyObject *meth_QAbstractSlider_setRepeatAction(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_setRepeatAction(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractSlider::SliderAction a0;
        int a1 = 500;
        int a2 = 50;
        ::QAbstractSlider *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_thresholdTime,
            sipName_repeatTime,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "pE|ii", &sipSelf, sipType_QAbstractSlider, &sipCpp, sipType_QAbstractSlider_SliderAction, &a0, &a1, &a2))
        {
            sipCpp->setRepeatAction(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_setRepeatAction, doc_QAbstractSlider_setRepeatAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_repeatAction, "repeatAction(self) -> QAbstractSlider.SliderAction");

extern "C" {static PyObject *meth_QAbstractSlider_repeatAction(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_repeatAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QAbstractSlider, &sipCpp))
        {
            ::QAbstractSlider::SliderAction sipRes;

            sipRes = sipCpp->repeatAction();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractSlider_SliderAction);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_repeatAction, doc_QAbstractSlider_repeatAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_sliderChange, "sliderChange(self, change: QAbstractSlider.SliderChange)");

extern "C" {static PyObject *meth_QAbstractSlider_sliderChange(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_sliderChange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QAbstractSlider::SliderChange a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QAbstractSlider, &sipCpp, sipType_QAbstractSlider_SliderChange, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSlider::sliderChange(a0) : sipCpp->sliderChange(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_sliderChange, doc_QAbstractSlider_sliderChange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_event, "event(self, e: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QAbstractSlider_event(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSlider, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QAbstractSlider::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_event, doc_QAbstractSlider_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_keyPressEvent, "keyPressEvent(self, ev: Optional[QKeyEvent])");

extern "C" {static PyObject *meth_QAbstractSlider_keyPressEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_keyPressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSlider, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSlider::keyPressEvent(a0) : sipCpp->keyPressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_keyPressEvent, doc_QAbstractSlider_keyPressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_timerEvent, "timerEvent(self, a0: Optional[QTimerEvent])");

extern "C" {static PyObject *meth_QAbstractSlider_timerEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_timerEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QTimerEvent* a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSlider, &sipCpp, sipType_QTimerEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSlider::timerEvent(a0) : sipCpp->timerEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_timerEvent, doc_QAbstractSlider_timerEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_wheelEvent, "wheelEvent(self, e: Optional[QWheelEvent])");

extern "C" {static PyObject *meth_QAbstractSlider_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWheelEvent* a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSlider, &sipCpp, sipType_QWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSlider::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_wheelEvent, doc_QAbstractSlider_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSlider_changeEvent, "changeEvent(self, e: Optional[QEvent])");

extern "C" {static PyObject *meth_QAbstractSlider_changeEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSlider_changeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QAbstractSlider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSlider, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSlider::changeEvent(a0) : sipCpp->changeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSlider, sipName_changeEvent, doc_QAbstractSlider_changeEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAbstractSlider(void *, const sipTypeDef *);}
static void *cast_QAbstractSlider(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAbstractSlider *sipCpp = reinterpret_cast<::QAbstractSlider *>(sipCppV);

    if (targetType == sipType_QAbstractSlider)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast<::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAbstractSlider(void *, int);}
static void release_QAbstractSlider(void *sipCppV, int)
{
    ::QAbstractSlider *sipCpp = reinterpret_cast<::QAbstractSlider *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QAbstractSlider(Py_ssize_t);}
static void *array_QAbstractSlider(Py_ssize_t sipNrElem)
{
    return new ::QAbstractSlider[sipNrElem];
}


extern "C" {static void array_delete_QAbstractSlider(void *);}
static void array_delete_QAbstractSlider(void *sipCpp)
{
    delete[] reinterpret_cast<::QAbstractSlider *>(sipCpp);
}


extern "C" {static void dealloc_QAbstractSlider(sipSimpleWrapper *);}
static void dealloc_QAbstractSlider(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAbstractSlider *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAbstractSlider(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAbstractSlider(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAbstractSlider(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAbstractSlider *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQAbstractSlider(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAbstractSlider[] = {{463, 255, 1}};


static PyMethodDef methods_QAbstractSlider[] = {
    {sipName_changeEvent, meth_QAbstractSlider_changeEvent, METH_VARARGS, doc_QAbstractSlider_changeEvent},
    {sipName_event, meth_QAbstractSlider_event, METH_VARARGS, doc_QAbstractSlider_event},
    {sipName_hasTracking, meth_QAbstractSlider_hasTracking, METH_VARARGS, doc_QAbstractSlider_hasTracking},
    {sipName_invertedAppearance, meth_QAbstractSlider_invertedAppearance, METH_VARARGS, doc_QAbstractSlider_invertedAppearance},
    {sipName_invertedControls, meth_QAbstractSlider_invertedControls, METH_VARARGS, doc_QAbstractSlider_invertedControls},
    {sipName_isSliderDown, meth_QAbstractSlider_isSliderDown, METH_VARARGS, doc_QAbstractSlider_isSliderDown},
    {sipName_keyPressEvent, meth_QAbstractSlider_keyPressEvent, METH_VARARGS, doc_QAbstractSlider_keyPressEvent},
    {sipName_maximum, meth_QAbstractSlider_maximum, METH_VARARGS, doc_QAbstractSlider_maximum},
    {sipName_minimum, meth_QAbstractSlider_minimum, METH_VARARGS, doc_QAbstractSlider_minimum},
    {sipName_orientation, meth_QAbstractSlider_orientation, METH_VARARGS, doc_QAbstractSlider_orientation},
    {sipName_pageStep, meth_QAbstractSlider_pageStep, METH_VARARGS, doc_QAbstractSlider_pageStep},
    {sipName_repeatAction, meth_QAbstractSlider_repeatAction, METH_VARARGS, doc_QAbstractSlider_repeatAction},
    {sipName_setInvertedAppearance, meth_QAbstractSlider_setInvertedAppearance, METH_VARARGS, doc_QAbstractSlider_setInvertedAppearance},
    {sipName_setInvertedControls, meth_QAbstractSlider_setInvertedControls, METH_VARARGS, doc_QAbstractSlider_setInvertedControls},
    {sipName_setMaximum, meth_QAbstractSlider_setMaximum, METH_VARARGS, doc_QAbstractSlider_setMaximum},
    {sipName_setMinimum, meth_QAbstractSlider_setMinimum, METH_VARARGS, doc_QAbstractSlider_setMinimum},
    {sipName_setOrientation, meth_QAbstractSlider_setOrientation, METH_VARARGS, doc_QAbstractSlider_setOrientation},
    {sipName_setPageStep, meth_QAbstractSlider_setPageStep, METH_VARARGS, doc_QAbstractSlider_setPageStep},
    {sipName_setRange, meth_QAbstractSlider_setRange, METH_VARARGS, doc_QAbstractSlider_setRange},
    {sipName_setRepeatAction, SIP_MLMETH_CAST(meth_QAbstractSlider_setRepeatAction), METH_VARARGS|METH_KEYWORDS, doc_QAbstractSlider_setRepeatAction},
    {sipName_setSingleStep, meth_QAbstractSlider_setSingleStep, METH_VARARGS, doc_QAbstractSlider_setSingleStep},
    {sipName_setSliderDown, meth_QAbstractSlider_setSliderDown, METH_VARARGS, doc_QAbstractSlider_setSliderDown},
    {sipName_setSliderPosition, meth_QAbstractSlider_setSliderPosition, METH_VARARGS, doc_QAbstractSlider_setSliderPosition},
    {sipName_setTracking, meth_QAbstractSlider_setTracking, METH_VARARGS, doc_QAbstractSlider_setTracking},
    {sipName_setValue, meth_QAbstractSlider_setValue, METH_VARARGS, doc_QAbstractSlider_setValue},
    {sipName_singleStep, meth_QAbstractSlider_singleStep, METH_VARARGS, doc_QAbstractSlider_singleStep},
    {sipName_sliderChange, meth_QAbstractSlider_sliderChange, METH_VARARGS, doc_QAbstractSlider_sliderChange},
    {sipName_sliderPosition, meth_QAbstractSlider_sliderPosition, METH_VARARGS, doc_QAbstractSlider_sliderPosition},
    {sipName_timerEvent, meth_QAbstractSlider_timerEvent, METH_VARARGS, doc_QAbstractSlider_timerEvent},
    {sipName_triggerAction, meth_QAbstractSlider_triggerAction, METH_VARARGS, doc_QAbstractSlider_triggerAction},
    {sipName_value, meth_QAbstractSlider_value, METH_VARARGS, doc_QAbstractSlider_value},
    {sipName_wheelEvent, meth_QAbstractSlider_wheelEvent, METH_VARARGS, doc_QAbstractSlider_wheelEvent}
};

static sipEnumMemberDef enummembers_QAbstractSlider[] = {
    {sipName_SliderMove, static_cast<int>(::QAbstractSlider::SliderMove), 18},
    {sipName_SliderNoAction, static_cast<int>(::QAbstractSlider::SliderNoAction), 18},
    {sipName_SliderOrientationChange, static_cast<int>(::QAbstractSlider::SliderOrientationChange), 19},
    {sipName_SliderPageStepAdd, static_cast<int>(::QAbstractSlider::SliderPageStepAdd), 18},
    {sipName_SliderPageStepSub, static_cast<int>(::QAbstractSlider::SliderPageStepSub), 18},
    {sipName_SliderRangeChange, static_cast<int>(::QAbstractSlider::SliderRangeChange), 19},
    {sipName_SliderSingleStepAdd, static_cast<int>(::QAbstractSlider::SliderSingleStepAdd), 18},
    {sipName_SliderSingleStepSub, static_cast<int>(::QAbstractSlider::SliderSingleStepSub), 18},
    {sipName_SliderStepsChange, static_cast<int>(::QAbstractSlider::SliderStepsChange), 19},
    {sipName_SliderToMaximum, static_cast<int>(::QAbstractSlider::SliderToMaximum), 18},
    {sipName_SliderToMinimum, static_cast<int>(::QAbstractSlider::SliderToMinimum), 18},
    {sipName_SliderValueChange, static_cast<int>(::QAbstractSlider::SliderValueChange), 19},
};

PyDoc_STRVAR(doc_QAbstractSlider, "\1QAbstractSlider(parent: Optional[QWidget] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QAbstractSlider[] = {
    {"actionTriggered(int)", "\1actionTriggered(self, action: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"rangeChanged(int,int)", "\1rangeChanged(self, min: int, max: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"sliderReleased()", "\1sliderReleased(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"sliderMoved(int)", "\1sliderMoved(self, position: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"sliderPressed()", "\1sliderPressed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"valueChanged(int)", "\1valueChanged(self, value: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QAbstractSlider = {
    &::QAbstractSlider::staticMetaObject,
    0,
    signals_QAbstractSlider,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QAbstractSlider = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAbstractSlider,
        SIP_NULLPTR,
        &plugin_QAbstractSlider,
    },
    {
        sipNameNr_QAbstractSlider,
        {0, 0, 1},
        32, methods_QAbstractSlider,
        12, enummembers_QAbstractSlider,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAbstractSlider,
    -1,
    -1,
    supers_QAbstractSlider,
    SIP_NULLPTR,
    init_type_QAbstractSlider,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAbstractSlider,
    SIP_NULLPTR,
    array_QAbstractSlider,
    SIP_NULLPTR,
    release_QAbstractSlider,
    cast_QAbstractSlider,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAbstractSlider,
    sizeof (::QAbstractSlider),
};
