/*
 * Internal module API header file.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtSvgAPI_H
#define _QtSvgAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_mouseDoubleClickEvent 0
#define sipName_mouseDoubleClickEvent &sipStrings_QtSvg[0]
#define sipNameNr_setMaximumCacheSize 22
#define sipName_setMaximumCacheSize &sipStrings_QtSvg[22]
#define sipNameNr_transformForElement 42
#define sipName_transformForElement &sipStrings_QtSvg[42]
#define sipNameNr_focusNextPrevChild 62
#define sipName_focusNextPrevChild &sipStrings_QtSvg[62]
#define sipNameNr_setAspectRatioMode 81
#define sipName_setAspectRatioMode &sipStrings_QtSvg[81]
#define sipNameNr_setFramesPerSecond 100
#define sipName_setFramesPerSecond &sipStrings_QtSvg[100]
#define sipNameNr_animationDuration 119
#define sipName_animationDuration &sipStrings_QtSvg[119]
#define sipNameNr_hasHeightForWidth 137
#define sipName_hasHeightForWidth &sipStrings_QtSvg[137]
#define sipNameNr_mouseReleaseEvent 155
#define sipName_mouseReleaseEvent &sipStrings_QtSvg[155]
#define sipNameNr_setSharedRenderer 173
#define sipName_setSharedRenderer &sipStrings_QtSvg[173]
#define sipNameNr_QGraphicsSvgItem 191
#define sipName_QGraphicsSvgItem &sipStrings_QtSvg[191]
#define sipNameNr_collidesWithItem 208
#define sipName_collidesWithItem &sipStrings_QtSvg[208]
#define sipNameNr_collidesWithPath 225
#define sipName_collidesWithPath &sipStrings_QtSvg[225]
#define sipNameNr_contextMenuEvent 242
#define sipName_contextMenuEvent &sipStrings_QtSvg[242]
#define sipNameNr_disconnectNotify 259
#define sipName_disconnectNotify &sipStrings_QtSvg[259]
#define sipNameNr_inputMethodEvent 276
#define sipName_inputMethodEvent &sipStrings_QtSvg[276]
#define sipNameNr_inputMethodQuery 293
#define sipName_inputMethodQuery &sipStrings_QtSvg[293]
#define sipNameNr_maximumCacheSize 310
#define sipName_maximumCacheSize &sipStrings_QtSvg[310]
#define sipNameNr_sceneEventFilter 327
#define sipName_sceneEventFilter &sipStrings_QtSvg[327]
#define sipNameNr_aspectRatioMode 344
#define sipName_aspectRatioMode &sipStrings_QtSvg[344]
#define sipNameNr_boundsOnElement 360
#define sipName_boundsOnElement &sipStrings_QtSvg[360]
#define sipNameNr_framesPerSecond 376
#define sipName_framesPerSecond &sipStrings_QtSvg[376]
#define sipNameNr_hoverEnterEvent 392
#define sipName_hoverEnterEvent &sipStrings_QtSvg[392]
#define sipNameNr_hoverLeaveEvent 408
#define sipName_hoverLeaveEvent &sipStrings_QtSvg[408]
#define sipNameNr_keyReleaseEvent 424
#define sipName_keyReleaseEvent &sipStrings_QtSvg[424]
#define sipNameNr_minimumSizeHint 440
#define sipName_minimumSizeHint &sipStrings_QtSvg[440]
#define sipNameNr_mousePressEvent 456
#define sipName_mousePressEvent &sipStrings_QtSvg[456]
#define sipNameNr_setCurrentFrame 472
#define sipName_setCurrentFrame &sipStrings_QtSvg[472]
#define sipNameNr_setOutputDevice 488
#define sipName_setOutputDevice &sipStrings_QtSvg[488]
#define sipNameNr_dragEnterEvent 504
#define sipName_dragEnterEvent &sipStrings_QtSvg[504]
#define sipNameNr_dragLeaveEvent 519
#define sipName_dragLeaveEvent &sipStrings_QtSvg[519]
#define sipNameNr_heightForWidth 534
#define sipName_heightForWidth &sipStrings_QtSvg[534]
#define sipNameNr_hoverMoveEvent 549
#define sipName_hoverMoveEvent &sipStrings_QtSvg[549]
#define sipNameNr_mouseMoveEvent 564
#define sipName_mouseMoveEvent &sipStrings_QtSvg[564]
#define sipNameNr_setDescription 579
#define sipName_setDescription &sipStrings_QtSvg[579]
#define sipNameNr_QSvgGenerator 594
#define sipName_QSvgGenerator &sipStrings_QtSvg[594]
#define sipNameNr_connectNotify 262
#define sipName_connectNotify &sipStrings_QtSvg[262]
#define sipNameNr_dragMoveEvent 608
#define sipName_dragMoveEvent &sipStrings_QtSvg[608]
#define sipNameNr_elementExists 622
#define sipName_elementExists &sipStrings_QtSvg[622]
#define sipNameNr_focusOutEvent 636
#define sipName_focusOutEvent &sipStrings_QtSvg[636]
#define sipNameNr_keyPressEvent 650
#define sipName_keyPressEvent &sipStrings_QtSvg[650]
#define sipNameNr_repaintNeeded 664
#define sipName_repaintNeeded &sipStrings_QtSvg[664]
#define sipNameNr_setResolution 678
#define sipName_setResolution &sipStrings_QtSvg[678]
#define sipNameNr_sharedPainter 692
#define sipName_sharedPainter &sipStrings_QtSvg[692]
#define sipNameNr_QSvgRenderer 706
#define sipName_QSvgRenderer &sipStrings_QtSvg[706]
#define sipNameNr_boundingRect 719
#define sipName_boundingRect &sipStrings_QtSvg[719]
#define sipNameNr_currentFrame 732
#define sipName_currentFrame &sipStrings_QtSvg[732]
#define sipNameNr_focusInEvent 745
#define sipName_focusInEvent &sipStrings_QtSvg[745]
#define sipNameNr_isObscuredBy 758
#define sipName_isObscuredBy &sipStrings_QtSvg[758]
#define sipNameNr_outputDevice 771
#define sipName_outputDevice &sipStrings_QtSvg[771]
#define sipNameNr_setElementId 784
#define sipName_setElementId &sipStrings_QtSvg[784]
#define sipNameNr_PyQt5_QtSvg 797
#define sipName_PyQt5_QtSvg &sipStrings_QtSvg[797]
#define sipNameNr_actionEvent 809
#define sipName_actionEvent &sipStrings_QtSvg[809]
#define sipNameNr_changeEvent 821
#define sipName_changeEvent &sipStrings_QtSvg[821]
#define sipNameNr_customEvent 833
#define sipName_customEvent &sipStrings_QtSvg[833]
#define sipNameNr_defaultSize 845
#define sipName_defaultSize &sipStrings_QtSvg[845]
#define sipNameNr_description 857
#define sipName_description &sipStrings_QtSvg[857]
#define sipNameNr_eventFilter 869
#define sipName_eventFilter &sipStrings_QtSvg[869]
#define sipNameNr_initPainter 881
#define sipName_initPainter &sipStrings_QtSvg[881]
#define sipNameNr_nativeEvent 893
#define sipName_nativeEvent &sipStrings_QtSvg[893]
#define sipNameNr_paintEngine 905
#define sipName_paintEngine &sipStrings_QtSvg[905]
#define sipNameNr_resizeEvent 917
#define sipName_resizeEvent &sipStrings_QtSvg[917]
#define sipNameNr_setFileName 929
#define sipName_setFileName &sipStrings_QtSvg[929]
#define sipNameNr_tabletEvent 941
#define sipName_tabletEvent &sipStrings_QtSvg[941]
#define sipNameNr_QSvgWidget 953
#define sipName_QSvgWidget &sipStrings_QtSvg[953]
#define sipNameNr_childEvent 964
#define sipName_childEvent &sipStrings_QtSvg[964]
#define sipNameNr_closeEvent 975
#define sipName_closeEvent &sipStrings_QtSvg[975]
#define sipNameNr_enterEvent 986
#define sipName_enterEvent &sipStrings_QtSvg[986]
#define sipNameNr_itemChange 997
#define sipName_itemChange &sipStrings_QtSvg[997]
#define sipNameNr_leaveEvent 1008
#define sipName_leaveEvent &sipStrings_QtSvg[1008]
#define sipNameNr_opaqueArea 1019
#define sipName_opaqueArea &sipStrings_QtSvg[1019]
#define sipNameNr_paintEvent 1030
#define sipName_paintEvent &sipStrings_QtSvg[1030]
#define sipNameNr_resolution 1041
#define sipName_resolution &sipStrings_QtSvg[1041]
#define sipNameNr_sceneEvent 1052
#define sipName_sceneEvent &sipStrings_QtSvg[1052]
#define sipNameNr_setViewBox 1063
#define sipName_setViewBox &sipStrings_QtSvg[1063]
#define sipNameNr_setVisible 1074
#define sipName_setVisible &sipStrings_QtSvg[1074]
#define sipNameNr_timerEvent 1085
#define sipName_timerEvent &sipStrings_QtSvg[1085]
#define sipNameNr_wheelEvent 1096
#define sipName_wheelEvent &sipStrings_QtSvg[1096]
#define sipNameNr_dropEvent 1107
#define sipName_dropEvent &sipStrings_QtSvg[1107]
#define sipNameNr_elementId 1117
#define sipName_elementId &sipStrings_QtSvg[1117]
#define sipNameNr_hideEvent 1127
#define sipName_hideEvent &sipStrings_QtSvg[1127]
#define sipNameNr_moveEvent 1137
#define sipName_moveEvent &sipStrings_QtSvg[1137]
#define sipNameNr_showEvent 1147
#define sipName_showEvent &sipStrings_QtSvg[1147]
#define sipNameNr_animated 1157
#define sipName_animated &sipStrings_QtSvg[1157]
#define sipNameNr_contains 1166
#define sipName_contains &sipStrings_QtSvg[1166]
#define sipNameNr_fileName 1175
#define sipName_fileName &sipStrings_QtSvg[1175]
#define sipNameNr_renderer 1184
#define sipName_renderer &sipStrings_QtSvg[1184]
#define sipNameNr_setTitle 1193
#define sipName_setTitle &sipStrings_QtSvg[1193]
#define sipNameNr_sizeHint 1202
#define sipName_sizeHint &sipStrings_QtSvg[1202]
#define sipNameNr_viewBoxF 1211
#define sipName_viewBoxF &sipStrings_QtSvg[1211]
#define sipNameNr_advance 1220
#define sipName_advance &sipStrings_QtSvg[1220]
#define sipNameNr_devType 1228
#define sipName_devType &sipStrings_QtSvg[1228]
#define sipNameNr_isValid 1236
#define sipName_isValid &sipStrings_QtSvg[1236]
#define sipNameNr_setSize 1244
#define sipName_setSize &sipStrings_QtSvg[1244]
#define sipNameNr_viewBox 1252
#define sipName_viewBox &sipStrings_QtSvg[1252]
#define sipNameNr_bounds 1260
#define sipName_bounds &sipStrings_QtSvg[1260]
#define sipNameNr_metric 1267
#define sipName_metric &sipStrings_QtSvg[1267]
#define sipNameNr_parent 1274
#define sipName_parent &sipStrings_QtSvg[1274]
#define sipNameNr_render 1281
#define sipName_render &sipStrings_QtSvg[1281]
#define sipNameNr_widget 1288
#define sipName_widget &sipStrings_QtSvg[1288]
#define sipNameNr_event 1295
#define sipName_event &sipStrings_QtSvg[1295]
#define sipNameNr_paint 1301
#define sipName_paint &sipStrings_QtSvg[1301]
#define sipNameNr_shape 1307
#define sipName_shape &sipStrings_QtSvg[1307]
#define sipNameNr_title 1313
#define sipName_title &sipStrings_QtSvg[1313]
#define sipNameNr_load 1319
#define sipName_load &sipStrings_QtSvg[1319]
#define sipNameNr_size 1324
#define sipName_size &sipStrings_QtSvg[1324]
#define sipNameNr_type 1329
#define sipName_type &sipStrings_QtSvg[1329]

#define sipMalloc                   sipAPI_QtSvg->api_malloc
#define sipFree                     sipAPI_QtSvg->api_free
#define sipBuildResult              sipAPI_QtSvg->api_build_result
#define sipCallMethod               sipAPI_QtSvg->api_call_method
#define sipCallProcedureMethod      sipAPI_QtSvg->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtSvg->api_call_error_handler
#define sipParseResultEx            sipAPI_QtSvg->api_parse_result_ex
#define sipParseResult              sipAPI_QtSvg->api_parse_result
#define sipParseArgs                sipAPI_QtSvg->api_parse_args
#define sipParseKwdArgs             sipAPI_QtSvg->api_parse_kwd_args
#define sipParsePair                sipAPI_QtSvg->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtSvg->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtSvg->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtSvg->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtSvg->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtSvg->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtSvg->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtSvg->api_add_exception
#define sipNoFunction               sipAPI_QtSvg->api_no_function
#define sipNoMethod                 sipAPI_QtSvg->api_no_method
#define sipAbstractMethod           sipAPI_QtSvg->api_abstract_method
#define sipBadClass                 sipAPI_QtSvg->api_bad_class
#define sipBadCatcherResult         sipAPI_QtSvg->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtSvg->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtSvg->api_bad_operator_arg
#define sipTrace                    sipAPI_QtSvg->api_trace
#define sipTransferBack             sipAPI_QtSvg->api_transfer_back
#define sipTransferTo               sipAPI_QtSvg->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtSvg->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtSvg->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtSvg->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtSvg->api_voidptr_type
#define sipGetPyObject              sipAPI_QtSvg->api_get_pyobject
#define sipGetAddress               sipAPI_QtSvg->api_get_address
#define sipGetMixinAddress          sipAPI_QtSvg->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtSvg->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtSvg->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtSvg->api_call_hook
#define sipEndThread                sipAPI_QtSvg->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtSvg->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtSvg->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtSvg->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtSvg->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtSvg->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtSvg->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtSvg->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtSvg->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtSvg->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtSvg->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtSvg->api_convert_to_bool
#define sipReleaseType              sipAPI_QtSvg->api_release_type
#define sipConvertFromType          sipAPI_QtSvg->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtSvg->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtSvg->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtSvg->api_convert_from_enum
#define sipGetState                 sipAPI_QtSvg->api_get_state
#define sipExportSymbol             sipAPI_QtSvg->api_export_symbol
#define sipImportSymbol             sipAPI_QtSvg->api_import_symbol
#define sipFindType                 sipAPI_QtSvg->api_find_type
#define sipBytes_AsChar             sipAPI_QtSvg->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtSvg->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtSvg->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtSvg->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtSvg->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtSvg->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtSvg->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtSvg->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtSvg->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtSvg->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtSvg->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtSvg->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtSvg->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtSvg->api_deprecated
#define sipGetReference             sipAPI_QtSvg->api_get_reference
#define sipKeepReference            sipAPI_QtSvg->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtSvg->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtSvg->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtSvg->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtSvg->api_type_scope
#define sipResolveTypedef           sipAPI_QtSvg->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtSvg->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtSvg->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtSvg->api_init_mixin
#define sipExportModule             sipAPI_QtSvg->api_export_module
#define sipInitModule               sipAPI_QtSvg->api_init_module
#define sipGetInterpreter           sipAPI_QtSvg->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtSvg->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtSvg->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtSvg->api_py_type_dict
#define sipPyTypeName               sipAPI_QtSvg->api_py_type_name
#define sipGetCFunction             sipAPI_QtSvg->api_get_c_function
#define sipGetMethod                sipAPI_QtSvg->api_get_method
#define sipFromMethod               sipAPI_QtSvg->api_from_method
#define sipGetDate                  sipAPI_QtSvg->api_get_date
#define sipFromDate                 sipAPI_QtSvg->api_from_date
#define sipGetDateTime              sipAPI_QtSvg->api_get_datetime
#define sipFromDateTime             sipAPI_QtSvg->api_from_datetime
#define sipGetTime                  sipAPI_QtSvg->api_get_time
#define sipFromTime                 sipAPI_QtSvg->api_from_time
#define sipIsUserType               sipAPI_QtSvg->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtSvg->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtSvg->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtSvg->api_unicode_write
#define sipUnicodeData              sipAPI_QtSvg->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtSvg->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtSvg->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtSvg->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtSvg->api_is_derived_class
#define sipGetUserObject            sipAPI_QtSvg->api_get_user_object
#define sipSetUserObject            sipAPI_QtSvg->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtSvg->api_register_event_handler
#define sipConvertToArray           sipAPI_QtSvg->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtSvg->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtSvg->api_enable_gc
#define sipPrintObject              sipAPI_QtSvg->api_print_object
#define sipLong_AsChar              sipAPI_QtSvg->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtSvg->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtSvg->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtSvg->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtSvg->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtSvg->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtSvg->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtSvg->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtSvg->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtSvg->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtSvg->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtSvg->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtSvg->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtSvg->api_register_exit_notifier
#define sipPyTypeDictRef            sipAPI_QtSvg->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtSvg->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtSvg->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtSvg->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtSvg->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtSvg->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtSvg->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtSvg->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtSvg->api_connect_rx
#define sipConvertRx                sipAPI_QtSvg->api_convert_rx
#define sipDisconnectRx             sipAPI_QtSvg->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtSvg->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtSvg->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtSvg->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtSvg->api_same_slot
#define sipSaveSlot                 sipAPI_QtSvg->api_save_slot
#define sipVisitSlot                sipAPI_QtSvg->api_visit_slot
#define sipIsPyMethod               sipAPI_QtSvg->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtSvg[];

#define sipType_QGraphicsSvgItem sipExportedTypes_QtSvg[0]

extern sipClassTypeDef sipTypeDef_QtSvg_QGraphicsSvgItem;

#define sipType_QSvgGenerator sipExportedTypes_QtSvg[1]

extern sipClassTypeDef sipTypeDef_QtSvg_QSvgGenerator;

#define sipType_QSvgRenderer sipExportedTypes_QtSvg[2]

extern sipClassTypeDef sipTypeDef_QtSvg_QSvgRenderer;

#define sipType_QSvgWidget sipExportedTypes_QtSvg[3]

extern sipClassTypeDef sipTypeDef_QtSvg_QSvgWidget;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtSvg;
extern sipExportedModuleDef sipModuleAPI_QtSvg;
extern sipTypeDef *sipExportedTypes_QtSvg[];

#define sipType_Qt_ItemSelectionMode sipImportedTypes_QtSvg_QtCore[16].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtSvg_QtCore[15].it_td

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtSvg_QtCore[14].it_td

#define sipType_QObject sipImportedTypes_QtSvg_QtCore[5].it_td

#define sipType_QIODevice sipImportedTypes_QtSvg_QtCore[3].it_td

#define sipType_QByteArray sipImportedTypes_QtSvg_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtSvg_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtSvg_QtCore[11].it_td

#define sipType_QChildEvent sipImportedTypes_QtSvg_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtSvg_QtCore[4].it_td

#define sipType_QPointF sipImportedTypes_QtSvg_QtCore[6].it_td

#define sipType_QRect sipImportedTypes_QtSvg_QtCore[7].it_td

#define sipType_QRectF sipImportedTypes_QtSvg_QtCore[8].it_td

#define sipType_QSize sipImportedTypes_QtSvg_QtCore[9].it_td

#define sipType_QVariant sipImportedTypes_QtSvg_QtCore[12].it_td

#define sipType_QXmlStreamReader sipImportedTypes_QtSvg_QtCore[13].it_td

#define sipType_QString sipImportedTypes_QtSvg_QtCore[10].it_td
extern sipImportedTypeDef sipImportedTypes_QtSvg_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSvg_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtSvg_QtGui[13].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtSvg_QtGui[14].it_td

#define sipType_QMouseEvent sipImportedTypes_QtSvg_QtGui[11].it_td

#define sipType_QWheelEvent sipImportedTypes_QtSvg_QtGui[23].it_td

#define sipType_QTabletEvent sipImportedTypes_QtSvg_QtGui[21].it_td

#define sipType_QKeyEvent sipImportedTypes_QtSvg_QtGui[10].it_td

#define sipType_QFocusEvent sipImportedTypes_QtSvg_QtGui[7].it_td

#define sipType_QPaintEvent sipImportedTypes_QtSvg_QtGui[16].it_td

#define sipType_QMoveEvent sipImportedTypes_QtSvg_QtGui[12].it_td

#define sipType_QResizeEvent sipImportedTypes_QtSvg_QtGui[19].it_td

#define sipType_QCloseEvent sipImportedTypes_QtSvg_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtSvg_QtGui[20].it_td

#define sipType_QHideEvent sipImportedTypes_QtSvg_QtGui[8].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtSvg_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtSvg_QtGui[9].it_td

#define sipType_QDropEvent sipImportedTypes_QtSvg_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtSvg_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtSvg_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtSvg_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtSvg_QtGui[0].it_td

#define sipType_QPainter sipImportedTypes_QtSvg_QtGui[17].it_td

#define sipType_QPaintEngine sipImportedTypes_QtSvg_QtGui[15].it_td

#define sipType_QPainterPath sipImportedTypes_QtSvg_QtGui[18].it_td

#define sipType_QTransform sipImportedTypes_QtSvg_QtGui[22].it_td
extern sipImportedTypeDef sipImportedTypes_QtSvg_QtGui[];

#define sipType_QWidget sipImportedTypes_QtSvg_QtWidgets[9].it_td

#define sipType_QGraphicsItem sipImportedTypes_QtSvg_QtWidgets[0].it_td

#define sipType_QGraphicsItem_GraphicsItemChange sipImportedTypes_QtSvg_QtWidgets[1].it_td

#define sipType_QGraphicsObject sipImportedTypes_QtSvg_QtWidgets[2].it_td

#define sipType_QGraphicsSceneMouseEvent sipImportedTypes_QtSvg_QtWidgets[6].it_td

#define sipType_QGraphicsSceneWheelEvent sipImportedTypes_QtSvg_QtWidgets[7].it_td

#define sipType_QGraphicsSceneContextMenuEvent sipImportedTypes_QtSvg_QtWidgets[3].it_td

#define sipType_QGraphicsSceneHoverEvent sipImportedTypes_QtSvg_QtWidgets[5].it_td

#define sipType_QGraphicsSceneDragDropEvent sipImportedTypes_QtSvg_QtWidgets[4].it_td

#define sipType_QStyleOptionGraphicsItem sipImportedTypes_QtSvg_QtWidgets[8].it_td
extern sipImportedTypeDef sipImportedTypes_QtSvg_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtSvg_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtSvg_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtSvg_qt_metacast;

#endif
