/*
 * Internal module API header file.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtGuiAPI_H
#define _QtGuiAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtGui[0]
#define sipNameNr_QOpenGLFramebufferObject__FramebufferRestorePolicy 53
#define sipName_QOpenGLFramebufferObject__FramebufferRestorePolicy &sipStrings_QtGui[53]
#define sipNameNr_QTextCharFormat__FontPropertiesInheritanceBehavior 104
#define sipName_QTextCharFormat__FontPropertiesInheritanceBehavior &sipStrings_QtGui[104]
#define sipNameNr_155 155
#define sipName_155 &sipStrings_QtGui[155]
#define sipNameNr_QAbstractTextDocumentLayout__PaintContext 203
#define sipName_QAbstractTextDocumentLayout__PaintContext &sipStrings_QtGui[203]
#define sipNameNr_QPlatformSurfaceEvent__SurfaceEventType 245
#define sipName_QPlatformSurfaceEvent__SurfaceEventType &sipStrings_QtGui[245]
#define sipNameNr_QAbstractTextDocumentLayout__Selection 285
#define sipName_QAbstractTextDocumentLayout__Selection &sipStrings_QtGui[285]
#define sipNameNr_AddSpaceForLineAndParagraphSeparators 324
#define sipName_AddSpaceForLineAndParagraphSeparators &sipStrings_QtGui[324]
#define sipNameNr_QOpenGLFramebufferObject__Attachment 362
#define sipName_QOpenGLFramebufferObject__Attachment &sipStrings_QtGui[362]
#define sipNameNr_QSurfaceFormat__OpenGLContextProfile 399
#define sipName_QSurfaceFormat__OpenGLContextProfile &sipStrings_QtGui[399]
#define sipNameNr_QIconEngine__AvailableSizesArgument 436
#define sipName_QIconEngine__AvailableSizesArgument &sipStrings_QtGui[436]
#define sipNameNr_472 472
#define sipName_472 &sipStrings_QtGui[472]
#define sipNameNr_508 508
#define sipName_508 &sipStrings_QtGui[508]
#define sipNameNr_QOpenGLTexture__CoordinateDirection 544
#define sipName_QOpenGLTexture__CoordinateDirection &sipStrings_QtGui[544]
#define sipNameNr_RasterOp_NotSourceAndNotDestination 580
#define sipName_RasterOp_NotSourceAndNotDestination &sipStrings_QtGui[580]
#define sipNameNr_mouseQuickSelectionThresholdChanged 616
#define sipName_mouseQuickSelectionThresholdChanged &sipStrings_QtGui[616]
#define sipNameNr_setHighDpiScaleFactorRoundingPolicy 652
#define sipName_setHighDpiScaleFactorRoundingPolicy &sipStrings_QtGui[652]
#define sipNameNr_QOpenGLTexture__ComparisonFunction 688
#define sipName_QOpenGLTexture__ComparisonFunction &sipStrings_QtGui[688]
#define sipNameNr_QTextCharFormat__VerticalAlignment 723
#define sipName_QTextCharFormat__VerticalAlignment &sipStrings_QtGui[723]
#define sipNameNr_QTouchEvent__TouchPoint__InfoFlags 758
#define sipName_QTouchEvent__TouchPoint__InfoFlags &sipStrings_QtGui[758]
#define sipNameNr_RasterOp_NotSourceOrNotDestination 793
#define sipName_RasterOp_NotSourceOrNotDestination &sipStrings_QtGui[793]
#define sipNameNr_RestoreFramebufferBindingToDefault 828
#define sipName_RestoreFramebufferBindingToDefault &sipStrings_QtGui[828]
#define sipNameNr_showShortcutsInContextMenusChanged 863
#define sipName_showShortcutsInContextMenusChanged &sipStrings_QtGui[863]
#define sipNameNr_BlockTrailingHorizontalRulerWidth 898
#define sipName_BlockTrailingHorizontalRulerWidth &sipStrings_QtGui[898]
#define sipNameNr_FontPropertiesInheritanceBehavior 121
#define sipName_FontPropertiesInheritanceBehavior &sipStrings_QtGui[121]
#define sipNameNr_QIconEngine__ScaledPixmapArgument 932
#define sipName_QIconEngine__ScaledPixmapArgument &sipStrings_QtGui[932]
#define sipNameNr_QPaintEngine__PaintEngineFeatures 966
#define sipName_QPaintEngine__PaintEngineFeatures &sipStrings_QtGui[966]
#define sipNameNr_QTextBlockFormat__LineHeightTypes 1000
#define sipName_QTextBlockFormat__LineHeightTypes &sipStrings_QtGui[1000]
#define sipNameNr_QTouchEvent__TouchPoint__InfoFlag 1034
#define sipName_QTouchEvent__TouchPoint__InfoFlag &sipStrings_QtGui[1034]
#define sipNameNr_1068 1068
#define sipName_1068 &sipStrings_QtGui[1068]
#define sipNameNr_setDefaultInnerTessellationLevels 1102
#define sipName_setDefaultInnerTessellationLevels &sipStrings_QtGui[1102]
#define sipNameNr_setDefaultOuterTessellationLevels 1136
#define sipName_setDefaultOuterTessellationLevels &sipStrings_QtGui[1136]
#define sipNameNr_QImageIOHandler__Transformations 1170
#define sipName_QImageIOHandler__Transformations &sipStrings_QtGui[1170]
#define sipNameNr_QInputMethodEvent__AttributeType 1203
#define sipName_QInputMethodEvent__AttributeType &sipStrings_QtGui[1203]
#define sipNameNr_QOpenGLContext__OpenGLModuleType 1236
#define sipName_QOpenGLContext__OpenGLModuleType &sipStrings_QtGui[1236]
#define sipNameNr_QOpenGLTexture__DepthStencilMode 1269
#define sipName_QOpenGLTexture__DepthStencilMode &sipStrings_QtGui[1269]
#define sipNameNr_QOpenGLTexture__MipMapGeneration 1302
#define sipName_QOpenGLTexture__MipMapGeneration &sipStrings_QtGui[1302]
#define sipNameNr_QOpenGLTexture__SwizzleComponent 1335
#define sipName_QOpenGLTexture__SwizzleComponent &sipStrings_QtGui[1335]
#define sipNameNr_QOpenGLTexture__TextureUnitReset 1368
#define sipName_QOpenGLTexture__TextureUnitReset &sipStrings_QtGui[1368]
#define sipNameNr_QOpenGLVertexArrayObject__Binder 1401
#define sipName_QOpenGLVertexArrayObject__Binder &sipStrings_QtGui[1401]
#define sipNameNr_QPaintEngine__PaintEngineFeature 1434
#define sipName_QPaintEngine__PaintEngineFeature &sipStrings_QtGui[1434]
#define sipNameNr_QPixelFormat__AlphaPremultiplied 1467
#define sipName_QPixelFormat__AlphaPremultiplied &sipStrings_QtGui[1467]
#define sipNameNr_QPixelFormat__TypeInterpretation 1500
#define sipName_QPixelFormat__TypeInterpretation &sipStrings_QtGui[1500]
#define sipNameNr_RasterOp_NotSourceAndDestination 1533
#define sipName_RasterOp_NotSourceAndDestination &sipStrings_QtGui[1533]
#define sipNameNr_RasterOp_NotSourceXorDestination 1566
#define sipName_RasterOp_NotSourceXorDestination &sipStrings_QtGui[1566]
#define sipNameNr_RasterOp_SourceAndNotDestination 1599
#define sipName_RasterOp_SourceAndNotDestination &sipStrings_QtGui[1599]
#define sipNameNr_addCacheableShaderFromSourceCode 1632
#define sipName_addCacheableShaderFromSourceCode &sipStrings_QtGui[1632]
#define sipNameNr_addCacheableShaderFromSourceFile 1665
#define sipName_addCacheableShaderFromSourceFile &sipStrings_QtGui[1665]
#define sipNameNr_highDpiScaleFactorRoundingPolicy 1698
#define sipName_highDpiScaleFactorRoundingPolicy &sipStrings_QtGui[1698]
#define sipNameNr_mousePressAndHoldIntervalChanged 1731
#define sipName_mousePressAndHoldIntervalChanged &sipStrings_QtGui[1731]
#define sipNameNr_BindingTarget2DMultisampleArray 1764
#define sipName_BindingTarget2DMultisampleArray &sipStrings_QtGui[1764]
#define sipNameNr_CompositionMode_DestinationAtop 1796
#define sipName_CompositionMode_DestinationAtop &sipStrings_QtGui[1796]
#define sipNameNr_CompositionMode_DestinationOver 1828
#define sipName_CompositionMode_DestinationOver &sipStrings_QtGui[1828]
#define sipNameNr_QImageIOHandler__Transformation 1860
#define sipName_QImageIOHandler__Transformation &sipStrings_QtGui[1860]
#define sipNameNr_1892 1892
#define sipName_1892 &sipStrings_QtGui[1892]
#define sipNameNr_QOpenGLBuffer__RangeAccessFlags 1924
#define sipName_QOpenGLBuffer__RangeAccessFlags &sipStrings_QtGui[1924]
#define sipNameNr_QOpenGLDebugLogger__LoggingMode 1956
#define sipName_QOpenGLDebugLogger__LoggingMode &sipStrings_QtGui[1956]
#define sipNameNr_QOpenGLDebugMessage__Severities 1988
#define sipName_QOpenGLDebugMessage__Severities &sipStrings_QtGui[1988]
#define sipNameNr_QPaintDevice__PaintDeviceMetric 2020
#define sipName_QPaintDevice__PaintDeviceMetric &sipStrings_QtGui[2020]
#define sipNameNr_QTextCharFormat__UnderlineStyle 2052
#define sipName_QTextCharFormat__UnderlineStyle &sipStrings_QtGui[2052]
#define sipNameNr_QTextDocument__MarkdownFeatures 2084
#define sipName_QTextDocument__MarkdownFeatures &sipStrings_QtGui[2084]
#define sipNameNr_RasterOp_NotSourceOrDestination 2116
#define sipName_RasterOp_NotSourceOrDestination &sipStrings_QtGui[2116]
#define sipNameNr_RasterOp_SourceOrNotDestination 2148
#define sipName_RasterOp_SourceOrNotDestination &sipStrings_QtGui[2148]
#define sipNameNr_TransformationMirrorAndRotate90 2180
#define sipName_TransformationMirrorAndRotate90 &sipStrings_QtGui[2180]
#define sipNameNr_mouseDoubleClickIntervalChanged 2212
#define sipName_mouseDoubleClickIntervalChanged &sipStrings_QtGui[2212]
#define sipNameNr_CompositionMode_DestinationOut 2244
#define sipName_CompositionMode_DestinationOut &sipStrings_QtGui[2244]
#define sipNameNr_QImageReader__ImageReaderError 2275
#define sipName_QImageReader__ImageReaderError &sipStrings_QtGui[2275]
#define sipNameNr_QImageWriter__ImageWriterError 2306
#define sipName_QImageWriter__ImageWriterError &sipStrings_QtGui[2306]
#define sipNameNr_2337 2337
#define sipName_2337 &sipStrings_QtGui[2337]
#define sipNameNr_QOpenGLBuffer__RangeAccessFlag 2368
#define sipName_QOpenGLBuffer__RangeAccessFlag &sipStrings_QtGui[2368]
#define sipNameNr_QOpenGLFramebufferObjectFormat 2399
#define sipName_QOpenGLFramebufferObjectFormat &sipStrings_QtGui[2399]
#define sipNameNr_QOpenGLTexture__ComparisonMode 2430
#define sipName_QOpenGLTexture__ComparisonMode &sipStrings_QtGui[2430]
#define sipNameNr_QSurfaceFormat__RenderableType 2461
#define sipName_QSurfaceFormat__RenderableType &sipStrings_QtGui[2461]
#define sipNameNr_QTextDocument__MarkdownFeature 2492
#define sipName_QTextDocument__MarkdownFeature &sipStrings_QtGui[2492]
#define sipNameNr_QTextDocument__MetaInformation 2523
#define sipName_QTextDocument__MetaInformation &sipStrings_QtGui[2523]
#define sipNameNr_QTransform__TransformationType 2554
#define sipName_QTransform__TransformationType &sipStrings_QtGui[2554]
#define sipNameNr_SRGB8_PunchThrough_Alpha1_ETC2 2585
#define sipName_SRGB8_PunchThrough_Alpha1_ETC2 &sipStrings_QtGui[2585]
#define sipNameNr_ShowLineAndParagraphSeparators 2616
#define sipName_ShowLineAndParagraphSeparators &sipStrings_QtGui[2616]
#define sipNameNr_defaultInnerTessellationLevels 2647
#define sipName_defaultInnerTessellationLevels &sipStrings_QtGui[2647]
#define sipNameNr_defaultOuterTessellationLevels 2678
#define sipName_defaultOuterTessellationLevels &sipStrings_QtGui[2678]
#define sipNameNr_reportContentOrientationChange 2709
#define sipName_reportContentOrientationChange &sipStrings_QtGui[2709]
#define sipNameNr_setAutoMipMapGenerationEnabled 2740
#define sipName_setAutoMipMapGenerationEnabled &sipStrings_QtGui[2740]
#define sipNameNr_setShowShortcutsInContextMenus 2771
#define sipName_setShowShortcutsInContextMenus &sipStrings_QtGui[2771]
#define sipNameNr_CompositionMode_DestinationIn 2802
#define sipName_CompositionMode_DestinationIn &sipStrings_QtGui[2802]
#define sipNameNr_DontRestoreFramebufferBinding 2832
#define sipName_DontRestoreFramebufferBinding &sipStrings_QtGui[2832]
#define sipNameNr_Format_ARGB4444_Premultiplied 2862
#define sipName_Format_ARGB4444_Premultiplied &sipStrings_QtGui[2862]
#define sipNameNr_Format_ARGB6666_Premultiplied 2892
#define sipName_Format_ARGB6666_Premultiplied &sipStrings_QtGui[2892]
#define sipNameNr_Format_ARGB8555_Premultiplied 2922
#define sipName_Format_ARGB8555_Premultiplied &sipStrings_QtGui[2922]
#define sipNameNr_Format_ARGB8565_Premultiplied 2952
#define sipName_Format_ARGB8565_Premultiplied &sipStrings_QtGui[2952]
#define sipNameNr_Format_RGBA8888_Premultiplied 2982
#define sipName_Format_RGBA8888_Premultiplied &sipStrings_QtGui[2982]
#define sipNameNr_QColorSpace__TransferFunction 3012
#define sipName_QColorSpace__TransferFunction &sipStrings_QtGui[3012]
#define sipNameNr_QOpenGLDebugMessage__Severity 3042
#define sipName_QOpenGLDebugMessage__Severity &sipStrings_QtGui[3042]
#define sipNameNr_QOpenGLTexture__BindingTarget 3072
#define sipName_QOpenGLTexture__BindingTarget &sipStrings_QtGui[3072]
#define sipNameNr_QOpenGLTexture__TextureFormat 3102
#define sipName_QOpenGLTexture__TextureFormat &sipStrings_QtGui[3102]
#define sipNameNr_QOpenGLTextureBlitter__Origin 3132
#define sipName_QOpenGLTextureBlitter__Origin &sipStrings_QtGui[3132]
#define sipNameNr_QOpenGLWindow__UpdateBehavior 3162
#define sipName_QOpenGLWindow__UpdateBehavior &sipStrings_QtGui[3162]
#define sipNameNr_QPagedPaintDevice__PdfVersion 3192
#define sipName_QPagedPaintDevice__PdfVersion &sipStrings_QtGui[3192]
#define sipNameNr_QPaintEngine__PolygonDrawMode 3222
#define sipName_QPaintEngine__PolygonDrawMode &sipStrings_QtGui[3222]
#define sipNameNr_QPainter__PixmapFragmentHints 3252
#define sipName_QPainter__PixmapFragmentHints &sipStrings_QtGui[3252]
#define sipNameNr_QSurfaceFormat__FormatOptions 3282
#define sipName_QSurfaceFormat__FormatOptions &sipStrings_QtGui[3282]
#define sipNameNr_QTextFrameFormat__BorderStyle 3312
#define sipName_QTextFrameFormat__BorderStyle &sipStrings_QtGui[3312]
#define sipNameNr_3342 3342
#define sipName_3342 &sipStrings_QtGui[3342]
#define sipNameNr_RGB8_PunchThrough_Alpha1_ETC2 2586
#define sipName_RGB8_PunchThrough_Alpha1_ETC2 &sipStrings_QtGui[2586]
#define sipNameNr_RasterOp_SourceAndDestination 3372
#define sipName_RasterOp_SourceAndDestination &sipStrings_QtGui[3372]
#define sipNameNr_RasterOp_SourceXorDestination 3402
#define sipName_RasterOp_SourceXorDestination &sipStrings_QtGui[3402]
#define sipNameNr_TransformationFlipAndRotate90 3432
#define sipName_TransformationFlipAndRotate90 &sipStrings_QtGui[3432]
#define sipNameNr_applicationDisplayNameChanged 3462
#define sipName_applicationDisplayNameChanged &sipStrings_QtGui[3462]
#define sipNameNr_inputItemClipRectangleChanged 3492
#define sipName_inputItemClipRectangleChanged &sipStrings_QtGui[3492]
#define sipNameNr_isAutoMipMapGenerationEnabled 3522
#define sipName_isAutoMipMapGenerationEnabled &sipStrings_QtGui[3522]
#define sipNameNr_qt_set_sequence_auto_mnemonic 3552
#define sipName_qt_set_sequence_auto_mnemonic &sipStrings_QtGui[3552]
#define sipNameNr_supportsThreadedFontRendering 3582
#define sipName_supportsThreadedFontRendering &sipStrings_QtGui[3582]
#define sipNameNr_Format_A2BGR30_Premultiplied 3612
#define sipName_Format_A2BGR30_Premultiplied &sipStrings_QtGui[3612]
#define sipNameNr_Format_A2RGB30_Premultiplied 3641
#define sipName_Format_A2RGB30_Premultiplied &sipStrings_QtGui[3641]
#define sipNameNr_QColorSpace__NamedColorSpace 3670
#define sipName_QColorSpace__NamedColorSpace &sipStrings_QtGui[3670]
#define sipNameNr_QFontDatabase__WritingSystem 3699
#define sipName_QFontDatabase__WritingSystem &sipStrings_QtGui[3699]
#define sipNameNr_QImageIOHandler__ImageOption 3728
#define sipName_QImageIOHandler__ImageOption &sipStrings_QtGui[3728]
#define sipNameNr_QInputMethodEvent__Attribute 3757
#define sipName_QInputMethodEvent__Attribute &sipStrings_QtGui[3757]
#define sipNameNr_QKeySequence__SequenceFormat 3786
#define sipName_QKeySequence__SequenceFormat &sipStrings_QtGui[3786]
#define sipNameNr_QOpenGLDebugMessage__Sources 3815
#define sipName_QOpenGLDebugMessage__Sources &sipStrings_QtGui[3815]
#define sipNameNr_QOpenGLShader__ShaderTypeBit 3844
#define sipName_QOpenGLShader__ShaderTypeBit &sipStrings_QtGui[3844]
#define sipNameNr_QOpenGLTexture__SwizzleValue 3873
#define sipName_QOpenGLTexture__SwizzleValue &sipStrings_QtGui[3873]
#define sipNameNr_QPainter__PixmapFragmentHint 3902
#define sipName_QPainter__PixmapFragmentHint &sipStrings_QtGui[3902]
#define sipNameNr_QStaticText__PerformanceHint 3931
#define sipName_QStaticText__PerformanceHint &sipStrings_QtGui[3931]
#define sipNameNr_QSurfaceFormat__FormatOption 3960
#define sipName_QSurfaceFormat__FormatOption &sipStrings_QtGui[3960]
#define sipNameNr_QSurfaceFormat__SwapBehavior 3989
#define sipName_QSurfaceFormat__SwapBehavior &sipStrings_QtGui[3989]
#define sipNameNr_QTextBlockFormat__MarkerType 4018
#define sipName_QTextBlockFormat__MarkerType &sipStrings_QtGui[4018]
#define sipNameNr_QTouchDevice__CapabilityFlag 4047
#define sipName_QTouchDevice__CapabilityFlag &sipStrings_QtGui[4047]
#define sipNameNr_RasterOp_SourceOrDestination 4076
#define sipName_RasterOp_SourceOrDestination &sipStrings_QtGui[4076]
#define sipNameNr_WrapAtWordBoundaryOrAnywhere 4105
#define sipName_WrapAtWordBoundaryOrAnywhere &sipStrings_QtGui[4105]
#define sipNameNr_keyboardInputIntervalChanged 4134
#define sipName_keyboardInputIntervalChanged &sipStrings_QtGui[4134]
#define sipNameNr_mouseQuickSelectionThreshold 4163
#define sipName_mouseQuickSelectionThreshold &sipStrings_QtGui[4163]
#define sipNameNr_setLeastSignificantByteFirst 4192
#define sipName_setLeastSignificantByteFirst &sipStrings_QtGui[4192]
#define sipNameNr_CompositionMode_Destination 4221
#define sipName_CompositionMode_Destination &sipStrings_QtGui[4221]
#define sipNameNr_FontPropertiesSpecifiedOnly 4249
#define sipName_FontPropertiesSpecifiedOnly &sipStrings_QtGui[4249]
#define sipNameNr_Format_ARGB32_Premultiplied 4277
#define sipName_Format_ARGB32_Premultiplied &sipStrings_QtGui[4277]
#define sipNameNr_Format_RGBA64_Premultiplied 4305
#define sipName_Format_RGBA64_Premultiplied &sipStrings_QtGui[4305]
#define sipNameNr_ImmutableMultisampleStorage 4333
#define sipName_ImmutableMultisampleStorage &sipStrings_QtGui[4333]
#define sipNameNr_ObjectBoundingModeGradients 4361
#define sipName_ObjectBoundingModeGradients &sipStrings_QtGui[4361]
#define sipNameNr_QAbstractTextDocumentLayout 4389
#define sipName_QAbstractTextDocumentLayout &sipStrings_QtGui[4389]
#define sipNameNr_QIconEngine__IconEngineHook 4417
#define sipName_QIconEngine__IconEngineHook &sipStrings_QtGui[4417]
#define sipNameNr_QKeySequence__SequenceMatch 4445
#define sipName_QKeySequence__SequenceMatch &sipStrings_QtGui[4445]
#define sipNameNr_QOpenGLBuffer__UsagePattern 4473
#define sipName_QOpenGLBuffer__UsagePattern &sipStrings_QtGui[4473]
#define sipNameNr_QOpenGLDebugMessage__Source 4501
#define sipName_QOpenGLDebugMessage__Source &sipStrings_QtGui[4501]
#define sipNameNr_QOpenGLPixelTransferOptions 4529
#define sipName_QOpenGLPixelTransferOptions &sipStrings_QtGui[4529]
#define sipNameNr_QOpenGLTexture__CubeMapFace 4557
#define sipName_QOpenGLTexture__CubeMapFace &sipStrings_QtGui[4557]
#define sipNameNr_QOpenGLTexture__PixelFormat 4585
#define sipName_QOpenGLTexture__PixelFormat &sipStrings_QtGui[4585]
#define sipNameNr_QPagedPaintDevice__PageSize 4613
#define sipName_QPagedPaintDevice__PageSize &sipStrings_QtGui[4613]
#define sipNameNr_QPixelFormat__AlphaPosition 4641
#define sipName_QPixelFormat__AlphaPosition &sipStrings_QtGui[4641]
#define sipNameNr_QRegularExpressionValidator 4669
#define sipName_QRegularExpressionValidator &sipStrings_QtGui[4669]
#define sipNameNr_QTextDocument__ResourceType 4697
#define sipName_QTextDocument__ResourceType &sipStrings_QtGui[4697]
#define sipNameNr_QTextFormat__PageBreakFlags 4725
#define sipName_QTextFormat__PageBreakFlags &sipStrings_QtGui[4725]
#define sipNameNr_TableColumnWidthConstraints 4753
#define sipName_TableColumnWidthConstraints &sipStrings_QtGui[4753]
#define sipNameNr_clearColumnWidthConstraints 4781
#define sipName_clearColumnWidthConstraints &sipStrings_QtGui[4781]
#define sipNameNr_hasOpenGLFramebufferObjects 4809
#define sipName_hasOpenGLFramebufferObjects &sipStrings_QtGui[4809]
#define sipNameNr_showShortcutsInContextMenus 4837
#define sipName_showShortcutsInContextMenus &sipStrings_QtGui[4837]
#define sipNameNr_BindingTarget2DMultisample 4865
#define sipName_BindingTarget2DMultisample &sipStrings_QtGui[4865]
#define sipNameNr_CompositionMode_ColorDodge 4892
#define sipName_CompositionMode_ColorDodge &sipStrings_QtGui[4892]
#define sipNameNr_CompositionMode_Difference 4919
#define sipName_CompositionMode_Difference &sipStrings_QtGui[4919]
#define sipNameNr_CompositionMode_SourceAtop 4946
#define sipName_CompositionMode_SourceAtop &sipStrings_QtGui[4946]
#define sipNameNr_CompositionMode_SourceOver 4973
#define sipName_CompositionMode_SourceOver &sipStrings_QtGui[4973]
#define sipNameNr_QDoubleValidator__Notation 5000
#define sipName_QDoubleValidator__Notation &sipStrings_QtGui[5000]
#define sipNameNr_5027 5027
#define sipName_5027 &sipStrings_QtGui[5027]
#define sipNameNr_QOpenGLDebugMessage__Types 5054
#define sipName_QOpenGLDebugMessage__Types &sipStrings_QtGui[5054]
#define sipNameNr_QPageSize__SizeMatchPolicy 5081
#define sipName_QPageSize__SizeMatchPolicy &sipStrings_QtGui[5081]
#define sipNameNr_QPagedPaintDevice__Margins 5108
#define sipName_QPagedPaintDevice__Margins &sipStrings_QtGui[5108]
#define sipNameNr_QRawFont__AntialiasingType 5135
#define sipName_QRawFont__AntialiasingType &sipStrings_QtGui[5135]
#define sipNameNr_QSurfaceFormat__ColorSpace 5162
#define sipName_QSurfaceFormat__ColorSpace &sipStrings_QtGui[5162]
#define sipNameNr_QTabletEvent__TabletDevice 5189
#define sipName_QTabletEvent__TabletDevice &sipStrings_QtGui[5189]
#define sipNameNr_QTextCursor__MoveOperation 5216
#define sipName_QTextCursor__MoveOperation &sipStrings_QtGui[5216]
#define sipNameNr_QTextCursor__SelectionType 5243
#define sipName_QTextCursor__SelectionType &sipStrings_QtGui[5243]
#define sipNameNr_QTextFormat__PageBreakFlag 5270
#define sipName_QTextFormat__PageBreakFlag &sipStrings_QtGui[5270]
#define sipNameNr_QTextFrameFormat__Position 5297
#define sipName_QTextFrameFormat__Position &sipStrings_QtGui[5297]
#define sipNameNr_QTouchDevice__Capabilities 5324
#define sipName_QTouchDevice__Capabilities &sipStrings_QtGui[5324]
#define sipNameNr_TableCellBottomBorderBrush 5351
#define sipName_TableCellBottomBorderBrush &sipStrings_QtGui[5351]
#define sipNameNr_TableCellBottomBorderStyle 5378
#define sipName_TableCellBottomBorderStyle &sipStrings_QtGui[5378]
#define sipNameNr_TextureComparisonOperators 5405
#define sipName_TextureComparisonOperators &sipStrings_QtGui[5405]
#define sipNameNr_addApplicationFontFromData 5432
#define sipName_addApplicationFontFromData &sipStrings_QtGui[5432]
#define sipNameNr_isLeastSignificantBitFirst 5459
#define sipName_isLeastSignificantBitFirst &sipStrings_QtGui[5459]
#define sipNameNr_physicalDotsPerInchChanged 5486
#define sipName_physicalDotsPerInchChanged &sipStrings_QtGui[5486]
#define sipNameNr_setDecideFormatFromContent 5513
#define sipName_setDecideFormatFromContent &sipStrings_QtGui[5513]
#define sipNameNr_transformationToColorSpace 5540
#define sipName_transformationToColorSpace &sipStrings_QtGui[5540]
#define sipNameNr_BindingTargetCubeMapArray 5567
#define sipName_BindingTargetCubeMapArray &sipStrings_QtGui[5567]
#define sipNameNr_CompositionMode_ColorBurn 5593
#define sipName_CompositionMode_ColorBurn &sipStrings_QtGui[5593]
#define sipNameNr_CompositionMode_Exclusion 5619
#define sipName_CompositionMode_Exclusion &sipStrings_QtGui[5619]
#define sipNameNr_CompositionMode_HardLight 5645
#define sipName_CompositionMode_HardLight &sipStrings_QtGui[5645]
#define sipNameNr_CompositionMode_SoftLight 5671
#define sipName_CompositionMode_SoftLight &sipStrings_QtGui[5671]
#define sipNameNr_CompositionMode_SourceOut 5697
#define sipName_CompositionMode_SourceOut &sipStrings_QtGui[5697]
#define sipNameNr_Float32_D32_UInt32_S8_X24 5723
#define sipName_Float32_D32_UInt32_S8_X24 &sipStrings_QtGui[5723]
#define sipNameNr_MarkdownDialectCommonMark 5749
#define sipName_MarkdownDialectCommonMark &sipStrings_QtGui[5749]
#define sipNameNr_PdmDevicePixelRatioScaled 5775
#define sipName_PdmDevicePixelRatioScaled &sipStrings_QtGui[5775]
#define sipNameNr_QContextMenuEvent__Reason 5801
#define sipName_QContextMenuEvent__Reason &sipStrings_QtGui[5801]
#define sipNameNr_QFontDatabase__SystemFont 5827
#define sipName_QFontDatabase__SystemFont &sipStrings_QtGui[5827]
#define sipNameNr_QGradient__CoordinateMode 5853
#define sipName_QGradient__CoordinateMode &sipStrings_QtGui[5853]
#define sipNameNr_QKeySequence__StandardKey 5879
#define sipName_QKeySequence__StandardKey &sipStrings_QtGui[5879]
#define sipNameNr_QOpenGLDebugMessage__Type 5905
#define sipName_QOpenGLDebugMessage__Type &sipStrings_QtGui[5905]
#define sipNameNr_QOpenGLShader__ShaderType 5931
#define sipName_QOpenGLShader__ShaderType &sipStrings_QtGui[5931]
#define sipNameNr_QOpenGLTexture__PixelType 5957
#define sipName_QOpenGLTexture__PixelType &sipStrings_QtGui[5957]
#define sipNameNr_QPainter__CompositionMode 5983
#define sipName_QPainter__CompositionMode &sipStrings_QtGui[5983]
#define sipNameNr_QPainterPath__ElementType 6009
#define sipName_QPainterPath__ElementType &sipStrings_QtGui[6009]
#define sipNameNr_QScrollEvent__ScrollState 6035
#define sipName_QScrollEvent__ScrollState &sipStrings_QtGui[6035]
#define sipNameNr_QTabletEvent__PointerType 6061
#define sipName_QTabletEvent__PointerType &sipStrings_QtGui[6061]
#define sipNameNr_QTextLine__CursorPosition 6087
#define sipName_QTextLine__CursorPosition &sipStrings_QtGui[6087]
#define sipNameNr_RasterOp_ClearDestination 6113
#define sipName_RasterOp_ClearDestination &sipStrings_QtGui[6113]
#define sipNameNr_RestoreFrameBufferBinding 6139
#define sipName_RestoreFrameBufferBinding &sipStrings_QtGui[6139]
#define sipNameNr_SurfaceAboutToBeDestroyed 6165
#define sipName_SurfaceAboutToBeDestroyed &sipStrings_QtGui[6165]
#define sipNameNr_TableCellRightBorderBrush 6191
#define sipName_TableCellRightBorderBrush &sipStrings_QtGui[6191]
#define sipNameNr_TableCellRightBorderStyle 6217
#define sipName_TableCellRightBorderStyle &sipStrings_QtGui[6217]
#define sipNameNr_contentOrientationChanged 6243
#define sipName_contentOrientationChanged &sipStrings_QtGui[6243]
#define sipNameNr_logicalDotsPerInchChanged 6269
#define sipName_logicalDotsPerInchChanged &sipStrings_QtGui[6269]
#define sipNameNr_maxGeometryOutputVertices 6295
#define sipName_maxGeometryOutputVertices &sipStrings_QtGui[6295]
#define sipNameNr_mousePressAndHoldInterval 6321
#define sipName_mousePressAndHoldInterval &sipStrings_QtGui[6321]
#define sipNameNr_primaryOrientationChanged 6347
#define sipName_primaryOrientationChanged &sipStrings_QtGui[6347]
#define sipNameNr_removeAllApplicationFonts 6373
#define sipName_removeAllApplicationFonts &sipStrings_QtGui[6373]
#define sipNameNr_setApplicationDisplayName 6399
#define sipName_setApplicationDisplayName &sipStrings_QtGui[6399]
#define sipNameNr_setColumnWidthConstraints 6425
#define sipName_setColumnWidthConstraints &sipStrings_QtGui[6425]
#define sipNameNr_setDefaultCursorMoveStyle 6451
#define sipName_setDefaultCursorMoveStyle &sipStrings_QtGui[6451]
#define sipNameNr_setHorizontalHeaderLabels 6477
#define sipName_setHorizontalHeaderLabels &sipStrings_QtGui[6477]
#define sipNameNr_setQuitOnLastWindowClosed 6503
#define sipName_setQuitOnLastWindowClosed &sipStrings_QtGui[6503]
#define sipNameNr_supportsExternalOESTarget 6529
#define sipName_supportsExternalOESTarget &sipStrings_QtGui[6529]
#define sipNameNr_CompositionMode_Multiply 6555
#define sipName_CompositionMode_Multiply &sipStrings_QtGui[6555]
#define sipNameNr_CompositionMode_SourceIn 6580
#define sipName_CompositionMode_SourceIn &sipStrings_QtGui[6580]
#define sipNameNr_FramebufferRestorePolicy 79
#define sipName_FramebufferRestorePolicy &sipStrings_QtGui[79]
#define sipNameNr_InsertParagraphSeparator 6605
#define sipName_InsertParagraphSeparator &sipStrings_QtGui[6605]
#define sipNameNr_QAbstractOpenGLFunctions 6630
#define sipName_QAbstractOpenGLFunctions &sipStrings_QtGui[6630]
#define sipNameNr_QFont__HintingPreference 6655
#define sipName_QFont__HintingPreference &sipStrings_QtGui[6655]
#define sipNameNr_QGlyphRun__GlyphRunFlags 6680
#define sipName_QGlyphRun__GlyphRunFlags &sipStrings_QtGui[6680]
#define sipNameNr_QOpenGLFramebufferObject 6705
#define sipName_QOpenGLFramebufferObject &sipStrings_QtGui[6705]
#define sipNameNr_QOpenGLTexture__Features 6730
#define sipName_QOpenGLTexture__Features &sipStrings_QtGui[6730]
#define sipNameNr_QOpenGLTexture__WrapMode 6755
#define sipName_QOpenGLTexture__WrapMode &sipStrings_QtGui[6755]
#define sipNameNr_QOpenGLVertexArrayObject 6780
#define sipName_QOpenGLVertexArrayObject &sipStrings_QtGui[6780]
#define sipNameNr_QPageLayout__Orientation 6805
#define sipName_QPageLayout__Orientation &sipStrings_QtGui[6805]
#define sipNameNr_QPaintEngine__DirtyFlags 6830
#define sipName_QPaintEngine__DirtyFlags &sipStrings_QtGui[6830]
#define sipNameNr_QPainter__PixmapFragment 6855
#define sipName_QPainter__PixmapFragment &sipStrings_QtGui[6855]
#define sipNameNr_QPixelFormat__AlphaUsage 6880
#define sipName_QPixelFormat__AlphaUsage &sipStrings_QtGui[6880]
#define sipNameNr_QPixelFormat__ColorModel 6905
#define sipName_QPixelFormat__ColorModel &sipStrings_QtGui[6905]
#define sipNameNr_QTextDocument__FindFlags 6930
#define sipName_QTextDocument__FindFlags &sipStrings_QtGui[6930]
#define sipNameNr_QTextFormat__ObjectTypes 6955
#define sipName_QTextFormat__ObjectTypes &sipStrings_QtGui[6955]
#define sipNameNr_QTextLayout__FormatRange 6980
#define sipName_QTextLayout__FormatRange &sipStrings_QtGui[6980]
#define sipNameNr_QTouchDevice__DeviceType 7005
#define sipName_QTouchDevice__DeviceType &sipStrings_QtGui[7005]
#define sipNameNr_TableCellLeftBorderBrush 7030
#define sipName_TableCellLeftBorderBrush &sipStrings_QtGui[7030]
#define sipNameNr_TableCellLeftBorderStyle 7055
#define sipName_TableCellLeftBorderStyle &sipStrings_QtGui[7055]
#define sipNameNr_Target2DMultisampleArray 1771
#define sipName_Target2DMultisampleArray &sipStrings_QtGui[1771]
#define sipNameNr_availableGeometryChanged 7080
#define sipName_availableGeometryChanged &sipStrings_QtGui[7080]
#define sipNameNr_availableVirtualGeometry 7105
#define sipName_availableVirtualGeometry &sipStrings_QtGui[7105]
#define sipNameNr_createApplicationMessage 7130
#define sipName_createApplicationMessage &sipStrings_QtGui[7130]
#define sipNameNr_defaultFramebufferObject 7155
#define sipName_defaultFramebufferObject &sipStrings_QtGui[7155]
#define sipNameNr_hasOpenGLFramebufferBlit 7180
#define sipName_hasOpenGLFramebufferBlit &sipStrings_QtGui[7180]
#define sipNameNr_keyboardRectangleChanged 7205
#define sipName_keyboardRectangleChanged &sipStrings_QtGui[7205]
#define sipNameNr_mouseDoubleClickDistance 7230
#define sipName_mouseDoubleClickDistance &sipStrings_QtGui[7230]
#define sipNameNr_mouseDoubleClickInterval 7255
#define sipName_mouseDoubleClickInterval &sipStrings_QtGui[7255]
#define sipNameNr_setAccessibleDescription 7280
#define sipName_setAccessibleDescription &sipStrings_QtGui[7280]
#define sipNameNr_setAutoDetectImageFormat 7305
#define sipName_setAutoDetectImageFormat &sipStrings_QtGui[7305]
#define sipNameNr_setFontHintingPreference 7330
#define sipName_setFontHintingPreference &sipStrings_QtGui[7330]
#define sipNameNr_setFontLetterSpacingType 7355
#define sipName_setFontLetterSpacingType &sipStrings_QtGui[7355]
#define sipNameNr_setInternalTextureFormat 7380
#define sipName_setInternalTextureFormat &sipStrings_QtGui[7380]
#define sipNameNr_setOrientationUpdateMask 7405
#define sipName_setOrientationUpdateMask &sipStrings_QtGui[7405]
#define sipNameNr_startDragDistanceChanged 7430
#define sipName_startDragDistanceChanged &sipStrings_QtGui[7430]
#define sipNameNr_supportedDocumentFormats 7455
#define sipName_supportedDocumentFormats &sipStrings_QtGui[7455]
#define sipNameNr_takeHorizontalHeaderItem 7480
#define sipName_takeHorizontalHeaderItem &sipStrings_QtGui[7480]
#define sipNameNr_CompositionMode_Lighten 7505
#define sipName_CompositionMode_Lighten &sipStrings_QtGui[7505]
#define sipNameNr_CompositionMode_Overlay 7529
#define sipName_CompositionMode_Overlay &sipStrings_QtGui[7529]
#define sipNameNr_CursorBetweenCharacters 7553
#define sipName_CursorBetweenCharacters &sipStrings_QtGui[7553]
#define sipNameNr_HighQualityAntialiasing 7577
#define sipName_HighQualityAntialiasing &sipStrings_QtGui[7577]
#define sipNameNr_QGlyphRun__GlyphRunFlag 7601
#define sipName_QGlyphRun__GlyphRunFlag &sipStrings_QtGui[7601]
#define sipNameNr_7625 7625
#define sipName_7625 &sipStrings_QtGui[7625]
#define sipNameNr_QOpenGLTexture__Feature 7649
#define sipName_QOpenGLTexture__Feature &sipStrings_QtGui[7649]
#define sipNameNr_QPaintEngine__DirtyFlag 7673
#define sipName_QPaintEngine__DirtyFlag &sipStrings_QtGui[7673]
#define sipNameNr_QPixelFormat__ByteOrder 7697
#define sipName_QPixelFormat__ByteOrder &sipStrings_QtGui[7697]
#define sipNameNr_QPixelFormat__YUVLayout 7721
#define sipName_QPixelFormat__YUVLayout &sipStrings_QtGui[7721]
#define sipNameNr_QPointingDeviceUniqueId 7745
#define sipName_QPointingDeviceUniqueId &sipStrings_QtGui[7745]
#define sipNameNr_QStandardItem__ItemType 7769
#define sipName_QStandardItem__ItemType &sipStrings_QtGui[7769]
#define sipNameNr_QTextDocument__FindFlag 7793
#define sipName_QTextDocument__FindFlag &sipStrings_QtGui[7793]
#define sipNameNr_QTextFormat__FormatType 7817
#define sipName_QTextFormat__FormatType &sipStrings_QtGui[7817]
#define sipNameNr_QTextLayout__CursorMode 7841
#define sipName_QTextLayout__CursorMode &sipStrings_QtGui[7841]
#define sipNameNr_QTouchEvent__TouchPoint 7865
#define sipName_QTouchEvent__TouchPoint &sipStrings_QtGui[7865]
#define sipNameNr_QWindowStateChangeEvent 7889
#define sipName_QWindowStateChangeEvent &sipStrings_QtGui[7889]
#define sipNameNr_RasterOp_NotDestination 7913
#define sipName_RasterOp_NotDestination &sipStrings_QtGui[7913]
#define sipNameNr_RasterOp_SetDestination 7937
#define sipName_RasterOp_SetDestination &sipStrings_QtGui[7937]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x10 7961
#define sipName_SRGB8_Alpha8_ASTC_10x10 &sipStrings_QtGui[7961]
#define sipNameNr_SRGB8_Alpha8_ASTC_12x10 7985
#define sipName_SRGB8_Alpha8_ASTC_12x10 &sipStrings_QtGui[7985]
#define sipNameNr_SRGB8_Alpha8_ASTC_12x12 8009
#define sipName_SRGB8_Alpha8_ASTC_12x12 &sipStrings_QtGui[8009]
#define sipNameNr_TableCellTopBorderBrush 8033
#define sipName_TableCellTopBorderBrush &sipStrings_QtGui[8033]
#define sipNameNr_TableCellTopBorderStyle 8057
#define sipName_TableCellTopBorderStyle &sipStrings_QtGui[8057]
#define sipNameNr_TransformationRotate180 8081
#define sipName_TransformationRotate180 &sipStrings_QtGui[8081]
#define sipNameNr_TransformationRotate270 8105
#define sipName_TransformationRotate270 &sipStrings_QtGui[8105]
#define sipNameNr_addShaderFromSourceCode 8129
#define sipName_addShaderFromSourceCode &sipStrings_QtGui[8129]
#define sipNameNr_addShaderFromSourceFile 8153
#define sipName_addShaderFromSourceFile &sipStrings_QtGui[8153]
#define sipNameNr_advancesForGlyphIndexes 8177
#define sipName_advancesForGlyphIndexes &sipStrings_QtGui[8177]
#define sipNameNr_applicationFontFamilies 8201
#define sipName_applicationFontFamilies &sipStrings_QtGui[8201]
#define sipNameNr_applicationStateChanged 8225
#define sipName_applicationStateChanged &sipStrings_QtGui[8225]
#define sipNameNr_createThirdPartyMessage 8249
#define sipName_createThirdPartyMessage &sipStrings_QtGui[8249]
#define sipNameNr_decideFormatFromContent 8273
#define sipName_decideFormatFromContent &sipStrings_QtGui[8273]
#define sipNameNr_hasOpenGLShaderPrograms 8297
#define sipName_hasOpenGLShaderPrograms &sipStrings_QtGui[8297]
#define sipNameNr_imageFormatsForMimeType 8321
#define sipName_imageFormatsForMimeType &sipStrings_QtGui[8321]
#define sipNameNr_setCurrentBlockUserData 8345
#define sipName_setCurrentBlockUserData &sipStrings_QtGui[8345]
#define sipNameNr_setDesktopSettingsAware 8369
#define sipName_setDesktopSettingsAware &sipStrings_QtGui[8369]
#define sipNameNr_setFixedSamplePositions 8393
#define sipName_setFixedSamplePositions &sipStrings_QtGui[8393]
#define sipNameNr_setHorizontalHeaderItem 8417
#define sipName_setHorizontalHeaderItem &sipStrings_QtGui[8417]
#define sipNameNr_setKeepPositionOnInsert 8441
#define sipName_setKeepPositionOnInsert &sipStrings_QtGui[8441]
#define sipNameNr_setMaximumLevelOfDetail 8465
#define sipName_setMaximumLevelOfDetail &sipStrings_QtGui[8465]
#define sipNameNr_setMinimumLevelOfDetail 8489
#define sipName_setMinimumLevelOfDetail &sipStrings_QtGui[8489]
#define sipNameNr_setProgressiveScanWrite 8513
#define sipName_setProgressiveScanWrite &sipStrings_QtGui[8513]
#define sipNameNr_setVerticalHeaderLabels 8537
#define sipName_setVerticalHeaderLabels &sipStrings_QtGui[8537]
#define sipNameNr_setViewTransformEnabled 8561
#define sipName_setViewTransformEnabled &sipStrings_QtGui[8561]
#define sipNameNr_supportedWritingSystems 8585
#define sipName_supportedWritingSystems &sipStrings_QtGui[8585]
#define sipNameNr_tabFocusBehaviorChanged 8609
#define sipName_tabFocusBehaviorChanged &sipStrings_QtGui[8609]
#define sipNameNr_wheelScrollLinesChanged 8633
#define sipName_wheelScrollLinesChanged &sipStrings_QtGui[8633]
#define sipNameNr_AvailableSizesArgument 449
#define sipName_AvailableSizesArgument &sipStrings_QtGui[449]
#define sipNameNr_BindingTargetRectangle 8657
#define sipName_BindingTargetRectangle &sipStrings_QtGui[8657]
#define sipNameNr_BlockNonBreakableLines 8680
#define sipName_BlockNonBreakableLines &sipStrings_QtGui[8680]
#define sipNameNr_BorderStyle_DotDotDash 8703
#define sipName_BorderStyle_DotDotDash &sipStrings_QtGui[8703]
#define sipNameNr_CompositionMode_Darken 8726
#define sipName_CompositionMode_Darken &sipStrings_QtGui[8726]
#define sipNameNr_CompositionMode_Screen 8749
#define sipName_CompositionMode_Screen &sipStrings_QtGui[8749]
#define sipNameNr_CompositionMode_Source 8772
#define sipName_CompositionMode_Source &sipStrings_QtGui[8772]
#define sipNameNr_DeprecatedBehaviorType 8795
#define sipName_DeprecatedBehaviorType &sipStrings_QtGui[8795]
#define sipNameNr_LosslessImageRendering 8818
#define sipName_LosslessImageRendering &sipStrings_QtGui[8818]
#define sipNameNr_PageBreak_AlwaysBefore 8841
#define sipName_PageBreak_AlwaysBefore &sipStrings_QtGui[8841]
#define sipNameNr_PaintOutsidePaintEvent 8864
#define sipName_PaintOutsidePaintEvent &sipStrings_QtGui[8864]
#define sipNameNr_QColorSpace__Primaries 8887
#define sipName_QColorSpace__Primaries &sipStrings_QtGui[8887]
#define sipNameNr_QInputMethodQueryEvent 8910
#define sipName_QInputMethodQueryEvent &sipStrings_QtGui[8910]
#define sipNameNr_8933 8933
#define sipName_8933 &sipStrings_QtGui[8933]
#define sipNameNr_QOpenGLTexture__Filter 8956
#define sipName_QOpenGLTexture__Filter &sipStrings_QtGui[8956]
#define sipNameNr_QOpenGLTexture__Target 8979
#define sipName_QOpenGLTexture__Target &sipStrings_QtGui[8979]
#define sipNameNr_QSurface__SurfaceClass 9002
#define sipName_QSurface__SurfaceClass &sipStrings_QtGui[9002]
#define sipNameNr_QTextItem__RenderFlags 9025
#define sipName_QTextItem__RenderFlags &sipStrings_QtGui[9025]
#define sipNameNr_QTextListFormat__Style 9048
#define sipName_QTextListFormat__Style &sipStrings_QtGui[9048]
#define sipNameNr_QWhatsThisClickedEvent 9071
#define sipName_QWhatsThisClickedEvent &sipStrings_QtGui[9071]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x5 9094
#define sipName_SRGB8_Alpha8_ASTC_10x5 &sipStrings_QtGui[9094]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x6 9117
#define sipName_SRGB8_Alpha8_ASTC_10x6 &sipStrings_QtGui[9117]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x8 9140
#define sipName_SRGB8_Alpha8_ASTC_10x8 &sipStrings_QtGui[9140]
#define sipNameNr_ShowDocumentTerminator 9163
#define sipName_ShowDocumentTerminator &sipStrings_QtGui[9163]
#define sipNameNr_TableCellBottomPadding 9186
#define sipName_TableCellBottomPadding &sipStrings_QtGui[9186]
#define sipNameNr_TessellationEvaluation 9209
#define sipName_TessellationEvaluation &sipStrings_QtGui[9209]
#define sipNameNr_TransformationRotate90 9232
#define sipName_TransformationRotate90 &sipStrings_QtGui[9232]
#define sipNameNr_UnsupportedFormatError 9255
#define sipName_UnsupportedFormatError &sipStrings_QtGui[9255]
#define sipNameNr_anchorRectangleChanged 9278
#define sipName_anchorRectangleChanged &sipStrings_QtGui[9278]
#define sipNameNr_applicationDisplayName 9301
#define sipName_applicationDisplayName &sipStrings_QtGui[9301]
#define sipNameNr_clearAdditionalFormats 9324
#define sipName_clearAdditionalFormats &sipStrings_QtGui[9324]
#define sipNameNr_columnWidthConstraints 9347
#define sipName_columnWidthConstraints &sipStrings_QtGui[9347]
#define sipNameNr_cursorFlashTimeChanged 9370
#define sipName_cursorFlashTimeChanged &sipStrings_QtGui[9370]
#define sipNameNr_cursorRectangleChanged 9393
#define sipName_cursorRectangleChanged &sipStrings_QtGui[9393]
#define sipNameNr_defaultCursorMoveStyle 9416
#define sipName_defaultCursorMoveStyle &sipStrings_QtGui[9416]
#define sipNameNr_devicePixelRatioFScale 9439
#define sipName_devicePixelRatioFScale &sipStrings_QtGui[9439]
#define sipNameNr_inputItemClipRectangle 9462
#define sipName_inputItemClipRectangle &sipStrings_QtGui[9462]
#define sipNameNr_isFixedSamplePositions 9485
#define sipName_isFixedSamplePositions &sipStrings_QtGui[9485]
#define sipNameNr_keyboardAutoRepeatRate 9508
#define sipName_keyboardAutoRepeatRate &sipStrings_QtGui[9508]
#define sipNameNr_layoutDirectionChanged 9531
#define sipName_layoutDirectionChanged &sipStrings_QtGui[9531]
#define sipNameNr_previousCursorPosition 9554
#define sipName_previousCursorPosition &sipStrings_QtGui[9554]
#define sipNameNr_queryKeyboardModifiers 9577
#define sipName_queryKeyboardModifiers &sipStrings_QtGui[9577]
#define sipNameNr_quitOnLastWindowClosed 9600
#define sipName_quitOnLastWindowClosed &sipStrings_QtGui[9600]
#define sipNameNr_setDocumentXmpMetadata 9623
#define sipName_setDocumentXmpMetadata &sipStrings_QtGui[9623]
#define sipNameNr_setFallbackSearchPaths 9646
#define sipName_setFallbackSearchPaths &sipStrings_QtGui[9646]
#define sipNameNr_setFocusOnTouchRelease 9669
#define sipName_setFocusOnTouchRelease &sipStrings_QtGui[9669]
#define sipNameNr_setKeyboardGrabEnabled 9692
#define sipName_setKeyboardGrabEnabled &sipStrings_QtGui[9692]
#define sipNameNr_setMagnificationFilter 9715
#define sipName_setMagnificationFilter &sipStrings_QtGui[9715]
#define sipNameNr_setTableCellColumnSpan 9738
#define sipName_setTableCellColumnSpan &sipStrings_QtGui[9738]
#define sipNameNr_supportsThreadedOpenGL 9761
#define sipName_supportsThreadedOpenGL &sipStrings_QtGui[9761]
#define sipNameNr_takeVerticalHeaderItem 9784
#define sipName_takeVerticalHeaderItem &sipStrings_QtGui[9784]
#define sipNameNr_touchDoubleTapDistance 9807
#define sipName_touchDoubleTapDistance &sipStrings_QtGui[9807]
#define sipNameNr_useHoverEffectsChanged 9830
#define sipName_useHoverEffectsChanged &sipStrings_QtGui[9830]
#define sipNameNr_virtualGeometryChanged 9853
#define sipName_virtualGeometryChanged &sipStrings_QtGui[9853]
#define sipNameNr_CompositionMode_Clear 9876
#define sipName_CompositionMode_Clear &sipStrings_QtGui[9876]
#define sipNameNr_DefaultRenderableType 9898
#define sipName_DefaultRenderableType &sipStrings_QtGui[9898]
#define sipNameNr_FontHintingPreference 7333
#define sipName_FontHintingPreference &sipStrings_QtGui[7333]
#define sipNameNr_FontLetterSpacingType 7358
#define sipName_FontLetterSpacingType &sipStrings_QtGui[7358]
#define sipNameNr_FuzzyOrientationMatch 9920
#define sipName_FuzzyOrientationMatch &sipStrings_QtGui[9920]
#define sipNameNr_IncludeTrailingSpaces 9942
#define sipName_IncludeTrailingSpaces &sipStrings_QtGui[9942]
#define sipNameNr_MarkdownDialectGitHub 9964
#define sipName_MarkdownDialectGitHub &sipStrings_QtGui[9964]
#define sipNameNr_MoveToStartOfDocument 9986
#define sipName_MoveToStartOfDocument &sipStrings_QtGui[9986]
#define sipNameNr_NonCosmeticDefaultPen 10008
#define sipName_NonCosmeticDefaultPen &sipStrings_QtGui[10008]
#define sipNameNr_PageBreak_AlwaysAfter 10030
#define sipName_PageBreak_AlwaysAfter &sipStrings_QtGui[10030]
#define sipNameNr_PreferVerticalHinting 10052
#define sipName_PreferVerticalHinting &sipStrings_QtGui[10052]
#define sipNameNr_QFont__Capitalization 10074
#define sipName_QFont__Capitalization &sipStrings_QtGui[10074]
#define sipNameNr_10096 10096
#define sipName_10096 &sipStrings_QtGui[10096]
#define sipNameNr_10118 10118
#define sipName_10118 &sipStrings_QtGui[10118]
#define sipNameNr_QOpenGLBuffer__Access 10140
#define sipName_QOpenGLBuffer__Access &sipStrings_QtGui[10140]
#define sipNameNr_QOpenGLTextureBlitter 10162
#define sipName_QOpenGLTextureBlitter &sipStrings_QtGui[10162]
#define sipNameNr_QOpenGLVersionProfile 10184
#define sipName_QOpenGLVersionProfile &sipStrings_QtGui[10184]
#define sipNameNr_QPageSize__PageSizeId 10206
#define sipName_QPageSize__PageSizeId &sipStrings_QtGui[10206]
#define sipNameNr_QPainter__RenderHints 10228
#define sipName_QPainter__RenderHints &sipStrings_QtGui[10228]
#define sipNameNr_QPainterPath__Element 10250
#define sipName_QPainterPath__Element &sipStrings_QtGui[10250]
#define sipNameNr_QPlatformSurfaceEvent 10272
#define sipName_QPlatformSurfaceEvent &sipStrings_QtGui[10272]
#define sipNameNr_QRawFont__LayoutFlags 10294
#define sipName_QRawFont__LayoutFlags &sipStrings_QtGui[10294]
#define sipNameNr_QSurface__SurfaceType 10316
#define sipName_QSurface__SurfaceType &sipStrings_QtGui[10316]
#define sipNameNr_QTextCursor__MoveMode 10338
#define sipName_QTextCursor__MoveMode &sipStrings_QtGui[10338]
#define sipNameNr_QTextDocument__Stacks 10360
#define sipName_QTextDocument__Stacks &sipStrings_QtGui[10360]
#define sipNameNr_QTextDocumentFragment 10382
#define sipName_QTextDocumentFragment &sipStrings_QtGui[10382]
#define sipNameNr_QTextFormat__Property 10404
#define sipName_QTextFormat__Property &sipStrings_QtGui[10404]
#define sipNameNr_QTextItem__RenderFlag 10426
#define sipName_QTextItem__RenderFlag &sipStrings_QtGui[10426]
#define sipNameNr_QTextOption__WrapMode 10448
#define sipName_QTextOption__WrapMode &sipStrings_QtGui[10448]
#define sipNameNr_QWindow__AncestorMode 10470
#define sipName_QWindow__AncestorMode &sipStrings_QtGui[10470]
#define sipNameNr_Qt4CompatiblePainting 10492
#define sipName_Qt4CompatiblePainting &sipStrings_QtGui[10492]
#define sipNameNr_RGB_BP_UNSIGNED_FLOAT 10514
#define sipName_RGB_BP_UNSIGNED_FLOAT &sipStrings_QtGui[10514]
#define sipNameNr_RangeInvalidateBuffer 10536
#define sipName_RangeInvalidateBuffer &sipStrings_QtGui[10536]
#define sipNameNr_SRGB8_Alpha8_ASTC_4x4 10558
#define sipName_SRGB8_Alpha8_ASTC_4x4 &sipStrings_QtGui[10558]
#define sipNameNr_SRGB8_Alpha8_ASTC_5x4 10580
#define sipName_SRGB8_Alpha8_ASTC_5x4 &sipStrings_QtGui[10580]
#define sipNameNr_SRGB8_Alpha8_ASTC_5x5 10602
#define sipName_SRGB8_Alpha8_ASTC_5x5 &sipStrings_QtGui[10602]
#define sipNameNr_SRGB8_Alpha8_ASTC_6x5 10624
#define sipName_SRGB8_Alpha8_ASTC_6x5 &sipStrings_QtGui[10624]
#define sipNameNr_SRGB8_Alpha8_ASTC_6x6 10646
#define sipName_SRGB8_Alpha8_ASTC_6x6 &sipStrings_QtGui[10646]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x5 10668
#define sipName_SRGB8_Alpha8_ASTC_8x5 &sipStrings_QtGui[10668]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x6 10690
#define sipName_SRGB8_Alpha8_ASTC_8x6 &sipStrings_QtGui[10690]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x8 10712
#define sipName_SRGB8_Alpha8_ASTC_8x8 &sipStrings_QtGui[10712]
#define sipNameNr_SRGB8_Alpha8_ETC2_EAC 10734
#define sipName_SRGB8_Alpha8_ETC2_EAC &sipStrings_QtGui[10734]
#define sipNameNr_SelectStartOfDocument 10756
#define sipName_SelectStartOfDocument &sipStrings_QtGui[10756]
#define sipNameNr_SmoothPixmapTransform 10778
#define sipName_SmoothPixmapTransform &sipStrings_QtGui[10778]
#define sipNameNr_TableCellBottomBorder 10800
#define sipName_TableCellBottomBorder &sipStrings_QtGui[10800]
#define sipNameNr_TableCellRightPadding 10822
#define sipName_TableCellRightPadding &sipStrings_QtGui[10822]
#define sipNameNr_TextVerticalAlignment 10844
#define sipName_TextVerticalAlignment &sipStrings_QtGui[10844]
#define sipNameNr_UndefinedBehaviorType 10866
#define sipName_UndefinedBehaviorType &sipStrings_QtGui[10866]
#define sipNameNr_accessibleDescription 10888
#define sipName_accessibleDescription &sipStrings_QtGui[10888]
#define sipNameNr_autoDetectImageFormat 10910
#define sipName_autoDetectImageFormat &sipStrings_QtGui[10910]
#define sipNameNr_bindAttributeLocation 10932
#define sipName_bindAttributeLocation &sipStrings_QtGui[10932]
#define sipNameNr_convertedToColorSpace 10954
#define sipName_convertedToColorSpace &sipStrings_QtGui[10954]
#define sipNameNr_cursorPositionChanged 10976
#define sipName_cursorPositionChanged &sipStrings_QtGui[10976]
#define sipNameNr_disableAttributeArray 10998
#define sipName_disableAttributeArray &sipStrings_QtGui[10998]
#define sipNameNr_documentLayoutChanged 11020
#define sipName_documentLayoutChanged &sipStrings_QtGui[11020]
#define sipNameNr_findBlockByLineNumber 11042
#define sipName_findBlockByLineNumber &sipStrings_QtGui[11042]
#define sipNameNr_fontHintingPreference 11064
#define sipName_fontHintingPreference &sipStrings_QtGui[11064]
#define sipNameNr_fontLetterSpacingType 11086
#define sipName_fontLetterSpacingType &sipStrings_QtGui[11086]
#define sipNameNr_glyphIndexesForString 11108
#define sipName_glyphIndexesForString &sipStrings_QtGui[11108]
#define sipNameNr_inputDirectionChanged 11130
#define sipName_inputDirectionChanged &sipStrings_QtGui[11130]
#define sipNameNr_internalTextureFormat 11152
#define sipName_internalTextureFormat &sipStrings_QtGui[11152]
#define sipNameNr_isValidCursorPosition 11174
#define sipName_isValidCursorPosition &sipStrings_QtGui[11174]
#define sipNameNr_joinPreviousEditBlock 11196
#define sipName_joinPreviousEditBlock &sipStrings_QtGui[11196]
#define sipNameNr_keyboardInputInterval 11218
#define sipName_keyboardInputInterval &sipStrings_QtGui[11218]
#define sipNameNr_mouseDoubleClickEvent 11240
#define sipName_mouseDoubleClickEvent &sipStrings_QtGui[11240]
#define sipNameNr_orientationUpdateMask 11262
#define sipName_orientationUpdateMask &sipStrings_QtGui[11262]
#define sipNameNr_passwordMaskCharacter 11284
#define sipName_passwordMaskCharacter &sipStrings_QtGui[11284]
#define sipNameNr_qPixelFormatGrayscale 11306
#define sipName_qPixelFormatGrayscale &sipStrings_QtGui[11306]
#define sipNameNr_removeApplicationFont 11328
#define sipName_removeApplicationFont &sipStrings_QtGui[11328]
#define sipNameNr_restoreOverrideCursor 11350
#define sipName_restoreOverrideCursor &sipStrings_QtGui[11350]
#define sipNameNr_setComparisonFunction 11372
#define sipName_setComparisonFunction &sipStrings_QtGui[11372]
#define sipNameNr_setFontCapitalization 11394
#define sipName_setFontCapitalization &sipStrings_QtGui[11394]
#define sipNameNr_setInputItemRectangle 11416
#define sipName_setInputItemRectangle &sipStrings_QtGui[11416]
#define sipNameNr_setInputItemTransform 11438
#define sipName_setInputItemTransform &sipStrings_QtGui[11438]
#define sipNameNr_setLevelOfDetailRange 11460
#define sipName_setLevelOfDetailRange &sipStrings_QtGui[11460]
#define sipNameNr_setMaximumTouchPoints 11482
#define sipName_setMaximumTouchPoints &sipStrings_QtGui[11482]
#define sipNameNr_setMinificationFilter 11504
#define sipName_setMinificationFilter &sipStrings_QtGui[11504]
#define sipNameNr_setVerticalHeaderItem 11526
#define sipName_setVerticalHeaderItem &sipStrings_QtGui[11526]
#define sipNameNr_setWorldMatrixEnabled 11548
#define sipName_setWorldMatrixEnabled &sipStrings_QtGui[11548]
#define sipNameNr_singleClickActivation 11570
#define sipName_singleClickActivation &sipStrings_QtGui[11570]
#define sipNameNr_supportedImageFormats 11592
#define sipName_supportedImageFormats &sipStrings_QtGui[11592]
#define sipNameNr_AnisotropicFiltering 11614
#define sipName_AnisotropicFiltering &sipStrings_QtGui[11614]
#define sipNameNr_BindingTarget1DArray 11635
#define sipName_BindingTarget1DArray &sipStrings_QtGui[11635]
#define sipNameNr_BindingTarget2DArray 11656
#define sipName_BindingTarget2DArray &sipStrings_QtGui[11656]
#define sipNameNr_BindingTargetCubeMap 11677
#define sipName_BindingTargetCubeMap &sipStrings_QtGui[11677]
#define sipNameNr_CombinedDepthStencil 11698
#define sipName_CombinedDepthStencil &sipStrings_QtGui[11698]
#define sipNameNr_CompatibilityProfile 11719
#define sipName_CompatibilityProfile &sipStrings_QtGui[11719]
#define sipNameNr_CompositionMode_Plus 11740
#define sipName_CompositionMode_Plus &sipStrings_QtGui[11740]
#define sipNameNr_DirtyCompositionMode 11761
#define sipName_DirtyCompositionMode &sipStrings_QtGui[11761]
#define sipNameNr_DontResetTextureUnit 11782
#define sipName_DontResetTextureUnit &sipStrings_QtGui[11782]
#define sipNameNr_LuminanceAlphaFormat 11803
#define sipName_LuminanceAlphaFormat &sipStrings_QtGui[11803]
#define sipNameNr_NearestMipMapNearest 11824
#define sipName_NearestMipMapNearest &sipStrings_QtGui[11824]
#define sipNameNr_NotificationSeverity 11845
#define sipName_NotificationSeverity &sipStrings_QtGui[11845]
#define sipNameNr_OpenGLContextProfile 415
#define sipName_OpenGLContextProfile &sipStrings_QtGui[415]
#define sipNameNr_PerspectiveTransform 11866
#define sipName_PerspectiveTransform &sipStrings_QtGui[11866]
#define sipNameNr_PreferDefaultHinting 11887
#define sipName_PreferDefaultHinting &sipStrings_QtGui[11887]
#define sipNameNr_ProgressiveScanWrite 8516
#define sipName_ProgressiveScanWrite &sipStrings_QtGui[8516]
#define sipNameNr_QColorConstants__Svg 11908
#define sipName_QColorConstants__Svg &sipStrings_QtGui[11908]
#define sipNameNr_QFont__StyleStrategy 11929
#define sipName_QFont__StyleStrategy &sipStrings_QtGui[11929]
#define sipNameNr_QInputMethod__Action 11950
#define sipName_QInputMethod__Action &sipStrings_QtGui[11950]
#define sipNameNr_11971 11971
#define sipName_11971 &sipStrings_QtGui[11971]
#define sipNameNr_QOpenGLShaderProgram 11992
#define sipName_QOpenGLShaderProgram &sipStrings_QtGui[11992]
#define sipNameNr_QPainter__RenderHint 12013
#define sipName_QPainter__RenderHint &sipStrings_QtGui[12013]
#define sipNameNr_QPalette__ColorGroup 12034
#define sipName_QPalette__ColorGroup &sipStrings_QtGui[12034]
#define sipNameNr_QRawFont__LayoutFlag 12055
#define sipName_QRawFont__LayoutFlag &sipStrings_QtGui[12055]
#define sipNameNr_QTextBlock__iterator 12076
#define sipName_QTextBlock__iterator &sipStrings_QtGui[12076]
#define sipNameNr_QTextFrame__iterator 12097
#define sipName_QTextFrame__iterator &sipStrings_QtGui[12097]
#define sipNameNr_QTextObjectInterface 12118
#define sipName_QTextObjectInterface &sipStrings_QtGui[12118]
#define sipNameNr_QTextOption__TabType 12139
#define sipName_QTextOption__TabType &sipStrings_QtGui[12139]
#define sipNameNr_QTextTableCellFormat 12160
#define sipName_QTextTableCellFormat &sipStrings_QtGui[12160]
#define sipNameNr_12181 12181
#define sipName_12181 &sipStrings_QtGui[12181]
#define sipNameNr_12202 12202
#define sipName_12202 &sipStrings_QtGui[12202]
#define sipNameNr_ScaledPixmapArgument 945
#define sipName_ScaledPixmapArgument &sipStrings_QtGui[945]
#define sipNameNr_ShaderCompilerSource 12223
#define sipName_ShaderCompilerSource &sipStrings_QtGui[12223]
#define sipNameNr_SmallestReadableFont 12244
#define sipName_SmallestReadableFont &sipStrings_QtGui[12244]
#define sipNameNr_SubPixelAntialiasing 12265
#define sipName_SubPixelAntialiasing &sipStrings_QtGui[12265]
#define sipNameNr_TableCellLeftPadding 12286
#define sipName_TableCellLeftPadding &sipStrings_QtGui[12286]
#define sipNameNr_TableCellRightBorder 12307
#define sipName_TableCellRightBorder &sipStrings_QtGui[12307]
#define sipNameNr_TextureCubeMapArrays 12328
#define sipName_TextureCubeMapArrays &sipStrings_QtGui[12328]
#define sipNameNr_TransformationMirror 12349
#define sipName_TransformationMirror &sipStrings_QtGui[12349]
#define sipNameNr_TransformedByDefault 12370
#define sipName_TransformedByDefault &sipStrings_QtGui[12370]
#define sipNameNr_acceptProposedAction 12391
#define sipName_acceptProposedAction &sipStrings_QtGui[12391]
#define sipNameNr_availableVirtualSize 12412
#define sipName_availableVirtualSize &sipStrings_QtGui[12412]
#define sipNameNr_changeOverrideCursor 12433
#define sipName_changeOverrideCursor &sipStrings_QtGui[12433]
#define sipNameNr_convertFromPlainText 12454
#define sipName_convertFromPlainText &sipStrings_QtGui[12454]
#define sipNameNr_currentBlockUserData 12475
#define sipName_currentBlockUserData &sipStrings_QtGui[12475]
#define sipNameNr_desktopSettingsAware 12496
#define sipName_desktopSettingsAware &sipStrings_QtGui[12496]
#define sipNameNr_enableAttributeArray 12517
#define sipName_enableAttributeArray &sipStrings_QtGui[12517]
#define sipNameNr_horizontalHeaderItem 12538
#define sipName_horizontalHeaderItem &sipStrings_QtGui[12538]
#define sipNameNr_keepPositionOnInsert 12559
#define sipName_keepPositionOnInsert &sipStrings_QtGui[12559]
#define sipNameNr_lengthVectorProperty 12580
#define sipName_lengthVectorProperty &sipStrings_QtGui[12580]
#define sipNameNr_lightgoldenrodyellow 12601
#define sipName_lightgoldenrodyellow &sipStrings_QtGui[12601]
#define sipNameNr_maximumHeightChanged 12622
#define sipName_maximumHeightChanged &sipStrings_QtGui[12622]
#define sipNameNr_maximumLevelOfDetail 12643
#define sipName_maximumLevelOfDetail &sipStrings_QtGui[12643]
#define sipNameNr_maximumMessageLength 12664
#define sipName_maximumMessageLength &sipStrings_QtGui[12664]
#define sipNameNr_mergeBlockCharFormat 12685
#define sipName_mergeBlockCharFormat &sipStrings_QtGui[12685]
#define sipNameNr_minimumHeightChanged 12706
#define sipName_minimumHeightChanged &sipStrings_QtGui[12706]
#define sipNameNr_minimumLevelOfDetail 12727
#define sipName_minimumLevelOfDetail &sipStrings_QtGui[12727]
#define sipNameNr_physicalDotsPerInchX 12748
#define sipName_physicalDotsPerInchX &sipStrings_QtGui[12748]
#define sipNameNr_physicalDotsPerInchY 12769
#define sipName_physicalDotsPerInchY &sipStrings_QtGui[12769]
#define sipNameNr_positionInlineObject 12790
#define sipName_positionInlineObject &sipStrings_QtGui[12790]
#define sipNameNr_primaryScreenChanged 12811
#define sipName_primaryScreenChanged &sipStrings_QtGui[12811]
#define sipNameNr_progressiveScanWrite 12832
#define sipName_progressiveScanWrite &sipStrings_QtGui[12832]
#define sipNameNr_setAdditionalFormats 12853
#define sipName_setAdditionalFormats &sipStrings_QtGui[12853]
#define sipNameNr_setBottomBorderBrush 12874
#define sipName_setBottomBorderBrush &sipStrings_QtGui[12874]
#define sipNameNr_setBottomBorderStyle 12895
#define sipName_setBottomBorderStyle &sipStrings_QtGui[12895]
#define sipNameNr_setCurrentBlockState 12916
#define sipName_setCurrentBlockState &sipStrings_QtGui[12916]
#define sipNameNr_setCurrentColorGroup 12937
#define sipName_setCurrentColorGroup &sipStrings_QtGui[12937]
#define sipNameNr_setDefaultStyleSheet 12958
#define sipName_setDefaultStyleSheet &sipStrings_QtGui[12958]
#define sipNameNr_setDefaultTextOption 12979
#define sipName_setDefaultTextOption &sipStrings_QtGui[12979]
#define sipNameNr_setElementPositionAt 13000
#define sipName_setElementPositionAt &sipStrings_QtGui[13000]
#define sipNameNr_setFallbackThemeName 13021
#define sipName_setFallbackThemeName &sipStrings_QtGui[13021]
#define sipNameNr_setFontLetterSpacing 13042
#define sipName_setFontLetterSpacing &sipStrings_QtGui[13042]
#define sipNameNr_setFontStyleStrategy 13063
#define sipName_setFontStyleStrategy &sipStrings_QtGui[13063]
#define sipNameNr_setHintingPreference 13084
#define sipName_setHintingPreference &sipStrings_QtGui[13084]
#define sipNameNr_setLevelofDetailBias 13105
#define sipName_setLevelofDetailBias &sipStrings_QtGui[13105]
#define sipNameNr_setMaximumAnisotropy 13126
#define sipName_setMaximumAnisotropy &sipStrings_QtGui[13126]
#define sipNameNr_setMaximumBlockCount 13147
#define sipName_setMaximumBlockCount &sipStrings_QtGui[13147]
#define sipNameNr_setNonBreakableLines 13168
#define sipName_setNonBreakableLines &sipStrings_QtGui[13168]
#define sipNameNr_setRegularExpression 13189
#define sipName_setRegularExpression &sipStrings_QtGui[13189]
#define sipNameNr_setStencilBufferSize 13210
#define sipName_setStencilBufferSize &sipStrings_QtGui[13210]
#define sipNameNr_setUniformValueArray 13231
#define sipName_setUniformValueArray &sipStrings_QtGui[13231]
#define sipNameNr_setVerticalAlignment 13252
#define sipName_setVerticalAlignment &sipStrings_QtGui[13252]
#define sipNameNr_setVerticalMovementX 13273
#define sipName_setVerticalMovementX &sipStrings_QtGui[13273]
#define sipNameNr_startDragTimeChanged 13294
#define sipName_startDragTimeChanged &sipStrings_QtGui[13294]
#define sipNameNr_supportedDragActions 13315
#define sipName_supportedDragActions &sipStrings_QtGui[13315]
#define sipNameNr_supportedDropActions 13336
#define sipName_supportedDropActions &sipStrings_QtGui[13336]
#define sipNameNr_tableCellFormatIndex 13357
#define sipName_tableCellFormatIndex &sipStrings_QtGui[13357]
#define sipNameNr_viewTransformEnabled 13378
#define sipName_viewTransformEnabled &sipStrings_QtGui[13378]
#define sipNameNr_withTransferFunction 13399
#define sipName_withTransferFunction &sipStrings_QtGui[13399]
#define sipNameNr_AsynchronousLogging 13420
#define sipName_AsynchronousLogging &sipStrings_QtGui[13420]
#define sipNameNr_AutomaticVisibility 13440
#define sipName_AutomaticVisibility &sipStrings_QtGui[13440]
#define sipNameNr_BindingTargetBuffer 13460
#define sipName_BindingTargetBuffer &sipStrings_QtGui[13460]
#define sipNameNr_BorderStyle_DotDash 13480
#define sipName_BorderStyle_DotDash &sipStrings_QtGui[13480]
#define sipNameNr_CompareGreaterEqual 13500
#define sipName_CompareGreaterEqual &sipStrings_QtGui[13500]
#define sipNameNr_CompareRefToTexture 13520
#define sipName_CompareRefToTexture &sipStrings_QtGui[13520]
#define sipNameNr_CompositionMode_Xor 13540
#define sipName_CompositionMode_Xor &sipStrings_QtGui[13540]
#define sipNameNr_ConicalGradientFill 13560
#define sipName_ConicalGradientFill &sipStrings_QtGui[13560]
#define sipNameNr_CoordinateDirection 560
#define sipName_CoordinateDirection &sipStrings_QtGui[560]
#define sipNameNr_CurrentSystemEndian 13580
#define sipName_CurrentSystemEndian &sipStrings_QtGui[13580]
#define sipNameNr_DefaultSwapBehavior 13600
#define sipName_DefaultSwapBehavior &sipStrings_QtGui[13600]
#define sipNameNr_DeprecatedFunctions 13620
#define sipName_DeprecatedFunctions &sipStrings_QtGui[13620]
#define sipNameNr_DirtyBackgroundMode 13640
#define sipName_DirtyBackgroundMode &sipStrings_QtGui[13640]
#define sipNameNr_DontGenerateMipMaps 13660
#define sipName_DontGenerateMipMaps &sipStrings_QtGui[13660]
#define sipNameNr_FindCaseSensitively 13680
#define sipName_FindCaseSensitively &sipStrings_QtGui[13680]
#define sipNameNr_ForceIntegerMetrics 13700
#define sipName_ForceIntegerMetrics &sipStrings_QtGui[13700]
#define sipNameNr_ImageTransformation 13720
#define sipName_ImageTransformation &sipStrings_QtGui[13720]
#define sipNameNr_InsertLineSeparator 13740
#define sipName_InsertLineSeparator &sipStrings_QtGui[13740]
#define sipNameNr_LinearMipMapNearest 13760
#define sipName_LinearMipMapNearest &sipStrings_QtGui[13760]
#define sipNameNr_MoveToEndOfDocument 13780
#define sipName_MoveToEndOfDocument &sipStrings_QtGui[13780]
#define sipNameNr_NearestMipMapLinear 13800
#define sipName_NearestMipMapLinear &sipStrings_QtGui[13800]
#define sipNameNr_NoSubpixelAntialias 13820
#define sipName_NoSubpixelAntialias &sipStrings_QtGui[13820]
#define sipNameNr_PaintEngineFeatures 980
#define sipName_PaintEngineFeatures &sipStrings_QtGui[980]
#define sipNameNr_PdmDevicePixelRatio 13840
#define sipName_PdmDevicePixelRatio &sipStrings_QtGui[13840]
#define sipNameNr_PixmapFragmentHints 3262
#define sipName_PixmapFragmentHints &sipStrings_QtGui[3262]
#define sipNameNr_13860 13860
#define sipName_13860 &sipStrings_QtGui[13860]
#define sipNameNr_QNativeGestureEvent 13880
#define sipName_QNativeGestureEvent &sipStrings_QtGui[13880]
#define sipNameNr_QOpenGLBuffer__Type 13900
#define sipName_QOpenGLBuffer__Type &sipStrings_QtGui[13900]
#define sipNameNr_QOpenGLContextGroup 13920
#define sipName_QOpenGLContextGroup &sipStrings_QtGui[13920]
#define sipNameNr_QOpenGLDebugMessage 13940
#define sipName_QOpenGLDebugMessage &sipStrings_QtGui[13940]
#define sipNameNr_QPainterPathStroker 13960
#define sipName_QPainterPathStroker &sipStrings_QtGui[13960]
#define sipNameNr_QPalette__ColorRole 13980
#define sipName_QPalette__ColorRole &sipStrings_QtGui[13980]
#define sipNameNr_QRegion__RegionType 14000
#define sipName_QRegion__RegionType &sipStrings_QtGui[14000]
#define sipNameNr_QScrollPrepareEvent 14020
#define sipName_QScrollPrepareEvent &sipStrings_QtGui[14020]
#define sipNameNr_QTextDocumentWriter 14040
#define sipName_QTextDocumentWriter &sipStrings_QtGui[14040]
#define sipNameNr_QWindow__Visibility 14060
#define sipName_QWindow__Visibility &sipStrings_QtGui[14060]
#define sipNameNr_RGB_BP_SIGNED_FLOAT 14080
#define sipName_RGB_BP_SIGNED_FLOAT &sipStrings_QtGui[14080]
#define sipNameNr_RangeUnsynchronized 14100
#define sipName_RangeUnsynchronized &sipStrings_QtGui[14100]
#define sipNameNr_SelectEndOfDocument 14120
#define sipName_SelectEndOfDocument &sipStrings_QtGui[14120]
#define sipNameNr_SpellCheckUnderline 14140
#define sipName_SpellCheckUnderline &sipStrings_QtGui[14140]
#define sipNameNr_StretchToDeviceMode 14160
#define sipName_StretchToDeviceMode &sipStrings_QtGui[14160]
#define sipNameNr_TableBorderCollapse 14180
#define sipName_TableBorderCollapse &sipStrings_QtGui[14180]
#define sipNameNr_TableCellColumnSpan 9741
#define sipName_TableCellColumnSpan &sipStrings_QtGui[9741]
#define sipNameNr_TableCellLeftBorder 14200
#define sipName_TableCellLeftBorder &sipStrings_QtGui[14200]
#define sipNameNr_TableCellTopPadding 14220
#define sipName_TableCellTopPadding &sipStrings_QtGui[14220]
#define sipNameNr_TableHeaderRowCount 14240
#define sipName_TableHeaderRowCount &sipStrings_QtGui[14240]
#define sipNameNr_Target2DMultisample 4872
#define sipName_Target2DMultisample &sipStrings_QtGui[4872]
#define sipNameNr_TessellationControl 14260
#define sipName_TessellationControl &sipStrings_QtGui[14260]
#define sipNameNr_applyColorTransform 14280
#define sipName_applyColorTransform &sipStrings_QtGui[14280]
#define sipNameNr_beginNativePainting 14300
#define sipName_beginNativePainting &sipStrings_QtGui[14300]
#define sipNameNr_brushNeedsResolving 14320
#define sipName_brushNeedsResolving &sipStrings_QtGui[14320]
#define sipNameNr_clearUndoRedoStacks 14340
#define sipName_clearUndoRedoStacks &sipStrings_QtGui[14340]
#define sipNameNr_convertToColorSpace 14360
#define sipName_convertToColorSpace &sipStrings_QtGui[14360]
#define sipNameNr_createHeuristicMask 14380
#define sipName_createHeuristicMask &sipStrings_QtGui[14380]
#define sipNameNr_createMaskFromColor 14400
#define sipName_createMaskFromColor &sipStrings_QtGui[14400]
#define sipNameNr_currentContextGroup 14420
#define sipName_currentContextGroup &sipStrings_QtGui[14420]
#define sipNameNr_documentSizeChanged 14440
#define sipName_documentSizeChanged &sipStrings_QtGui[14440]
#define sipNameNr_documentXmpMetadata 14460
#define sipName_documentXmpMetadata &sipStrings_QtGui[14460]
#define sipNameNr_drawPixmapFragments 14480
#define sipName_drawPixmapFragments &sipStrings_QtGui[14480]
#define sipNameNr_fallbackSearchPaths 14500
#define sipName_fallbackSearchPaths &sipStrings_QtGui[14500]
#define sipNameNr_firstCursorPosition 14520
#define sipName_firstCursorPosition &sipStrings_QtGui[14520]
#define sipNameNr_fontDatabaseChanged 14540
#define sipName_fontDatabaseChanged &sipStrings_QtGui[14540]
#define sipNameNr_hasComplexSelection 14560
#define sipName_hasComplexSelection &sipStrings_QtGui[14560]
#define sipNameNr_insertSubstitutions 14580
#define sipName_insertSubstitutions &sipStrings_QtGui[14580]
#define sipNameNr_lineForTextPosition 14600
#define sipName_lineForTextPosition &sipStrings_QtGui[14600]
#define sipNameNr_logicalDotsPerInchX 14620
#define sipName_logicalDotsPerInchX &sipStrings_QtGui[14620]
#define sipNameNr_logicalDotsPerInchY 14640
#define sipName_logicalDotsPerInchY &sipStrings_QtGui[14640]
#define sipNameNr_magnificationFilter 14660
#define sipName_magnificationFilter &sipStrings_QtGui[14660]
#define sipNameNr_maximumWidthChanged 14680
#define sipName_maximumWidthChanged &sipStrings_QtGui[14680]
#define sipNameNr_minimumWidthChanged 14700
#define sipName_minimumWidthChanged &sipStrings_QtGui[14700]
#define sipNameNr_modificationChanged 14720
#define sipName_modificationChanged &sipStrings_QtGui[14720]
#define sipNameNr_physicalDotsPerInch 14740
#define sipName_physicalDotsPerInch &sipStrings_QtGui[14740]
#define sipNameNr_physicalSizeChanged 14760
#define sipName_physicalSizeChanged &sipStrings_QtGui[14760]
#define sipNameNr_preeditAreaPosition 14780
#define sipName_preeditAreaPosition &sipStrings_QtGui[14780]
#define sipNameNr_reinterpretAsFormat 14800
#define sipName_reinterpretAsFormat &sipStrings_QtGui[14800]
#define sipNameNr_removeSubstitutions 14820
#define sipName_removeSubstitutions &sipStrings_QtGui[14820]
#define sipNameNr_rightCursorPosition 14840
#define sipName_rightCursorPosition &sipStrings_QtGui[14840]
#define sipNameNr_setDepthStencilMode 14860
#define sipName_setDepthStencilMode &sipStrings_QtGui[14860]
#define sipNameNr_setDevicePixelRatio 14880
#define sipName_setDevicePixelRatio &sipStrings_QtGui[14880]
#define sipNameNr_setMouseGrabEnabled 14900
#define sipName_setMouseGrabEnabled &sipStrings_QtGui[14900]
#define sipNameNr_setPatchVertexCount 14920
#define sipName_setPatchVertexCount &sipStrings_QtGui[14920]
#define sipNameNr_setRightBorderBrush 14940
#define sipName_setRightBorderBrush &sipStrings_QtGui[14940]
#define sipNameNr_setRightBorderStyle 14960
#define sipName_setRightBorderStyle &sipStrings_QtGui[14960]
#define sipNameNr_setSwapBytesEnabled 14980
#define sipName_setSwapBytesEnabled &sipStrings_QtGui[14980]
#define sipNameNr_setTableCellRowSpan 15000
#define sipName_setTableCellRowSpan &sipStrings_QtGui[15000]
#define sipNameNr_setThemeSearchPaths 15020
#define sipName_setThemeSearchPaths &sipStrings_QtGui[15020]
#define sipNameNr_setTransferFunction 15040
#define sipName_setTransferFunction &sipStrings_QtGui[15040]
#define sipNameNr_setUseDesignMetrics 15060
#define sipName_setUseDesignMetrics &sipStrings_QtGui[15060]
#define sipNameNr_setVisualNavigation 15080
#define sipName_setVisualNavigation &sipStrings_QtGui[15080]
#define sipNameNr_tableCellColumnSpan 15100
#define sipName_tableCellColumnSpan &sipStrings_QtGui[15100]
#define sipNameNr_writingSystemSample 15120
#define sipName_writingSystemSample &sipStrings_QtGui[15120]
#define sipNameNr_AlphaPremultiplied 1481
#define sipName_AlphaPremultiplied &sipStrings_QtGui[1481]
#define sipNameNr_AvailableSizesHook 15140
#define sipName_AvailableSizesHook &sipStrings_QtGui[15140]
#define sipNameNr_BackgroundImageUrl 15159
#define sipName_BackgroundImageUrl &sipStrings_QtGui[15159]
#define sipNameNr_BorderStyle_Dashed 15178
#define sipName_BorderStyle_Dashed &sipStrings_QtGui[15178]
#define sipNameNr_BorderStyle_Dotted 15197
#define sipName_BorderStyle_Dotted &sipStrings_QtGui[15197]
#define sipNameNr_BorderStyle_Double 15216
#define sipName_BorderStyle_Double &sipStrings_QtGui[15216]
#define sipNameNr_BorderStyle_Groove 15235
#define sipName_BorderStyle_Groove &sipStrings_QtGui[15235]
#define sipNameNr_BorderStyle_Outset 15254
#define sipName_BorderStyle_Outset &sipStrings_QtGui[15254]
#define sipNameNr_ComparisonFunction 704
#define sipName_ComparisonFunction &sipStrings_QtGui[704]
#define sipNameNr_CurveToDataElement 15273
#define sipName_CurveToDataElement &sipStrings_QtGui[15273]
#define sipNameNr_DeleteCompleteLine 15292
#define sipName_DeleteCompleteLine &sipStrings_QtGui[15292]
#define sipNameNr_FanFoldGermanLegal 15311
#define sipName_FanFoldGermanLegal &sipStrings_QtGui[15311]
#define sipNameNr_FontCapitalization 11397
#define sipName_FontCapitalization &sipStrings_QtGui[11397]
#define sipNameNr_FontSizeAdjustment 15330
#define sipName_FontSizeAdjustment &sipStrings_QtGui[15330]
#define sipNameNr_Format_Grayscale16 15349
#define sipName_Format_Grayscale16 &sipStrings_QtGui[15349]
#define sipNameNr_FullWidthSelection 15368
#define sipName_FullWidthSelection &sipStrings_QtGui[15368]
#define sipNameNr_IncrementalReading 15387
#define sipName_IncrementalReading &sipStrings_QtGui[15387]
#define sipNameNr_LineDistanceHeight 15406
#define sipName_LineDistanceHeight &sipStrings_QtGui[15406]
#define sipNameNr_LinearGradientFill 15425
#define sipName_LinearGradientFill &sipStrings_QtGui[15425]
#define sipNameNr_LinearMipMapLinear 15444
#define sipName_LinearMipMapLinear &sipStrings_QtGui[15444]
#define sipNameNr_MoveToPreviousChar 15463
#define sipName_MoveToPreviousChar &sipStrings_QtGui[15463]
#define sipNameNr_MoveToPreviousLine 15482
#define sipName_MoveToPreviousLine &sipStrings_QtGui[15482]
#define sipNameNr_MoveToPreviousPage 15501
#define sipName_MoveToPreviousPage &sipStrings_QtGui[15501]
#define sipNameNr_MoveToPreviousWord 15520
#define sipName_MoveToPreviousWord &sipStrings_QtGui[15520]
#define sipNameNr_MoveToStartOfBlock 15539
#define sipName_MoveToStartOfBlock &sipStrings_QtGui[15539]
#define sipNameNr_NormalizedPosition 15558
#define sipName_NormalizedPosition &sipStrings_QtGui[15558]
#define sipNameNr_ObjectBoundingMode 15577
#define sipName_ObjectBoundingMode &sipStrings_QtGui[15577]
#define sipNameNr_PaintEngineFeature 1448
#define sipName_PaintEngineFeature &sipStrings_QtGui[1448]
#define sipNameNr_PartialUpdateBlend 15596
#define sipName_PartialUpdateBlend &sipStrings_QtGui[15596]
#define sipNameNr_PixmapFragmentHint 3912
#define sipName_PixmapFragmentHint &sipStrings_QtGui[3912]
#define sipNameNr_PrimitiveTransform 15615
#define sipName_PrimitiveTransform &sipStrings_QtGui[15615]
#define sipNameNr_ProportionalHeight 15634
#define sipName_ProportionalHeight &sipStrings_QtGui[15634]
#define sipNameNr_QColor__NameFormat 15653
#define sipName_QColor__NameFormat &sipStrings_QtGui[15653]
#define sipNameNr_QFont__SpacingType 15672
#define sipName_QFont__SpacingType &sipStrings_QtGui[15672]
#define sipNameNr_QImage__InvertMode 15691
#define sipName_QImage__InvertMode &sipStrings_QtGui[15691]
#define sipNameNr_15710 15710
#define sipName_15710 &sipStrings_QtGui[15710]
#define sipNameNr_QMovie__MovieState 15729
#define sipName_QMovie__MovieState &sipStrings_QtGui[15729]
#define sipNameNr_QOpenGLDebugLogger 15748
#define sipName_QOpenGLDebugLogger &sipStrings_QtGui[15748]
#define sipNameNr_QOpenGLPaintDevice 15767
#define sipName_QOpenGLPaintDevice &sipStrings_QtGui[15767]
#define sipNameNr_QPaintDeviceWindow 15786
#define sipName_QPaintDeviceWindow &sipStrings_QtGui[15786]
#define sipNameNr_QPaintEngine__Type 15805
#define sipName_QPaintEngine__Type &sipStrings_QtGui[15805]
#define sipNameNr_15824 15824
#define sipName_15824 &sipStrings_QtGui[15824]
#define sipNameNr_QStandardItemModel 15843
#define sipName_QStandardItemModel &sipStrings_QtGui[15843]
#define sipNameNr_QSyntaxHighlighter 15862
#define sipName_QSyntaxHighlighter &sipStrings_QtGui[15862]
#define sipNameNr_QTextBlockUserData 15881
#define sipName_QTextBlockUserData &sipStrings_QtGui[15881]
#define sipNameNr_QTextOption__Flags 15900
#define sipName_QTextOption__Flags &sipStrings_QtGui[15900]
#define sipNameNr_RadialGradientFill 15919
#define sipName_RadialGradientFill &sipStrings_QtGui[15919]
#define sipNameNr_RangeFlushExplicit 15938
#define sipName_RangeFlushExplicit &sipStrings_QtGui[15938]
#define sipNameNr_RasterOp_NotSource 15957
#define sipName_RasterOp_NotSource &sipStrings_QtGui[15957]
#define sipNameNr_ScientificNotation 15976
#define sipName_ScientificNotation &sipStrings_QtGui[15976]
#define sipNameNr_SelectPreviousChar 15995
#define sipName_SelectPreviousChar &sipStrings_QtGui[15995]
#define sipNameNr_SelectPreviousLine 16014
#define sipName_SelectPreviousLine &sipStrings_QtGui[16014]
#define sipNameNr_SelectPreviousPage 16033
#define sipName_SelectPreviousPage &sipStrings_QtGui[16033]
#define sipNameNr_SelectPreviousWord 16052
#define sipName_SelectPreviousWord &sipStrings_QtGui[16052]
#define sipNameNr_SelectStartOfBlock 16071
#define sipName_SelectStartOfBlock &sipStrings_QtGui[16071]
#define sipNameNr_StyleSheetResource 16090
#define sipName_StyleSheetResource &sipStrings_QtGui[16090]
#define sipNameNr_SynchronousLogging 16109
#define sipName_SynchronousLogging &sipStrings_QtGui[16109]
#define sipNameNr_TableCellTopBorder 16128
#define sipName_TableCellTopBorder &sipStrings_QtGui[16128]
#define sipNameNr_TargetCubeMapArray 5574
#define sipName_TargetCubeMapArray &sipStrings_QtGui[5574]
#define sipNameNr_TextUnderlineColor 16147
#define sipName_TextUnderlineColor &sipStrings_QtGui[16147]
#define sipNameNr_TextUnderlineStyle 16166
#define sipName_TextUnderlineStyle &sipStrings_QtGui[16166]
#define sipNameNr_TextureMipMapLevel 16185
#define sipName_TextureMipMapLevel &sipStrings_QtGui[16185]
#define sipNameNr_TextureMultisample 16204
#define sipName_TextureMultisample &sipStrings_QtGui[16204]
#define sipNameNr_TraditionalChinese 16223
#define sipName_TraditionalChinese &sipStrings_QtGui[16223]
#define sipNameNr_TransformationFlip 16242
#define sipName_TransformationFlip &sipStrings_QtGui[16242]
#define sipNameNr_TransformationNone 16261
#define sipName_TransformationNone &sipStrings_QtGui[16261]
#define sipNameNr_TransformationType 2566
#define sipName_TransformationType &sipStrings_QtGui[2566]
#define sipNameNr_TypeInterpretation 1514
#define sipName_TypeInterpretation &sipStrings_QtGui[1514]
#define sipNameNr_UInt32_RGB10A2_Rev 16280
#define sipName_UInt32_RGB10A2_Rev &sipStrings_QtGui[16280]
#define sipNameNr_WindowSystemSource 16299
#define sipName_WindowSystemSource &sipStrings_QtGui[16299]
#define sipNameNr_aboutToBeDestroyed 16318
#define sipName_aboutToBeDestroyed &sipStrings_QtGui[16318]
#define sipNameNr_addApplicationFont 16337
#define sipName_addApplicationFont &sipStrings_QtGui[16337]
#define sipNameNr_addColorAttachment 16356
#define sipName_addColorAttachment &sipStrings_QtGui[16356]
#define sipNameNr_availableRedoSteps 16375
#define sipName_availableRedoSteps &sipStrings_QtGui[16375]
#define sipNameNr_availableUndoSteps 16394
#define sipName_availableUndoSteps &sipStrings_QtGui[16394]
#define sipNameNr_blockFormatChanged 16413
#define sipName_blockFormatChanged &sipStrings_QtGui[16413]
#define sipNameNr_comparisonFunction 16432
#define sipName_comparisonFunction &sipStrings_QtGui[16432]
#define sipNameNr_contentOrientation 16451
#define sipName_contentOrientation &sipStrings_QtGui[16451]
#define sipNameNr_currentFrameNumber 16470
#define sipName_currentFrameNumber &sipStrings_QtGui[16470]
#define sipNameNr_currentImageNumber 16489
#define sipName_currentImageNumber &sipStrings_QtGui[16489]
#define sipNameNr_deletePreviousChar 16508
#define sipName_deletePreviousChar &sipStrings_QtGui[16508]
#define sipNameNr_ensureActiveTarget 16527
#define sipName_ensureActiveTarget &sipStrings_QtGui[16527]
#define sipNameNr_focusObjectChanged 16546
#define sipName_focusObjectChanged &sipStrings_QtGui[16546]
#define sipNameNr_focusWindowChanged 16565
#define sipName_focusWindowChanged &sipStrings_QtGui[16565]
#define sipNameNr_fontCapitalization 16584
#define sipName_fontCapitalization &sipStrings_QtGui[16584]
#define sipNameNr_fontSmoothingGamma 16603
#define sipName_fontSmoothingGamma &sipStrings_QtGui[16603]
#define sipNameNr_fromRotationMatrix 16622
#define sipName_fromRotationMatrix &sipStrings_QtGui[16622]
#define sipNameNr_globalShareContext 16641
#define sipName_globalShareContext &sipStrings_QtGui[16641]
#define sipNameNr_inputItemRectangle 16660
#define sipName_inputItemRectangle &sipStrings_QtGui[16660]
#define sipNameNr_inputItemTransform 16679
#define sipName_inputItemTransform &sipStrings_QtGui[16679]
#define sipNameNr_insertSubstitution 16698
#define sipName_insertSubstitution &sipStrings_QtGui[16698]
#define sipNameNr_isSmoothlyScalable 16717
#define sipName_isSmoothlyScalable &sipStrings_QtGui[16717]
#define sipNameNr_isStorageAllocated 16736
#define sipName_isStorageAllocated &sipStrings_QtGui[16736]
#define sipNameNr_isSwapBytesEnabled 16755
#define sipName_isSwapBytesEnabled &sipStrings_QtGui[16755]
#define sipNameNr_lastCursorPosition 16774
#define sipName_lastCursorPosition &sipStrings_QtGui[16774]
#define sipNameNr_leftCursorPosition 16793
#define sipName_leftCursorPosition &sipStrings_QtGui[16793]
#define sipNameNr_levelOfDetailRange 16812
#define sipName_levelOfDetailRange &sipStrings_QtGui[16812]
#define sipNameNr_logicalDotsPerInch 16831
#define sipName_logicalDotsPerInch &sipStrings_QtGui[16831]
#define sipNameNr_maximumTouchPoints 16850
#define sipName_maximumTouchPoints &sipStrings_QtGui[16850]
#define sipNameNr_minificationFilter 16869
#define sipName_minificationFilter &sipStrings_QtGui[16869]
#define sipNameNr_nextCursorPosition 16888
#define sipName_nextCursorPosition &sipStrings_QtGui[16888]
#define sipNameNr_openGLModuleHandle 16907
#define sipName_openGLModuleHandle &sipStrings_QtGui[16907]
#define sipNameNr_orientationChanged 16926
#define sipName_orientationChanged &sipStrings_QtGui[16926]
#define sipNameNr_previousBlockState 16945
#define sipName_previousBlockState &sipStrings_QtGui[16945]
#define sipNameNr_primaryOrientation 16964
#define sipName_primaryOrientation &sipStrings_QtGui[16964]
#define sipNameNr_rawScreenPositions 16983
#define sipName_rawScreenPositions &sipStrings_QtGui[16983]
#define sipNameNr_refreshRateChanged 17002
#define sipName_refreshRateChanged &sipStrings_QtGui[17002]
#define sipNameNr_removeSelectedText 17021
#define sipName_removeSelectedText &sipStrings_QtGui[17021]
#define sipNameNr_resizeInlineObject 17040
#define sipName_resizeInlineObject &sipStrings_QtGui[17040]
#define sipNameNr_selectedTableCells 17059
#define sipName_selectedTableCells &sipStrings_QtGui[17059]
#define sipNameNr_setAlphaBufferSize 17078
#define sipName_setAlphaBufferSize &sipStrings_QtGui[17078]
#define sipNameNr_setAttributeBuffer 17097
#define sipName_setAttributeBuffer &sipStrings_QtGui[17097]
#define sipNameNr_setBackgroundColor 17116
#define sipName_setBackgroundColor &sipStrings_QtGui[17116]
#define sipNameNr_setBlockCharFormat 17135
#define sipName_setBlockCharFormat &sipStrings_QtGui[17135]
#define sipNameNr_setCompositionMode 17154
#define sipName_setCompositionMode &sipStrings_QtGui[17154]
#define sipNameNr_setContentPosRange 17173
#define sipName_setContentPosRange &sipStrings_QtGui[17173]
#define sipNameNr_setCursorMoveStyle 17192
#define sipName_setCursorMoveStyle &sipStrings_QtGui[17192]
#define sipNameNr_setDepthBufferSize 17211
#define sipName_setDepthBufferSize &sipStrings_QtGui[17211]
#define sipNameNr_setDesktopFileName 17230
#define sipName_setDesktopFileName &sipStrings_QtGui[17230]
#define sipNameNr_setFontWordSpacing 17249
#define sipName_setFontWordSpacing &sipStrings_QtGui[17249]
#define sipNameNr_setGreenBufferSize 17268
#define sipName_setGreenBufferSize &sipStrings_QtGui[17268]
#define sipNameNr_setLayoutDirection 17287
#define sipName_setLayoutDirection &sipStrings_QtGui[17287]
#define sipNameNr_setLeadingIncluded 17306
#define sipName_setLeadingIncluded &sipStrings_QtGui[17306]
#define sipNameNr_setLeftBorderBrush 17325
#define sipName_setLeftBorderBrush &sipStrings_QtGui[17325]
#define sipNameNr_setLeftBorderStyle 17344
#define sipName_setLeftBorderStyle &sipStrings_QtGui[17344]
#define sipNameNr_setMetaInformation 17363
#define sipName_setMetaInformation &sipStrings_QtGui[17363]
#define sipNameNr_setPageBreakPolicy 17382
#define sipName_setPageBreakPolicy &sipStrings_QtGui[17382]
#define sipNameNr_setPageOrientation 17401
#define sipName_setPageOrientation &sipStrings_QtGui[17401]
#define sipNameNr_setPerformanceHint 17420
#define sipName_setPerformanceHint &sipStrings_QtGui[17420]
#define sipNameNr_setTabStopDistance 17439
#define sipName_setTabStopDistance &sipStrings_QtGui[17439]
#define sipNameNr_setTransientParent 17458
#define sipName_setTransientParent &sipStrings_QtGui[17458]
#define sipNameNr_setUndoRedoEnabled 17477
#define sipName_setUndoRedoEnabled &sipStrings_QtGui[17477]
#define sipNameNr_setUseHoverEffects 17496
#define sipName_setUseHoverEffects &sipStrings_QtGui[17496]
#define sipNameNr_startNormalizedPos 17515
#define sipName_startNormalizedPos &sipStrings_QtGui[17515]
#define sipNameNr_supportedMimeTypes 17534
#define sipName_supportedMimeTypes &sipStrings_QtGui[17534]
#define sipNameNr_supportsFindBuffer 17553
#define sipName_supportsFindBuffer &sipStrings_QtGui[17553]
#define sipNameNr_tangentialPressure 17572
#define sipName_tangentialPressure &sipStrings_QtGui[17572]
#define sipNameNr_typeInterpretation 17591
#define sipName_typeInterpretation &sipStrings_QtGui[17591]
#define sipNameNr_verticalHeaderItem 17610
#define sipName_verticalHeaderItem &sipStrings_QtGui[17610]
#define sipNameNr_windowStateChanged 17629
#define sipName_windowStateChanged &sipStrings_QtGui[17629]
#define sipNameNr_windowTitleChanged 17648
#define sipName_windowTitleChanged &sipStrings_QtGui[17648]
#define sipNameNr_worldMatrixEnabled 17667
#define sipName_worldMatrixEnabled &sipStrings_QtGui[17667]
#define sipNameNr_AggressiveCaching 17686
#define sipName_AggressiveCaching &sipStrings_QtGui[17686]
#define sipNameNr_ApplicationSource 17704
#define sipName_ApplicationSource &sipStrings_QtGui[17704]
#define sipNameNr_BlockBottomMargin 17722
#define sipName_BlockBottomMargin &sipStrings_QtGui[17722]
#define sipNameNr_BlockCodeLanguage 17740
#define sipName_BlockCodeLanguage &sipStrings_QtGui[17740]
#define sipNameNr_BorderStyle_Inset 17758
#define sipName_BorderStyle_Inset &sipStrings_QtGui[17758]
#define sipNameNr_BorderStyle_Ridge 17776
#define sipName_BorderStyle_Ridge &sipStrings_QtGui[17776]
#define sipNameNr_BorderStyle_Solid 17794
#define sipName_BorderStyle_Solid &sipStrings_QtGui[17794]
#define sipNameNr_CursorOnCharacter 17812
#define sipName_CursorOnCharacter &sipStrings_QtGui[17812]
#define sipNameNr_DefaultColorSpace 17830
#define sipName_DefaultColorSpace &sipStrings_QtGui[17830]
#define sipNameNr_DeleteStartOfWord 17848
#define sipName_DeleteStartOfWord &sipStrings_QtGui[17848]
#define sipNameNr_ExcludeTransients 17866
#define sipName_ExcludeTransients &sipStrings_QtGui[17866]
#define sipNameNr_ExecutiveStandard 17884
#define sipName_ExecutiveStandard &sipStrings_QtGui[17884]
#define sipNameNr_FileNotFoundError 17902
#define sipName_FileNotFoundError &sipStrings_QtGui[17902]
#define sipNameNr_FirstFontProperty 17920
#define sipName_FirstFontProperty &sipStrings_QtGui[17920]
#define sipNameNr_FontLetterSpacing 13045
#define sipName_FontLetterSpacing &sipStrings_QtGui[13045]
#define sipNameNr_FontPropertiesAll 17938
#define sipName_FontPropertiesAll &sipStrings_QtGui[17938]
#define sipNameNr_FontSizeIncrement 17956
#define sipName_FontSizeIncrement &sipStrings_QtGui[17956]
#define sipNameNr_FontStyleStrategy 13066
#define sipName_FontStyleStrategy &sipStrings_QtGui[13066]
#define sipNameNr_Format_Grayscale8 17974
#define sipName_Format_Grayscale8 &sipStrings_QtGui[17974]
#define sipNameNr_FrameBottomMargin 17992
#define sipName_FrameBottomMargin &sipStrings_QtGui[17992]
#define sipNameNr_HintingPreference 6662
#define sipName_HintingPreference &sipStrings_QtGui[6662]
#define sipNameNr_IncludeTransients 18010
#define sipName_IncludeTransients &sipStrings_QtGui[18010]
#define sipNameNr_InvalidImageError 18028
#define sipName_InvalidImageError &sipStrings_QtGui[18028]
#define sipNameNr_MoveToStartOfLine 18046
#define sipName_MoveToStartOfLine &sipStrings_QtGui[18046]
#define sipNameNr_NPOTTextureRepeat 18064
#define sipName_NPOTTextureRepeat &sipStrings_QtGui[18064]
#define sipNameNr_PaintDeviceMetric 2034
#define sipName_PaintDeviceMetric &sipStrings_QtGui[2034]
#define sipNameNr_PartialUpdateBlit 18082
#define sipName_PartialUpdateBlit &sipStrings_QtGui[18082]
#define sipNameNr_PercentageSpacing 18100
#define sipName_PercentageSpacing &sipStrings_QtGui[18100]
#define sipNameNr_PixelAntialiasing 12268
#define sipName_PixelAntialiasing &sipStrings_QtGui[12268]
#define sipNameNr_PixelUnpackBuffer 18118
#define sipName_PixelUnpackBuffer &sipStrings_QtGui[18118]
#define sipNameNr_PreferFullHinting 18136
#define sipName_PreferFullHinting &sipStrings_QtGui[18136]
#define sipNameNr_PreviousCharacter 18154
#define sipName_PreviousCharacter &sipStrings_QtGui[18154]
#define sipNameNr_QContextMenuEvent 18172
#define sipName_QContextMenuEvent &sipStrings_QtGui[18172]
#define sipNameNr_QGradient__Preset 18190
#define sipName_QGradient__Preset &sipStrings_QtGui[18190]
#define sipNameNr_QGradient__Spread 18208
#define sipName_QGradient__Spread &sipStrings_QtGui[18208]
#define sipNameNr_QInputMethodEvent 18226
#define sipName_QInputMethodEvent &sipStrings_QtGui[18226]
#define sipNameNr_18244 18244
#define sipName_18244 &sipStrings_QtGui[18244]
#define sipNameNr_QMovie__CacheMode 18262
#define sipName_QMovie__CacheMode &sipStrings_QtGui[18262]
#define sipNameNr_QOffscreenSurface 18280
#define sipName_QOffscreenSurface &sipStrings_QtGui[18280]
#define sipNameNr_QPageLayout__Mode 18298
#define sipName_QPageLayout__Mode &sipStrings_QtGui[18298]
#define sipNameNr_QPageLayout__Unit 18316
#define sipName_QPageLayout__Unit &sipStrings_QtGui[18316]
#define sipNameNr_QPagedPaintDevice 18334
#define sipName_QPagedPaintDevice &sipStrings_QtGui[18334]
#define sipNameNr_QPaintEngineState 18352
#define sipName_QPaintEngineState &sipStrings_QtGui[18352]
#define sipNameNr_QPixmapCache__Key 18370
#define sipName_QPixmapCache__Key &sipStrings_QtGui[18370]
#define sipNameNr_QTextInlineObject 18388
#define sipName_QTextInlineObject &sipStrings_QtGui[18388]
#define sipNameNr_QTextLength__Type 18406
#define sipName_QTextLength__Type &sipStrings_QtGui[18406]
#define sipNameNr_QTextOption__Flag 18424
#define sipName_QTextOption__Flag &sipStrings_QtGui[18424]
#define sipNameNr_QValidator__State 18442
#define sipName_QValidator__State &sipStrings_QtGui[18442]
#define sipNameNr_ResetNotification 18460
#define sipName_ResetNotification &sipStrings_QtGui[18460]
#define sipNameNr_SelectStartOfLine 18478
#define sipName_SelectStartOfLine &sipStrings_QtGui[18478]
#define sipNameNr_ShowTabsAndSpaces 18496
#define sipName_ShowTabsAndSpaces &sipStrings_QtGui[18496]
#define sipNameNr_SimplifiedChinese 18514
#define sipName_SimplifiedChinese &sipStrings_QtGui[18514]
#define sipNameNr_SupportedSubTypes 18532
#define sipName_SupportedSubTypes &sipStrings_QtGui[18532]
#define sipNameNr_UInt16_R5G6B5_Rev 18550
#define sipName_UInt16_R5G6B5_Rev &sipStrings_QtGui[18550]
#define sipNameNr_UInt16_RGB5A1_Rev 18568
#define sipName_UInt16_RGB5A1_Rev &sipStrings_QtGui[18568]
#define sipNameNr_UndoAndRedoStacks 18586
#define sipName_UndoAndRedoStacks &sipStrings_QtGui[18586]
#define sipNameNr_VerticalAlignment 740
#define sipName_VerticalAlignment &sipStrings_QtGui[740]
#define sipNameNr_addFileAttachment 18604
#define sipName_addFileAttachment &sipStrings_QtGui[18604]
#define sipNameNr_additionalFormats 18622
#define sipName_additionalFormats &sipStrings_QtGui[18622]
#define sipNameNr_attributeLocation 18640
#define sipName_attributeLocation &sipStrings_QtGui[18640]
#define sipNameNr_availableGeometry 18658
#define sipName_availableGeometry &sipStrings_QtGui[18658]
#define sipNameNr_blockBoundingRect 18676
#define sipName_blockBoundingRect &sipStrings_QtGui[18676]
#define sipNameNr_blockCountChanged 18694
#define sipName_blockCountChanged &sipStrings_QtGui[18694]
#define sipNameNr_blockWithMarkerAt 18712
#define sipName_blockWithMarkerAt &sipStrings_QtGui[18712]
#define sipNameNr_bottomBorderBrush 18730
#define sipName_bottomBorderBrush &sipStrings_QtGui[18730]
#define sipNameNr_bottomBorderStyle 18748
#define sipName_bottomBorderStyle &sipStrings_QtGui[18748]
#define sipNameNr_combinedTransform 18766
#define sipName_combinedTransform &sipStrings_QtGui[18766]
#define sipNameNr_compileSourceCode 18784
#define sipName_compileSourceCode &sipStrings_QtGui[18784]
#define sipNameNr_compileSourceFile 18802
#define sipName_compileSourceFile &sipStrings_QtGui[18802]
#define sipNameNr_createTextureView 18820
#define sipName_createTextureView &sipStrings_QtGui[18820]
#define sipNameNr_currentBlockState 18838
#define sipName_currentBlockState &sipStrings_QtGui[18838]
#define sipNameNr_currentColorGroup 18856
#define sipName_currentColorGroup &sipStrings_QtGui[18856]
#define sipNameNr_defaultStyleSheet 18874
#define sipName_defaultStyleSheet &sipStrings_QtGui[18874]
#define sipNameNr_defaultTextOption 18892
#define sipName_defaultTextOption &sipStrings_QtGui[18892]
#define sipNameNr_devicePixelRatioF 18910
#define sipName_devicePixelRatioF &sipStrings_QtGui[18910]
#define sipNameNr_drawConvexPolygon 18928
#define sipName_drawConvexPolygon &sipStrings_QtGui[18928]
#define sipNameNr_endNativePainting 18946
#define sipName_endNativePainting &sipStrings_QtGui[18946]
#define sipNameNr_fallbackThemeName 18964
#define sipName_fallbackThemeName &sipStrings_QtGui[18964]
#define sipNameNr_findBlockByNumber 18982
#define sipName_findBlockByNumber &sipStrings_QtGui[18982]
#define sipNameNr_findBufferChanged 19000
#define sipName_findBufferChanged &sipStrings_QtGui[19000]
#define sipNameNr_fontLetterSpacing 19018
#define sipName_fontLetterSpacing &sipStrings_QtGui[19018]
#define sipNameNr_fontStyleStrategy 19036
#define sipName_fontStyleStrategy &sipStrings_QtGui[19036]
#define sipNameNr_frameBoundingRect 19054
#define sipName_frameBoundingRect &sipStrings_QtGui[19054]
#define sipNameNr_hasStaticContents 19072
#define sipName_hasStaticContents &sipStrings_QtGui[19072]
#define sipNameNr_hintingPreference 19090
#define sipName_hintingPreference &sipStrings_QtGui[19090]
#define sipNameNr_horizontalAdvance 19108
#define sipName_horizontalAdvance &sipStrings_QtGui[19108]
#define sipNameNr_invisibleRootItem 19126
#define sipName_invisibleRootItem &sipStrings_QtGui[19126]
#define sipNameNr_isTableCellFormat 19144
#define sipName_isTableCellFormat &sipStrings_QtGui[19144]
#define sipNameNr_isUndoRedoEnabled 19162
#define sipName_isUndoRedoEnabled &sipStrings_QtGui[19162]
#define sipNameNr_keyboardModifiers 19180
#define sipName_keyboardModifiers &sipStrings_QtGui[19180]
#define sipNameNr_keyboardRectangle 19198
#define sipName_keyboardRectangle &sipStrings_QtGui[19198]
#define sipNameNr_lastNormalizedPos 19216
#define sipName_lastNormalizedPos &sipStrings_QtGui[19216]
#define sipNameNr_letterSpacingType 19234
#define sipName_letterSpacingType &sipStrings_QtGui[19234]
#define sipNameNr_levelofDetailBias 19252
#define sipName_levelofDetailBias &sipStrings_QtGui[19252]
#define sipNameNr_markContentsDirty 19270
#define sipName_markContentsDirty &sipStrings_QtGui[19270]
#define sipNameNr_maximumAnisotropy 19288
#define sipName_maximumAnisotropy &sipStrings_QtGui[19288]
#define sipNameNr_maximumBlockCount 19306
#define sipName_maximumBlockCount &sipStrings_QtGui[19306]
#define sipNameNr_mediumspringgreen 19324
#define sipName_mediumspringgreen &sipStrings_QtGui[19324]
#define sipNameNr_mouseReleaseEvent 19342
#define sipName_mouseReleaseEvent &sipStrings_QtGui[19342]
#define sipNameNr_nativeOrientation 19360
#define sipName_nativeOrientation &sipStrings_QtGui[19360]
#define sipNameNr_nonBreakableLines 19378
#define sipName_nonBreakableLines &sipStrings_QtGui[19378]
#define sipNameNr_overshootDistance 19396
#define sipName_overshootDistance &sipStrings_QtGui[19396]
#define sipNameNr_passwordMaskDelay 19414
#define sipName_passwordMaskDelay &sipStrings_QtGui[19414]
#define sipNameNr_penNeedsResolving 19432
#define sipName_penNeedsResolving &sipStrings_QtGui[19432]
#define sipNameNr_qPixelFormatAlpha 19450
#define sipName_qPixelFormatAlpha &sipStrings_QtGui[19450]
#define sipNameNr_regularExpression 19468
#define sipName_regularExpression &sipStrings_QtGui[19468]
#define sipNameNr_replacementLength 19486
#define sipName_replacementLength &sipStrings_QtGui[19486]
#define sipNameNr_setAccessibleText 19504
#define sipName_setAccessibleText &sipStrings_QtGui[19504]
#define sipNameNr_setAttributeArray 19522
#define sipName_setAttributeArray &sipStrings_QtGui[19522]
#define sipNameNr_setAttributeValue 19540
#define sipName_setAttributeValue &sipStrings_QtGui[19540]
#define sipNameNr_setBackgroundMode 19558
#define sipName_setBackgroundMode &sipStrings_QtGui[19558]
#define sipNameNr_setBlueBufferSize 19576
#define sipName_setBlueBufferSize &sipStrings_QtGui[19576]
#define sipNameNr_setBorderCollapse 19594
#define sipName_setBorderCollapse &sipStrings_QtGui[19594]
#define sipNameNr_setCapitalization 19612
#define sipName_setCapitalization &sipStrings_QtGui[19612]
#define sipNameNr_setComparisonMode 19630
#define sipName_setComparisonMode &sipStrings_QtGui[19630]
#define sipNameNr_setCompressedData 19648
#define sipName_setCompressedData &sipStrings_QtGui[19648]
#define sipNameNr_setCoordinateMode 19666
#define sipName_setCoordinateMode &sipStrings_QtGui[19666]
#define sipNameNr_setCurveThreshold 19684
#define sipName_setCurveThreshold &sipStrings_QtGui[19684]
#define sipNameNr_setDocumentLayout 19702
#define sipName_setDocumentLayout &sipStrings_QtGui[19702]
#define sipNameNr_setDocumentMargin 19720
#define sipName_setDocumentMargin &sipStrings_QtGui[19720]
#define sipNameNr_setFontFixedPitch 19738
#define sipName_setFontFixedPitch &sipStrings_QtGui[19738]
#define sipNameNr_setHeaderRowCount 19756
#define sipName_setHeaderRowCount &sipStrings_QtGui[19756]
#define sipNameNr_setMinimumMargins 19774
#define sipName_setMinimumMargins &sipStrings_QtGui[19774]
#define sipNameNr_setOptimizedWrite 19792
#define sipName_setOptimizedWrite &sipStrings_QtGui[19792]
#define sipNameNr_setOverrideCursor 19810
#define sipName_setOverrideCursor &sipStrings_QtGui[19810]
#define sipNameNr_setRedBlueSwizzle 19828
#define sipName_setRedBlueSwizzle &sipStrings_QtGui[19828]
#define sipNameNr_setRenderableType 19846
#define sipName_setRenderableType &sipStrings_QtGui[19846]
#define sipNameNr_setScaledClipRect 19864
#define sipName_setScaledClipRect &sipStrings_QtGui[19864]
#define sipNameNr_setStaticContents 19882
#define sipName_setStaticContents &sipStrings_QtGui[19882]
#define sipNameNr_setTopBorderBrush 19900
#define sipName_setTopBorderBrush &sipStrings_QtGui[19900]
#define sipNameNr_setTopBorderStyle 19918
#define sipName_setTopBorderStyle &sipStrings_QtGui[19918]
#define sipNameNr_setTransformation 19936
#define sipName_setTransformation &sipStrings_QtGui[19936]
#define sipNameNr_setUnderlineColor 19954
#define sipName_setUnderlineColor &sipStrings_QtGui[19954]
#define sipNameNr_setUnderlineStyle 19972
#define sipName_setUnderlineStyle &sipStrings_QtGui[19972]
#define sipNameNr_setWorldTransform 19990
#define sipName_setWorldTransform &sipStrings_QtGui[19990]
#define sipNameNr_sip_simplewrapper 20008
#define sipName_sip_simplewrapper &sipStrings_QtGui[20008]
#define sipNameNr_startDragDistance 20026
#define sipName_startDragDistance &sipStrings_QtGui[20026]
#define sipNameNr_startDragVelocity 20044
#define sipName_startDragVelocity &sipStrings_QtGui[20044]
#define sipNameNr_startSystemResize 20062
#define sipName_startSystemResize &sipStrings_QtGui[20062]
#define sipNameNr_stencilBufferSize 20080
#define sipName_stencilBufferSize &sipStrings_QtGui[20080]
#define sipNameNr_supportedSubTypes 20098
#define sipName_supportedSubTypes &sipStrings_QtGui[20098]
#define sipNameNr_supportsAnimation 20116
#define sipName_supportsAnimation &sipStrings_QtGui[20116]
#define sipNameNr_supportsCharacter 20134
#define sipName_supportsCharacter &sipStrings_QtGui[20134]
#define sipNameNr_supportsSelection 20152
#define sipName_supportsSelection &sipStrings_QtGui[20152]
#define sipNameNr_tightBoundingRect 20170
#define sipName_tightBoundingRect &sipStrings_QtGui[20170]
#define sipNameNr_toSubpathPolygons 20188
#define sipName_toSubpathPolygons &sipStrings_QtGui[20188]
#define sipNameNr_toTableCellFormat 20206
#define sipName_toTableCellFormat &sipStrings_QtGui[20206]
#define sipNameNr_underlinePosition 20224
#define sipName_underlinePosition &sipStrings_QtGui[20224]
#define sipNameNr_unregisterHandler 20242
#define sipName_unregisterHandler &sipStrings_QtGui[20242]
#define sipNameNr_verticalAlignment 20260
#define sipName_verticalAlignment &sipStrings_QtGui[20260]
#define sipNameNr_verticalMovementX 20278
#define sipName_verticalMovementX &sipStrings_QtGui[20278]
#define sipNameNr_visibilityChanged 20296
#define sipName_visibilityChanged &sipStrings_QtGui[20296]
#define sipNameNr_writingSystemName 20314
#define sipName_writingSystemName &sipStrings_QtGui[20314]
#define sipNameNr_AlignSuperScript 20332
#define sipName_AlignSuperScript &sipStrings_QtGui[20332]
#define sipNameNr_AntialiasingType 5145
#define sipName_AntialiasingType &sipStrings_QtGui[5145]
#define sipNameNr_BlockRightMargin 20349
#define sipName_BlockRightMargin &sipStrings_QtGui[20349]
#define sipNameNr_BlockUnderCursor 20366
#define sipName_BlockUnderCursor &sipStrings_QtGui[20366]
#define sipNameNr_BorderStyle_None 20383
#define sipName_BorderStyle_None &sipStrings_QtGui[20383]
#define sipNameNr_CommpareNotEqual 20400
#define sipName_CommpareNotEqual &sipStrings_QtGui[20400]
#define sipNameNr_CompareLessEqual 20417
#define sipName_CompareLessEqual &sipStrings_QtGui[20417]
#define sipNameNr_CompressionRatio 20434
#define sipName_CompressionRatio &sipStrings_QtGui[20434]
#define sipNameNr_CubeMapNegativeX 20451
#define sipName_CubeMapNegativeX &sipStrings_QtGui[20451]
#define sipNameNr_CubeMapNegativeY 20468
#define sipName_CubeMapNegativeY &sipStrings_QtGui[20468]
#define sipNameNr_CubeMapNegativeZ 20485
#define sipName_CubeMapNegativeZ &sipStrings_QtGui[20485]
#define sipNameNr_CubeMapPositiveX 20502
#define sipName_CubeMapPositiveX &sipStrings_QtGui[20502]
#define sipNameNr_CubeMapPositiveY 20519
#define sipName_CubeMapPositiveY &sipStrings_QtGui[20519]
#define sipNameNr_CubeMapPositiveZ 20536
#define sipName_CubeMapPositiveZ &sipStrings_QtGui[20536]
#define sipNameNr_DepthStencilMode 1285
#define sipName_DepthStencilMode &sipStrings_QtGui[1285]
#define sipNameNr_DirtyBrushOrigin 20553
#define sipName_DirtyBrushOrigin &sipStrings_QtGui[20553]
#define sipNameNr_DirtyClipEnabled 20570
#define sipName_DirtyClipEnabled &sipStrings_QtGui[20570]
#define sipNameNr_EnvelopePersonal 20587
#define sipName_EnvelopePersonal &sipStrings_QtGui[20587]
#define sipNameNr_EternalConstance 20604
#define sipName_EternalConstance &sipStrings_QtGui[20604]
#define sipNameNr_FrameBorderBrush 20621
#define sipName_FrameBorderBrush &sipStrings_QtGui[20621]
#define sipNameNr_FrameBorderStyle 20638
#define sipName_FrameBorderStyle &sipStrings_QtGui[20638]
#define sipNameNr_FrameRightMargin 20655
#define sipName_FrameRightMargin &sipStrings_QtGui[20655]
#define sipNameNr_ImageReaderError 2289
#define sipName_ImageReaderError &sipStrings_QtGui[2289]
#define sipNameNr_ImageWriterError 2320
#define sipName_ImageWriterError &sipStrings_QtGui[2320]
#define sipNameNr_ImmutableStorage 20672
#define sipName_ImmutableStorage &sipStrings_QtGui[20672]
#define sipNameNr_InvalidDataError 20689
#define sipName_InvalidDataError &sipStrings_QtGui[20689]
#define sipNameNr_LastFontProperty 20706
#define sipName_LastFontProperty &sipStrings_QtGui[20706]
#define sipNameNr_ListNumberPrefix 20723
#define sipName_ListNumberPrefix &sipStrings_QtGui[20723]
#define sipNameNr_ListNumberSuffix 20740
#define sipName_ListNumberSuffix &sipStrings_QtGui[20740]
#define sipNameNr_MarkdownFeatures 2099
#define sipName_MarkdownFeatures &sipStrings_QtGui[2099]
#define sipNameNr_MarkdownResource 20757
#define sipName_MarkdownResource &sipStrings_QtGui[20757]
#define sipNameNr_MipMapGeneration 1318
#define sipName_MipMapGeneration &sipStrings_QtGui[1318]
#define sipNameNr_MoveToEndOfBlock 20774
#define sipName_MoveToEndOfBlock &sipStrings_QtGui[20774]
#define sipNameNr_NotPremultiplied 20791
#define sipName_NotPremultiplied &sipStrings_QtGui[20791]
#define sipNameNr_OpenGLCompatible 20808
#define sipName_OpenGLCompatible &sipStrings_QtGui[20808]
#define sipNameNr_OpenGLModuleType 1252
#define sipName_OpenGLModuleType &sipStrings_QtGui[1252]
#define sipNameNr_OriginBottomLeft 20825
#define sipName_OriginBottomLeft &sipStrings_QtGui[20825]
#define sipNameNr_PatternTransform 20842
#define sipName_PatternTransform &sipStrings_QtGui[20842]
#define sipNameNr_PercentageLength 20859
#define sipName_PercentageLength &sipStrings_QtGui[20859]
#define sipNameNr_QClipboard__Mode 20876
#define sipName_QClipboard__Mode &sipStrings_QtGui[20876]
#define sipNameNr_QConicalGradient 20893
#define sipName_QConicalGradient &sipStrings_QtGui[20893]
#define sipNameNr_QDesktopServices 20910
#define sipName_QDesktopServices &sipStrings_QtGui[20910]
#define sipNameNr_QDoubleValidator 20927
#define sipName_QDoubleValidator &sipStrings_QtGui[20927]
#define sipNameNr_QFont__StyleHint 20944
#define sipName_QFont__StyleHint &sipStrings_QtGui[20944]
#define sipNameNr_20961 20961
#define sipName_20961 &sipStrings_QtGui[20961]
#define sipNameNr_20978 20978
#define sipName_20978 &sipStrings_QtGui[20978]
#define sipNameNr_QRegExpValidator 20995
#define sipName_QRegExpValidator &sipStrings_QtGui[20995]
#define sipNameNr_21012 21012
#define sipName_21012 &sipStrings_QtGui[21012]
#define sipNameNr_QTextBlockFormat 21029
#define sipName_QTextBlockFormat &sipStrings_QtGui[21029]
#define sipNameNr_QTextFrameFormat 21046
#define sipName_QTextFrameFormat &sipStrings_QtGui[21046]
#define sipNameNr_QTextImageFormat 21063
#define sipName_QTextImageFormat &sipStrings_QtGui[21063]
#define sipNameNr_QTextOption__Tab 21080
#define sipName_QTextOption__Tab &sipStrings_QtGui[21080]
#define sipNameNr_QTextTableFormat 21097
#define sipName_QTextTableFormat &sipStrings_QtGui[21097]
#define sipNameNr_RangeAccessFlags 1939
#define sipName_RangeAccessFlags &sipStrings_QtGui[1939]
#define sipNameNr_ResetTextureUnit 11786
#define sipName_ResetTextureUnit &sipStrings_QtGui[11786]
#define sipNameNr_ScaledPixmapHook 21114
#define sipName_ScaledPixmapHook &sipStrings_QtGui[21114]
#define sipNameNr_SelectEndOfBlock 21131
#define sipName_SelectEndOfBlock &sipStrings_QtGui[21131]
#define sipNameNr_SeparateAdvances 21148
#define sipName_SeparateAdvances &sipStrings_QtGui[21148]
#define sipNameNr_StandardNotation 21165
#define sipName_StandardNotation &sipStrings_QtGui[21165]
#define sipNameNr_StencilTexturing 21182
#define sipName_StencilTexturing &sipStrings_QtGui[21182]
#define sipNameNr_SurfaceEventType 268
#define sipName_SurfaceEventType &sipStrings_QtGui[268]
#define sipNameNr_SwizzleComponent 1351
#define sipName_SwizzleComponent &sipStrings_QtGui[1351]
#define sipNameNr_TableCellPadding 21199
#define sipName_TableCellPadding &sipStrings_QtGui[21199]
#define sipNameNr_TableCellRowSpan 15003
#define sipName_TableCellRowSpan &sipStrings_QtGui[15003]
#define sipNameNr_TableCellSpacing 21216
#define sipName_TableCellSpacing &sipStrings_QtGui[21216]
#define sipNameNr_TextAntialiasing 21233
#define sipName_TextAntialiasing &sipStrings_QtGui[21233]
#define sipNameNr_TextureRectangle 21250
#define sipName_TextureRectangle &sipStrings_QtGui[21250]
#define sipNameNr_TextureUnitReset 1384
#define sipName_TextureUnitReset &sipStrings_QtGui[1384]
#define sipNameNr_ThirdPartySource 21267
#define sipName_ThirdPartySource &sipStrings_QtGui[21267]
#define sipNameNr_TransferFunction 3025
#define sipName_TransferFunction &sipStrings_QtGui[3025]
#define sipNameNr_UInt16_RGBA4_Rev 21284
#define sipName_UInt16_RGBA4_Rev &sipStrings_QtGui[21284]
#define sipNameNr_UInt32_RGBA8_Rev 21301
#define sipName_UInt32_RGBA8_Rev &sipStrings_QtGui[21301]
#define sipNameNr_UseDesignMetrics 15063
#define sipName_UseDesignMetrics &sipStrings_QtGui[15063]
#define sipNameNr_alphaMapForGlyph 21318
#define sipName_alphaMapForGlyph &sipStrings_QtGui[21318]
#define sipNameNr_animatingChanged 21335
#define sipName_animatingChanged &sipStrings_QtGui[21335]
#define sipNameNr_antialiasingType 21352
#define sipName_antialiasingType &sipStrings_QtGui[21352]
#define sipNameNr_applicationState 21369
#define sipName_applicationState &sipStrings_QtGui[21369]
#define sipNameNr_averageCharWidth 21386
#define sipName_averageCharWidth &sipStrings_QtGui[21386]
#define sipNameNr_blockFormatIndex 21403
#define sipName_blockFormatIndex &sipStrings_QtGui[21403]
#define sipNameNr_boundingRectChar 21420
#define sipName_boundingRectChar &sipStrings_QtGui[21420]
#define sipNameNr_clipBoundingRect 21437
#define sipName_clipBoundingRect &sipStrings_QtGui[21437]
#define sipNameNr_controlPointRect 21454
#define sipName_controlPointRect &sipStrings_QtGui[21454]
#define sipNameNr_convertFromImage 21471
#define sipName_convertFromImage &sipStrings_QtGui[21471]
#define sipNameNr_currentImageRect 21488
#define sipName_currentImageRect &sipStrings_QtGui[21488]
#define sipNameNr_depthStencilMode 21505
#define sipName_depthStencilMode &sipStrings_QtGui[21505]
#define sipNameNr_devicePixelRatio 21522
#define sipName_devicePixelRatio &sipStrings_QtGui[21522]
#define sipNameNr_disconnectNotify 21539
#define sipName_disconnectNotify &sipStrings_QtGui[21539]
#define sipNameNr_drawInlineObject 21556
#define sipName_drawInlineObject &sipStrings_QtGui[21556]
#define sipNameNr_ellipseDiameters 21573
#define sipName_ellipseDiameters &sipStrings_QtGui[21573]
#define sipNameNr_fromAxisAndAngle 21590
#define sipName_fromAxisAndAngle &sipStrings_QtGui[21590]
#define sipNameNr_handlerForObject 21607
#define sipName_handlerForObject &sipStrings_QtGui[21607]
#define sipNameNr_hasOpenGLShaders 21624
#define sipName_hasOpenGLShaders &sipStrings_QtGui[21624]
#define sipNameNr_isBitmapScalable 21641
#define sipName_isBitmapScalable &sipStrings_QtGui[21641]
#define sipNameNr_lastResortFamily 21658
#define sipName_lastResortFamily &sipStrings_QtGui[21658]
#define sipNameNr_lastWindowClosed 21675
#define sipName_lastWindowClosed &sipStrings_QtGui[21675]
#define sipNameNr_maximumMipLevels 21692
#define sipName_maximumMipLevels &sipStrings_QtGui[21692]
#define sipNameNr_mediumaquamarine 21709
#define sipName_mediumaquamarine &sipStrings_QtGui[21709]
#define sipNameNr_mergeBlockFormat 21726
#define sipName_mergeBlockFormat &sipStrings_QtGui[21726]
#define sipNameNr_nativeVirtualKey 21743
#define sipName_nativeVirtualKey &sipStrings_QtGui[21743]
#define sipNameNr_naturalTextWidth 21760
#define sipName_naturalTextWidth &sipStrings_QtGui[21760]
#define sipNameNr_openGLModuleType 21777
#define sipName_openGLModuleType &sipStrings_QtGui[21777]
#define sipNameNr_pageCountChanged 21794
#define sipName_pageCountChanged &sipStrings_QtGui[21794]
#define sipNameNr_patchVertexCount 21811
#define sipName_patchVertexCount &sipStrings_QtGui[21811]
#define sipNameNr_qPixelFormatCmyk 21828
#define sipName_qPixelFormatCmyk &sipStrings_QtGui[21828]
#define sipNameNr_qPixelFormatRgba 21845
#define sipName_qPixelFormatRgba &sipStrings_QtGui[21845]
#define sipNameNr_queryFocusObject 21862
#define sipName_queryFocusObject &sipStrings_QtGui[21862]
#define sipNameNr_rehighlightBlock 21879
#define sipName_rehighlightBlock &sipStrings_QtGui[21879]
#define sipNameNr_removeAllShaders 21896
#define sipName_removeAllShaders &sipStrings_QtGui[21896]
#define sipNameNr_replacementStart 21913
#define sipName_replacementStart &sipStrings_QtGui[21913]
#define sipNameNr_rightBorderBrush 21930
#define sipName_rightBorderBrush &sipStrings_QtGui[21930]
#define sipNameNr_rightBorderStyle 21947
#define sipName_rightBorderStyle &sipStrings_QtGui[21947]
#define sipNameNr_selectionChanged 21964
#define sipName_selectionChanged &sipStrings_QtGui[21964]
#define sipNameNr_setAutoTransform 21981
#define sipName_setAutoTransform &sipStrings_QtGui[21981]
#define sipNameNr_setBottomPadding 21998
#define sipName_setBottomPadding &sipStrings_QtGui[21998]
#define sipNameNr_setDefaultFormat 22015
#define sipName_setDefaultFormat &sipStrings_QtGui[22015]
#define sipNameNr_setDotsPerMeterX 22032
#define sipName_setDotsPerMeterX &sipStrings_QtGui[22032]
#define sipNameNr_setDotsPerMeterY 22049
#define sipName_setDotsPerMeterY &sipStrings_QtGui[22049]
#define sipNameNr_setFontPointSize 22066
#define sipName_setFontPointSize &sipStrings_QtGui[22066]
#define sipNameNr_setFontStrikeOut 22083
#define sipName_setFontStrikeOut &sipStrings_QtGui[22083]
#define sipNameNr_setFontStyleHint 22100
#define sipName_setFontStyleHint &sipStrings_QtGui[22100]
#define sipNameNr_setFontStyleName 22117
#define sipName_setFontStyleName &sipStrings_QtGui[22117]
#define sipNameNr_setFontUnderline 22134
#define sipName_setFontUnderline &sipStrings_QtGui[22134]
#define sipNameNr_setFramePosition 22151
#define sipName_setFramePosition &sipStrings_QtGui[22151]
#define sipNameNr_setItemPrototype 22168
#define sipName_setItemPrototype &sipStrings_QtGui[22168]
#define sipNameNr_setItemRoleNames 22185
#define sipName_setItemRoleNames &sipStrings_QtGui[22185]
#define sipNameNr_setLetterSpacing 22202
#define sipName_setLetterSpacing &sipStrings_QtGui[22202]
#define sipNameNr_setMaximumHeight 22219
#define sipName_setMaximumHeight &sipStrings_QtGui[22219]
#define sipNameNr_setMinMagFilters 22236
#define sipName_setMinMagFilters &sipStrings_QtGui[22236]
#define sipNameNr_setMinimumHeight 22253
#define sipName_setMinimumHeight &sipStrings_QtGui[22253]
#define sipNameNr_setMipLevelRange 22270
#define sipName_setMipLevelRange &sipStrings_QtGui[22270]
#define sipNameNr_setRedBufferSize 22287
#define sipName_setRedBufferSize &sipStrings_QtGui[22287]
#define sipNameNr_setSizeIncrement 22304
#define sipName_setSizeIncrement &sipStrings_QtGui[22304]
#define sipNameNr_setStyleStrategy 22321
#define sipName_setStyleStrategy &sipStrings_QtGui[22321]
#define sipNameNr_setTextAlignment 22338
#define sipName_setTextAlignment &sipStrings_QtGui[22338]
#define sipNameNr_setTextDirection 22355
#define sipName_setTextDirection &sipStrings_QtGui[22355]
#define sipNameNr_setTextureTarget 22372
#define sipName_setTextureTarget &sipStrings_QtGui[22372]
#define sipNameNr_showIsFullScreen 22389
#define sipName_showIsFullScreen &sipStrings_QtGui[22389]
#define sipNameNr_supportedActions 22406
#define sipName_supportedActions &sipStrings_QtGui[22406]
#define sipNameNr_supportedFormats 22423
#define sipName_supportedFormats &sipStrings_QtGui[22423]
#define sipNameNr_surfaceEventType 22440
#define sipName_surfaceEventType &sipStrings_QtGui[22440]
#define sipNameNr_tabFocusBehavior 22457
#define sipName_tabFocusBehavior &sipStrings_QtGui[22457]
#define sipNameNr_tableCellRowSpan 22474
#define sipName_tableCellRowSpan &sipStrings_QtGui[22474]
#define sipNameNr_themeSearchPaths 22491
#define sipName_themeSearchPaths &sipStrings_QtGui[22491]
#define sipNameNr_toRotationMatrix 22508
#define sipName_toRotationMatrix &sipStrings_QtGui[22508]
#define sipNameNr_toVector2DAffine 22525
#define sipName_toVector2DAffine &sipStrings_QtGui[22525]
#define sipNameNr_toVector3DAffine 22542
#define sipName_toVector3DAffine &sipStrings_QtGui[22542]
#define sipNameNr_touchPointStates 22559
#define sipName_touchPointStates &sipStrings_QtGui[22559]
#define sipNameNr_transferFunction 22576
#define sipName_transferFunction &sipStrings_QtGui[22576]
#define sipNameNr_transformBetween 22593
#define sipName_transformBetween &sipStrings_QtGui[22593]
#define sipNameNr_undoCommandAdded 22610
#define sipName_undoCommandAdded &sipStrings_QtGui[22610]
#define sipNameNr_useDesignMetrics 22627
#define sipName_useDesignMetrics &sipStrings_QtGui[22627]
#define sipNameNr_useRtlExtensions 22644
#define sipName_useRtlExtensions &sipStrings_QtGui[22644]
#define sipNameNr_versionFunctions 22661
#define sipName_versionFunctions &sipStrings_QtGui[22661]
#define sipNameNr_virtualSiblingAt 22678
#define sipName_virtualSiblingAt &sipStrings_QtGui[22678]
#define sipNameNr_visualNavigation 22695
#define sipName_visualNavigation &sipStrings_QtGui[22695]
#define sipNameNr_wheelScrollLines 22712
#define sipName_wheelScrollLines &sipStrings_QtGui[22712]
#define sipNameNr_AbsoluteSpacing 22729
#define sipName_AbsoluteSpacing &sipStrings_QtGui[22729]
#define sipNameNr_BackgroundBrush 22745
#define sipName_BackgroundBrush &sipStrings_QtGui[22745]
#define sipNameNr_BackgroundColor 17119
#define sipName_BackgroundColor &sipStrings_QtGui[17119]
#define sipNameNr_BindingTarget1D 22761
#define sipName_BindingTarget1D &sipStrings_QtGui[22761]
#define sipNameNr_BindingTarget2D 22777
#define sipName_BindingTarget2D &sipStrings_QtGui[22777]
#define sipNameNr_BindingTarget3D 22793
#define sipName_BindingTarget3D &sipStrings_QtGui[22793]
#define sipNameNr_BlockLeftMargin 22809
#define sipName_BlockLeftMargin &sipStrings_QtGui[22809]
#define sipNameNr_BlockQuoteLevel 22825
#define sipName_BlockQuoteLevel &sipStrings_QtGui[22825]
#define sipNameNr_CheerfulCaramel 22841
#define sipName_CheerfulCaramel &sipStrings_QtGui[22841]
#define sipNameNr_CloudyKnoxville 22857
#define sipName_CloudyKnoxville &sipStrings_QtGui[22857]
#define sipNameNr_CompositionMode 5993
#define sipName_CompositionMode &sipStrings_QtGui[5993]
#define sipNameNr_ConicalGradient 20894
#define sipName_ConicalGradient &sipStrings_QtGui[20894]
#define sipNameNr_ConstantOpacity 22873
#define sipName_ConstantOpacity &sipStrings_QtGui[22873]
#define sipNameNr_DeleteEndOfLine 22889
#define sipName_DeleteEndOfLine &sipStrings_QtGui[22889]
#define sipNameNr_DeleteEndOfWord 22905
#define sipName_DeleteEndOfWord &sipStrings_QtGui[22905]
#define sipNameNr_DirtyBackground 22921
#define sipName_DirtyBackground &sipStrings_QtGui[22921]
#define sipNameNr_DirtyClipRegion 22937
#define sipName_DirtyClipRegion &sipStrings_QtGui[22937]
#define sipNameNr_EnvelopeItalian 22953
#define sipName_EnvelopeItalian &sipStrings_QtGui[22953]
#define sipNameNr_EnvelopeMonarch 22969
#define sipName_EnvelopeMonarch &sipStrings_QtGui[22969]
#define sipNameNr_FontWordSpacing 17252
#define sipName_FontWordSpacing &sipStrings_QtGui[17252]
#define sipNameNr_ForegroundBrush 22985
#define sipName_ForegroundBrush &sipStrings_QtGui[22985]
#define sipNameNr_Format_Indexed8 23001
#define sipName_Format_Indexed8 &sipStrings_QtGui[23001]
#define sipNameNr_Format_RGBA8888 23017
#define sipName_Format_RGBA8888 &sipStrings_QtGui[23017]
#define sipNameNr_Format_RGBX8888 23033
#define sipName_Format_RGBX8888 &sipStrings_QtGui[23033]
#define sipNameNr_FrameLeftMargin 23049
#define sipName_FrameLeftMargin &sipStrings_QtGui[23049]
#define sipNameNr_GenerateMipMaps 13664
#define sipName_GenerateMipMaps &sipStrings_QtGui[13664]
#define sipNameNr_HighlightedText 23065
#define sipName_HighlightedText &sipStrings_QtGui[23065]
#define sipNameNr_InvalidSeverity 23081
#define sipName_InvalidSeverity &sipStrings_QtGui[23081]
#define sipNameNr_LandingAircraft 23097
#define sipName_LandingAircraft &sipStrings_QtGui[23097]
#define sipNameNr_LayoutDirection 17290
#define sipName_LayoutDirection &sipStrings_QtGui[17290]
#define sipNameNr_LineHeightTypes 1018
#define sipName_LineHeightTypes &sipStrings_QtGui[1018]
#define sipNameNr_LineUnderCursor 23113
#define sipName_LineUnderCursor &sipStrings_QtGui[23113]
#define sipNameNr_LuminanceFormat 23129
#define sipName_LuminanceFormat &sipStrings_QtGui[23129]
#define sipNameNr_MarkdownFeature 2507
#define sipName_MarkdownFeature &sipStrings_QtGui[2507]
#define sipNameNr_MetaInformation 2538
#define sipName_MetaInformation &sipStrings_QtGui[2538]
#define sipNameNr_ModerateCaching 23145
#define sipName_ModerateCaching &sipStrings_QtGui[23145]
#define sipNameNr_MoveToEndOfLine 23161
#define sipName_MoveToEndOfLine &sipStrings_QtGui[23161]
#define sipNameNr_NamedColorSpace 3683
#define sipName_NamedColorSpace &sipStrings_QtGui[3683]
#define sipNameNr_NoPartialUpdate 23177
#define sipName_NoPartialUpdate &sipStrings_QtGui[23177]
#define sipNameNr_PageBreakPolicy 17385
#define sipName_PageBreakPolicy &sipStrings_QtGui[17385]
#define sipNameNr_PdmPhysicalDpiX 23193
#define sipName_PdmPhysicalDpiX &sipStrings_QtGui[23193]
#define sipNameNr_PdmPhysicalDpiY 23209
#define sipName_PdmPhysicalDpiY &sipStrings_QtGui[23209]
#define sipNameNr_PerformanceHint 3944
#define sipName_PerformanceHint &sipStrings_QtGui[3944]
#define sipNameNr_PerformanceType 23225
#define sipName_PerformanceType &sipStrings_QtGui[23225]
#define sipNameNr_PixelPackBuffer 23241
#define sipName_PixelPackBuffer &sipStrings_QtGui[23241]
#define sipNameNr_PixmapTransform 10784
#define sipName_PixmapTransform &sipStrings_QtGui[10784]
#define sipNameNr_PlaceholderText 23257
#define sipName_PlaceholderText &sipStrings_QtGui[23257]
#define sipNameNr_PolygonDrawMode 3236
#define sipName_PolygonDrawMode &sipStrings_QtGui[3236]
#define sipNameNr_PortabilityType 23273
#define sipName_PortabilityType &sipStrings_QtGui[23273]
#define sipNameNr_PreferAntialias 23289
#define sipName_PreferAntialias &sipStrings_QtGui[23289]
#define sipNameNr_PreferNoHinting 23305
#define sipName_PreferNoHinting &sipStrings_QtGui[23305]
#define sipNameNr_PreferNoShaping 23321
#define sipName_PreferNoShaping &sipStrings_QtGui[23321]
#define sipNameNr_QColorConstants 23337
#define sipName_QColorConstants &sipStrings_QtGui[23337]
#define sipNameNr_QColorTransform 23353
#define sipName_QColorTransform &sipStrings_QtGui[23353]
#define sipNameNr_QDragEnterEvent 23369
#define sipName_QDragEnterEvent &sipStrings_QtGui[23369]
#define sipNameNr_QDragLeaveEvent 23385
#define sipName_QDragLeaveEvent &sipStrings_QtGui[23385]
#define sipNameNr_QGradient__Type 23401
#define sipName_QGradient__Type &sipStrings_QtGui[23401]
#define sipNameNr_QGuiApplication 23417
#define sipName_QGuiApplication &sipStrings_QtGui[23417]
#define sipNameNr_QImageIOHandler 23433
#define sipName_QImageIOHandler &sipStrings_QtGui[23433]
#define sipNameNr_QLinearGradient 23449
#define sipName_QLinearGradient &sipStrings_QtGui[23449]
#define sipNameNr_23465 23465
#define sipName_23465 &sipStrings_QtGui[23465]
#define sipNameNr_23481 23481
#define sipName_23481 &sipStrings_QtGui[23481]
#define sipNameNr_QPageSize__Unit 23497
#define sipName_QPageSize__Unit &sipStrings_QtGui[23497]
#define sipNameNr_QRadialGradient 23513
#define sipName_QRadialGradient &sipStrings_QtGui[23513]
#define sipNameNr_QStatusTipEvent 23529
#define sipName_QStatusTipEvent &sipStrings_QtGui[23529]
#define sipNameNr_QTextBlockGroup 23545
#define sipName_QTextBlockGroup &sipStrings_QtGui[23545]
#define sipNameNr_QTextCharFormat 23561
#define sipName_QTextCharFormat &sipStrings_QtGui[23561]
#define sipNameNr_QTextLine__Edge 23577
#define sipName_QTextLine__Edge &sipStrings_QtGui[23577]
#define sipNameNr_QTextListFormat 23593
#define sipName_QTextListFormat &sipStrings_QtGui[23593]
#define sipNameNr_23609 23609
#define sipName_23609 &sipStrings_QtGui[23609]
#define sipNameNr_RGBA_ASTC_10x10 23625
#define sipName_RGBA_ASTC_10x10 &sipStrings_QtGui[23625]
#define sipNameNr_RGBA_ASTC_12x10 23641
#define sipName_RGBA_ASTC_12x10 &sipStrings_QtGui[23641]
#define sipNameNr_RGBA_ASTC_12x12 23657
#define sipName_RGBA_ASTC_12x12 &sipStrings_QtGui[23657]
#define sipNameNr_RangeAccessFlag 2383
#define sipName_RangeAccessFlag &sipStrings_QtGui[2383]
#define sipNameNr_RangeInvalidate 23673
#define sipName_RangeInvalidate &sipStrings_QtGui[23673]
#define sipNameNr_RasterGLSurface 23689
#define sipName_RasterGLSurface &sipStrings_QtGui[23689]
#define sipNameNr_SRGB_Alpha_DXT1 23705
#define sipName_SRGB_Alpha_DXT1 &sipStrings_QtGui[23705]
#define sipNameNr_SRGB_Alpha_DXT3 23721
#define sipName_SRGB_Alpha_DXT3 &sipStrings_QtGui[23721]
#define sipNameNr_SRGB_Alpha_DXT5 23737
#define sipName_SRGB_Alpha_DXT5 &sipStrings_QtGui[23737]
#define sipNameNr_SaintPetersburg 23753
#define sipName_SaintPetersburg &sipStrings_QtGui[23753]
#define sipNameNr_SelectEndOfLine 23769
#define sipName_SelectEndOfLine &sipStrings_QtGui[23769]
#define sipNameNr_SingleUnderline 23785
#define sipName_SingleUnderline &sipStrings_QtGui[23785]
#define sipNameNr_SizeMatchPolicy 5092
#define sipName_SizeMatchPolicy &sipStrings_QtGui[5092]
#define sipNameNr_TableCellObject 23801
#define sipName_TableCellObject &sipStrings_QtGui[23801]
#define sipNameNr_TargetRectangle 8664
#define sipName_TargetRectangle &sipStrings_QtGui[8664]
#define sipNameNr_Transformations 1187
#define sipName_Transformations &sipStrings_QtGui[1187]
#define sipNameNr_UInt32_RG11B10F 23817
#define sipName_UInt32_RG11B10F &sipStrings_QtGui[23817]
#define sipNameNr_UInt8_RG3B2_Rev 23833
#define sipName_UInt8_RG3B2_Rev &sipStrings_QtGui[23833]
#define sipNameNr_UnknownResource 23849
#define sipName_UnknownResource &sipStrings_QtGui[23849]
#define sipNameNr_UnsignedInteger 23865
#define sipName_UnsignedInteger &sipStrings_QtGui[23865]
#define sipNameNr_WordUnderCursor 23881
#define sipName_WordUnderCursor &sipStrings_QtGui[23881]
#define sipNameNr_allocateStorage 23897
#define sipName_allocateStorage &sipStrings_QtGui[23897]
#define sipNameNr_alphaBufferSize 23913
#define sipName_alphaBufferSize &sipStrings_QtGui[23913]
#define sipNameNr_anchorRectangle 23929
#define sipName_anchorRectangle &sipStrings_QtGui[23929]
#define sipNameNr_aspectRatioMode 23945
#define sipName_aspectRatioMode &sipStrings_QtGui[23945]
#define sipNameNr_backgroundBrush 23961
#define sipName_backgroundBrush &sipStrings_QtGui[23961]
#define sipNameNr_backgroundColor 23977
#define sipName_backgroundColor &sipStrings_QtGui[23977]
#define sipNameNr_blitFramebuffer 23993
#define sipName_blitFramebuffer &sipStrings_QtGui[23993]
#define sipNameNr_blockCharFormat 24009
#define sipName_blockCharFormat &sipStrings_QtGui[24009]
#define sipNameNr_cacheStatistics 24025
#define sipName_cacheStatistics &sipStrings_QtGui[24025]
#define sipNameNr_canDropMimeData 24041
#define sipName_canDropMimeData &sipStrings_QtGui[24041]
#define sipNameNr_charFormatIndex 24057
#define sipName_charFormatIndex &sipStrings_QtGui[24057]
#define sipNameNr_clearBackground 24073
#define sipName_clearBackground &sipStrings_QtGui[24073]
#define sipNameNr_clearForeground 24089
#define sipName_clearForeground &sipStrings_QtGui[24089]
#define sipNameNr_compositionMode 24105
#define sipName_compositionMode &sipStrings_QtGui[24105]
#define sipNameNr_contentPosRange 24121
#define sipName_contentPosRange &sipStrings_QtGui[24121]
#define sipNameNr_contentsChanged 24137
#define sipName_contentsChanged &sipStrings_QtGui[24137]
#define sipNameNr_convertToFormat 24153
#define sipName_convertToFormat &sipStrings_QtGui[24153]
#define sipNameNr_createAlphaMask 24169
#define sipName_createAlphaMask &sipStrings_QtGui[24169]
#define sipNameNr_currentPosition 24185
#define sipName_currentPosition &sipStrings_QtGui[24185]
#define sipNameNr_cursorFlashTime 24201
#define sipName_cursorFlashTime &sipStrings_QtGui[24201]
#define sipNameNr_cursorMoveStyle 24217
#define sipName_cursorMoveStyle &sipStrings_QtGui[24217]
#define sipNameNr_cursorRectangle 24233
#define sipName_cursorRectangle &sipStrings_QtGui[24233]
#define sipNameNr_defineIOHandler 24249
#define sipName_defineIOHandler &sipStrings_QtGui[24249]
#define sipNameNr_definitionUnits 24265
#define sipName_definitionUnits &sipStrings_QtGui[24265]
#define sipNameNr_depthBufferSize 24281
#define sipName_depthBufferSize &sipStrings_QtGui[24281]
#define sipNameNr_desktopFileName 24297
#define sipName_desktopFileName &sipStrings_QtGui[24297]
#define sipNameNr_deviceTransform 24313
#define sipName_deviceTransform &sipStrings_QtGui[24313]
#define sipNameNr_disableMessages 24329
#define sipName_disableMessages &sipStrings_QtGui[24329]
#define sipNameNr_distanceToPlane 24345
#define sipName_distanceToPlane &sipStrings_QtGui[24345]
#define sipNameNr_distanceToPoint 24361
#define sipName_distanceToPoint &sipStrings_QtGui[24361]
#define sipNameNr_documentChanged 24377
#define sipName_documentChanged &sipStrings_QtGui[24377]
#define sipNameNr_drawRoundedRect 24393
#define sipName_drawRoundedRect &sipStrings_QtGui[24393]
#define sipNameNr_drawTiledPixmap 24409
#define sipName_drawTiledPixmap &sipStrings_QtGui[24409]
#define sipNameNr_emitDataChanged 24425
#define sipName_emitDataChanged &sipStrings_QtGui[24425]
#define sipNameNr_firstLineNumber 24441
#define sipName_firstLineNumber &sipStrings_QtGui[24441]
#define sipNameNr_fontWordSpacing 24457
#define sipName_fontWordSpacing &sipStrings_QtGui[24457]
#define sipNameNr_fromEulerAngles 24473
#define sipName_fromEulerAngles &sipStrings_QtGui[24473]
#define sipNameNr_fromImageReader 24489
#define sipName_fromImageReader &sipStrings_QtGui[24489]
#define sipNameNr_generateMipMaps 24505
#define sipName_generateMipMaps &sipStrings_QtGui[24505]
#define sipNameNr_geometryChanged 24521
#define sipName_geometryChanged &sipStrings_QtGui[24521]
#define sipNameNr_getAxisAndAngle 24537
#define sipName_getAxisAndAngle &sipStrings_QtGui[24537]
#define sipNameNr_grabFramebuffer 24553
#define sipName_grabFramebuffer &sipStrings_QtGui[24553]
#define sipNameNr_greenBufferSize 24569
#define sipName_greenBufferSize &sipStrings_QtGui[24569]
#define sipNameNr_hasAlphaChannel 24585
#define sipName_hasAlphaChannel &sipStrings_QtGui[24585]
#define sipNameNr_highlightedText 24601
#define sipName_highlightedText &sipStrings_QtGui[24601]
#define sipNameNr_internal_format 24617
#define sipName_internal_format &sipStrings_QtGui[24617]
#define sipNameNr_isLegacyVersion 24633
#define sipName_isLegacyVersion &sipStrings_QtGui[24633]
#define sipNameNr_isPrivateFamily 24649
#define sipName_isPrivateFamily &sipStrings_QtGui[24649]
#define sipNameNr_isRedoAvailable 24665
#define sipName_isRedoAvailable &sipStrings_QtGui[24665]
#define sipNameNr_isUndoAvailable 24681
#define sipName_isUndoAvailable &sipStrings_QtGui[24681]
#define sipNameNr_jumpToNextFrame 24697
#define sipName_jumpToNextFrame &sipStrings_QtGui[24697]
#define sipNameNr_jumpToNextImage 24713
#define sipName_jumpToNextImage &sipStrings_QtGui[24713]
#define sipNameNr_keyReleaseEvent 24729
#define sipName_keyReleaseEvent &sipStrings_QtGui[24729]
#define sipNameNr_lastErrorString 24745
#define sipName_lastErrorString &sipStrings_QtGui[24745]
#define sipNameNr_layoutDirection 24761
#define sipName_layoutDirection &sipStrings_QtGui[24761]
#define sipNameNr_leadingIncluded 24777
#define sipName_leadingIncluded &sipStrings_QtGui[24777]
#define sipNameNr_leftBorderBrush 24793
#define sipName_leftBorderBrush &sipStrings_QtGui[24793]
#define sipNameNr_leftBorderStyle 24809
#define sipName_leftBorderStyle &sipStrings_QtGui[24809]
#define sipNameNr_mediumslateblue 24825
#define sipName_mediumslateblue &sipStrings_QtGui[24825]
#define sipNameNr_mediumturquoise 24841
#define sipName_mediumturquoise &sipStrings_QtGui[24841]
#define sipNameNr_mediumvioletred 24857
#define sipName_mediumvioletred &sipStrings_QtGui[24857]
#define sipNameNr_mergeCharFormat 24873
#define sipName_mergeCharFormat &sipStrings_QtGui[24873]
#define sipNameNr_metaInformation 24889
#define sipName_metaInformation &sipStrings_QtGui[24889]
#define sipNameNr_mightBeRichText 24905
#define sipName_mightBeRichText &sipStrings_QtGui[24905]
#define sipNameNr_minRightBearing 24921
#define sipName_minRightBearing &sipStrings_QtGui[24921]
#define sipNameNr_modalityChanged 24937
#define sipName_modalityChanged &sipStrings_QtGui[24937]
#define sipNameNr_mousePressEvent 24953
#define sipName_mousePressEvent &sipStrings_QtGui[24953]
#define sipNameNr_nativeModifiers 24969
#define sipName_nativeModifiers &sipStrings_QtGui[24969]
#define sipNameNr_naturalTextRect 24985
#define sipName_naturalTextRect &sipStrings_QtGui[24985]
#define sipNameNr_objectForFormat 25001
#define sipName_objectForFormat &sipStrings_QtGui[25001]
#define sipNameNr_pageBreakPolicy 25017
#define sipName_pageBreakPolicy &sipStrings_QtGui[25017]
#define sipNameNr_paintRectPixels 25033
#define sipName_paintRectPixels &sipStrings_QtGui[25033]
#define sipNameNr_paintRectPoints 25049
#define sipName_paintRectPoints &sipStrings_QtGui[25049]
#define sipNameNr_percentAtLength 25065
#define sipName_percentAtLength &sipStrings_QtGui[25065]
#define sipNameNr_performanceHint 25081
#define sipName_performanceHint &sipStrings_QtGui[25081]
#define sipNameNr_placeholderText 25097
#define sipName_placeholderText &sipStrings_QtGui[25097]
#define sipNameNr_positionInBlock 25113
#define sipName_positionInBlock &sipStrings_QtGui[25113]
#define sipNameNr_possibleActions 25129
#define sipName_possibleActions &sipStrings_QtGui[25129]
#define sipNameNr_preeditAreaText 25145
#define sipName_preeditAreaText &sipStrings_QtGui[25145]
#define sipNameNr_qPixelFormatHsl 25161
#define sipName_qPixelFormatHsl &sipStrings_QtGui[25161]
#define sipNameNr_qPixelFormatHsv 25177
#define sipName_qPixelFormatHsv &sipStrings_QtGui[25177]
#define sipNameNr_qPixelFormatYuv 25193
#define sipName_qPixelFormatYuv &sipStrings_QtGui[25193]
#define sipNameNr_registerHandler 20244
#define sipName_registerHandler &sipStrings_QtGui[20244]
#define sipNameNr_requestActivate 25209
#define sipName_requestActivate &sipStrings_QtGui[25209]
#define sipNameNr_requestedFormat 25225
#define sipName_requestedFormat &sipStrings_QtGui[25225]
#define sipNameNr_setAlphaChannel 25241
#define sipName_setAlphaChannel &sipStrings_QtGui[25241]
#define sipNameNr_setAutoTristate 25257
#define sipName_setAutoTristate &sipStrings_QtGui[25257]
#define sipNameNr_setBottomBorder 25273
#define sipName_setBottomBorder &sipStrings_QtGui[25273]
#define sipNameNr_setBottomMargin 25289
#define sipName_setBottomMargin &sipStrings_QtGui[25289]
#define sipNameNr_setBoundingRect 25305
#define sipName_setBoundingRect &sipStrings_QtGui[25305]
#define sipNameNr_setCacheEnabled 25321
#define sipName_setCacheEnabled &sipStrings_QtGui[25321]
#define sipNameNr_setCapabilities 25337
#define sipName_setCapabilities &sipStrings_QtGui[25337]
#define sipNameNr_setCenterRadius 25353
#define sipName_setCenterRadius &sipStrings_QtGui[25353]
#define sipNameNr_setCommitString 25369
#define sipName_setCommitString &sipStrings_QtGui[25369]
#define sipNameNr_setFontFamilies 25385
#define sipName_setFontFamilies &sipStrings_QtGui[25385]
#define sipNameNr_setFontOverline 25401
#define sipName_setFontOverline &sipStrings_QtGui[25401]
#define sipNameNr_setGlyphIndexes 25417
#define sipName_setGlyphIndexes &sipStrings_QtGui[25417]
#define sipNameNr_setHeadingLevel 25433
#define sipName_setHeadingLevel &sipStrings_QtGui[25433]
#define sipNameNr_setMajorVersion 25449
#define sipName_setMajorVersion &sipStrings_QtGui[25449]
#define sipNameNr_setMaximumWidth 25465
#define sipName_setMaximumWidth &sipStrings_QtGui[25465]
#define sipNameNr_setMinimumWidth 25481
#define sipName_setMinimumWidth &sipStrings_QtGui[25481]
#define sipNameNr_setMinorVersion 25497
#define sipName_setMinorVersion &sipStrings_QtGui[25497]
#define sipNameNr_setMipBaseLevel 25513
#define sipName_setMipBaseLevel &sipStrings_QtGui[25513]
#define sipNameNr_setNativeHandle 25529
#define sipName_setNativeHandle &sipStrings_QtGui[25529]
#define sipNameNr_setNumberPrefix 25545
#define sipName_setNumberPrefix &sipStrings_QtGui[25545]
#define sipNameNr_setNumberSuffix 25561
#define sipName_setNumberSuffix &sipStrings_QtGui[25561]
#define sipNameNr_setPaintFlipped 25577
#define sipName_setPaintFlipped &sipStrings_QtGui[25577]
#define sipNameNr_setRightPadding 25593
#define sipName_setRightPadding &sipStrings_QtGui[25593]
#define sipNameNr_setShareContext 25609
#define sipName_setShareContext &sipStrings_QtGui[25609]
#define sipNameNr_setSwapBehavior 25625
#define sipName_setSwapBehavior &sipStrings_QtGui[25625]
#define sipNameNr_setSwapInterval 25641
#define sipName_setSwapInterval &sipStrings_QtGui[25641]
#define sipNameNr_setTabPositions 25657
#define sipName_setTabPositions &sipStrings_QtGui[25657]
#define sipNameNr_setTextureImage 25673
#define sipName_setTextureImage &sipStrings_QtGui[25673]
#define sipNameNr_setUniformValue 25689
#define sipName_setUniformValue &sipStrings_QtGui[25689]
#define sipNameNr_setUsagePattern 25705
#define sipName_setUsagePattern &sipStrings_QtGui[25705]
#define sipNameNr_setUserTristate 25721
#define sipName_setUserTristate &sipStrings_QtGui[25721]
#define sipNameNr_setViewportSize 25737
#define sipName_setViewportSize &sipStrings_QtGui[25737]
#define sipNameNr_setWindowStates 25753
#define sipName_setWindowStates &sipStrings_QtGui[25753]
#define sipNameNr_showIsMaximized 25769
#define sipName_showIsMaximized &sipStrings_QtGui[25769]
#define sipNameNr_sourceTransform 25785
#define sipName_sourceTransform &sipStrings_QtGui[25785]
#define sipNameNr_startSystemMove 25801
#define sipName_startSystemMove &sipStrings_QtGui[25801]
#define sipNameNr_tabStopDistance 25817
#define sipName_tabStopDistance &sipStrings_QtGui[25817]
#define sipNameNr_targetTransform 25833
#define sipName_targetTransform &sipStrings_QtGui[25833]
#define sipNameNr_topLevelWindows 25849
#define sipName_topLevelWindows &sipStrings_QtGui[25849]
#define sipNameNr_transientParent 25865
#define sipName_transientParent &sipStrings_QtGui[25865]
#define sipNameNr_uniformLocation 25881
#define sipName_uniformLocation &sipStrings_QtGui[25881]
#define sipNameNr_unpremultiplied 25897
#define sipName_unpremultiplied &sipStrings_QtGui[25897]
#define sipNameNr_unsetUrlHandler 25913
#define sipName_unsetUrlHandler &sipStrings_QtGui[25913]
#define sipNameNr_useHoverEffects 25929
#define sipName_useHoverEffects &sipStrings_QtGui[25929]
#define sipNameNr_virtualGeometry 25945
#define sipName_virtualGeometry &sipStrings_QtGui[25945]
#define sipNameNr_virtualSiblings 25961
#define sipName_virtualSiblings &sipStrings_QtGui[25961]
#define sipNameNr_AlignSubScript 25977
#define sipName_AlignSubScript &sipStrings_QtGui[25977]
#define sipNameNr_BlockAlignment 25992
#define sipName_BlockAlignment &sipStrings_QtGui[25992]
#define sipNameNr_BlockCodeFence 26007
#define sipName_BlockCodeFence &sipStrings_QtGui[26007]
#define sipNameNr_BlockTopMargin 26022
#define sipName_BlockTopMargin &sipStrings_QtGui[26022]
#define sipNameNr_CapabilityFlag 4061
#define sipName_CapabilityFlag &sipStrings_QtGui[4061]
#define sipNameNr_Capitalization 10081
#define sipName_Capitalization &sipStrings_QtGui[10081]
#define sipNameNr_CompareGreater 26037
#define sipName_CompareGreater &sipStrings_QtGui[26037]
#define sipNameNr_ComparisonMode 2446
#define sipName_ComparisonMode &sipStrings_QtGui[2446]
#define sipNameNr_ConfidentCloud 26052
#define sipName_ConfidentCloud &sipStrings_QtGui[26052]
#define sipNameNr_CoordinateMode 5864
#define sipName_CoordinateMode &sipStrings_QtGui[5864]
#define sipNameNr_CursorPosition 6098
#define sipName_CursorPosition &sipStrings_QtGui[6098]
#define sipNameNr_CurveToElement 26067
#define sipName_CurveToElement &sipStrings_QtGui[26067]
#define sipNameNr_DashDotDotLine 26082
#define sipName_DashDotDotLine &sipStrings_QtGui[26082]
#define sipNameNr_DirtyTransform 26097
#define sipName_DirtyTransform &sipStrings_QtGui[26097]
#define sipNameNr_DoublePostcard 26112
#define sipName_DoublePostcard &sipStrings_QtGui[26112]
#define sipNameNr_EnvelopeInvite 26127
#define sipName_EnvelopeInvite &sipStrings_QtGui[26127]
#define sipNameNr_EverlastingSky 26142
#define sipName_EverlastingSky &sipStrings_QtGui[26142]
#define sipNameNr_ExtraCondensed 26157
#define sipName_ExtraCondensed &sipStrings_QtGui[26157]
#define sipNameNr_FindWholeWords 26172
#define sipName_FindWholeWords &sipStrings_QtGui[26172]
#define sipNameNr_FontFixedPitch 19741
#define sipName_FontFixedPitch &sipStrings_QtGui[19741]
#define sipNameNr_Format_Invalid 26187
#define sipName_Format_Invalid &sipStrings_QtGui[26187]
#define sipNameNr_Format_MonoLSB 26202
#define sipName_Format_MonoLSB &sipStrings_QtGui[26202]
#define sipNameNr_FrameTopMargin 26217
#define sipName_FrameTopMargin &sipStrings_QtGui[26217]
#define sipNameNr_IconEngineHook 4430
#define sipName_IconEngineHook &sipStrings_QtGui[4430]
#define sipNameNr_KernedAdvances 26232
#define sipName_KernedAdvances &sipStrings_QtGui[26232]
#define sipNameNr_LineHeightType 26247
#define sipName_LineHeightType &sipStrings_QtGui[26247]
#define sipNameNr_LinearGradient 23450
#define sipName_LinearGradient &sipStrings_QtGui[23450]
#define sipNameNr_ListLowerAlpha 26262
#define sipName_ListLowerAlpha &sipStrings_QtGui[26262]
#define sipNameNr_ListLowerRoman 26277
#define sipName_ListLowerRoman &sipStrings_QtGui[26277]
#define sipNameNr_ListUpperAlpha 26292
#define sipName_ListUpperAlpha &sipStrings_QtGui[26292]
#define sipNameNr_ListUpperRoman 26307
#define sipName_ListUpperRoman &sipStrings_QtGui[26307]
#define sipNameNr_LuminanceAlpha 26322
#define sipName_LuminanceAlpha &sipStrings_QtGui[26322]
#define sipNameNr_MarkdownNoHTML 26337
#define sipName_MarkdownNoHTML &sipStrings_QtGui[26337]
#define sipNameNr_MediumSeverity 26352
#define sipName_MediumSeverity &sipStrings_QtGui[26352]
#define sipNameNr_MillenniumPine 26367
#define sipName_MillenniumPine &sipStrings_QtGui[26367]
#define sipNameNr_MirroredRepeat 26382
#define sipName_MirroredRepeat &sipStrings_QtGui[26382]
#define sipNameNr_MouseEmulation 26397
#define sipName_MouseEmulation &sipStrings_QtGui[26397]
#define sipNameNr_MoveToNextChar 26412
#define sipName_MoveToNextChar &sipStrings_QtGui[26412]
#define sipNameNr_MoveToNextLine 26427
#define sipName_MoveToNextLine &sipStrings_QtGui[26427]
#define sipNameNr_MoveToNextPage 26442
#define sipName_MoveToNextPage &sipStrings_QtGui[26442]
#define sipNameNr_MoveToNextWord 26457
#define sipName_MoveToNextWord &sipStrings_QtGui[26457]
#define sipNameNr_NoSourceFormat 26472
#define sipName_NoSourceFormat &sipStrings_QtGui[26472]
#define sipNameNr_OctoberSilence 26487
#define sipName_OctoberSilence &sipStrings_QtGui[26487]
#define sipNameNr_OptimizedWrite 19795
#define sipName_OptimizedWrite &sipStrings_QtGui[19795]
#define sipNameNr_PageBreakFlags 4738
#define sipName_PageBreakFlags &sipStrings_QtGui[4738]
#define sipNameNr_PageBreak_Auto 26502
#define sipName_PageBreak_Auto &sipStrings_QtGui[26502]
#define sipNameNr_PdfVersion_1_4 26517
#define sipName_PdfVersion_1_4 &sipStrings_QtGui[26517]
#define sipNameNr_PdfVersion_1_6 26532
#define sipName_PdfVersion_1_6 &sipStrings_QtGui[26532]
#define sipNameNr_PdfVersion_A1b 26547
#define sipName_PdfVersion_A1b &sipStrings_QtGui[26547]
#define sipNameNr_PixmapFragment 6865
#define sipName_PixmapFragment &sipStrings_QtGui[6865]
#define sipNameNr_PurpleDivision 26562
#define sipName_PurpleDivision &sipStrings_QtGui[26562]
#define sipNameNr_QDragMoveEvent 26577
#define sipName_QDragMoveEvent &sipStrings_QtGui[26577]
#define sipNameNr_QFileOpenEvent 26592
#define sipName_QFileOpenEvent &sipStrings_QtGui[26592]
#define sipNameNr_QFont__Stretch 26607
#define sipName_QFont__Stretch &sipStrings_QtGui[26607]
#define sipNameNr_QIconDragEvent 26622
#define sipName_QIconDragEvent &sipStrings_QtGui[26622]
#define sipNameNr_QImage__Format 26637
#define sipName_QImage__Format &sipStrings_QtGui[26637]
#define sipNameNr_QOpenGLContext 26652
#define sipName_QOpenGLContext &sipStrings_QtGui[26652]
#define sipNameNr_QOpenGLTexture 26667
#define sipName_QOpenGLTexture &sipStrings_QtGui[26667]
#define sipNameNr_QShortcutEvent 26682
#define sipName_QShortcutEvent &sipStrings_QtGui[26682]
#define sipNameNr_QSurfaceFormat 26697
#define sipName_QSurfaceFormat &sipStrings_QtGui[26697]
#define sipNameNr_QTextTableCell 26712
#define sipName_QTextTableCell &sipStrings_QtGui[26712]
#define sipNameNr_26727 26727
#define sipName_26727 &sipStrings_QtGui[26727]
#define sipNameNr_26742 26742
#define sipName_26742 &sipStrings_QtGui[26742]
#define sipNameNr_26757 26757
#define sipName_26757 &sipStrings_QtGui[26757]
#define sipNameNr_26772 26772
#define sipName_26772 &sipStrings_QtGui[26772]
#define sipNameNr_RG11_EAC_SNorm 26787
#define sipName_RG11_EAC_SNorm &sipStrings_QtGui[26787]
#define sipNameNr_RG11_EAC_UNorm 26802
#define sipName_RG11_EAC_UNorm &sipStrings_QtGui[26802]
#define sipNameNr_RGBA8_ETC2_EAC 26817
#define sipName_RGBA8_ETC2_EAC &sipStrings_QtGui[26817]
#define sipNameNr_RGBA_ASTC_10x5 26832
#define sipName_RGBA_ASTC_10x5 &sipStrings_QtGui[26832]
#define sipNameNr_RGBA_ASTC_10x6 26847
#define sipName_RGBA_ASTC_10x6 &sipStrings_QtGui[26847]
#define sipNameNr_RGBA_ASTC_10x8 26862
#define sipName_RGBA_ASTC_10x8 &sipStrings_QtGui[26862]
#define sipNameNr_RG_ATI2N_SNorm 26877
#define sipName_RG_ATI2N_SNorm &sipStrings_QtGui[26877]
#define sipNameNr_RG_ATI2N_UNorm 26892
#define sipName_RG_ATI2N_UNorm &sipStrings_QtGui[26892]
#define sipNameNr_RadialGradient 23514
#define sipName_RadialGradient &sipStrings_QtGui[23514]
#define sipNameNr_RenderableType 2477
#define sipName_RenderableType &sipStrings_QtGui[2477]
#define sipNameNr_RotationStylus 26907
#define sipName_RotationStylus &sipStrings_QtGui[26907]
#define sipNameNr_ScaledClipRect 19867
#define sipName_ScaledClipRect &sipStrings_QtGui[19867]
#define sipNameNr_ScrollFinished 26922
#define sipName_ScrollFinished &sipStrings_QtGui[26922]
#define sipNameNr_SelectNextChar 26937
#define sipName_SelectNextChar &sipStrings_QtGui[26937]
#define sipNameNr_SelectNextLine 26952
#define sipName_SelectNextLine &sipStrings_QtGui[26952]
#define sipNameNr_SelectNextPage 26967
#define sipName_SelectNextPage &sipStrings_QtGui[26967]
#define sipNameNr_SelectNextWord 26982
#define sipName_SelectNextWord &sipStrings_QtGui[26982]
#define sipNameNr_SequenceFormat 3800
#define sipName_SequenceFormat &sipStrings_QtGui[3800]
#define sipNameNr_SkipCharacters 26997
#define sipName_SkipCharacters &sipStrings_QtGui[26997]
#define sipNameNr_SleeplessNight 27012
#define sipName_SleeplessNight &sipStrings_QtGui[27012]
#define sipNameNr_StrictNovember 27027
#define sipName_StrictNovember &sipStrings_QtGui[27027]
#define sipNameNr_SuppressColors 27042
#define sipName_SuppressColors &sipStrings_QtGui[27042]
#define sipNameNr_SurfaceCreated 27057
#define sipName_SurfaceCreated &sipStrings_QtGui[27057]
#define sipNameNr_Transformation 1877
#define sipName_Transformation &sipStrings_QtGui[1877]
#define sipNameNr_UInt32_RGB10A2 27072
#define sipName_UInt32_RGB10A2 &sipStrings_QtGui[27072]
#define sipNameNr_UInt32_RGB9_E5 27087
#define sipName_UInt32_RGB9_E5 &sipStrings_QtGui[27087]
#define sipNameNr_UltraCondensed 27102
#define sipName_UltraCondensed &sipStrings_QtGui[27102]
#define sipNameNr_UnderlineStyle 2069
#define sipName_UnderlineStyle &sipStrings_QtGui[2069]
#define sipNameNr_UnknownPointer 27117
#define sipName_UnknownPointer &sipStrings_QtGui[27117]
#define sipNameNr_UpdateBehavior 3177
#define sipName_UpdateBehavior &sipStrings_QtGui[3177]
#define sipNameNr_VariableLength 27132
#define sipName_VariableLength &sipStrings_QtGui[27132]
#define sipNameNr_accessibleText 27147
#define sipName_accessibleText &sipStrings_QtGui[27147]
#define sipNameNr_addRoundedRect 27162
#define sipName_addRoundedRect &sipStrings_QtGui[27162]
#define sipNameNr_angleAtPercent 27177
#define sipName_angleAtPercent &sipStrings_QtGui[27177]
#define sipNameNr_availableSizes 27192
#define sipName_availableSizes &sipStrings_QtGui[27192]
#define sipNameNr_backgroundMode 27207
#define sipName_backgroundMode &sipStrings_QtGui[27207]
#define sipNameNr_baseUrlChanged 27222
#define sipName_baseUrlChanged &sipStrings_QtGui[27222]
#define sipNameNr_beginEditBlock 27237
#define sipName_beginEditBlock &sipStrings_QtGui[27237]
#define sipNameNr_blanchedalmond 27252
#define sipName_blanchedalmond &sipStrings_QtGui[27252]
#define sipNameNr_blueBufferSize 27267
#define sipName_blueBufferSize &sipStrings_QtGui[27267]
#define sipNameNr_borderCollapse 27282
#define sipName_borderCollapse &sipStrings_QtGui[27282]
#define sipNameNr_boundTextureId 27297
#define sipName_boundTextureId &sipStrings_QtGui[27297]
#define sipNameNr_brightnessSize 27312
#define sipName_brightnessSize &sipStrings_QtGui[27312]
#define sipNameNr_capitalization 27327
#define sipName_capitalization &sipStrings_QtGui[27327]
#define sipNameNr_characterCount 27342
#define sipName_characterCount &sipStrings_QtGui[27342]
#define sipNameNr_clearSelection 27357
#define sipName_clearSelection &sipStrings_QtGui[27357]
#define sipNameNr_comparisonMode 27372
#define sipName_comparisonMode &sipStrings_QtGui[27372]
#define sipNameNr_contentsChange 27387
#define sipName_contentsChange &sipStrings_QtGui[27387]
#define sipNameNr_coordinateMode 27402
#define sipName_coordinateMode &sipStrings_QtGui[27402]
#define sipNameNr_cornflowerblue 27417
#define sipName_cornflowerblue &sipStrings_QtGui[27417]
#define sipNameNr_currentContext 27432
#define sipName_currentContext &sipStrings_QtGui[27432]
#define sipNameNr_cursorPosition 27447
#define sipName_cursorPosition &sipStrings_QtGui[27447]
#define sipNameNr_curveThreshold 27462
#define sipName_curveThreshold &sipStrings_QtGui[27462]
#define sipNameNr_darkolivegreen 27477
#define sipName_darkolivegreen &sipStrings_QtGui[27477]
#define sipNameNr_definitionSize 27492
#define sipName_definitionSize &sipStrings_QtGui[27492]
#define sipNameNr_distanceToLine 27507
#define sipName_distanceToLine &sipStrings_QtGui[27507]
#define sipNameNr_documentLayout 27522
#define sipName_documentLayout &sipStrings_QtGui[27522]
#define sipNameNr_documentMargin 27537
#define sipName_documentMargin &sipStrings_QtGui[27537]
#define sipNameNr_doubleProperty 27552
#define sipName_doubleProperty &sipStrings_QtGui[27552]
#define sipNameNr_drawStaticText 27567
#define sipName_drawStaticText &sipStrings_QtGui[27567]
#define sipNameNr_enableMessages 27582
#define sipName_enableMessages &sipStrings_QtGui[27582]
#define sipNameNr_fontFixedPitch 27597
#define sipName_fontFixedPitch &sipStrings_QtGui[27597]
#define sipNameNr_fromIccProfile 27612
#define sipName_fromIccProfile &sipStrings_QtGui[27612]
#define sipNameNr_fullRectPixels 27627
#define sipName_fullRectPixels &sipStrings_QtGui[27627]
#define sipNameNr_fullRectPoints 27642
#define sipName_fullRectPoints &sipStrings_QtGui[27642]
#define sipNameNr_getEulerAngles 27657
#define sipName_getEulerAngles &sipStrings_QtGui[27657]
#define sipNameNr_getProcAddress 27672
#define sipName_getProcAddress &sipStrings_QtGui[27672]
#define sipNameNr_globalPosition 27687
#define sipName_globalPosition &sipStrings_QtGui[27687]
#define sipNameNr_headerRowCount 27702
#define sipName_headerRowCount &sipStrings_QtGui[27702]
#define sipNameNr_highlightBlock 21881
#define sipName_highlightBlock &sipStrings_QtGui[21881]
#define sipNameNr_hslSaturationF 27717
#define sipName_hslSaturationF &sipStrings_QtGui[27717]
#define sipNameNr_hsvSaturationF 27732
#define sipName_hsvSaturationF &sipStrings_QtGui[27732]
#define sipNameNr_inputDirection 27747
#define sipName_inputDirection &sipStrings_QtGui[27747]
#define sipNameNr_insertFragment 27762
#define sipName_insertFragment &sipStrings_QtGui[27762]
#define sipNameNr_isAutoTristate 27777
#define sipName_isAutoTristate &sipStrings_QtGui[27777]
#define sipNameNr_isEquivalentTo 27792
#define sipName_isEquivalentTo &sipStrings_QtGui[27792]
#define sipNameNr_isUserTristate 27807
#define sipName_isUserTristate &sipStrings_QtGui[27807]
#define sipNameNr_lastResortFont 27822
#define sipName_lastResortFont &sipStrings_QtGui[27822]
#define sipNameNr_lengthProperty 27837
#define sipName_lengthProperty &sipStrings_QtGui[27837]
#define sipNameNr_lightslategray 27852
#define sipName_lightslategray &sipStrings_QtGui[27852]
#define sipNameNr_lightslategrey 27867
#define sipName_lightslategrey &sipStrings_QtGui[27867]
#define sipNameNr_lightsteelblue 27882
#define sipName_lightsteelblue &sipStrings_QtGui[27882]
#define sipNameNr_lineHeightType 27897
#define sipName_lineHeightType &sipStrings_QtGui[27897]
#define sipNameNr_listFromString 27912
#define sipName_listFromString &sipStrings_QtGui[27912]
#define sipNameNr_loggedMessages 27927
#define sipName_loggedMessages &sipStrings_QtGui[27927]
#define sipNameNr_maximumMargins 27942
#define sipName_maximumMargins &sipStrings_QtGui[27942]
#define sipNameNr_mediumseagreen 27957
#define sipName_mediumseagreen &sipStrings_QtGui[27957]
#define sipNameNr_minLeftBearing 27972
#define sipName_minLeftBearing &sipStrings_QtGui[27972]
#define sipNameNr_minimumMargins 27987
#define sipName_minimumMargins &sipStrings_QtGui[27987]
#define sipNameNr_mouseMoveEvent 28002
#define sipName_mouseMoveEvent &sipStrings_QtGui[28002]
#define sipNameNr_nativeScanCode 28017
#define sipName_nativeScanCode &sipStrings_QtGui[28017]
#define sipNameNr_nextFrameDelay 28032
#define sipName_nextFrameDelay &sipStrings_QtGui[28032]
#define sipNameNr_nextImageDelay 28047
#define sipName_nextImageDelay &sipStrings_QtGui[28047]
#define sipNameNr_opacityChanged 28062
#define sipName_opacityChanged &sipStrings_QtGui[28062]
#define sipNameNr_optimizedWrite 28077
#define sipName_optimizedWrite &sipStrings_QtGui[28077]
#define sipNameNr_overrideCursor 28092
#define sipName_overrideCursor &sipStrings_QtGui[28092]
#define sipNameNr_ownsFindBuffer 28107
#define sipName_ownsFindBuffer &sipStrings_QtGui[28107]
#define sipNameNr_paintingActive 28122
#define sipName_paintingActive &sipStrings_QtGui[28122]
#define sipNameNr_paletteChanged 28137
#define sipName_paletteChanged &sipStrings_QtGui[28137]
#define sipNameNr_pointAtPercent 28152
#define sipName_pointAtPercent &sipStrings_QtGui[28152]
#define sipNameNr_proposedAction 28167
#define sipName_proposedAction &sipStrings_QtGui[28167]
#define sipNameNr_qUnpremultiply 28182
#define sipName_qUnpremultiply &sipStrings_QtGui[28182]
#define sipNameNr_renderableType 28197
#define sipName_renderableType &sipStrings_QtGui[28197]
#define sipNameNr_resetBaseLevel 28212
#define sipName_resetBaseLevel &sipStrings_QtGui[28212]
#define sipNameNr_resetTransform 28227
#define sipName_resetTransform &sipStrings_QtGui[28227]
#define sipNameNr_sRGBColorSpace 28242
#define sipName_sRGBColorSpace &sipStrings_QtGui[28242]
#define sipNameNr_saturationSize 28257
#define sipName_saturationSize &sipStrings_QtGui[28257]
#define sipNameNr_scaledClipRect 28272
#define sipName_scaledClipRect &sipStrings_QtGui[28272]
#define sipNameNr_scaledToHeight 28287
#define sipName_scaledToHeight &sipStrings_QtGui[28287]
#define sipNameNr_selectionStart 28302
#define sipName_selectionStart &sipStrings_QtGui[28302]
#define sipNameNr_setAnchorNames 28317
#define sipName_setAnchorNames &sipStrings_QtGui[28317]
#define sipNameNr_setBlockFormat 28332
#define sipName_setBlockFormat &sipStrings_QtGui[28332]
#define sipNameNr_setBorderBrush 28347
#define sipName_setBorderBrush &sipStrings_QtGui[28347]
#define sipNameNr_setBorderColor 28362
#define sipName_setBorderColor &sipStrings_QtGui[28362]
#define sipNameNr_setBorderStyle 28377
#define sipName_setBorderStyle &sipStrings_QtGui[28377]
#define sipNameNr_setBrushOrigin 28392
#define sipName_setBrushOrigin &sipStrings_QtGui[28392]
#define sipNameNr_setCellPadding 28407
#define sipName_setCellPadding &sipStrings_QtGui[28407]
#define sipNameNr_setCellSpacing 28422
#define sipName_setCellSpacing &sipStrings_QtGui[28422]
#define sipNameNr_setColumnCount 28437
#define sipName_setColumnCount &sipStrings_QtGui[28437]
#define sipNameNr_setCompression 28452
#define sipName_setCompression &sipStrings_QtGui[28452]
#define sipNameNr_setDashPattern 28467
#define sipName_setDashPattern &sipStrings_QtGui[28467]
#define sipNameNr_setDefaultFont 28482
#define sipName_setDefaultFont &sipStrings_QtGui[28482]
#define sipNameNr_setDescription 28497
#define sipName_setDescription &sipStrings_QtGui[28497]
#define sipNameNr_setDragEnabled 28512
#define sipName_setDragEnabled &sipStrings_QtGui[28512]
#define sipNameNr_setDropEnabled 28527
#define sipName_setDropEnabled &sipStrings_QtGui[28527]
#define sipNameNr_setFocalRadius 28542
#define sipName_setFocalRadius &sipStrings_QtGui[28542]
#define sipNameNr_setFontKerning 28557
#define sipName_setFontKerning &sipStrings_QtGui[28557]
#define sipNameNr_setFontStretch 28572
#define sipName_setFontStretch &sipStrings_QtGui[28572]
#define sipNameNr_setFrameFormat 28587
#define sipName_setFrameFormat &sipStrings_QtGui[28587]
#define sipNameNr_setImageHeight 28602
#define sipName_setImageHeight &sipStrings_QtGui[28602]
#define sipNameNr_setIndentWidth 28617
#define sipName_setIndentWidth &sipStrings_QtGui[28617]
#define sipNameNr_setLeftPadding 28632
#define sipName_setLeftPadding &sipStrings_QtGui[28632]
#define sipNameNr_setMaximumSize 28647
#define sipName_setMaximumSize &sipStrings_QtGui[28647]
#define sipNameNr_setMinimumSize 28662
#define sipName_setMinimumSize &sipStrings_QtGui[28662]
#define sipNameNr_setMipMaxLevel 28677
#define sipName_setMipMaxLevel &sipStrings_QtGui[28677]
#define sipNameNr_setObjectIndex 28692
#define sipName_setObjectIndex &sipStrings_QtGui[28692]
#define sipNameNr_setOrientation 28707
#define sipName_setOrientation &sipStrings_QtGui[28707]
#define sipNameNr_setPageMargins 28722
#define sipName_setPageMargins &sipStrings_QtGui[28722]
#define sipNameNr_setPaintDevice 28737
#define sipName_setPaintDevice &sipStrings_QtGui[28737]
#define sipNameNr_setPreeditArea 28752
#define sipName_setPreeditArea &sipStrings_QtGui[28752]
#define sipNameNr_setRenderHints 28767
#define sipName_setRenderHints &sipStrings_QtGui[28767]
#define sipNameNr_setRightBorder 28782
#define sipName_setRightBorder &sipStrings_QtGui[28782]
#define sipNameNr_setRightMargin 28797
#define sipName_setRightMargin &sipStrings_QtGui[28797]
#define sipNameNr_setRightToLeft 28812
#define sipName_setRightToLeft &sipStrings_QtGui[28812]
#define sipNameNr_setSurfaceType 28827
#define sipName_setSurfaceType &sipStrings_QtGui[28827]
#define sipNameNr_setSwizzleMask 28842
#define sipName_setSwizzleMask &sipStrings_QtGui[28842]
#define sipNameNr_setTextOutline 28857
#define sipName_setTextOutline &sipStrings_QtGui[28857]
#define sipNameNr_setWindowState 28872
#define sipName_setWindowState &sipStrings_QtGui[28872]
#define sipNameNr_setWordSpacing 28887
#define sipName_setWordSpacing &sipStrings_QtGui[28887]
#define sipNameNr_showFullScreen 28902
#define sipName_showFullScreen &sipStrings_QtGui[28902]
#define sipNameNr_slopeAtPercent 28917
#define sipName_slopeAtPercent &sipStrings_QtGui[28917]
#define sipNameNr_startScreenPos 28932
#define sipName_startScreenPos &sipStrings_QtGui[28932]
#define sipNameNr_staticContents 28947
#define sipName_staticContents &sipStrings_QtGui[28947]
#define sipNameNr_stringProperty 28962
#define sipName_stringProperty &sipStrings_QtGui[28962]
#define sipNameNr_supportsOpenGL 28977
#define sipName_supportsOpenGL &sipStrings_QtGui[28977]
#define sipNameNr_supportsOption 28992
#define sipName_supportsOption &sipStrings_QtGui[28992]
#define sipNameNr_testRenderHint 29007
#define sipName_testRenderHint &sipStrings_QtGui[29007]
#define sipNameNr_toFillPolygons 29022
#define sipName_toFillPolygons &sipStrings_QtGui[29022]
#define sipNameNr_topBorderBrush 29037
#define sipName_topBorderBrush &sipStrings_QtGui[29037]
#define sipNameNr_topBorderStyle 29052
#define sipName_topBorderStyle &sipStrings_QtGui[29052]
#define sipNameNr_transformation 29067
#define sipName_transformation &sipStrings_QtGui[29067]
#define sipNameNr_underlineColor 29082
#define sipName_underlineColor &sipStrings_QtGui[29082]
#define sipNameNr_underlineStyle 29097
#define sipName_underlineStyle &sipStrings_QtGui[29097]
#define sipNameNr_updateBehavior 29112
#define sipName_updateBehavior &sipStrings_QtGui[29112]
#define sipNameNr_versionProfile 29127
#define sipName_versionProfile &sipStrings_QtGui[29127]
#define sipNameNr_visibleChanged 29142
#define sipName_visibleChanged &sipStrings_QtGui[29142]
#define sipNameNr_worldTransform 29157
#define sipName_worldTransform &sipStrings_QtGui[29157]
#define sipNameNr_writingSystems 29172
#define sipName_writingSystems &sipStrings_QtGui[29172]
#define sipNameNr_AlignBaseline 29187
#define sipName_AlignBaseline &sipStrings_QtGui[29187]
#define sipNameNr_AlphaPosition 4655
#define sipName_AlphaPosition &sipStrings_QtGui[4655]
#define sipNameNr_AlternateBase 29201
#define sipName_AlternateBase &sipStrings_QtGui[29201]
#define sipNameNr_AttributeType 1222
#define sipName_AttributeType &sipStrings_QtGui[1222]
#define sipNameNr_BindingTarget 3088
#define sipName_BindingTarget &sipStrings_QtGui[3088]
#define sipNameNr_BurningSpring 29215
#define sipName_BurningSpring &sipStrings_QtGui[29215]
#define sipNameNr_ClampToBorder 29229
#define sipName_ClampToBorder &sipStrings_QtGui[29229]
#define sipNameNr_ColorfulPeach 29243
#define sipName_ColorfulPeach &sipStrings_QtGui[29243]
#define sipNameNr_CompareAlways 29257
#define sipName_CompareAlways &sipStrings_QtGui[29257]
#define sipNameNr_DashUnderline 29271
#define sipName_DashUnderline &sipStrings_QtGui[29271]
#define sipNameNr_DirtyClipPath 29285
#define sipName_DirtyClipPath &sipStrings_QtGui[29285]
#define sipNameNr_DocumentTitle 29299
#define sipName_DocumentTitle &sipStrings_QtGui[29299]
#define sipNameNr_EnvelopeChou3 29313
#define sipName_EnvelopeChou3 &sipStrings_QtGui[29313]
#define sipNameNr_EnvelopeChou4 29327
#define sipName_EnvelopeChou4 &sipStrings_QtGui[29327]
#define sipNameNr_EnvelopeKaku2 29341
#define sipName_EnvelopeKaku2 &sipStrings_QtGui[29341]
#define sipNameNr_EnvelopeKaku3 29355
#define sipName_EnvelopeKaku3 &sipStrings_QtGui[29355]
#define sipNameNr_EnvelopePrc10 29369
#define sipName_EnvelopePrc10 &sipStrings_QtGui[29369]
#define sipNameNr_ExtraExpanded 29383
#define sipName_ExtraExpanded &sipStrings_QtGui[29383]
#define sipNameNr_FanFoldGerman 29397
#define sipName_FanFoldGerman &sipStrings_QtGui[29397]
#define sipNameNr_FloatingPoint 29411
#define sipName_FloatingPoint &sipStrings_QtGui[29411]
#define sipNameNr_FontPixelSize 29425
#define sipName_FontPixelSize &sipStrings_QtGui[29425]
#define sipNameNr_FontPointSize 22069
#define sipName_FontPointSize &sipStrings_QtGui[22069]
#define sipNameNr_FontStrikeOut 22086
#define sipName_FontStrikeOut &sipStrings_QtGui[22086]
#define sipNameNr_FontStyleHint 22103
#define sipName_FontStyleHint &sipStrings_QtGui[22103]
#define sipNameNr_FontStyleName 22120
#define sipName_FontStyleName &sipStrings_QtGui[22120]
#define sipNameNr_FontUnderline 22137
#define sipName_FontUnderline &sipStrings_QtGui[22137]
#define sipNameNr_FormatOptions 3298
#define sipName_FormatOptions &sipStrings_QtGui[3298]
#define sipNameNr_Format_ARGB32 29439
#define sipName_Format_ARGB32 &sipStrings_QtGui[29439]
#define sipNameNr_Format_Alpha8 29453
#define sipName_Format_Alpha8 &sipStrings_QtGui[29453]
#define sipNameNr_Format_BGR888 29467
#define sipName_Format_BGR888 &sipStrings_QtGui[29467]
#define sipNameNr_Format_RGB444 29481
#define sipName_Format_RGB444 &sipStrings_QtGui[29481]
#define sipNameNr_Format_RGB555 29495
#define sipName_Format_RGB555 &sipStrings_QtGui[29495]
#define sipNameNr_Format_RGB666 29509
#define sipName_Format_RGB666 &sipStrings_QtGui[29509]
#define sipNameNr_Format_RGB888 29523
#define sipName_Format_RGB888 &sipStrings_QtGui[29523]
#define sipNameNr_Format_RGBA64 29537
#define sipName_Format_RGBA64 &sipStrings_QtGui[29537]
#define sipNameNr_Format_RGBX64 29551
#define sipName_Format_RGBX64 &sipStrings_QtGui[29551]
#define sipNameNr_GlyphRunFlags 6691
#define sipName_GlyphRunFlags &sipStrings_QtGui[6691]
#define sipNameNr_GroupPushType 29565
#define sipName_GroupPushType &sipStrings_QtGui[29565]
#define sipNameNr_HappyMemories 29579
#define sipName_HappyMemories &sipStrings_QtGui[29579]
#define sipNameNr_ImageResource 29593
#define sipName_ImageResource &sipStrings_QtGui[29593]
#define sipNameNr_Imperial10x11 29607
#define sipName_Imperial10x11 &sipStrings_QtGui[29607]
#define sipNameNr_Imperial10x13 29621
#define sipName_Imperial10x13 &sipStrings_QtGui[29621]
#define sipNameNr_Imperial10x14 29635
#define sipName_Imperial10x14 &sipStrings_QtGui[29635]
#define sipNameNr_Imperial12x11 29649
#define sipName_Imperial12x11 &sipStrings_QtGui[29649]
#define sipNameNr_Imperial15x11 29663
#define sipName_Imperial15x11 &sipStrings_QtGui[29663]
#define sipNameNr_InvalidFormat 29677
#define sipName_InvalidFormat &sipStrings_QtGui[29677]
#define sipNameNr_InvalidSource 29691
#define sipName_InvalidSource &sipStrings_QtGui[29691]
#define sipNameNr_ItmeoBranding 29705
#define sipName_ItmeoBranding &sipStrings_QtGui[29705]
#define sipNameNr_LineToElement 29719
#define sipName_LineToElement &sipStrings_QtGui[29719]
#define sipNameNr_MidnightBloom 29733
#define sipName_MidnightBloom &sipStrings_QtGui[29733]
#define sipNameNr_MinimumHeight 22256
#define sipName_MinimumHeight &sipStrings_QtGui[22256]
#define sipNameNr_MoveOperation 5229
#define sipName_MoveOperation &sipStrings_QtGui[5229]
#define sipNameNr_MoveToElement 29747
#define sipName_MoveToElement &sipStrings_QtGui[29747]
#define sipNameNr_NextCharacter 29761
#define sipName_NextCharacter &sipStrings_QtGui[29761]
#define sipNameNr_NoFontMerging 29775
#define sipName_NoFontMerging &sipStrings_QtGui[29775]
#define sipNameNr_OpenGLSurface 29789
#define sipName_OpenGLSurface &sipStrings_QtGui[29789]
#define sipNameNr_OpenVGSurface 29803
#define sipName_OpenVGSurface &sipStrings_QtGui[29803]
#define sipNameNr_OriginTopLeft 29817
#define sipName_OriginTopLeft &sipStrings_QtGui[29817]
#define sipNameNr_PageBreakFlag 5283
#define sipName_PageBreakFlag &sipStrings_QtGui[5283]
#define sipNameNr_PassionateBed 29831
#define sipName_PassionateBed &sipStrings_QtGui[29831]
#define sipNameNr_PreferDefault 29845
#define sipName_PreferDefault &sipStrings_QtGui[29845]
#define sipNameNr_PreferOutline 29859
#define sipName_PreferOutline &sipStrings_QtGui[29859]
#define sipNameNr_PreferQuality 29873
#define sipName_PreferQuality &sipStrings_QtGui[29873]
#define sipNameNr_Premultiplied 1486
#define sipName_Premultiplied &sipStrings_QtGui[1486]
#define sipNameNr_PreviousBlock 29887
#define sipName_PreviousBlock &sipStrings_QtGui[29887]
#define sipNameNr_PreviousChild 29901
#define sipName_PreviousChild &sipStrings_QtGui[29901]
#define sipNameNr_QBackingStore 29915
#define sipName_QBackingStore &sipStrings_QtGui[29915]
#define sipNameNr_QFont__Weight 29929
#define sipName_QFont__Weight &sipStrings_QtGui[29929]
#define sipNameNr_QFontDatabase 29943
#define sipName_QFontDatabase &sipStrings_QtGui[29943]
#define sipNameNr_QFontMetricsF 29957
#define sipName_QFontMetricsF &sipStrings_QtGui[29957]
#define sipNameNr_QIntValidator 29971
#define sipName_QIntValidator &sipStrings_QtGui[29971]
#define sipNameNr_QOpenGLBuffer 29985
#define sipName_QOpenGLBuffer &sipStrings_QtGui[29985]
#define sipNameNr_QOpenGLShader 29999
#define sipName_QOpenGLShader &sipStrings_QtGui[29999]
#define sipNameNr_QOpenGLWindow 30013
#define sipName_QOpenGLWindow &sipStrings_QtGui[30013]
#define sipNameNr_QRasterWindow 30027
#define sipName_QRasterWindow &sipStrings_QtGui[30027]
#define sipNameNr_QStandardItem 30041
#define sipName_QStandardItem &sipStrings_QtGui[30041]
#define sipNameNr_QTextDocument 30055
#define sipName_QTextDocument &sipStrings_QtGui[30055]
#define sipNameNr_QTextFragment 30069
#define sipName_QTextFragment &sipStrings_QtGui[30069]
#define sipNameNr_30083 30083
#define sipName_30083 &sipStrings_QtGui[30083]
#define sipNameNr_QWindowSystem 30097
#define sipName_QWindowSystem &sipStrings_QtGui[30097]
#define sipNameNr_R11_EAC_SNorm 30111
#define sipName_R11_EAC_SNorm &sipStrings_QtGui[30111]
#define sipNameNr_R11_EAC_UNorm 30125
#define sipName_R11_EAC_UNorm &sipStrings_QtGui[30125]
#define sipNameNr_RGBA_ASTC_4x4 30139
#define sipName_RGBA_ASTC_4x4 &sipStrings_QtGui[30139]
#define sipNameNr_RGBA_ASTC_5x4 30153
#define sipName_RGBA_ASTC_5x4 &sipStrings_QtGui[30153]
#define sipNameNr_RGBA_ASTC_5x5 30167
#define sipName_RGBA_ASTC_5x5 &sipStrings_QtGui[30167]
#define sipNameNr_RGBA_ASTC_6x5 30181
#define sipName_RGBA_ASTC_6x5 &sipStrings_QtGui[30181]
#define sipNameNr_RGBA_ASTC_6x6 30195
#define sipName_RGBA_ASTC_6x6 &sipStrings_QtGui[30195]
#define sipNameNr_RGBA_ASTC_8x5 30209
#define sipName_RGBA_ASTC_8x5 &sipStrings_QtGui[30209]
#define sipNameNr_RGBA_ASTC_8x6 30223
#define sipName_RGBA_ASTC_8x6 &sipStrings_QtGui[30223]
#define sipNameNr_RGBA_ASTC_8x8 30237
#define sipName_RGBA_ASTC_8x8 &sipStrings_QtGui[30237]
#define sipNameNr_R_ATI1N_SNorm 30251
#define sipName_R_ATI1N_SNorm &sipStrings_QtGui[30251]
#define sipNameNr_R_ATI1N_UNorm 30265
#define sipName_R_ATI1N_UNorm &sipStrings_QtGui[30265]
#define sipNameNr_RainyAshville 30279
#define sipName_RainyAshville &sipStrings_QtGui[30279]
#define sipNameNr_RasterOpModes 30293
#define sipName_RasterOpModes &sipStrings_QtGui[30293]
#define sipNameNr_RasterSurface 30307
#define sipName_RasterSurface &sipStrings_QtGui[30307]
#define sipNameNr_ReflectSpread 30321
#define sipName_ReflectSpread &sipStrings_QtGui[30321]
#define sipNameNr_RiskyConcrete 30335
#define sipName_RiskyConcrete &sipStrings_QtGui[30335]
#define sipNameNr_SRGB_BP_UNorm 30349
#define sipName_SRGB_BP_UNorm &sipStrings_QtGui[30349]
#define sipNameNr_ScrollStarted 30363
#define sipName_ScrollStarted &sipStrings_QtGui[30363]
#define sipNameNr_ScrollUpdated 30377
#define sipName_ScrollUpdated &sipStrings_QtGui[30377]
#define sipNameNr_SelectionType 5256
#define sipName_SelectionType &sipStrings_QtGui[5256]
#define sipNameNr_SemiCondensed 30391
#define sipName_SemiCondensed &sipStrings_QtGui[30391]
#define sipNameNr_SequenceMatch 4459
#define sipName_SequenceMatch &sipStrings_QtGui[4459]
#define sipNameNr_ShaderTypeBit 3859
#define sipName_ShaderTypeBit &sipStrings_QtGui[3859]
#define sipNameNr_SharpeyeEagle 30405
#define sipName_SharpeyeEagle &sipStrings_QtGui[30405]
#define sipNameNr_SplitLigature 30419
#define sipName_SplitLigature &sipStrings_QtGui[30419]
#define sipNameNr_StereoBuffers 30433
#define sipName_StereoBuffers &sipStrings_QtGui[30433]
#define sipNameNr_StyleStrategy 11936
#define sipName_StyleStrategy &sipStrings_QtGui[11936]
#define sipNameNr_SugarLollipop 30447
#define sipName_SugarLollipop &sipStrings_QtGui[30447]
#define sipNameNr_Target1DArray 11642
#define sipName_Target1DArray &sipStrings_QtGui[11642]
#define sipNameNr_Target2DArray 11663
#define sipName_Target2DArray &sipStrings_QtGui[11663]
#define sipNameNr_TargetCubeMap 11684
#define sipName_TargetCubeMap &sipStrings_QtGui[11684]
#define sipNameNr_TemptingAzure 30461
#define sipName_TemptingAzure &sipStrings_QtGui[30461]
#define sipNameNr_TextureArrays 30475
#define sipName_TextureArrays &sipStrings_QtGui[30475]
#define sipNameNr_TextureBuffer 30489
#define sipName_TextureBuffer &sipStrings_QtGui[30489]
#define sipNameNr_TextureFormat 3118
#define sipName_TextureFormat &sipStrings_QtGui[3118]
#define sipNameNr_UInt16_R5G6B5 30503
#define sipName_UInt16_R5G6B5 &sipStrings_QtGui[30503]
#define sipNameNr_UInt16_RGB5A1 30517
#define sipName_UInt16_RGB5A1 &sipStrings_QtGui[30517]
#define sipNameNr_UltraExpanded 30531
#define sipName_UltraExpanded &sipStrings_QtGui[30531]
#define sipNameNr_UnsignedShort 30545
#define sipName_UnsignedShort &sipStrings_QtGui[30545]
#define sipNameNr_ViciousStance 30559
#define sipName_ViciousStance &sipStrings_QtGui[30559]
#define sipNameNr_VulkanSurface 30573
#define sipName_VulkanSurface &sipStrings_QtGui[30573]
#define sipNameNr_WaveUnderline 30587
#define sipName_WaveUnderline &sipStrings_QtGui[30587]
#define sipNameNr_WritingSystem 3714
#define sipName_WritingSystem &sipStrings_QtGui[3714]
#define sipNameNr_actionChanged 30601
#define sipName_actionChanged &sipStrings_QtGui[30601]
#define sipNameNr_activeChanged 30615
#define sipName_activeChanged &sipStrings_QtGui[30615]
#define sipNameNr_alphaPosition 30629
#define sipName_alphaPosition &sipStrings_QtGui[30629]
#define sipNameNr_alternateBase 30643
#define sipName_alternateBase &sipStrings_QtGui[30643]
#define sipNameNr_appendColumns 30657
#define sipName_appendColumns &sipStrings_QtGui[30657]
#define sipNameNr_autoTransform 30671
#define sipName_autoTransform &sipStrings_QtGui[30671]
#define sipNameNr_availableSize 30685
#define sipName_availableSize &sipStrings_QtGui[30685]
#define sipNameNr_bitPlaneCount 30699
#define sipName_bitPlaneCount &sipStrings_QtGui[30699]
#define sipNameNr_blockInserted 30713
#define sipName_blockInserted &sipStrings_QtGui[30713]
#define sipNameNr_bottomPadding 30727
#define sipName_bottomPadding &sipStrings_QtGui[30727]
#define sipNameNr_brushProperty 30741
#define sipName_brushProperty &sipStrings_QtGui[30741]
#define sipNameNr_clearItemData 30755
#define sipName_clearItemData &sipStrings_QtGui[30755]
#define sipNameNr_clearProperty 30769
#define sipName_clearProperty &sipStrings_QtGui[30769]
#define sipNameNr_clipOperation 30783
#define sipName_clipOperation &sipStrings_QtGui[30783]
#define sipNameNr_colorProperty 30797
#define sipName_colorProperty &sipStrings_QtGui[30797]
#define sipNameNr_connectNotify 21542
#define sipName_connectNotify &sipStrings_QtGui[21542]
#define sipNameNr_constScanLine 30811
#define sipName_constScanLine &sipStrings_QtGui[30811]
#define sipNameNr_containsPoint 30825
#define sipName_containsPoint &sipStrings_QtGui[30825]
#define sipNameNr_currentPixmap 30839
#define sipName_currentPixmap &sipStrings_QtGui[30839]
#define sipNameNr_darkgoldenrod 30853
#define sipName_darkgoldenrod &sipStrings_QtGui[30853]
#define sipNameNr_darkslateblue 30867
#define sipName_darkslateblue &sipStrings_QtGui[30867]
#define sipNameNr_darkslategray 30881
#define sipName_darkslategray &sipStrings_QtGui[30881]
#define sipNameNr_darkslategrey 30895
#define sipName_darkslategrey &sipStrings_QtGui[30895]
#define sipNameNr_darkturquoise 30909
#define sipName_darkturquoise &sipStrings_QtGui[30909]
#define sipNameNr_defaultAction 30923
#define sipName_defaultAction &sipStrings_QtGui[30923]
#define sipNameNr_defaultFamily 30937
#define sipName_defaultFamily &sipStrings_QtGui[30937]
#define sipNameNr_defaultFormat 30951
#define sipName_defaultFormat &sipStrings_QtGui[30951]
#define sipNameNr_dotsPerMeterX 30965
#define sipName_dotsPerMeterX &sipStrings_QtGui[30965]
#define sipNameNr_dotsPerMeterY 30979
#define sipName_dotsPerMeterY &sipStrings_QtGui[30979]
#define sipNameNr_firstPosition 30993
#define sipName_firstPosition &sipStrings_QtGui[30993]
#define sipNameNr_focusOutEvent 31007
#define sipName_focusOutEvent &sipStrings_QtGui[31007]
#define sipNameNr_fontPointSize 31021
#define sipName_fontPointSize &sipStrings_QtGui[31021]
#define sipNameNr_fontStrikeOut 31035
#define sipName_fontStrikeOut &sipStrings_QtGui[31035]
#define sipNameNr_fontStyleHint 31049
#define sipName_fontStyleHint &sipStrings_QtGui[31049]
#define sipNameNr_fontStyleName 31063
#define sipName_fontStyleName &sipStrings_QtGui[31063]
#define sipNameNr_fontUnderline 31077
#define sipName_fontUnderline &sipStrings_QtGui[31077]
#define sipNameNr_formatVersion 31091
#define sipName_formatVersion &sipStrings_QtGui[31091]
#define sipNameNr_frameGeometry 31105
#define sipName_frameGeometry &sipStrings_QtGui[31105]
#define sipNameNr_framePosition 31119
#define sipName_framePosition &sipStrings_QtGui[31119]
#define sipNameNr_fromDirection 31133
#define sipName_fromDirection &sipStrings_QtGui[31133]
#define sipNameNr_fromNumericId 31147
#define sipName_fromNumericId &sipStrings_QtGui[31147]
#define sipNameNr_fromPlainText 31161
#define sipName_fromPlainText &sipStrings_QtGui[31161]
#define sipNameNr_fromTranslate 31175
#define sipName_fromTranslate &sipStrings_QtGui[31175]
#define sipNameNr_heightChanged 31189
#define sipName_heightChanged &sipStrings_QtGui[31189]
#define sipNameNr_hslSaturation 31203
#define sipName_hslSaturation &sipStrings_QtGui[31203]
#define sipNameNr_hsvSaturation 31217
#define sipName_hsvSaturation &sipStrings_QtGui[31217]
#define sipNameNr_indexFromItem 31231
#define sipName_indexFromItem &sipStrings_QtGui[31231]
#define sipNameNr_insertColumns 31245
#define sipName_insertColumns &sipStrings_QtGui[31245]
#define sipNameNr_intrinsicSize 31259
#define sipName_intrinsicSize &sipStrings_QtGui[31259]
#define sipNameNr_isBlockFormat 31273
#define sipName_isBlockFormat &sipStrings_QtGui[31273]
#define sipNameNr_isClipEnabled 31287
#define sipName_isClipEnabled &sipStrings_QtGui[31287]
#define sipNameNr_isDragEnabled 31301
#define sipName_isDragEnabled &sipStrings_QtGui[31301]
#define sipNameNr_isDropEnabled 31315
#define sipName_isDropEnabled &sipStrings_QtGui[31315]
#define sipNameNr_isFrameFormat 31329
#define sipName_isFrameFormat &sipStrings_QtGui[31329]
#define sipNameNr_isImageFormat 31343
#define sipName_isImageFormat &sipStrings_QtGui[31343]
#define sipNameNr_isLeftToRight 31357
#define sipName_isLeftToRight &sipStrings_QtGui[31357]
#define sipNameNr_isRightToLeft 31371
#define sipName_isRightToLeft &sipStrings_QtGui[31371]
#define sipNameNr_isTableFormat 31385
#define sipName_isTableFormat &sipStrings_QtGui[31385]
#define sipNameNr_isTextureView 31399
#define sipName_isTextureView &sipStrings_QtGui[31399]
#define sipNameNr_isTranslating 31413
#define sipName_isTranslating &sipStrings_QtGui[31413]
#define sipNameNr_isTransparent 31427
#define sipName_isTransparent &sipStrings_QtGui[31427]
#define sipNameNr_itemFromIndex 31441
#define sipName_itemFromIndex &sipStrings_QtGui[31441]
#define sipNameNr_itemPrototype 31455
#define sipName_itemPrototype &sipStrings_QtGui[31455]
#define sipNameNr_keyPressEvent 31469
#define sipName_keyPressEvent &sipStrings_QtGui[31469]
#define sipNameNr_lastScreenPos 31483
#define sipName_lastScreenPos &sipStrings_QtGui[31483]
#define sipNameNr_lavenderblush 31497
#define sipName_lavenderblush &sipStrings_QtGui[31497]
#define sipNameNr_lengthSquared 31511
#define sipName_lengthSquared &sipStrings_QtGui[31511]
#define sipNameNr_letterSpacing 31525
#define sipName_letterSpacing &sipStrings_QtGui[31525]
#define sipNameNr_lightnessSize 31539
#define sipName_lightnessSize &sipStrings_QtGui[31539]
#define sipNameNr_lightseagreen 31553
#define sipName_lightseagreen &sipStrings_QtGui[31553]
#define sipNameNr_lineThickness 31567
#define sipName_lineThickness &sipStrings_QtGui[31567]
#define sipNameNr_localeChanged 31581
#define sipName_localeChanged &sipStrings_QtGui[31581]
#define sipNameNr_mapFromGlobal 31595
#define sipName_mapFromGlobal &sipStrings_QtGui[31595]
#define sipNameNr_marginsPixels 31609
#define sipName_marginsPixels &sipStrings_QtGui[31609]
#define sipNameNr_marginsPoints 31623
#define sipName_marginsPoints &sipStrings_QtGui[31623]
#define sipNameNr_maximumHeight 31637
#define sipName_maximumHeight &sipStrings_QtGui[31637]
#define sipNameNr_messageLogged 31651
#define sipName_messageLogged &sipStrings_QtGui[31651]
#define sipNameNr_minMagFilters 31665
#define sipName_minMagFilters &sipStrings_QtGui[31665]
#define sipNameNr_minimumHeight 31679
#define sipName_minimumHeight &sipStrings_QtGui[31679]
#define sipNameNr_mipLevelRange 31693
#define sipName_mipLevelRange &sipStrings_QtGui[31693]
#define sipNameNr_normalizedPos 31707
#define sipName_normalizedPos &sipStrings_QtGui[31707]
#define sipNameNr_outputFormats 31721
#define sipName_outputFormats &sipStrings_QtGui[31721]
#define sipNameNr_ownsClipboard 31735
#define sipName_ownsClipboard &sipStrings_QtGui[31735]
#define sipNameNr_ownsSelection 31749
#define sipName_ownsSelection &sipStrings_QtGui[31749]
#define sipNameNr_palegoldenrod 31763
#define sipName_palegoldenrod &sipStrings_QtGui[31763]
#define sipNameNr_paleturquoise 31777
#define sipName_paleturquoise &sipStrings_QtGui[31777]
#define sipNameNr_palevioletred 31791
#define sipName_palevioletred &sipStrings_QtGui[31791]
#define sipNameNr_pictureFormat 31805
#define sipName_pictureFormat &sipStrings_QtGui[31805]
#define sipNameNr_preeditString 31819
#define sipName_preeditString &sipStrings_QtGui[31819]
#define sipNameNr_premultiplied 25899
#define sipName_premultiplied &sipStrings_QtGui[25899]
#define sipNameNr_primaryScreen 31833
#define sipName_primaryScreen &sipStrings_QtGui[31833]
#define sipNameNr_propertyCount 31847
#define sipName_propertyCount &sipStrings_QtGui[31847]
#define sipNameNr_qFuzzyCompare 31861
#define sipName_qFuzzyCompare &sipStrings_QtGui[31861]
#define sipNameNr_redBufferSize 31875
#define sipName_redBufferSize &sipStrings_QtGui[31875]
#define sipNameNr_redoAvailable 31889
#define sipName_redoAvailable &sipStrings_QtGui[31889]
#define sipNameNr_removeColumns 31903
#define sipName_removeColumns &sipStrings_QtGui[31903]
#define sipNameNr_requestUpdate 31917
#define sipName_requestUpdate &sipStrings_QtGui[31917]
#define sipNameNr_rotateRadians 31931
#define sipName_rotateRadians &sipStrings_QtGui[31931]
#define sipNameNr_rotatedVector 31945
#define sipName_rotatedVector &sipStrings_QtGui[31945]
#define sipNameNr_scaledToWidth 31959
#define sipName_scaledToWidth &sipStrings_QtGui[31959]
#define sipNameNr_screenChanged 31973
#define sipName_screenChanged &sipStrings_QtGui[31973]
#define sipNameNr_screenRemoved 31987
#define sipName_screenRemoved &sipStrings_QtGui[31987]
#define sipNameNr_setAnchorHref 32001
#define sipName_setAnchorHref &sipStrings_QtGui[32001]
#define sipNameNr_setAttachment 32015
#define sipName_setAttachment &sipStrings_QtGui[32015]
#define sipNameNr_setBackground 32029
#define sipName_setBackground &sipStrings_QtGui[32029]
#define sipNameNr_setCacheLimit 32043
#define sipName_setCacheLimit &sipStrings_QtGui[32043]
#define sipNameNr_setCharFormat 32057
#define sipName_setCharFormat &sipStrings_QtGui[32057]
#define sipNameNr_setCheckState 32071
#define sipName_setCheckState &sipStrings_QtGui[32071]
#define sipNameNr_setClipRegion 32085
#define sipName_setClipRegion &sipStrings_QtGui[32085]
#define sipNameNr_setColorCount 32099
#define sipName_setColorCount &sipStrings_QtGui[32099]
#define sipNameNr_setColorGroup 32113
#define sipName_setColorGroup &sipStrings_QtGui[32113]
#define sipNameNr_setColorSpace 32127
#define sipName_setColorSpace &sipStrings_QtGui[32127]
#define sipNameNr_setColorTable 32141
#define sipName_setColorTable &sipStrings_QtGui[32141]
#define sipNameNr_setContentPos 32155
#define sipName_setContentPos &sipStrings_QtGui[32155]
#define sipNameNr_setDashOffset 32169
#define sipName_setDashOffset &sipStrings_QtGui[32169]
#define sipNameNr_setDragCursor 32183
#define sipName_setDragCursor &sipStrings_QtGui[32183]
#define sipNameNr_setDropAction 32197
#define sipName_setDropAction &sipStrings_QtGui[32197]
#define sipNameNr_setFixedPitch 32211
#define sipName_setFixedPitch &sipStrings_QtGui[32211]
#define sipNameNr_setFocalPoint 32225
#define sipName_setFocalPoint &sipStrings_QtGui[32225]
#define sipNameNr_setFontFamily 32239
#define sipName_setFontFamily &sipStrings_QtGui[32239]
#define sipNameNr_setFontItalic 32253
#define sipName_setFontItalic &sipStrings_QtGui[32253]
#define sipNameNr_setFontWeight 32267
#define sipName_setFontWeight &sipStrings_QtGui[32267]
#define sipNameNr_setForeground 32281
#define sipName_setForeground &sipStrings_QtGui[32281]
#define sipNameNr_setHeaderData 32295
#define sipName_setHeaderData &sipStrings_QtGui[32295]
#define sipNameNr_setLeftBorder 32309
#define sipName_setLeftBorder &sipStrings_QtGui[32309]
#define sipNameNr_setLeftMargin 32323
#define sipName_setLeftMargin &sipStrings_QtGui[32323]
#define sipNameNr_setLineHeight 32337
#define sipName_setLineHeight &sipStrings_QtGui[32337]
#define sipNameNr_setMiterLimit 32351
#define sipName_setMiterLimit &sipStrings_QtGui[32351]
#define sipNameNr_setNamedColor 32365
#define sipName_setNamedColor &sipStrings_QtGui[32365]
#define sipNameNr_setNumColumns 32379
#define sipName_setNumColumns &sipStrings_QtGui[32379]
#define sipNameNr_setObjectType 32393
#define sipName_setObjectType &sipStrings_QtGui[32393]
#define sipNameNr_setPageLayout 32407
#define sipName_setPageLayout &sipStrings_QtGui[32407]
#define sipNameNr_setPageSizeMM 32421
#define sipName_setPageSizeMM &sipStrings_QtGui[32421]
#define sipNameNr_setParameters 32435
#define sipName_setParameters &sipStrings_QtGui[32435]
#define sipNameNr_setPdfVersion 32449
#define sipName_setPdfVersion &sipStrings_QtGui[32449]
#define sipNameNr_setPixelColor 32463
#define sipName_setPixelColor &sipStrings_QtGui[32463]
#define sipNameNr_setPointSizeF 32477
#define sipName_setPointSizeF &sipStrings_QtGui[32477]
#define sipNameNr_setRenderHint 32491
#define sipName_setRenderHint &sipStrings_QtGui[32491]
#define sipNameNr_setResolution 32505
#define sipName_setResolution &sipStrings_QtGui[32505]
#define sipNameNr_setScaledSize 32519
#define sipName_setScaledSize &sipStrings_QtGui[32519]
#define sipNameNr_setSelectable 32533
#define sipName_setSelectable &sipStrings_QtGui[32533]
#define sipNameNr_setSkipImages 32547
#define sipName_setSkipImages &sipStrings_QtGui[32547]
#define sipNameNr_setSkipPixels 32561
#define sipName_setSkipPixels &sipStrings_QtGui[32561]
#define sipNameNr_setTextFormat 32575
#define sipName_setTextFormat &sipStrings_QtGui[32575]
#define sipNameNr_setTextIndent 32589
#define sipName_setTextIndent &sipStrings_QtGui[32589]
#define sipNameNr_setTextOption 32603
#define sipName_setTextOption &sipStrings_QtGui[32603]
#define sipNameNr_setToIdentity 32617
#define sipName_setToIdentity &sipStrings_QtGui[32617]
#define sipNameNr_setTopPadding 32631
#define sipName_setTopPadding &sipStrings_QtGui[32631]
#define sipNameNr_setUrlHandler 25915
#define sipName_setUrlHandler &sipStrings_QtGui[25915]
#define sipNameNr_setVisibility 32645
#define sipName_setVisibility &sipStrings_QtGui[32645]
#define sipNameNr_setWindowIcon 32659
#define sipName_setWindowIcon &sipStrings_QtGui[32659]
#define sipNameNr_showMaximized 32673
#define sipName_showMaximized &sipStrings_QtGui[32673]
#define sipNameNr_showMinimized 32687
#define sipName_showMinimized &sipStrings_QtGui[32687]
#define sipNameNr_sizeIncrement 32701
#define sipName_sizeIncrement &sipStrings_QtGui[32701]
#define sipNameNr_standardSizes 32715
#define sipName_standardSizes &sipStrings_QtGui[32715]
#define sipNameNr_startDragTime 32729
#define sipName_startDragTime &sipStrings_QtGui[32729]
#define sipNameNr_startScenePos 32743
#define sipName_startScenePos &sipStrings_QtGui[32743]
#define sipNameNr_styleStrategy 32757
#define sipName_styleStrategy &sipStrings_QtGui[32757]
#define sipNameNr_substitutions 32771
#define sipName_substitutions &sipStrings_QtGui[32771]
#define sipNameNr_targetChanged 32785
#define sipName_targetChanged &sipStrings_QtGui[32785]
#define sipNameNr_textAlignment 32799
#define sipName_textAlignment &sipStrings_QtGui[32799]
#define sipNameNr_textDirection 32813
#define sipName_textDirection &sipStrings_QtGui[32813]
#define sipNameNr_textureTarget 32827
#define sipName_textureTarget &sipStrings_QtGui[32827]
#define sipNameNr_toBlockFormat 32841
#define sipName_toBlockFormat &sipStrings_QtGui[32841]
#define sipNameNr_toEulerAngles 32855
#define sipName_toEulerAngles &sipStrings_QtGui[32855]
#define sipNameNr_toExtendedRgb 32869
#define sipName_toExtendedRgb &sipStrings_QtGui[32869]
#define sipNameNr_toFillPolygon 32883
#define sipName_toFillPolygon &sipStrings_QtGui[32883]
#define sipNameNr_toFrameFormat 32897
#define sipName_toFrameFormat &sipStrings_QtGui[32897]
#define sipNameNr_toImageFormat 32911
#define sipName_toImageFormat &sipStrings_QtGui[32911]
#define sipNameNr_toPixelFormat 32925
#define sipName_toPixelFormat &sipStrings_QtGui[32925]
#define sipNameNr_toTableFormat 32939
#define sipName_toTableFormat &sipStrings_QtGui[32939]
#define sipNameNr_transformMode 32953
#define sipName_transformMode &sipStrings_QtGui[32953]
#define sipNameNr_undoAvailable 32967
#define sipName_undoAvailable &sipStrings_QtGui[32967]
#define sipNameNr_writingSystem 32981
#define sipName_writingSystem &sipStrings_QtGui[32981]
#define sipNameNr_AfricanField 32995
#define sipName_AfricanField &sipStrings_QtGui[32995]
#define sipNameNr_AlchemistLab 33008
#define sipName_AlchemistLab &sipStrings_QtGui[33008]
#define sipNameNr_AllLowercase 33021
#define sipName_AllLowercase &sipStrings_QtGui[33021]
#define sipNameNr_AllUppercase 33034
#define sipName_AllUppercase &sipStrings_QtGui[33034]
#define sipNameNr_AncestorMode 10479
#define sipName_AncestorMode &sipStrings_QtGui[10479]
#define sipNameNr_Antialiasing 7588
#define sipName_Antialiasing &sipStrings_QtGui[7588]
#define sipNameNr_AquaGuidance 33047
#define sipName_AquaGuidance &sipStrings_QtGui[33047]
#define sipNameNr_BGRA_Integer 33060
#define sipName_BGRA_Integer &sipStrings_QtGui[33060]
#define sipNameNr_Capabilities 5338
#define sipName_Capabilities &sipStrings_QtGui[5338]
#define sipNameNr_CompareEqual 33073
#define sipName_CompareEqual &sipStrings_QtGui[33073]
#define sipNameNr_CompareNever 33086
#define sipName_CompareNever &sipStrings_QtGui[33086]
#define sipNameNr_CoreGraphics 33099
#define sipName_CoreGraphics &sipStrings_QtGui[33099]
#define sipNameNr_CrystalRiver 33112
#define sipName_CrystalRiver &sipStrings_QtGui[33112]
#define sipNameNr_DebugContext 33125
#define sipName_DebugContext &sipStrings_QtGui[33125]
#define sipNameNr_DelimiterTab 33138
#define sipName_DelimiterTab &sipStrings_QtGui[33138]
#define sipNameNr_DepthStencil 11706
#define sipName_DepthStencil &sipStrings_QtGui[11706]
#define sipNameNr_DirtyOpacity 33151
#define sipName_DirtyOpacity &sipStrings_QtGui[33151]
#define sipNameNr_DoubleBuffer 33164
#define sipName_DoubleBuffer &sipStrings_QtGui[33164]
#define sipNameNr_EnvelopePrc1 33177
#define sipName_EnvelopePrc1 &sipStrings_QtGui[33177]
#define sipNameNr_EnvelopePrc2 33190
#define sipName_EnvelopePrc2 &sipStrings_QtGui[33190]
#define sipNameNr_EnvelopePrc3 33203
#define sipName_EnvelopePrc3 &sipStrings_QtGui[33203]
#define sipNameNr_EnvelopePrc4 33216
#define sipName_EnvelopePrc4 &sipStrings_QtGui[33216]
#define sipNameNr_EnvelopePrc5 33229
#define sipName_EnvelopePrc5 &sipStrings_QtGui[33229]
#define sipNameNr_EnvelopePrc6 33242
#define sipName_EnvelopePrc6 &sipStrings_QtGui[33242]
#define sipNameNr_EnvelopePrc7 33255
#define sipName_EnvelopePrc7 &sipStrings_QtGui[33255]
#define sipNameNr_EnvelopePrc8 33268
#define sipName_EnvelopePrc8 &sipStrings_QtGui[33268]
#define sipNameNr_EnvelopePrc9 33281
#define sipName_EnvelopePrc9 &sipStrings_QtGui[33281]
#define sipNameNr_EnvelopeYou4 33294
#define sipName_EnvelopeYou4 &sipStrings_QtGui[33294]
#define sipNameNr_FabledSunset 33307
#define sipName_FabledSunset &sipStrings_QtGui[33307]
#define sipNameNr_FarawayRiver 33320
#define sipName_FarawayRiver &sipStrings_QtGui[33320]
#define sipNameNr_FindBackward 33333
#define sipName_FindBackward &sipStrings_QtGui[33333]
#define sipNameNr_FindPrevious 33346
#define sipName_FindPrevious &sipStrings_QtGui[33346]
#define sipNameNr_FontFamilies 8212
#define sipName_FontFamilies &sipStrings_QtGui[8212]
#define sipNameNr_FontOverline 25404
#define sipName_FontOverline &sipStrings_QtGui[25404]
#define sipNameNr_ForceOutline 33359
#define sipName_ForceOutline &sipStrings_QtGui[33359]
#define sipNameNr_FormatOption 3976
#define sipName_FormatOption &sipStrings_QtGui[3976]
#define sipNameNr_Format_BGR30 33372
#define sipName_Format_BGR30 &sipStrings_QtGui[33372]
#define sipNameNr_Format_RGB16 33385
#define sipName_Format_RGB16 &sipStrings_QtGui[33385]
#define sipNameNr_Format_RGB30 33398
#define sipName_Format_RGB30 &sipStrings_QtGui[33398]
#define sipNameNr_Format_RGB32 33411
#define sipName_Format_RGB32 &sipStrings_QtGui[33411]
#define sipNameNr_FramePadding 33424
#define sipName_FramePadding &sipStrings_QtGui[33424]
#define sipNameNr_FrozenDreams 33437
#define sipName_FrozenDreams &sipStrings_QtGui[33437]
#define sipNameNr_FullPageMode 33450
#define sipName_FullPageMode &sipStrings_QtGui[33450]
#define sipNameNr_GlyphRunFlag 7612
#define sipName_GlyphRunFlag &sipStrings_QtGui[7612]
#define sipNameNr_GrassShampoo 33463
#define sipName_GrassShampoo &sipStrings_QtGui[33463]
#define sipNameNr_GroupPopType 33476
#define sipName_GroupPopType &sipStrings_QtGui[33476]
#define sipNameNr_HappyUnicorn 33489
#define sipName_HappyUnicorn &sipStrings_QtGui[33489]
#define sipNameNr_HeadingLevel 25436
#define sipName_HeadingLevel &sipStrings_QtGui[25436]
#define sipNameNr_HealthyWater 33502
#define sipName_HealthyWater &sipStrings_QtGui[33502]
#define sipNameNr_HelpContents 33515
#define sipName_HelpContents &sipStrings_QtGui[33515]
#define sipNameNr_HiddenJaguar 33528
#define sipName_HiddenJaguar &sipStrings_QtGui[33528]
#define sipNameNr_HighSeverity 33541
#define sipName_HighSeverity &sipStrings_QtGui[33541]
#define sipNameNr_HtmlResource 33554
#define sipName_HtmlResource &sipStrings_QtGui[33554]
#define sipNameNr_IconNameHook 33567
#define sipName_IconNameHook &sipStrings_QtGui[33567]
#define sipNameNr_IgnoresAlpha 33580
#define sipName_IgnoresAlpha &sipStrings_QtGui[33580]
#define sipNameNr_ImageAltText 33593
#define sipName_ImageAltText &sipStrings_QtGui[33593]
#define sipNameNr_ImageQuality 33606
#define sipName_ImageQuality &sipStrings_QtGui[33606]
#define sipNameNr_Imperial8x10 33619
#define sipName_Imperial8x10 &sipStrings_QtGui[33619]
#define sipNameNr_Imperial9x11 33632
#define sipName_Imperial9x11 &sipStrings_QtGui[33632]
#define sipNameNr_Imperial9x12 33645
#define sipName_Imperial9x12 &sipStrings_QtGui[33645]
#define sipNameNr_Intermediate 33658
#define sipName_Intermediate &sipStrings_QtGui[33658]
#define sipNameNr_LadogaBottom 33671
#define sipName_LadogaBottom &sipStrings_QtGui[33671]
#define sipNameNr_LastPageSize 33684
#define sipName_LastPageSize &sipStrings_QtGui[33684]
#define sipNameNr_LittleEndian 33697
#define sipName_LittleEndian &sipStrings_QtGui[33697]
#define sipNameNr_MetalSurface 33710
#define sipName_MetalSurface &sipStrings_QtGui[33710]
#define sipNameNr_MorningSalad 33723
#define sipName_MorningSalad &sipStrings_QtGui[33723]
#define sipNameNr_MountainRock 33736
#define sipName_MountainRock &sipStrings_QtGui[33736]
#define sipNameNr_NColorGroups 33749
#define sipName_NColorGroups &sipStrings_QtGui[33749]
#define sipNameNr_NPOTTextures 33762
#define sipName_NPOTTextures &sipStrings_QtGui[33762]
#define sipNameNr_NewRetrowave 33775
#define sipName_NewRetrowave &sipStrings_QtGui[33775]
#define sipNameNr_NoAttachment 33788
#define sipName_NoAttachment &sipStrings_QtGui[33788]
#define sipNameNr_NorthMiracle 33801
#define sipName_NorthMiracle &sipStrings_QtGui[33801]
#define sipNameNr_PaintContext 232
#define sipName_PaintContext &sipStrings_QtGui[232]
#define sipNameNr_PainterPaths 33814
#define sipName_PainterPaths &sipStrings_QtGui[33814]
#define sipNameNr_PartialMatch 33827
#define sipName_PartialMatch &sipStrings_QtGui[33827]
#define sipNameNr_PatternBrush 33840
#define sipName_PatternBrush &sipStrings_QtGui[33840]
#define sipNameNr_PdmNumColors 33853
#define sipName_PdmNumColors &sipStrings_QtGui[33853]
#define sipNameNr_PerfectWhite 33866
#define sipName_PerfectWhite &sipStrings_QtGui[33866]
#define sipNameNr_PhoenixStart 33879
#define sipName_PhoenixStart &sipStrings_QtGui[33879]
#define sipNameNr_PoliteRumors 33892
#define sipName_PoliteRumors &sipStrings_QtGui[33892]
#define sipNameNr_PolylineMode 33905
#define sipName_PolylineMode &sipStrings_QtGui[33905]
#define sipNameNr_PortableText 33918
#define sipName_PortableText &sipStrings_QtGui[33918]
#define sipNameNr_PreferBitmap 33931
#define sipName_PreferBitmap &sipStrings_QtGui[33931]
#define sipNameNr_PreferDevice 33944
#define sipName_PreferDevice &sipStrings_QtGui[33944]
#define sipNameNr_PremiumWhite 33957
#define sipName_PremiumWhite &sipStrings_QtGui[33957]
#define sipNameNr_PreviousCell 33970
#define sipName_PreviousCell &sipStrings_QtGui[33970]
#define sipNameNr_PreviousWord 15526
#define sipName_PreviousWord &sipStrings_QtGui[15526]
#define sipNameNr_QActionEvent 33983
#define sipName_QActionEvent &sipStrings_QtGui[33983]
#define sipNameNr_QColor__Spec 33996
#define sipName_QColor__Spec &sipStrings_QtGui[33996]
#define sipNameNr_QExposeEvent 34009
#define sipName_QExposeEvent &sipStrings_QtGui[34009]
#define sipNameNr_QFont__Style 34022
#define sipName_QFont__Style &sipStrings_QtGui[34022]
#define sipNameNr_QFontMetrics 34035
#define sipName_QFontMetrics &sipStrings_QtGui[34035]
#define sipNameNr_QIcon__State 34048
#define sipName_QIcon__State &sipStrings_QtGui[34048]
#define sipNameNr_QImageReader 34061
#define sipName_QImageReader &sipStrings_QtGui[34061]
#define sipNameNr_QImageWriter 34074
#define sipName_QImageWriter &sipStrings_QtGui[34074]
#define sipNameNr_QInputMethod 34087
#define sipName_QInputMethod &sipStrings_QtGui[34087]
#define sipNameNr_QKeySequence 34100
#define sipName_QKeySequence &sipStrings_QtGui[34100]
#define sipNameNr_34113 34113
#define sipName_34113 &sipStrings_QtGui[34113]
#define sipNameNr_QPaintDevice 34126
#define sipName_QPaintDevice &sipStrings_QtGui[34126]
#define sipNameNr_QPaintEngine 34139
#define sipName_QPaintEngine &sipStrings_QtGui[34139]
#define sipNameNr_QPainterPath 34152
#define sipName_QPainterPath &sipStrings_QtGui[34152]
#define sipNameNr_QPixelFormat 34165
#define sipName_QPixelFormat &sipStrings_QtGui[34165]
#define sipNameNr_QPixmapCache 34178
#define sipName_QPixmapCache &sipStrings_QtGui[34178]
#define sipNameNr_QResizeEvent 34191
#define sipName_QResizeEvent &sipStrings_QtGui[34191]
#define sipNameNr_QScrollEvent 34204
#define sipName_QScrollEvent &sipStrings_QtGui[34204]
#define sipNameNr_QTabletEvent 34217
#define sipName_QTabletEvent &sipStrings_QtGui[34217]
#define sipNameNr_QTouchDevice 34230
#define sipName_QTouchDevice &sipStrings_QtGui[34230]
#define sipNameNr_RGBA16_SNorm 34243
#define sipName_RGBA16_SNorm &sipStrings_QtGui[34243]
#define sipNameNr_RGBA16_UNorm 34256
#define sipName_RGBA16_UNorm &sipStrings_QtGui[34256]
#define sipNameNr_RGBA_Integer 34269
#define sipName_RGBA_Integer &sipStrings_QtGui[34269]
#define sipNameNr_RGB_BP_UNorm 30350
#define sipName_RGB_BP_UNorm &sipStrings_QtGui[30350]
#define sipNameNr_RawPositions 34282
#define sipName_RawPositions &sipStrings_QtGui[34282]
#define sipNameNr_RedSalvation 34295
#define sipName_RedSalvation &sipStrings_QtGui[34295]
#define sipNameNr_RepeatSpread 34308
#define sipName_RepeatSpread &sipStrings_QtGui[34308]
#define sipNameNr_ResourceType 4712
#define sipName_ResourceType &sipStrings_QtGui[4712]
#define sipNameNr_SRGB8_Alpha8 34321
#define sipName_SRGB8_Alpha8 &sipStrings_QtGui[34321]
#define sipNameNr_SaltMountain 34334
#define sipName_SaltMountain &sipStrings_QtGui[34334]
#define sipNameNr_SemiExpanded 34347
#define sipName_SemiExpanded &sipStrings_QtGui[34347]
#define sipNameNr_SingleBuffer 34360
#define sipName_SingleBuffer &sipStrings_QtGui[34360]
#define sipNameNr_SingleHeight 34373
#define sipName_SingleHeight &sipStrings_QtGui[34373]
#define sipNameNr_SoftLipstick 34386
#define sipName_SoftLipstick &sipStrings_QtGui[34386]
#define sipNameNr_SpringWarmth 34399
#define sipName_SpringWarmth &sipStrings_QtGui[34399]
#define sipNameNr_StandardMode 34412
#define sipName_StandardMode &sipStrings_QtGui[34412]
#define sipNameNr_StartOfBlock 15545
#define sipName_StartOfBlock &sipStrings_QtGui[15545]
#define sipNameNr_StyleOblique 34425
#define sipName_StyleOblique &sipStrings_QtGui[34425]
#define sipNameNr_SunnyMorning 34438
#define sipName_SunnyMorning &sipStrings_QtGui[34438]
#define sipNameNr_SurfaceClass 9012
#define sipName_SurfaceClass &sipStrings_QtGui[9012]
#define sipNameNr_SwapBehavior 4005
#define sipName_SwapBehavior &sipStrings_QtGui[4005]
#define sipNameNr_SweetDessert 34451
#define sipName_SweetDessert &sipStrings_QtGui[34451]
#define sipNameNr_SwizzleAlpha 34464
#define sipName_SwizzleAlpha &sipStrings_QtGui[34464]
#define sipNameNr_SwizzleGreen 34477
#define sipName_SwizzleGreen &sipStrings_QtGui[34477]
#define sipNameNr_SwizzleValue 3889
#define sipName_SwizzleValue &sipStrings_QtGui[3889]
#define sipNameNr_TabPositions 25660
#define sipName_TabPositions &sipStrings_QtGui[25660]
#define sipNameNr_TableColumns 34490
#define sipName_TableColumns &sipStrings_QtGui[34490]
#define sipNameNr_TabletDevice 5203
#define sipName_TabletDevice &sipStrings_QtGui[5203]
#define sipNameNr_TabloidExtra 34503
#define sipName_TabloidExtra &sipStrings_QtGui[34503]
#define sipNameNr_TargetBuffer 13467
#define sipName_TargetBuffer &sipStrings_QtGui[13467]
#define sipNameNr_TeenNotebook 34516
#define sipName_TeenNotebook &sipStrings_QtGui[34516]
#define sipNameNr_TripleBuffer 34529
#define sipName_TripleBuffer &sipStrings_QtGui[34529]
#define sipNameNr_UInt16_RGBA4 34542
#define sipName_UInt16_RGBA4 &sipStrings_QtGui[34542]
#define sipNameNr_UInt32_D24S8 34555
#define sipName_UInt32_D24S8 &sipStrings_QtGui[34555]
#define sipNameNr_UInt32_RGBA8 34568
#define sipName_UInt32_RGBA8 &sipStrings_QtGui[34568]
#define sipNameNr_UnknownError 34581
#define sipName_UnknownError &sipStrings_QtGui[34581]
#define sipNameNr_UnsignedByte 34594
#define sipName_UnsignedByte &sipStrings_QtGui[34594]
#define sipNameNr_UsagePattern 4488
#define sipName_UsagePattern &sipStrings_QtGui[4488]
#define sipNameNr_UserProperty 34607
#define sipName_UserProperty &sipStrings_QtGui[34607]
#define sipNameNr_UserResource 34620
#define sipName_UserResource &sipStrings_QtGui[34620]
#define sipNameNr_VertexBuffer 34633
#define sipName_VertexBuffer &sipStrings_QtGui[34633]
#define sipNameNr_WrapAnywhere 34646
#define sipName_WrapAnywhere &sipStrings_QtGui[34646]
#define sipNameNr_YoungPassion 34659
#define sipName_YoungPassion &sipStrings_QtGui[34659]
#define sipNameNr___contains__ 34672
#define sipName___contains__ &sipStrings_QtGui[34672]
#define sipNameNr___itruediv__ 34685
#define sipName___itruediv__ &sipStrings_QtGui[34685]
#define sipNameNr_angleBetween 34698
#define sipName_angleBetween &sipStrings_QtGui[34698]
#define sipNameNr_antiquewhite 34711
#define sipName_antiquewhite &sipStrings_QtGui[34711]
#define sipNameNr_appendColumn 34724
#define sipName_appendColumn &sipStrings_QtGui[34724]
#define sipNameNr_atBlockStart 34737
#define sipName_atBlockStart &sipStrings_QtGui[34737]
#define sipNameNr_bitsPerPixel 34750
#define sipName_bitsPerPixel &sipStrings_QtGui[34750]
#define sipNameNr_blockRemoved 34763
#define sipName_blockRemoved &sipStrings_QtGui[34763]
#define sipNameNr_boolProperty 34776
#define sipName_boolProperty &sipStrings_QtGui[34776]
#define sipNameNr_bottomBorder 34789
#define sipName_bottomBorder &sipStrings_QtGui[34789]
#define sipNameNr_bottomMargin 34802
#define sipName_bottomMargin &sipStrings_QtGui[34802]
#define sipNameNr_boundingRect 34815
#define sipName_boundingRect &sipStrings_QtGui[34815]
#define sipNameNr_bytesPerLine 34828
#define sipName_bytesPerLine &sipStrings_QtGui[34828]
#define sipNameNr_cacheEnabled 34841
#define sipName_cacheEnabled &sipStrings_QtGui[34841]
#define sipNameNr_canFetchMore 34854
#define sipName_canFetchMore &sipStrings_QtGui[34854]
#define sipNameNr_capabilities 34867
#define sipName_capabilities &sipStrings_QtGui[34867]
#define sipNameNr_centerRadius 34880
#define sipName_centerRadius &sipStrings_QtGui[34880]
#define sipNameNr_channelCount 34893
#define sipName_channelCount &sipStrings_QtGui[34893]
#define sipNameNr_clearFormats 34906
#define sipName_clearFormats &sipStrings_QtGui[34906]
#define sipNameNr_closeSubpath 34919
#define sipName_closeSubpath &sipStrings_QtGui[34919]
#define sipNameNr_columnNumber 34932
#define sipName_columnNumber &sipStrings_QtGui[34932]
#define sipNameNr_commitString 34945
#define sipName_commitString &sipStrings_QtGui[34945]
#define sipNameNr_createObject 34958
#define sipName_createObject &sipStrings_QtGui[34958]
#define sipNameNr_createStroke 34971
#define sipName_createStroke &sipStrings_QtGui[34971]
#define sipNameNr_crossProduct 34984
#define sipName_crossProduct &sipStrings_QtGui[34984]
#define sipNameNr_currentBlock 34997
#define sipName_currentBlock &sipStrings_QtGui[34997]
#define sipNameNr_currentFrame 35010
#define sipName_currentFrame &sipStrings_QtGui[35010]
#define sipNameNr_currentImage 35023
#define sipName_currentImage &sipStrings_QtGui[35023]
#define sipNameNr_currentTable 35036
#define sipName_currentTable &sipStrings_QtGui[35036]
#define sipNameNr_darkseagreen 35049
#define sipName_darkseagreen &sipStrings_QtGui[35049]
#define sipNameNr_defaultDepth 35062
#define sipName_defaultDepth &sipStrings_QtGui[35062]
#define sipNameNr_documentSize 35075
#define sipName_documentSize &sipStrings_QtGui[35075]
#define sipNameNr_drawContents 35088
#define sipName_drawContents &sipStrings_QtGui[35088]
#define sipNameNr_drawGlyphRun 35101
#define sipName_drawGlyphRun &sipStrings_QtGui[35101]
#define sipNameNr_drawPolyline 35114
#define sipName_drawPolyline &sipStrings_QtGui[35114]
#define sipNameNr_drawTextItem 35127
#define sipName_drawTextItem &sipStrings_QtGui[35127]
#define sipNameNr_dropMimeData 35140
#define sipName_dropMimeData &sipStrings_QtGui[35140]
#define sipNameNr_elementCount 35153
#define sipName_elementCount &sipStrings_QtGui[35153]
#define sipNameNr_endEditBlock 35166
#define sipName_endEditBlock &sipStrings_QtGui[35166]
#define sipNameNr_focusInEvent 35179
#define sipName_focusInEvent &sipStrings_QtGui[35179]
#define sipNameNr_fontFamilies 35192
#define sipName_fontFamilies &sipStrings_QtGui[35192]
#define sipNameNr_fontOverline 35205
#define sipName_fontOverline &sipStrings_QtGui[35205]
#define sipNameNr_frameChanged 35218
#define sipName_frameChanged &sipStrings_QtGui[35218]
#define sipNameNr_frameMargins 35231
#define sipName_frameMargins &sipStrings_QtGui[35231]
#define sipNameNr_frameSwapped 35244
#define sipName_frameSwapped &sipStrings_QtGui[35244]
#define sipNameNr_glyphIndexes 35257
#define sipName_glyphIndexes &sipStrings_QtGui[35257]
#define sipNameNr_hasExtension 35270
#define sipName_hasExtension &sipStrings_QtGui[35270]
#define sipNameNr_hasSelection 35283
#define sipName_hasSelection &sipStrings_QtGui[35283]
#define sipNameNr_hasThemeIcon 35296
#define sipName_hasThemeIcon &sipStrings_QtGui[35296]
#define sipNameNr_headingLevel 35309
#define sipName_headingLevel &sipStrings_QtGui[35309]
#define sipNameNr_hiResGlobalX 35322
#define sipName_hiResGlobalX &sipStrings_QtGui[35322]
#define sipNameNr_hiResGlobalY 35335
#define sipName_hiResGlobalY &sipStrings_QtGui[35335]
#define sipNameNr_initializeGL 35348
#define sipName_initializeGL &sipStrings_QtGui[35348]
#define sipNameNr_inputFormats 35361
#define sipName_inputFormats &sipStrings_QtGui[35361]
#define sipNameNr_insertColumn 35374
#define sipName_insertColumn &sipStrings_QtGui[35374]
#define sipNameNr_invertPixels 35387
#define sipName_invertPixels &sipStrings_QtGui[35387]
#define sipNameNr_invokeAction 35400
#define sipName_invokeAction &sipStrings_QtGui[35400]
#define sipNameNr_isAncestorOf 35413
#define sipName_isAncestorOf &sipStrings_QtGui[35413]
#define sipNameNr_isAutoRepeat 35426
#define sipName_isAutoRepeat &sipStrings_QtGui[35426]
#define sipNameNr_isCharFormat 35439
#define sipName_isCharFormat &sipStrings_QtGui[35439]
#define sipNameNr_isFixedPitch 35452
#define sipName_isFixedPitch &sipStrings_QtGui[35452]
#define sipNameNr_isInvertible 35465
#define sipName_isInvertible &sipStrings_QtGui[35465]
#define sipNameNr_isListFormat 35478
#define sipName_isListFormat &sipStrings_QtGui[35478]
#define sipNameNr_isSelectable 35491
#define sipName_isSelectable &sipStrings_QtGui[35491]
#define sipNameNr_isValidColor 35504
#define sipName_isValidColor &sipStrings_QtGui[35504]
#define sipNameNr_lastPosition 35517
#define sipName_lastPosition &sipStrings_QtGui[35517]
#define sipNameNr_lastScenePos 35530
#define sipName_lastScenePos &sipStrings_QtGui[35530]
#define sipNameNr_lemonchiffon 35543
#define sipName_lemonchiffon &sipStrings_QtGui[35543]
#define sipNameNr_lightskyblue 35556
#define sipName_lightskyblue &sipStrings_QtGui[35556]
#define sipNameNr_listToString 35569
#define sipName_listToString &sipStrings_QtGui[35569]
#define sipNameNr_loadFromData 35582
#define sipName_loadFromData &sipStrings_QtGui[35582]
#define sipNameNr_loadFromFile 35595
#define sipName_loadFromFile &sipStrings_QtGui[35595]
#define sipNameNr_loadResource 35608
#define sipName_loadResource &sipStrings_QtGui[35608]
#define sipNameNr_majorVersion 35621
#define sipName_majorVersion &sipStrings_QtGui[35621]
#define sipNameNr_manufacturer 35634
#define sipName_manufacturer &sipStrings_QtGui[35634]
#define sipNameNr_mapToPolygon 35647
#define sipName_mapToPolygon &sipStrings_QtGui[35647]
#define sipNameNr_maxCharWidth 35660
#define sipName_maxCharWidth &sipStrings_QtGui[35660]
#define sipNameNr_maximumWidth 35673
#define sipName_maximumWidth &sipStrings_QtGui[35673]
#define sipNameNr_mediumorchid 35686
#define sipName_mediumorchid &sipStrings_QtGui[35686]
#define sipNameNr_mediumpurple 35699
#define sipName_mediumpurple &sipStrings_QtGui[35699]
#define sipNameNr_midnightblue 35712
#define sipName_midnightblue &sipStrings_QtGui[35712]
#define sipNameNr_minimumWidth 35725
#define sipName_minimumWidth &sipStrings_QtGui[35725]
#define sipNameNr_minorVersion 35738
#define sipName_minorVersion &sipStrings_QtGui[35738]
#define sipNameNr_mipBaseLevel 35751
#define sipName_mipBaseLevel &sipStrings_QtGui[35751]
#define sipNameNr_mouseButtons 35764
#define sipName_mouseButtons &sipStrings_QtGui[35764]
#define sipNameNr_movePosition 35777
#define sipName_movePosition &sipStrings_QtGui[35777]
#define sipNameNr_nativeHandle 35790
#define sipName_nativeHandle &sipStrings_QtGui[35790]
#define sipNameNr_normalMatrix 35803
#define sipName_normalMatrix &sipStrings_QtGui[35803]
#define sipNameNr_numberPrefix 35816
#define sipName_numberPrefix &sipStrings_QtGui[35816]
#define sipNameNr_numberSuffix 35829
#define sipName_numberSuffix &sipStrings_QtGui[35829]
#define sipNameNr_paintFlipped 35842
#define sipName_paintFlipped &sipStrings_QtGui[35842]
#define sipNameNr_paintUnderGL 35855
#define sipName_paintUnderGL &sipStrings_QtGui[35855]
#define sipNameNr_pathForGlyph 35868
#define sipName_pathForGlyph &sipStrings_QtGui[35868]
#define sipNameNr_physicalDpiX 35881
#define sipName_physicalDpiX &sipStrings_QtGui[35881]
#define sipNameNr_physicalDpiY 35894
#define sipName_physicalDpiY &sipStrings_QtGui[35894]
#define sipNameNr_physicalSize 35907
#define sipName_physicalSize &sipStrings_QtGui[35907]
#define sipNameNr_platformName 35920
#define sipName_platformName &sipStrings_QtGui[35920]
#define sipNameNr_qPremultiply 35933
#define sipName_qPremultiply &sipStrings_QtGui[35933]
#define sipNameNr_quadToSquare 35946
#define sipName_quadToSquare &sipStrings_QtGui[35946]
#define sipNameNr_removeColumn 35959
#define sipName_removeColumn &sipStrings_QtGui[35959]
#define sipNameNr_removeShader 35972
#define sipName_removeShader &sipStrings_QtGui[35972]
#define sipNameNr_rightBearing 35985
#define sipName_rightBearing &sipStrings_QtGui[35985]
#define sipNameNr_rightPadding 35998
#define sipName_rightPadding &sipStrings_QtGui[35998]
#define sipNameNr_scaledPixmap 36011
#define sipName_scaledPixmap &sipStrings_QtGui[36011]
#define sipNameNr_selectedText 36024
#define sipName_selectedText &sipStrings_QtGui[36024]
#define sipNameNr_selectionEnd 36037
#define sipName_selectionEnd &sipStrings_QtGui[36037]
#define sipNameNr_serialNumber 36050
#define sipName_serialNumber &sipStrings_QtGui[36050]
#define sipNameNr_setAlignment 36063
#define sipName_setAlignment &sipStrings_QtGui[36063]
#define sipNameNr_setCacheMode 36076
#define sipName_setCacheMode &sipStrings_QtGui[36076]
#define sipNameNr_setCheckable 36089
#define sipName_setCheckable &sipStrings_QtGui[36089]
#define sipNameNr_setFinalStop 36102
#define sipName_setFinalStop &sipStrings_QtGui[36102]
#define sipNameNr_setJoinStyle 36115
#define sipName_setJoinStyle &sipStrings_QtGui[36115]
#define sipNameNr_setLineCount 36128
#define sipName_setLineCount &sipStrings_QtGui[36128]
#define sipNameNr_setLineWidth 36141
#define sipName_setLineWidth &sipStrings_QtGui[36141]
#define sipNameNr_setMipLevels 36154
#define sipName_setMipLevels &sipStrings_QtGui[36154]
#define sipNameNr_setPixelSize 36167
#define sipName_setPixelSize &sipStrings_QtGui[36167]
#define sipNameNr_setPlainText 36180
#define sipName_setPlainText &sipStrings_QtGui[36180]
#define sipNameNr_setPointSize 36193
#define sipName_setPointSize &sipStrings_QtGui[36193]
#define sipNameNr_setPositions 36206
#define sipName_setPositions &sipStrings_QtGui[36206]
#define sipNameNr_setPrimaries 36219
#define sipName_setPrimaries &sipStrings_QtGui[36219]
#define sipNameNr_setRowLength 36232
#define sipName_setRowLength &sipStrings_QtGui[36232]
#define sipNameNr_setStatusTip 36245
#define sipName_setStatusTip &sipStrings_QtGui[36245]
#define sipNameNr_setStrikeOut 36258
#define sipName_setStrikeOut &sipStrings_QtGui[36258]
#define sipNameNr_setStyleHint 36271
#define sipName_setStyleHint &sipStrings_QtGui[36271]
#define sipNameNr_setStyleName 36284
#define sipName_setStyleName &sipStrings_QtGui[36284]
#define sipNameNr_setTextWidth 36297
#define sipName_setTextWidth &sipStrings_QtGui[36297]
#define sipNameNr_setThemeName 36310
#define sipName_setThemeName &sipStrings_QtGui[36310]
#define sipNameNr_setTimestamp 36323
#define sipName_setTimestamp &sipStrings_QtGui[36323]
#define sipNameNr_setTopBorder 36336
#define sipName_setTopBorder &sipStrings_QtGui[36336]
#define sipNameNr_setTopMargin 36349
#define sipName_setTopMargin &sipStrings_QtGui[36349]
#define sipNameNr_setTransform 28229
#define sipName_setTransform &sipStrings_QtGui[28229]
#define sipNameNr_setUnderline 36362
#define sipName_setUnderline &sipStrings_QtGui[36362]
#define sipNameNr_setUserState 36375
#define sipName_setUserState &sipStrings_QtGui[36375]
#define sipNameNr_setWhatsThis 36388
#define sipName_setWhatsThis &sipStrings_QtGui[36388]
#define sipNameNr_shareContext 36401
#define sipName_shareContext &sipStrings_QtGui[36401]
#define sipNameNr_smoothScaled 36414
#define sipName_smoothScaled &sipStrings_QtGui[36414]
#define sipNameNr_sortChildren 36427
#define sipName_sortChildren &sipStrings_QtGui[36427]
#define sipNameNr_squareToQuad 36440
#define sipName_squareToQuad &sipStrings_QtGui[36440]
#define sipNameNr_startLogging 36453
#define sipName_startLogging &sipStrings_QtGui[36453]
#define sipNameNr_stateChanged 36466
#define sipName_stateChanged &sipStrings_QtGui[36466]
#define sipNameNr_strikeOutPos 36479
#define sipName_strikeOutPos &sipStrings_QtGui[36479]
#define sipNameNr_surfaceClass 36492
#define sipName_surfaceClass &sipStrings_QtGui[36492]
#define sipNameNr_swapBehavior 36505
#define sipName_swapBehavior &sipStrings_QtGui[36505]
#define sipNameNr_swapInterval 36518
#define sipName_swapInterval &sipStrings_QtGui[36518]
#define sipNameNr_tabPositions 36531
#define sipName_tabPositions &sipStrings_QtGui[36531]
#define sipNameNr_textPosition 36544
#define sipName_textPosition &sipStrings_QtGui[36544]
#define sipNameNr_textureImage 36557
#define sipName_textureImage &sipStrings_QtGui[36557]
#define sipNameNr_toCharFormat 36570
#define sipName_toCharFormat &sipStrings_QtGui[36570]
#define sipNameNr_toListFormat 36583
#define sipName_toListFormat &sipStrings_QtGui[36583]
#define sipNameNr_underlinePos 36596
#define sipName_underlinePos &sipStrings_QtGui[36596]
#define sipNameNr_usagePattern 36609
#define sipName_usagePattern &sipStrings_QtGui[36609]
#define sipNameNr_viewportSize 36622
#define sipName_viewportSize &sipStrings_QtGui[36622]
#define sipNameNr_widthChanged 36635
#define sipName_widthChanged &sipStrings_QtGui[36635]
#define sipNameNr_windowStates 36648
#define sipName_windowStates &sipStrings_QtGui[36648]
#define sipNameNr_AboveTheSky 36661
#define sipName_AboveTheSky &sipStrings_QtGui[36661]
#define sipNameNr_AlignBottom 36673
#define sipName_AlignBottom &sipStrings_QtGui[36673]
#define sipNameNr_AlignMiddle 36685
#define sipName_AlignMiddle &sipStrings_QtGui[36685]
#define sipNameNr_AlignNormal 36697
#define sipName_AlignNormal &sipStrings_QtGui[36697]
#define sipNameNr_AllFeatures 36709
#define sipName_AllFeatures &sipStrings_QtGui[36709]
#define sipNameNr_AlphaFormat 11812
#define sipName_AlphaFormat &sipStrings_QtGui[11812]
#define sipNameNr_AnySeverity 36721
#define sipName_AnySeverity &sipStrings_QtGui[36721]
#define sipNameNr_AtBeginning 36733
#define sipName_AtBeginning &sipStrings_QtGui[36733]
#define sipNameNr_AwesomePine 36745
#define sipName_AwesomePine &sipStrings_QtGui[36745]
#define sipNameNr_BGR_Integer 36757
#define sipName_BGR_Integer &sipStrings_QtGui[36757]
#define sipNameNr_BlockFormat 21034
#define sipName_BlockFormat &sipStrings_QtGui[21034]
#define sipNameNr_BlockIndent 36769
#define sipName_BlockIndent &sipStrings_QtGui[36769]
#define sipNameNr_BlockMarker 36781
#define sipName_BlockMarker &sipStrings_QtGui[36781]
#define sipNameNr_BorderStyle 3330
#define sipName_BorderStyle &sipStrings_QtGui[3330]
#define sipNameNr_BrushStroke 36793
#define sipName_BrushStroke &sipStrings_QtGui[36793]
#define sipNameNr_ClampToEdge 36805
#define sipName_ClampToEdge &sipStrings_QtGui[36805]
#define sipNameNr_CleanMirror 36817
#define sipName_CleanMirror &sipStrings_QtGui[36817]
#define sipNameNr_CloudyApple 36829
#define sipName_CloudyApple &sipStrings_QtGui[36829]
#define sipNameNr_CochitiLake 36841
#define sipName_CochitiLake &sipStrings_QtGui[36841]
#define sipNameNr_ColdEvening 36853
#define sipName_ColdEvening &sipStrings_QtGui[36853]
#define sipNameNr_CompareLess 36865
#define sipName_CompareLess &sipStrings_QtGui[36865]
#define sipNameNr_CompareNone 36877
#define sipName_CompareNone &sipStrings_QtGui[36877]
#define sipNameNr_ContextMenu 36889
#define sipName_ContextMenu &sipStrings_QtGui[36889]
#define sipNameNr_CoreProfile 36901
#define sipName_CoreProfile &sipStrings_QtGui[36901]
#define sipNameNr_Crystalline 36913
#define sipName_Crystalline &sipStrings_QtGui[36913]
#define sipNameNr_CubeMapFace 4573
#define sipName_CubeMapFace &sipStrings_QtGui[4573]
#define sipNameNr_DarkMagenta 36925
#define sipName_DarkMagenta &sipStrings_QtGui[36925]
#define sipNameNr_DashDotLine 36937
#define sipName_DashDotLine &sipStrings_QtGui[36937]
#define sipNameNr_DepthFormat 36949
#define sipName_DepthFormat &sipStrings_QtGui[36949]
#define sipNameNr_Description 7293
#define sipName_Description &sipStrings_QtGui[7293]
#define sipNameNr_DeviceError 36961
#define sipName_DeviceError &sipStrings_QtGui[36961]
#define sipNameNr_DirtyBeauty 36973
#define sipName_DirtyBeauty &sipStrings_QtGui[36973]
#define sipNameNr_DocumentUrl 36985
#define sipName_DocumentUrl &sipStrings_QtGui[36985]
#define sipNameNr_DynamicCopy 36997
#define sipName_DynamicCopy &sipStrings_QtGui[36997]
#define sipNameNr_DynamicDraw 37009
#define sipName_DynamicDraw &sipStrings_QtGui[37009]
#define sipNameNr_DynamicRead 37021
#define sipName_DynamicRead &sipStrings_QtGui[37021]
#define sipNameNr_ElementType 6023
#define sipName_ElementType &sipStrings_QtGui[6023]
#define sipNameNr_EnvelopeC65 37033
#define sipName_EnvelopeC65 &sipStrings_QtGui[37033]
#define sipNameNr_ExtendedRgb 32871
#define sipName_ExtendedRgb &sipStrings_QtGui[32871]
#define sipNameNr_FebruaryInk 37045
#define sipName_FebruaryInk &sipStrings_QtGui[37045]
#define sipNameNr_FixedHeight 37057
#define sipName_FixedHeight &sipStrings_QtGui[37057]
#define sipNameNr_FixedLength 37069
#define sipName_FixedLength &sipStrings_QtGui[37069]
#define sipNameNr_FlyingLemon 37081
#define sipName_FlyingLemon &sipStrings_QtGui[37081]
#define sipNameNr_FontKerning 28560
#define sipName_FontKerning &sipStrings_QtGui[28560]
#define sipNameNr_FontStretch 28575
#define sipName_FontStretch &sipStrings_QtGui[28575]
#define sipNameNr_FormatRange 6993
#define sipName_FormatRange &sipStrings_QtGui[6993]
#define sipNameNr_Format_Mono 37093
#define sipName_Format_Mono &sipStrings_QtGui[37093]
#define sipNameNr_FrameBorder 37105
#define sipName_FrameBorder &sipStrings_QtGui[37105]
#define sipNameNr_FrameFormat 21051
#define sipName_FrameFormat &sipStrings_QtGui[21051]
#define sipNameNr_FrameHeight 37117
#define sipName_FrameHeight &sipStrings_QtGui[37117]
#define sipNameNr_FrameMargin 37129
#define sipName_FrameMargin &sipStrings_QtGui[37129]
#define sipNameNr_FrozenBerry 37141
#define sipName_FrozenBerry &sipStrings_QtGui[37141]
#define sipNameNr_GagarinView 37153
#define sipName_GagarinView &sipStrings_QtGui[37153]
#define sipNameNr_GeneralFont 37165
#define sipName_GeneralFont &sipStrings_QtGui[37165]
#define sipNameNr_HappyFisher 37177
#define sipName_HappyFisher &sipStrings_QtGui[37177]
#define sipNameNr_HeavenPeach 37189
#define sipName_HeavenPeach &sipStrings_QtGui[37189]
#define sipNameNr_ImageHeight 28605
#define sipName_ImageHeight &sipStrings_QtGui[28605]
#define sipNameNr_ImageObject 37201
#define sipName_ImageObject &sipStrings_QtGui[37201]
#define sipNameNr_ImageOption 3745
#define sipName_ImageOption &sipStrings_QtGui[3745]
#define sipNameNr_Imperial7x9 37213
#define sipName_Imperial7x9 &sipStrings_QtGui[37213]
#define sipNameNr_IndexBuffer 37225
#define sipName_IndexBuffer &sipStrings_QtGui[37225]
#define sipNameNr_InvalidType 37237
#define sipName_InvalidType &sipStrings_QtGui[37237]
#define sipNameNr_LayoutFlags 10304
#define sipName_LayoutFlags &sipStrings_QtGui[10304]
#define sipNameNr_LetterExtra 37249
#define sipName_LetterExtra &sipStrings_QtGui[37249]
#define sipNameNr_LetterSmall 37261
#define sipName_LetterSmall &sipStrings_QtGui[37261]
#define sipNameNr_LinkVisited 37273
#define sipName_LinkVisited &sipStrings_QtGui[37273]
#define sipNameNr_ListDecimal 37285
#define sipName_ListDecimal &sipStrings_QtGui[37285]
#define sipNameNr_LoggingMode 1976
#define sipName_LoggingMode &sipStrings_QtGui[1976]
#define sipNameNr_LogicalMode 37297
#define sipName_LogicalMode &sipStrings_QtGui[37297]
#define sipNameNr_LowSeverity 37309
#define sipName_LowSeverity &sipStrings_QtGui[37309]
#define sipNameNr_MalibuBeach 37321
#define sipName_MalibuBeach &sipStrings_QtGui[37321]
#define sipNameNr_MaskedBrush 37333
#define sipName_MaskedBrush &sipStrings_QtGui[37333]
#define sipNameNr_MorpheusDen 37345
#define sipName_MorpheusDen &sipStrings_QtGui[37345]
#define sipNameNr_NColorRoles 37357
#define sipName_NColorRoles &sipStrings_QtGui[37357]
#define sipNameNr_NoAntialias 37369
#define sipName_NoAntialias &sipStrings_QtGui[37369]
#define sipNameNr_NoPixelType 37381
#define sipName_NoPixelType &sipStrings_QtGui[37381]
#define sipNameNr_NoUnderline 37393
#define sipName_NoUnderline &sipStrings_QtGui[37393]
#define sipNameNr_NorseBeauty 37405
#define sipName_NorseBeauty &sipStrings_QtGui[37405]
#define sipNameNr_ObjectIndex 28695
#define sipName_ObjectIndex &sipStrings_QtGui[28695]
#define sipNameNr_ObjectTypes 6968
#define sipName_ObjectTypes &sipStrings_QtGui[6968]
#define sipNameNr_OddEvenMode 37417
#define sipName_OddEvenMode &sipStrings_QtGui[37417]
#define sipNameNr_OrangeJuice 37429
#define sipName_OrangeJuice &sipStrings_QtGui[37429]
#define sipNameNr_Orientation 6818
#define sipName_Orientation &sipStrings_QtGui[6818]
#define sipNameNr_OtherSource 37441
#define sipName_OtherSource &sipStrings_QtGui[37441]
#define sipNameNr_PaintBuffer 37453
#define sipName_PaintBuffer &sipStrings_QtGui[37453]
#define sipNameNr_PdmHeightMM 37465
#define sipName_PdmHeightMM &sipStrings_QtGui[37465]
#define sipNameNr_PerfectBlue 37477
#define sipName_PerfectBlue &sipStrings_QtGui[37477]
#define sipNameNr_PixelFormat 4601
#define sipName_PixelFormat &sipStrings_QtGui[4601]
#define sipNameNr_PointerType 6075
#define sipName_PointerType &sipStrings_QtGui[6075]
#define sipNameNr_PreferMatch 37489
#define sipName_PreferMatch &sipStrings_QtGui[37489]
#define sipNameNr_Preferences 37501
#define sipName_Preferences &sipStrings_QtGui[37501]
#define sipNameNr_PremiumDark 37513
#define sipName_PremiumDark &sipStrings_QtGui[37513]
#define sipNameNr_PreviousRow 37525
#define sipName_PreviousRow &sipStrings_QtGui[37525]
#define sipNameNr_ProPhotoRgb 37537
#define sipName_ProPhotoRgb &sipStrings_QtGui[37537]
#define sipNameNr_PyQt5_QtGui 37549
#define sipName_PyQt5_QtGui &sipStrings_QtGui[37549]
#define sipNameNr_QCloseEvent 37561
#define sipName_QCloseEvent &sipStrings_QtGui[37561]
#define sipNameNr_QColorSpace 37573
#define sipName_QColorSpace &sipStrings_QtGui[37573]
#define sipNameNr_QEnterEvent 37585
#define sipName_QEnterEvent &sipStrings_QtGui[37585]
#define sipNameNr_QFocusEvent 37597
#define sipName_QFocusEvent &sipStrings_QtGui[37597]
#define sipNameNr_QHoverEvent 37609
#define sipName_QHoverEvent &sipStrings_QtGui[37609]
#define sipNameNr_QIcon__Mode 37621
#define sipName_QIcon__Mode &sipStrings_QtGui[37621]
#define sipNameNr_QIconEngine 37633
#define sipName_QIconEngine &sipStrings_QtGui[37633]
#define sipNameNr_QInputEvent 37645
#define sipName_QInputEvent &sipStrings_QtGui[37645]
#define sipNameNr_QMouseEvent 37657
#define sipName_QMouseEvent &sipStrings_QtGui[37657]
#define sipNameNr_QPageLayout 37669
#define sipName_QPageLayout &sipStrings_QtGui[37669]
#define sipNameNr_QPaintEvent 37681
#define sipName_QPaintEvent &sipStrings_QtGui[37681]
#define sipNameNr_QQuaternion 37693
#define sipName_QQuaternion &sipStrings_QtGui[37693]
#define sipNameNr_QStaticText 37705
#define sipName_QStaticText &sipStrings_QtGui[37705]
#define sipNameNr_QStyleHints 37717
#define sipName_QStyleHints &sipStrings_QtGui[37717]
#define sipNameNr_QTextCursor 37729
#define sipName_QTextCursor &sipStrings_QtGui[37729]
#define sipNameNr_QTextFormat 37741
#define sipName_QTextFormat &sipStrings_QtGui[37741]
#define sipNameNr_QTextLayout 37753
#define sipName_QTextLayout &sipStrings_QtGui[37753]
#define sipNameNr_QTextLength 37765
#define sipName_QTextLength &sipStrings_QtGui[37765]
#define sipNameNr_QTextObject 37777
#define sipName_QTextObject &sipStrings_QtGui[37777]
#define sipNameNr_QTextOption 37789
#define sipName_QTextOption &sipStrings_QtGui[37789]
#define sipNameNr_QTouchEvent 37801
#define sipName_QTouchEvent &sipStrings_QtGui[37801]
#define sipNameNr_QWheelEvent 37813
#define sipName_QWheelEvent &sipStrings_QtGui[37813]
#define sipNameNr_RGB16_SNorm 37825
#define sipName_RGB16_SNorm &sipStrings_QtGui[37825]
#define sipNameNr_RGB16_UNorm 37837
#define sipName_RGB16_UNorm &sipStrings_QtGui[37837]
#define sipNameNr_RGBA8_SNorm 37849
#define sipName_RGBA8_SNorm &sipStrings_QtGui[37849]
#define sipNameNr_RGBA8_UNorm 37861
#define sipName_RGBA8_UNorm &sipStrings_QtGui[37861]
#define sipNameNr_RGB_Integer 37873
#define sipName_RGB_Integer &sipStrings_QtGui[37873]
#define sipNameNr_Red_Integer 37885
#define sipName_Red_Integer &sipStrings_QtGui[37885]
#define sipNameNr_RenderFlags 9036
#define sipName_RenderFlags &sipStrings_QtGui[9036]
#define sipNameNr_RenderHints 10238
#define sipName_RenderHints &sipStrings_QtGui[10238]
#define sipNameNr_RightToLeft 28815
#define sipName_RightToLeft &sipStrings_QtGui[28815]
#define sipNameNr_RipeMalinka 37897
#define sipName_RipeMalinka &sipStrings_QtGui[37897]
#define sipNameNr_RoyalGarden 37909
#define sipName_RoyalGarden &sipStrings_QtGui[37909]
#define sipNameNr_ScrollState 6049
#define sipName_ScrollState &sipStrings_QtGui[6049]
#define sipNameNr_SmartIndigo 37921
#define sipName_SmartIndigo &sipStrings_QtGui[37921]
#define sipNameNr_SmilingRain 37933
#define sipName_SmilingRain &sipStrings_QtGui[37933]
#define sipNameNr_SoftCherish 37945
#define sipName_SoftCherish &sipStrings_QtGui[37945]
#define sipNameNr_SpacingType 7368
#define sipName_SpacingType &sipStrings_QtGui[7368]
#define sipNameNr_StandardKey 5893
#define sipName_StandardKey &sipStrings_QtGui[5893]
#define sipNameNr_StartOfLine 18052
#define sipName_StartOfLine &sipStrings_QtGui[18052]
#define sipNameNr_StartOfWord 17854
#define sipName_StartOfWord &sipStrings_QtGui[17854]
#define sipNameNr_StencilMode 1290
#define sipName_StencilMode &sipStrings_QtGui[1290]
#define sipNameNr_StrongBliss 37957
#define sipName_StrongBliss &sipStrings_QtGui[37957]
#define sipNameNr_StrongStick 37969
#define sipName_StrongStick &sipStrings_QtGui[37969]
#define sipNameNr_StyleItalic 37981
#define sipName_StyleItalic &sipStrings_QtGui[37981]
#define sipNameNr_StyleNormal 37993
#define sipName_StyleNormal &sipStrings_QtGui[37993]
#define sipNameNr_SummerGames 38005
#define sipName_SummerGames &sipStrings_QtGui[38005]
#define sipNameNr_SurfaceType 10326
#define sipName_SurfaceType &sipStrings_QtGui[10326]
#define sipNameNr_SweetPeriod 38017
#define sipName_SweetPeriod &sipStrings_QtGui[38017]
#define sipNameNr_SwizzleBlue 38029
#define sipName_SwizzleBlue &sipStrings_QtGui[38029]
#define sipNameNr_TableFormat 21102
#define sipName_TableFormat &sipStrings_QtGui[21102]
#define sipNameNr_TableObject 38041
#define sipName_TableObject &sipStrings_QtGui[38041]
#define sipNameNr_TextOutline 28860
#define sipName_TextOutline &sipStrings_QtGui[28860]
#define sipNameNr_TextToolTip 38053
#define sipName_TextToolTip &sipStrings_QtGui[38053]
#define sipNameNr_ToolTipBase 38065
#define sipName_ToolTipBase &sipStrings_QtGui[38065]
#define sipNameNr_ToolTipText 38077
#define sipName_ToolTipText &sipStrings_QtGui[38077]
#define sipNameNr_TouchScreen 38089
#define sipName_TouchScreen &sipStrings_QtGui[38089]
#define sipNameNr_Transparent 31429
#define sipName_Transparent &sipStrings_QtGui[31429]
#define sipNameNr_TxTranslate 38101
#define sipName_TxTranslate &sipStrings_QtGui[38101]
#define sipNameNr_UInt8_RG3B2 38113
#define sipName_UInt8_RG3B2 &sipStrings_QtGui[38113]
#define sipNameNr_Unstretched 38125
#define sipName_Unstretched &sipStrings_QtGui[38125]
#define sipNameNr_WindingMode 38137
#define sipName_WindingMode &sipStrings_QtGui[38137]
#define sipNameNr_XFreeEraser 38149
#define sipName_XFreeEraser &sipStrings_QtGui[38149]
#define sipNameNr_ZeusMiracle 38161
#define sipName_ZeusMiracle &sipStrings_QtGui[38161]
#define sipNameNr___delitem__ 38173
#define sipName___delitem__ &sipStrings_QtGui[38173]
#define sipNameNr___getitem__ 38185
#define sipName___getitem__ &sipStrings_QtGui[38185]
#define sipNameNr___imatmul__ 38197
#define sipName___imatmul__ &sipStrings_QtGui[38197]
#define sipNameNr___setitem__ 38209
#define sipName___setitem__ &sipStrings_QtGui[38209]
#define sipNameNr___truediv__ 38221
#define sipName___truediv__ &sipStrings_QtGui[38221]
#define sipNameNr_addResource 38233
#define sipName_addResource &sipStrings_QtGui[38233]
#define sipNameNr_anchorNames 38245
#define sipName_anchorNames &sipStrings_QtGui[38245]
#define sipNameNr_beginLayout 38257
#define sipName_beginLayout &sipStrings_QtGui[38257]
#define sipNameNr_bindDefault 38269
#define sipName_bindDefault &sipStrings_QtGui[38269]
#define sipNameNr_blockFormat 38281
#define sipName_blockFormat &sipStrings_QtGui[38281]
#define sipNameNr_blockNumber 38293
#define sipName_blockNumber &sipStrings_QtGui[38293]
#define sipNameNr_borderBrush 38305
#define sipName_borderBrush &sipStrings_QtGui[38305]
#define sipNameNr_borderColor 38317
#define sipName_borderColor &sipStrings_QtGui[38317]
#define sipNameNr_borderStyle 38329
#define sipName_borderStyle &sipStrings_QtGui[38329]
#define sipNameNr_brushOrigin 38341
#define sipName_brushOrigin &sipStrings_QtGui[38341]
#define sipNameNr_cellPadding 38353
#define sipName_cellPadding &sipStrings_QtGui[38353]
#define sipNameNr_cellSpacing 38365
#define sipName_cellSpacing &sipStrings_QtGui[38365]
#define sipNameNr_characterAt 38377
#define sipName_characterAt &sipStrings_QtGui[38377]
#define sipNameNr_childFrames 38389
#define sipName_childFrames &sipStrings_QtGui[38389]
#define sipNameNr_clearLayout 38401
#define sipName_clearLayout &sipStrings_QtGui[38401]
#define sipNameNr_columnCount 38413
#define sipName_columnCount &sipStrings_QtGui[38413]
#define sipNameNr_compression 38425
#define sipName_compression &sipStrings_QtGui[38425]
#define sipNameNr_connectPath 38437
#define sipName_connectPath &sipStrings_QtGui[38437]
#define sipNameNr_currentList 38449
#define sipName_currentList &sipStrings_QtGui[38449]
#define sipNameNr_customEvent 38461
#define sipName_customEvent &sipStrings_QtGui[38461]
#define sipNameNr_darkmagenta 38473
#define sipName_darkmagenta &sipStrings_QtGui[38473]
#define sipNameNr_dashPattern 38485
#define sipName_dashPattern &sipStrings_QtGui[38485]
#define sipNameNr_dataChanged 38497
#define sipName_dataChanged &sipStrings_QtGui[38497]
#define sipNameNr_deepskyblue 38509
#define sipName_deepskyblue &sipStrings_QtGui[38509]
#define sipNameNr_defaultFont 38521
#define sipName_defaultFont &sipStrings_QtGui[38521]
#define sipNameNr_description 38533
#define sipName_description &sipStrings_QtGui[38533]
#define sipNameNr_determinant 38545
#define sipName_determinant &sipStrings_QtGui[38545]
#define sipNameNr_doneCurrent 38557
#define sipName_doneCurrent &sipStrings_QtGui[38557]
#define sipNameNr_drawEllipse 38569
#define sipName_drawEllipse &sipStrings_QtGui[38569]
#define sipNameNr_drawPicture 38581
#define sipName_drawPicture &sipStrings_QtGui[38581]
#define sipNameNr_drawPolygon 38593
#define sipName_drawPolygon &sipStrings_QtGui[38593]
#define sipNameNr_errorString 38605
#define sipName_errorString &sipStrings_QtGui[38605]
#define sipNameNr_eventFilter 38617
#define sipName_eventFilter &sipStrings_QtGui[38617]
#define sipNameNr_exposeEvent 38629
#define sipName_exposeEvent &sipStrings_QtGui[38629]
#define sipNameNr_floralwhite 38641
#define sipName_floralwhite &sipStrings_QtGui[38641]
#define sipNameNr_focalRadius 38653
#define sipName_focalRadius &sipStrings_QtGui[38653]
#define sipNameNr_focusObject 38665
#define sipName_focusObject &sipStrings_QtGui[38665]
#define sipNameNr_focusWindow 38677
#define sipName_focusWindow &sipStrings_QtGui[38677]
#define sipNameNr_fontChanged 38689
#define sipName_fontChanged &sipStrings_QtGui[38689]
#define sipNameNr_fontKerning 38701
#define sipName_fontKerning &sipStrings_QtGui[38701]
#define sipNameNr_fontMetrics 38713
#define sipName_fontMetrics &sipStrings_QtGui[38713]
#define sipNameNr_fontStretch 38725
#define sipName_fontStretch &sipStrings_QtGui[38725]
#define sipNameNr_forestgreen 38737
#define sipName_forestgreen &sipStrings_QtGui[38737]
#define sipNameNr_formatIndex 38749
#define sipName_formatIndex &sipStrings_QtGui[38749]
#define sipNameNr_frameFormat 38761
#define sipName_frameFormat &sipStrings_QtGui[38761]
#define sipNameNr_gestureType 38773
#define sipName_gestureType &sipStrings_QtGui[38773]
#define sipNameNr_greenyellow 38785
#define sipName_greenyellow &sipStrings_QtGui[38785]
#define sipNameNr_hasChildren 38797
#define sipName_hasChildren &sipStrings_QtGui[38797]
#define sipNameNr_hasClipping 38809
#define sipName_hasClipping &sipStrings_QtGui[38809]
#define sipNameNr_hasProfiles 38821
#define sipName_hasProfiles &sipStrings_QtGui[38821]
#define sipNameNr_hasProperty 38833
#define sipName_hasProperty &sipStrings_QtGui[38833]
#define sipNameNr_imageFormat 38845
#define sipName_imageFormat &sipStrings_QtGui[38845]
#define sipNameNr_imageHeight 38857
#define sipName_imageHeight &sipStrings_QtGui[38857]
#define sipNameNr_indentWidth 38869
#define sipName_indentWidth &sipStrings_QtGui[38869]
#define sipNameNr_inputMethod 38881
#define sipName_inputMethod &sipStrings_QtGui[38881]
#define sipNameNr_insertBlock 38893
#define sipName_insertBlock &sipStrings_QtGui[38893]
#define sipNameNr_insertFrame 38905
#define sipName_insertFrame &sipStrings_QtGui[38905]
#define sipNameNr_insertImage 38917
#define sipName_insertImage &sipStrings_QtGui[38917]
#define sipNameNr_insertTable 38929
#define sipName_insertTable &sipStrings_QtGui[38929]
#define sipNameNr_intProperty 38941
#define sipName_intProperty &sipStrings_QtGui[38941]
#define sipNameNr_intersected 38953
#define sipName_intersected &sipStrings_QtGui[38953]
#define sipNameNr_isAmbiguous 38965
#define sipName_isAmbiguous &sipStrings_QtGui[38965]
#define sipNameNr_isAnimating 38977
#define sipName_isAnimating &sipStrings_QtGui[38977]
#define sipNameNr_isCheckable 38989
#define sipName_isCheckable &sipStrings_QtGui[38989]
#define sipNameNr_isGrayscale 39001
#define sipName_isGrayscale &sipStrings_QtGui[39001]
#define sipNameNr_isLandscape 39013
#define sipName_isLandscape &sipStrings_QtGui[39013]
#define sipNameNr_itemChanged 39025
#define sipName_itemChanged &sipStrings_QtGui[39025]
#define sipNameNr_jumpToFrame 39037
#define sipName_jumpToFrame &sipStrings_QtGui[39037]
#define sipNameNr_jumpToImage 39049
#define sipName_jumpToImage &sipStrings_QtGui[39049]
#define sipNameNr_keyBindings 39061
#define sipName_keyBindings &sipStrings_QtGui[39061]
#define sipNameNr_lastIndexOf 39073
#define sipName_lastIndexOf &sipStrings_QtGui[39073]
#define sipNameNr_leftBearing 39085
#define sipName_leftBearing &sipStrings_QtGui[39085]
#define sipNameNr_leftPadding 39097
#define sipName_leftPadding &sipStrings_QtGui[39097]
#define sipNameNr_lightsalmon 39109
#define sipName_lightsalmon &sipStrings_QtGui[39109]
#define sipNameNr_lightyellow 39121
#define sipName_lightyellow &sipStrings_QtGui[39121]
#define sipNameNr_lineSpacing 39133
#define sipName_lineSpacing &sipStrings_QtGui[39133]
#define sipNameNr_linkVisited 39145
#define sipName_linkVisited &sipStrings_QtGui[39145]
#define sipNameNr_loggingMode 39157
#define sipName_loggingMode &sipStrings_QtGui[39157]
#define sipNameNr_logicalDpiX 39169
#define sipName_logicalDpiX &sipStrings_QtGui[39169]
#define sipNameNr_logicalDpiY 39181
#define sipName_logicalDpiY &sipStrings_QtGui[39181]
#define sipNameNr_magentaSize 39193
#define sipName_magentaSize &sipStrings_QtGui[39193]
#define sipNameNr_makeCurrent 39205
#define sipName_makeCurrent &sipStrings_QtGui[39205]
#define sipNameNr_mapToGlobal 39217
#define sipName_mapToGlobal &sipStrings_QtGui[39217]
#define sipNameNr_matchPolicy 39229
#define sipName_matchPolicy &sipStrings_QtGui[39229]
#define sipNameNr_maximumSize 39241
#define sipName_maximumSize &sipStrings_QtGui[39241]
#define sipNameNr_minimumSize 39253
#define sipName_minimumSize &sipStrings_QtGui[39253]
#define sipNameNr_mipMaxLevel 39265
#define sipName_mipMaxLevel &sipStrings_QtGui[39265]
#define sipNameNr_modalWindow 39277
#define sipName_modalWindow &sipStrings_QtGui[39277]
#define sipNameNr_moveColumns 31905
#define sipName_moveColumns &sipStrings_QtGui[31905]
#define sipNameNr_navajowhite 39289
#define sipName_navajowhite &sipStrings_QtGui[39289]
#define sipNameNr_objectIndex 39301
#define sipName_objectIndex &sipStrings_QtGui[39301]
#define sipNameNr_orientation 39313
#define sipName_orientation &sipStrings_QtGui[39313]
#define sipNameNr_overlinePos 39325
#define sipName_overlinePos &sipStrings_QtGui[39325]
#define sipNameNr_paintDevice 39337
#define sipName_paintDevice &sipStrings_QtGui[39337]
#define sipNameNr_paintEngine 39349
#define sipName_paintEngine &sipStrings_QtGui[39349]
#define sipNameNr_paintOverGL 39361
#define sipName_paintOverGL &sipStrings_QtGui[39361]
#define sipNameNr_parentFrame 39373
#define sipName_parentFrame &sipStrings_QtGui[39373]
#define sipNameNr_penProperty 39385
#define sipName_penProperty &sipStrings_QtGui[39385]
#define sipNameNr_perspective 39397
#define sipName_perspective &sipStrings_QtGui[39397]
#define sipNameNr_pixelFormat 39409
#define sipName_pixelFormat &sipStrings_QtGui[39409]
#define sipNameNr_pointerType 39421
#define sipName_pointerType &sipStrings_QtGui[39421]
#define sipNameNr_refreshRate 39433
#define sipName_refreshRate &sipStrings_QtGui[39433]
#define sipNameNr_rehighlight 39445
#define sipName_rehighlight &sipStrings_QtGui[39445]
#define sipNameNr_renderFlags 39457
#define sipName_renderFlags &sipStrings_QtGui[39457]
#define sipNameNr_renderHints 39469
#define sipName_renderHints &sipStrings_QtGui[39469]
#define sipNameNr_resizeEvent 39481
#define sipName_resizeEvent &sipStrings_QtGui[39481]
#define sipNameNr_rightBorder 39493
#define sipName_rightBorder &sipStrings_QtGui[39493]
#define sipNameNr_rightMargin 39505
#define sipName_rightMargin &sipStrings_QtGui[39505]
#define sipNameNr_saddlebrown 39517
#define sipName_saddlebrown &sipStrings_QtGui[39517]
#define sipNameNr_saturationF 39529
#define sipName_saturationF &sipStrings_QtGui[39529]
#define sipNameNr_screenAdded 39541
#define sipName_screenAdded &sipStrings_QtGui[39541]
#define sipNameNr_scrollState 39553
#define sipName_scrollState &sipStrings_QtGui[39553]
#define sipNameNr_setBaseSize 39565
#define sipName_setBaseSize &sipStrings_QtGui[39565]
#define sipNameNr_setCapStyle 39577
#define sipName_setCapStyle &sipStrings_QtGui[39577]
#define sipNameNr_setClipPath 39589
#define sipName_setClipPath &sipStrings_QtGui[39589]
#define sipNameNr_setClipRect 39601
#define sipName_setClipRect &sipStrings_QtGui[39601]
#define sipNameNr_setClipping 39613
#define sipName_setClipping &sipStrings_QtGui[39613]
#define sipNameNr_setCosmetic 39625
#define sipName_setCosmetic &sipStrings_QtGui[39625]
#define sipNameNr_setDecimals 39637
#define sipName_setDecimals &sipStrings_QtGui[39637]
#define sipNameNr_setDocument 39649
#define sipName_setDocument &sipStrings_QtGui[39649]
#define sipNameNr_setEditable 39661
#define sipName_setEditable &sipStrings_QtGui[39661]
#define sipNameNr_setFamilies 39673
#define sipName_setFamilies &sipStrings_QtGui[39673]
#define sipNameNr_setFileName 39685
#define sipName_setFileName &sipStrings_QtGui[39685]
#define sipNameNr_setFilePath 39697
#define sipName_setFilePath &sipStrings_QtGui[39697]
#define sipNameNr_setFillRule 39709
#define sipName_setFillRule &sipStrings_QtGui[39709]
#define sipNameNr_setGeometry 39721
#define sipName_setGeometry &sipStrings_QtGui[39721]
#define sipNameNr_setIODevice 39733
#define sipName_setIODevice &sipStrings_QtGui[39733]
#define sipNameNr_setItemData 39745
#define sipName_setItemData &sipStrings_QtGui[39745]
#define sipNameNr_setMarkdown 39757
#define sipName_setMarkdown &sipStrings_QtGui[39757]
#define sipNameNr_setMimeData 39769
#define sipName_setMimeData &sipStrings_QtGui[39769]
#define sipNameNr_setModality 39781
#define sipName_setModality &sipStrings_QtGui[39781]
#define sipNameNr_setModified 39793
#define sipName_setModified &sipStrings_QtGui[39793]
#define sipNameNr_setNotation 39805
#define sipName_setNotation &sipStrings_QtGui[39805]
#define sipNameNr_setOverline 39817
#define sipName_setOverline &sipStrings_QtGui[39817]
#define sipNameNr_setPageSize 39829
#define sipName_setPageSize &sipStrings_QtGui[39829]
#define sipNameNr_setPosition 39841
#define sipName_setPosition &sipStrings_QtGui[39841]
#define sipNameNr_setProperty 39853
#define sipName_setProperty &sipStrings_QtGui[39853]
#define sipNameNr_setRevision 39865
#define sipName_setRevision &sipStrings_QtGui[39865]
#define sipNameNr_setRowCount 39877
#define sipName_setRowCount &sipStrings_QtGui[39877]
#define sipNameNr_setSizeHint 39889
#define sipName_setSizeHint &sipStrings_QtGui[39889]
#define sipNameNr_setSkipRows 39901
#define sipName_setSkipRows &sipStrings_QtGui[39901]
#define sipNameNr_setSortRole 39913
#define sipName_setSortRole &sipStrings_QtGui[39913]
#define sipNameNr_setTabArray 39925
#define sipName_setTabArray &sipStrings_QtGui[39925]
#define sipNameNr_setTristate 39937
#define sipName_setTristate &sipStrings_QtGui[39937]
#define sipNameNr_setUserData 39949
#define sipName_setUserData &sipStrings_QtGui[39949]
#define sipNameNr_setViewport 39961
#define sipName_setViewport &sipStrings_QtGui[39961]
#define sipNameNr_setWrapMode 39973
#define sipName_setWrapMode &sipStrings_QtGui[39973]
#define sipNameNr_sizeInBytes 39985
#define sipName_sizeInBytes &sipStrings_QtGui[39985]
#define sipNameNr_smoothSizes 39997
#define sipName_smoothSizes &sipStrings_QtGui[39997]
#define sipNameNr_springgreen 19330
#define sipName_springgreen &sipStrings_QtGui[19330]
#define sipNameNr_stopLogging 40009
#define sipName_stopLogging &sipStrings_QtGui[40009]
#define sipNameNr_styleString 40021
#define sipName_styleString &sipStrings_QtGui[40021]
#define sipNameNr_substitutes 40033
#define sipName_substitutes &sipStrings_QtGui[40033]
#define sipNameNr_surfaceType 40045
#define sipName_surfaceType &sipStrings_QtGui[40045]
#define sipNameNr_swapBuffers 40057
#define sipName_swapBuffers &sipStrings_QtGui[40057]
#define sipNameNr_swizzleMask 40069
#define sipName_swizzleMask &sipStrings_QtGui[40069]
#define sipNameNr_tabletEvent 40081
#define sipName_tabletEvent &sipStrings_QtGui[40081]
#define sipNameNr_takeTexture 40093
#define sipName_takeTexture &sipStrings_QtGui[40093]
#define sipNameNr_textFormats 40105
#define sipName_textFormats &sipStrings_QtGui[40105]
#define sipNameNr_textOutline 40117
#define sipName_textOutline &sipStrings_QtGui[40117]
#define sipNameNr_toPlainText 40129
#define sipName_toPlainText &sipStrings_QtGui[40129]
#define sipNameNr_toTransform 21986
#define sipName_toTransform &sipStrings_QtGui[21986]
#define sipNameNr_toolTipBase 40141
#define sipName_toolTipBase &sipStrings_QtGui[40141]
#define sipNameNr_toolTipText 40153
#define sipName_toolTipText &sipStrings_QtGui[40153]
#define sipNameNr_touchPoints 40165
#define sipName_touchPoints &sipStrings_QtGui[40165]
#define sipNameNr_transformed 40177
#define sipName_transformed &sipStrings_QtGui[40177]
#define sipNameNr_unsetCursor 40189
#define sipName_unsetCursor &sipStrings_QtGui[40189]
#define sipNameNr_updateBlock 40201
#define sipName_updateBlock &sipStrings_QtGui[40201]
#define sipNameNr_updateState 40213
#define sipName_updateState &sipStrings_QtGui[40213]
#define sipNameNr_virtualSize 40225
#define sipName_virtualSize &sipStrings_QtGui[40225]
#define sipNameNr_windowState 40237
#define sipName_windowState &sipStrings_QtGui[40237]
#define sipNameNr_wordSpacing 40249
#define sipName_wordSpacing &sipStrings_QtGui[40249]
#define sipNameNr_yellowgreen 40261
#define sipName_yellowgreen &sipStrings_QtGui[40261]
#define sipNameNr_Acceptable 40273
#define sipName_Acceptable &sipStrings_QtGui[40273]
#define sipNameNr_AlphaBlend 40284
#define sipName_AlphaBlend &sipStrings_QtGui[40284]
#define sipNameNr_AlphaUsage 6894
#define sipName_AlphaUsage &sipStrings_QtGui[6894]
#define sipNameNr_AlphaValue 40295
#define sipName_AlphaValue &sipStrings_QtGui[40295]
#define sipNameNr_AmourAmour 40306
#define sipName_AmourAmour &sipStrings_QtGui[40306]
#define sipNameNr_AnchorHref 32004
#define sipName_AnchorHref &sipStrings_QtGui[32004]
#define sipNameNr_AnchorName 40317
#define sipName_AnchorName &sipStrings_QtGui[40317]
#define sipNameNr_AnyStretch 40328
#define sipName_AnyStretch &sipStrings_QtGui[40328]
#define sipNameNr_AquaSplash 40339
#define sipName_AquaSplash &sipStrings_QtGui[40339]
#define sipNameNr_Attachment 388
#define sipName_Attachment &sipStrings_QtGui[388]
#define sipNameNr_Background 22926
#define sipName_Background &sipStrings_QtGui[22926]
#define sipNameNr_BlendModes 40350
#define sipName_BlendModes &sipStrings_QtGui[40350]
#define sipNameNr_BrightText 40361
#define sipName_BrightText &sipStrings_QtGui[40361]
#define sipNameNr_ButtonText 40372
#define sipName_ButtonText &sipStrings_QtGui[40372]
#define sipNameNr_Capitalize 40383
#define sipName_Capitalize &sipStrings_QtGui[40383]
#define sipNameNr_CharFormat 12695
#define sipName_CharFormat &sipStrings_QtGui[12695]
#define sipNameNr_ColorGroup 12044
#define sipName_ColorGroup &sipStrings_QtGui[12044]
#define sipNameNr_ColorModel 6919
#define sipName_ColorModel &sipStrings_QtGui[6919]
#define sipNameNr_ColorSpace 3688
#define sipName_ColorSpace &sipStrings_QtGui[3688]
#define sipNameNr_ConvexMode 40394
#define sipName_ConvexMode &sipStrings_QtGui[40394]
#define sipNameNr_CursorMode 7854
#define sipName_CursorMode &sipStrings_QtGui[7854]
#define sipNameNr_DarkYellow 40405
#define sipName_DarkYellow &sipStrings_QtGui[40405]
#define sipNameNr_Decorative 40416
#define sipName_Decorative &sipStrings_QtGui[40416]
#define sipNameNr_DeepRelief 40427
#define sipName_DeepRelief &sipStrings_QtGui[40427]
#define sipNameNr_DenseWater 40438
#define sipName_DenseWater &sipStrings_QtGui[40438]
#define sipNameNr_DesertHump 40449
#define sipName_DesertHump &sipStrings_QtGui[40449]
#define sipNameNr_Devanagari 40460
#define sipName_Devanagari &sipStrings_QtGui[40460]
#define sipNameNr_DeviceType 7019
#define sipName_DeviceType &sipStrings_QtGui[7019]
#define sipNameNr_DirectionR 40471
#define sipName_DirectionR &sipStrings_QtGui[40471]
#define sipNameNr_DirectionS 40482
#define sipName_DirectionS &sipStrings_QtGui[40482]
#define sipNameNr_DirectionT 40493
#define sipName_DirectionT &sipStrings_QtGui[40493]
#define sipNameNr_DirtyBrush 40504
#define sipName_DirtyBrush &sipStrings_QtGui[40504]
#define sipNameNr_DirtyFlags 6844
#define sipName_DirtyFlags &sipStrings_QtGui[6844]
#define sipNameNr_DirtyHints 40515
#define sipName_DirtyHints &sipStrings_QtGui[40515]
#define sipNameNr_DustyGrass 40526
#define sipName_DustyGrass &sipStrings_QtGui[40526]
#define sipNameNr_EndOfBlock 20780
#define sipName_EndOfBlock &sipStrings_QtGui[20780]
#define sipNameNr_Endianness 40537
#define sipName_Endianness &sipStrings_QtGui[40537]
#define sipNameNr_Envelope10 40548
#define sipName_Envelope10 &sipStrings_QtGui[40548]
#define sipNameNr_Envelope11 40559
#define sipName_Envelope11 &sipStrings_QtGui[40559]
#define sipNameNr_Envelope12 40570
#define sipName_Envelope12 &sipStrings_QtGui[40570]
#define sipNameNr_Envelope14 40581
#define sipName_Envelope14 &sipStrings_QtGui[40581]
#define sipNameNr_EnvelopeB4 40592
#define sipName_EnvelopeB4 &sipStrings_QtGui[40592]
#define sipNameNr_EnvelopeB5 40603
#define sipName_EnvelopeB5 &sipStrings_QtGui[40603]
#define sipNameNr_EnvelopeB6 40614
#define sipName_EnvelopeB6 &sipStrings_QtGui[40614]
#define sipNameNr_EnvelopeC0 40625
#define sipName_EnvelopeC0 &sipStrings_QtGui[40625]
#define sipNameNr_EnvelopeC1 40636
#define sipName_EnvelopeC1 &sipStrings_QtGui[40636]
#define sipNameNr_EnvelopeC2 40647
#define sipName_EnvelopeC2 &sipStrings_QtGui[40647]
#define sipNameNr_EnvelopeC3 40658
#define sipName_EnvelopeC3 &sipStrings_QtGui[40658]
#define sipNameNr_EnvelopeC4 40669
#define sipName_EnvelopeC4 &sipStrings_QtGui[40669]
#define sipNameNr_EnvelopeC5 40680
#define sipName_EnvelopeC5 &sipStrings_QtGui[40680]
#define sipNameNr_EnvelopeC6 40691
#define sipName_EnvelopeC6 &sipStrings_QtGui[40691]
#define sipNameNr_EnvelopeC7 40702
#define sipName_EnvelopeC7 &sipStrings_QtGui[40702]
#define sipNameNr_EnvelopeDL 40713
#define sipName_EnvelopeDL &sipStrings_QtGui[40713]
#define sipNameNr_ExactMatch 40724
#define sipName_ExactMatch &sipStrings_QtGui[40724]
#define sipNameNr_ExtraLight 40735
#define sipName_ExtraLight &sipStrings_QtGui[40735]
#define sipNameNr_FindBuffer 17561
#define sipName_FindBuffer &sipStrings_QtGui[17561]
#define sipNameNr_Float16OES 40746
#define sipName_Float16OES &sipStrings_QtGui[40746]
#define sipNameNr_FloatRight 40757
#define sipName_FloatRight &sipStrings_QtGui[40757]
#define sipNameNr_FontFamily 32242
#define sipName_FontFamily &sipStrings_QtGui[32242]
#define sipNameNr_FontItalic 32256
#define sipName_FontItalic &sipStrings_QtGui[32256]
#define sipNameNr_FontWeight 32270
#define sipName_FontWeight &sipStrings_QtGui[32270]
#define sipNameNr_Foreground 24094
#define sipName_Foreground &sipStrings_QtGui[24094]
#define sipNameNr_ForestInei 40768
#define sipName_ForestInei &sipStrings_QtGui[40768]
#define sipNameNr_FormatType 7830
#define sipName_FormatType &sipStrings_QtGui[7830]
#define sipNameNr_FourDMouse 40779
#define sipName_FourDMouse &sipStrings_QtGui[40779]
#define sipNameNr_FrameWidth 40790
#define sipName_FrameWidth &sipStrings_QtGui[40790]
#define sipNameNr_FreshOasis 40801
#define sipName_FreshOasis &sipStrings_QtGui[40801]
#define sipNameNr_FrozenHeat 40812
#define sipName_FrozenHeat &sipStrings_QtGui[40812]
#define sipNameNr_FruitBlend 40823
#define sipName_FruitBlend &sipStrings_QtGui[40823]
#define sipNameNr_FullScreen 22395
#define sipName_FullScreen &sipStrings_QtGui[22395]
#define sipNameNr_FuzzyMatch 40834
#define sipName_FuzzyMatch &sipStrings_QtGui[40834]
#define sipNameNr_GentleCare 40845
#define sipName_GentleCare &sipStrings_QtGui[40845]
#define sipNameNr_GlassWater 40856
#define sipName_GlassWater &sipStrings_QtGui[40856]
#define sipNameNr_GreatWhale 40867
#define sipName_GreatWhale &sipStrings_QtGui[40867]
#define sipNameNr_GreenValue 40878
#define sipName_GreenValue &sipStrings_QtGui[40878]
#define sipNameNr_GrownEarly 40889
#define sipName_GrownEarly &sipStrings_QtGui[40889]
#define sipNameNr_HighFlight 40900
#define sipName_HighFlight &sipStrings_QtGui[40900]
#define sipNameNr_ImageTitle 40911
#define sipName_ImageTitle &sipStrings_QtGui[40911]
#define sipNameNr_ImageWidth 40922
#define sipName_ImageWidth &sipStrings_QtGui[40922]
#define sipNameNr_InvertMode 15699
#define sipName_InvertMode &sipStrings_QtGui[15699]
#define sipNameNr_InvertRgba 40933
#define sipName_InvertRgba &sipStrings_QtGui[40933]
#define sipNameNr_IsNullHook 40944
#define sipName_IsNullHook &sipStrings_QtGui[40944]
#define sipNameNr_JapanBlush 40955
#define sipName_JapanBlush &sipStrings_QtGui[40955]
#define sipNameNr_JuicyPeach 40966
#define sipName_JuicyPeach &sipStrings_QtGui[40966]
#define sipNameNr_KeepAnchor 40977
#define sipName_KeepAnchor &sipStrings_QtGui[40977]
#define sipNameNr_LayoutFlag 12065
#define sipName_LayoutFlag &sipStrings_QtGui[12065]
#define sipNameNr_LeCocktail 40988
#define sipName_LeCocktail &sipStrings_QtGui[40988]
#define sipNameNr_LegalExtra 40999
#define sipName_LegalExtra &sipStrings_QtGui[40999]
#define sipNameNr_LetterPlus 41010
#define sipName_LetterPlus &sipStrings_QtGui[41010]
#define sipNameNr_LilyMeadow 41021
#define sipName_LilyMeadow &sipStrings_QtGui[41021]
#define sipNameNr_LineHeight 32340
#define sipName_LineHeight &sipStrings_QtGui[32340]
#define sipNameNr_ListCircle 41032
#define sipName_ListCircle &sipStrings_QtGui[41032]
#define sipNameNr_ListFormat 23598
#define sipName_ListFormat &sipStrings_QtGui[23598]
#define sipNameNr_ListIndent 41043
#define sipName_ListIndent &sipStrings_QtGui[41043]
#define sipNameNr_ListSquare 41054
#define sipName_ListSquare &sipStrings_QtGui[41054]
#define sipNameNr_MacPrinter 41065
#define sipName_MacPrinter &sipStrings_QtGui[41065]
#define sipNameNr_ManualWrap 41076
#define sipName_ManualWrap &sipStrings_QtGui[41076]
#define sipNameNr_MarbleWall 41087
#define sipName_MarbleWall &sipStrings_QtGui[41087]
#define sipNameNr_MarkerType 4036
#define sipName_MarkerType &sipStrings_QtGui[4036]
#define sipNameNr_Millimeter 41098
#define sipName_Millimeter &sipStrings_QtGui[41098]
#define sipNameNr_MixedHopes 41109
#define sipName_MixedHopes &sipStrings_QtGui[41109]
#define sipNameNr_MoveAnchor 41120
#define sipName_MoveAnchor &sipStrings_QtGui[41120]
#define sipNameNr_MovieState 15737
#define sipName_MovieState &sipStrings_QtGui[15737]
#define sipNameNr_NPaperSize 41131
#define sipName_NPaperSize &sipStrings_QtGui[41131]
#define sipNameNr_NameFormat 15661
#define sipName_NameFormat &sipStrings_QtGui[15661]
#define sipNameNr_NativeText 41142
#define sipName_NativeText &sipStrings_QtGui[41142]
#define sipNameNr_NightParty 41153
#define sipName_NightParty &sipStrings_QtGui[41153]
#define sipNameNr_NoGradient 41164
#define sipName_NoGradient &sipStrings_QtGui[41164]
#define sipNameNr_NotRunning 41175
#define sipName_NotRunning &sipStrings_QtGui[41175]
#define sipNameNr_NumPresets 41186
#define sipName_NumPresets &sipStrings_QtGui[41186]
#define sipNameNr_ObjectMode 41197
#define sipName_ObjectMode &sipStrings_QtGui[41197]
#define sipNameNr_ObjectType 32396
#define sipName_ObjectType &sipStrings_QtGui[32396]
#define sipNameNr_OldEnglish 41208
#define sipName_OldEnglish &sipStrings_QtGui[41208]
#define sipNameNr_OpaqueHint 41219
#define sipName_OpaqueHint &sipStrings_QtGui[41219]
#define sipNameNr_OutlinePen 41230
#define sipName_OutlinePen &sipStrings_QtGui[41230]
#define sipNameNr_PageSizeId 10217
#define sipName_PageSizeId &sipStrings_QtGui[10217]
#define sipNameNr_PartyBliss 41241
#define sipName_PartyBliss &sipStrings_QtGui[41241]
#define sipNameNr_PdfVersion 3211
#define sipName_PdfVersion &sipStrings_QtGui[3211]
#define sipNameNr_PdmWidthMM 41252
#define sipName_PdmWidthMM &sipStrings_QtGui[41252]
#define sipNameNr_PorterDuff 41263
#define sipName_PorterDuff &sipStrings_QtGui[41263]
#define sipNameNr_PostScript 41274
#define sipName_PostScript &sipStrings_QtGui[41274]
#define sipNameNr_QClipboard 41285
#define sipName_QClipboard &sipStrings_QtGui[41285]
#define sipNameNr_QDropEvent 41296
#define sipName_QDropEvent &sipStrings_QtGui[41296]
#define sipNameNr_QHelpEvent 41307
#define sipName_QHelpEvent &sipStrings_QtGui[41307]
#define sipNameNr_QHideEvent 41318
#define sipName_QHideEvent &sipStrings_QtGui[41318]
#define sipNameNr_QMatrix2x2 41329
#define sipName_QMatrix2x2 &sipStrings_QtGui[41329]
#define sipNameNr_QMatrix2x3 41340
#define sipName_QMatrix2x3 &sipStrings_QtGui[41340]
#define sipNameNr_QMatrix2x4 41351
#define sipName_QMatrix2x4 &sipStrings_QtGui[41351]
#define sipNameNr_QMatrix3x2 41362
#define sipName_QMatrix3x2 &sipStrings_QtGui[41362]
#define sipNameNr_QMatrix3x3 41373
#define sipName_QMatrix3x3 &sipStrings_QtGui[41373]
#define sipNameNr_QMatrix3x4 41384
#define sipName_QMatrix3x4 &sipStrings_QtGui[41384]
#define sipNameNr_QMatrix4x2 41395
#define sipName_QMatrix4x2 &sipStrings_QtGui[41395]
#define sipNameNr_QMatrix4x3 41406
#define sipName_QMatrix4x3 &sipStrings_QtGui[41406]
#define sipNameNr_QMatrix4x4 41417
#define sipName_QMatrix4x4 &sipStrings_QtGui[41417]
#define sipNameNr_QMoveEvent 41428
#define sipName_QMoveEvent &sipStrings_QtGui[41428]
#define sipNameNr_QPdfWriter 41439
#define sipName_QPdfWriter &sipStrings_QtGui[41439]
#define sipNameNr_QPictureIO 41450
#define sipName_QPictureIO &sipStrings_QtGui[41450]
#define sipNameNr_QShowEvent 41461
#define sipName_QShowEvent &sipStrings_QtGui[41461]
#define sipNameNr_QTextBlock 41472
#define sipName_QTextBlock &sipStrings_QtGui[41472]
#define sipNameNr_QTextFrame 41483
#define sipName_QTextFrame &sipStrings_QtGui[41483]
#define sipNameNr_QTextTable 41494
#define sipName_QTextTable &sipStrings_QtGui[41494]
#define sipNameNr_QTransform 41505
#define sipName_QTransform &sipStrings_QtGui[41505]
#define sipNameNr_QValidator 41516
#define sipName_QValidator &sipStrings_QtGui[41516]
#define sipNameNr_RG16_SNorm 41527
#define sipName_RG16_SNorm &sipStrings_QtGui[41527]
#define sipNameNr_RG16_UNorm 41538
#define sipName_RG16_UNorm &sipStrings_QtGui[41538]
#define sipNameNr_RGB8_SNorm 41549
#define sipName_RGB8_SNorm &sipStrings_QtGui[41549]
#define sipNameNr_RGB8_UNorm 41560
#define sipName_RGB8_UNorm &sipStrings_QtGui[41560]
#define sipNameNr_RGBAFormat 41571
#define sipName_RGBAFormat &sipStrings_QtGui[41571]
#define sipNameNr_RG_Integer 41582
#define sipName_RG_Integer &sipStrings_QtGui[41582]
#define sipNameNr_RangeWrite 41593
#define sipName_RangeWrite &sipStrings_QtGui[41593]
#define sipNameNr_RegionType 14009
#define sipName_RegionType &sipStrings_QtGui[14009]
#define sipNameNr_RenderFlag 10437
#define sipName_RenderFlag &sipStrings_QtGui[10437]
#define sipNameNr_RenderHint 12023
#define sipName_RenderHint &sipStrings_QtGui[12023]
#define sipNameNr_SRGB8_ETC2 41604
#define sipName_SRGB8_ETC2 &sipStrings_QtGui[41604]
#define sipNameNr_SRgbLinear 41615
#define sipName_SRgbLinear &sipStrings_QtGui[41615]
#define sipNameNr_SandStrike 41626
#define sipName_SandStrike &sipStrings_QtGui[41626]
#define sipNameNr_ScaledSize 32522
#define sipName_ScaledSize &sipStrings_QtGui[32522]
#define sipNameNr_Severities 2009
#define sipName_Severities &sipStrings_QtGui[2009]
#define sipNameNr_ShaderType 5946
#define sipName_ShaderType &sipStrings_QtGui[5946]
#define sipNameNr_ShadyWater 41637
#define sipName_ShadyWater &sipStrings_QtGui[41637]
#define sipNameNr_SharpBlues 41648
#define sipName_SharpBlues &sipStrings_QtGui[41648]
#define sipNameNr_ShyRainbow 41659
#define sipName_ShyRainbow &sipStrings_QtGui[41659]
#define sipNameNr_SolidStone 41670
#define sipName_SolidStone &sipStrings_QtGui[41670]
#define sipNameNr_SpaceShift 41681
#define sipName_SpaceShift &sipStrings_QtGui[41681]
#define sipNameNr_StaticCopy 41692
#define sipName_StaticCopy &sipStrings_QtGui[41692]
#define sipNameNr_StaticDraw 41703
#define sipName_StaticDraw &sipStrings_QtGui[41703]
#define sipNameNr_StaticRead 41714
#define sipName_StaticRead &sipStrings_QtGui[41714]
#define sipNameNr_StreamCopy 41725
#define sipName_StreamCopy &sipStrings_QtGui[41725]
#define sipNameNr_StreamDraw 41736
#define sipName_StreamDraw &sipStrings_QtGui[41736]
#define sipNameNr_StreamRead 41747
#define sipName_StreamRead &sipStrings_QtGui[41747]
#define sipNameNr_SupremeSky 41758
#define sipName_SupremeSky &sipStrings_QtGui[41758]
#define sipNameNr_SwizzleRed 41769
#define sipName_SwizzleRed &sipStrings_QtGui[41769]
#define sipNameNr_SystemFont 5842
#define sipName_SystemFont &sipStrings_QtGui[5842]
#define sipNameNr_TextFormat 32578
#define sipName_TextFormat &sipStrings_QtGui[32578]
#define sipNameNr_TextIndent 32592
#define sipName_TextIndent &sipStrings_QtGui[32592]
#define sipNameNr_TouchPoint 7878
#define sipName_TouchPoint &sipStrings_QtGui[7878]
#define sipNameNr_TrueSunset 41780
#define sipName_TrueSunset &sipStrings_QtGui[41780]
#define sipNameNr_TypeWriter 41791
#define sipName_TypeWriter &sipStrings_QtGui[41791]
#define sipNameNr_UnknownKey 41802
#define sipName_UnknownKey &sipStrings_QtGui[41802]
#define sipNameNr_UserFormat 41813
#define sipName_UserFormat &sipStrings_QtGui[41813]
#define sipNameNr_UserObject 41824
#define sipName_UserObject &sipStrings_QtGui[41824]
#define sipNameNr_Vietnamese 41835
#define sipName_Vietnamese &sipStrings_QtGui[41835]
#define sipNameNr_Visibility 13449
#define sipName_Visibility &sipStrings_QtGui[13449]
#define sipNameNr_WideMatrix 41846
#define sipName_WideMatrix &sipStrings_QtGui[41846]
#define sipNameNr_WindowText 41857
#define sipName_WindowText &sipStrings_QtGui[41857]
#define sipNameNr_WinterNeva 41868
#define sipName_WinterNeva &sipStrings_QtGui[41868]
#define sipNameNr_WitchDance 41879
#define sipName_WitchDance &sipStrings_QtGui[41879]
#define sipNameNr_YoungGrass 41890
#define sipName_YoungGrass &sipStrings_QtGui[41890]
#define sipNameNr___invert__ 41901
#define sipName___invert__ &sipStrings_QtGui[41901]
#define sipNameNr___lshift__ 41912
#define sipName___lshift__ &sipStrings_QtGui[41912]
#define sipNameNr___matmul__ 41923
#define sipName___matmul__ &sipStrings_QtGui[41923]
#define sipNameNr___rshift__ 41934
#define sipName___rshift__ &sipStrings_QtGui[41934]
#define sipNameNr_actualSize 41945
#define sipName_actualSize &sipStrings_QtGui[41945]
#define sipNameNr_addEllipse 41956
#define sipName_addEllipse &sipStrings_QtGui[41956]
#define sipNameNr_addPolygon 41967
#define sipName_addPolygon &sipStrings_QtGui[41967]
#define sipNameNr_adjustSize 41978
#define sipName_adjustSize &sipStrings_QtGui[41978]
#define sipNameNr_allFormats 41989
#define sipName_allFormats &sipStrings_QtGui[41989]
#define sipNameNr_allWindows 42000
#define sipName_allWindows &sipStrings_QtGui[42000]
#define sipNameNr_alphaUsage 42011
#define sipName_alphaUsage &sipStrings_QtGui[42011]
#define sipNameNr_anchorHref 42022
#define sipName_anchorHref &sipStrings_QtGui[42022]
#define sipNameNr_angleDelta 42033
#define sipName_angleDelta &sipStrings_QtGui[42033]
#define sipNameNr_answerRect 42044
#define sipName_answerRect &sipStrings_QtGui[42044]
#define sipNameNr_appendRows 42055
#define sipName_appendRows &sipStrings_QtGui[42055]
#define sipNameNr_aquamarine 21715
#define sipName_aquamarine &sipStrings_QtGui[21715]
#define sipNameNr_areSharing 42066
#define sipName_areSharing &sipStrings_QtGui[42066]
#define sipNameNr_atBlockEnd 42077
#define sipName_atBlockEnd &sipStrings_QtGui[42077]
#define sipNameNr_attachment 42088
#define sipName_attachment &sipStrings_QtGui[42088]
#define sipNameNr_attributes 42099
#define sipName_attributes &sipStrings_QtGui[42099]
#define sipNameNr_background 42110
#define sipName_background &sipStrings_QtGui[42110]
#define sipNameNr_beginPaint 42121
#define sipName_beginPaint &sipStrings_QtGui[42121]
#define sipNameNr_blockCount 42132
#define sipName_blockCount &sipStrings_QtGui[42132]
#define sipNameNr_blueviolet 42143
#define sipName_blueviolet &sipStrings_QtGui[42143]
#define sipNameNr_brightText 42154
#define sipName_brightText &sipStrings_QtGui[42154]
#define sipNameNr_buttonText 42165
#define sipName_buttonText &sipStrings_QtGui[42165]
#define sipNameNr_cacheLimit 42176
#define sipName_cacheLimit &sipStrings_QtGui[42176]
#define sipNameNr_charFormat 42187
#define sipName_charFormat &sipStrings_QtGui[42187]
#define sipNameNr_chartreuse 42198
#define sipName_chartreuse &sipStrings_QtGui[42198]
#define sipNameNr_checkState 42209
#define sipName_checkState &sipStrings_QtGui[42209]
#define sipNameNr_childEvent 42220
#define sipName_childEvent &sipStrings_QtGui[42220]
#define sipNameNr_clipRegion 42231
#define sipName_clipRegion &sipStrings_QtGui[42231]
#define sipNameNr_colorCount 42242
#define sipName_colorCount &sipStrings_QtGui[42242]
#define sipNameNr_colorModel 42253
#define sipName_colorModel &sipStrings_QtGui[42253]
#define sipNameNr_colorNames 42264
#define sipName_colorNames &sipStrings_QtGui[42264]
#define sipNameNr_colorSpace 42275
#define sipName_colorSpace &sipStrings_QtGui[42275]
#define sipNameNr_colorTable 42286
#define sipName_colorTable &sipStrings_QtGui[42286]
#define sipNameNr_columnSpan 42297
#define sipName_columnSpan &sipStrings_QtGui[42297]
#define sipNameNr_conjugated 42308
#define sipName_conjugated &sipStrings_QtGui[42308]
#define sipNameNr_contentPos 42319
#define sipName_contentPos &sipStrings_QtGui[42319]
#define sipNameNr_copyDataTo 42330
#define sipName_copyDataTo &sipStrings_QtGui[42330]
#define sipNameNr_createLine 42341
#define sipName_createLine &sipStrings_QtGui[42341]
#define sipNameNr_createList 42352
#define sipName_createList &sipStrings_QtGui[42352]
#define sipNameNr_darkorange 42363
#define sipName_darkorange &sipStrings_QtGui[42363]
#define sipNameNr_darkorchid 42374
#define sipName_darkorchid &sipStrings_QtGui[42374]
#define sipNameNr_darksalmon 42385
#define sipName_darksalmon &sipStrings_QtGui[42385]
#define sipNameNr_darkviolet 42396
#define sipName_darkviolet &sipStrings_QtGui[42396]
#define sipNameNr_dashOffset 42407
#define sipName_dashOffset &sipStrings_QtGui[42407]
#define sipNameNr_deleteChar 42418
#define sipName_deleteChar &sipStrings_QtGui[42418]
#define sipNameNr_deviceType 42429
#define sipName_deviceType &sipStrings_QtGui[42429]
#define sipNameNr_dodgerblue 42440
#define sipName_dodgerblue &sipStrings_QtGui[42440]
#define sipNameNr_dotProduct 42451
#define sipName_dotProduct &sipStrings_QtGui[42451]
#define sipNameNr_dragCursor 42462
#define sipName_dragCursor &sipStrings_QtGui[42462]
#define sipNameNr_drawCursor 42473
#define sipName_drawCursor &sipStrings_QtGui[42473]
#define sipNameNr_drawObject 42484
#define sipName_drawObject &sipStrings_QtGui[42484]
#define sipNameNr_drawPixmap 42495
#define sipName_drawPixmap &sipStrings_QtGui[42495]
#define sipNameNr_drawPoints 42506
#define sipName_drawPoints &sipStrings_QtGui[42506]
#define sipNameNr_dropAction 42517
#define sipName_dropAction &sipStrings_QtGui[42517]
#define sipNameNr_elidedText 42528
#define sipName_elidedText &sipStrings_QtGui[42528]
#define sipNameNr_exactMatch 42539
#define sipName_exactMatch &sipStrings_QtGui[42539]
#define sipNameNr_extensions 42550
#define sipName_extensions &sipStrings_QtGui[42550]
#define sipNameNr_familyName 42561
#define sipName_familyName &sipStrings_QtGui[42561]
#define sipNameNr_firstBlock 42572
#define sipName_firstBlock &sipStrings_QtGui[42572]
#define sipNameNr_fixedPitch 42583
#define sipName_fixedPitch &sipStrings_QtGui[42583]
#define sipNameNr_focalPoint 42594
#define sipName_focalPoint &sipStrings_QtGui[42594]
#define sipNameNr_fontFamily 42605
#define sipName_fontFamily &sipStrings_QtGui[42605]
#define sipNameNr_fontItalic 42616
#define sipName_fontItalic &sipStrings_QtGui[42616]
#define sipNameNr_fontWeight 42627
#define sipName_fontWeight &sipStrings_QtGui[42627]
#define sipNameNr_foreground 42638
#define sipName_foreground &sipStrings_QtGui[42638]
#define sipNameNr_frameCount 42649
#define sipName_frameCount &sipStrings_QtGui[42649]
#define sipNameNr_fromArgb32 42660
#define sipName_fromArgb32 &sipStrings_QtGui[42660]
#define sipNameNr_fromRgba64 42671
#define sipName_fromRgba64 &sipStrings_QtGui[42671]
#define sipNameNr_fromString 42682
#define sipName_fromString &sipStrings_QtGui[42682]
#define sipNameNr_genMipMaps 42693
#define sipName_genMipMaps &sipStrings_QtGui[42693]
#define sipNameNr_ghostwhite 42704
#define sipName_ghostwhite &sipStrings_QtGui[42704]
#define sipNameNr_globalPosF 42715
#define sipName_globalPosF &sipStrings_QtGui[42715]
#define sipNameNr_grabWindow 42726
#define sipName_grabWindow &sipStrings_QtGui[42726]
#define sipNameNr_hasFeature 42737
#define sipName_hasFeature &sipStrings_QtGui[42737]
#define sipNameNr_headerData 42748
#define sipName_headerData &sipStrings_QtGui[42748]
#define sipNameNr_horizontal 42759
#define sipName_horizontal &sipStrings_QtGui[42759]
#define sipNameNr_iccProfile 42770
#define sipName_iccProfile &sipStrings_QtGui[42770]
#define sipNameNr_idealWidth 42781
#define sipName_idealWidth &sipStrings_QtGui[42781]
#define sipNameNr_imageCount 42792
#define sipName_imageCount &sipStrings_QtGui[42792]
#define sipNameNr_inFontUcs4 42803
#define sipName_inFontUcs4 &sipStrings_QtGui[42803]
#define sipNameNr_initialize 42814
#define sipName_initialize &sipStrings_QtGui[42814]
#define sipNameNr_insertHtml 42825
#define sipName_insertHtml &sipStrings_QtGui[42825]
#define sipNameNr_insertList 42836
#define sipName_insertList &sipStrings_QtGui[42836]
#define sipNameNr_insertRows 42847
#define sipName_insertRows &sipStrings_QtGui[42847]
#define sipNameNr_insertText 42858
#define sipName_insertText &sipStrings_QtGui[42858]
#define sipNameNr_intersects 42869
#define sipName_intersects &sipStrings_QtGui[42869]
#define sipNameNr_invertible 42880
#define sipName_invertible &sipStrings_QtGui[42880]
#define sipNameNr_isBrushSet 42891
#define sipName_isBrushSet &sipStrings_QtGui[42891]
#define sipNameNr_isCompiled 42902
#define sipName_isCompiled &sipStrings_QtGui[42902]
#define sipNameNr_isCosmetic 42913
#define sipName_isCosmetic &sipStrings_QtGui[42913]
#define sipNameNr_isDetached 42924
#define sipName_isDetached &sipStrings_QtGui[42924]
#define sipNameNr_isEditable 42935
#define sipName_isEditable &sipStrings_QtGui[42935]
#define sipNameNr_isIdentity 42946
#define sipName_isIdentity &sipStrings_QtGui[42946]
#define sipNameNr_isModified 42957
#define sipName_isModified &sipStrings_QtGui[42957]
#define sipNameNr_isOpenGLES 42968
#define sipName_isOpenGLES &sipStrings_QtGui[42968]
#define sipNameNr_isPortrait 42979
#define sipName_isPortrait &sipStrings_QtGui[42979]
#define sipNameNr_isRotating 42990
#define sipName_isRotating &sipStrings_QtGui[42990]
#define sipNameNr_isScalable 43001
#define sipName_isScalable &sipStrings_QtGui[43001]
#define sipNameNr_isTopLevel 43012
#define sipName_isTopLevel &sipStrings_QtGui[43012]
#define sipNameNr_isTristate 43023
#define sipName_isTristate &sipStrings_QtGui[43023]
#define sipNameNr_itemNumber 43034
#define sipName_itemNumber &sipStrings_QtGui[43034]
#define sipNameNr_leftBorder 43045
#define sipName_leftBorder &sipStrings_QtGui[43045]
#define sipNameNr_leftMargin 43056
#define sipName_leftMargin &sipStrings_QtGui[43056]
#define sipNameNr_lightcoral 43067
#define sipName_lightcoral &sipStrings_QtGui[43067]
#define sipNameNr_lightgreen 43078
#define sipName_lightgreen &sipStrings_QtGui[43078]
#define sipNameNr_lightnessF 43089
#define sipName_lightnessF &sipStrings_QtGui[43089]
#define sipNameNr_lineHeight 43100
#define sipName_lineHeight &sipStrings_QtGui[43100]
#define sipNameNr_lineNumber 43111
#define sipName_lineNumber &sipStrings_QtGui[43111]
#define sipNameNr_logMessage 43122
#define sipName_logMessage &sipStrings_QtGui[43122]
#define sipNameNr_mapBetween 43133
#define sipName_mapBetween &sipStrings_QtGui[43133]
#define sipNameNr_mediumblue 43144
#define sipName_mediumblue &sipStrings_QtGui[43144]
#define sipNameNr_mergeCells 43155
#define sipName_mergeCells &sipStrings_QtGui[43155]
#define sipNameNr_minMargins 43166
#define sipName_minMargins &sipStrings_QtGui[43166]
#define sipNameNr_miterLimit 43177
#define sipName_miterLimit &sipStrings_QtGui[43177]
#define sipNameNr_normalized 43188
#define sipName_normalized &sipStrings_QtGui[43188]
#define sipNameNr_objectType 43199
#define sipName_objectType &sipStrings_QtGui[43199]
#define sipNameNr_pageLayout 43210
#define sipName_pageLayout &sipStrings_QtGui[43210]
#define sipNameNr_pageSizeMM 43221
#define sipName_pageSizeMM &sipStrings_QtGui[43221]
#define sipNameNr_paintEvent 43232
#define sipName_paintEvent &sipStrings_QtGui[43232]
#define sipNameNr_papayawhip 43243
#define sipName_papayawhip &sipStrings_QtGui[43243]
#define sipNameNr_parameters 43254
#define sipName_parameters &sipStrings_QtGui[43254]
#define sipNameNr_pdfVersion 43265
#define sipName_pdfVersion &sipStrings_QtGui[43265]
#define sipNameNr_pixelColor 43276
#define sipName_pixelColor &sipStrings_QtGui[43276]
#define sipNameNr_pixelDelta 43287
#define sipName_pixelDelta &sipStrings_QtGui[43287]
#define sipNameNr_pixelIndex 43298
#define sipName_pixelIndex &sipStrings_QtGui[43298]
#define sipNameNr_pointSizeF 43309
#define sipName_pointSizeF &sipStrings_QtGui[43309]
#define sipNameNr_pointSizes 43320
#define sipName_pointSizes &sipStrings_QtGui[43320]
#define sipNameNr_powderblue 43331
#define sipName_powderblue &sipStrings_QtGui[43331]
#define sipNameNr_properties 43342
#define sipName_properties &sipStrings_QtGui[43342]
#define sipNameNr_quadToQuad 43353
#define sipName_quadToQuad &sipStrings_QtGui[43353]
#define sipNameNr_rectPixels 43364
#define sipName_rectPixels &sipStrings_QtGui[43364]
#define sipNameNr_rectPoints 43375
#define sipName_rectPoints &sipStrings_QtGui[43375]
#define sipNameNr_removeItem 43386
#define sipName_removeItem &sipStrings_QtGui[43386]
#define sipNameNr_removeRows 43397
#define sipName_removeRows &sipStrings_QtGui[43397]
#define sipNameNr_resolution 43408
#define sipName_resolution &sipStrings_QtGui[43408]
#define sipNameNr_rgbSwapped 43419
#define sipName_rgbSwapped &sipStrings_QtGui[43419]
#define sipNameNr_rotationTo 43430
#define sipName_rotationTo &sipStrings_QtGui[43430]
#define sipNameNr_sandybrown 43441
#define sipName_sandybrown &sipStrings_QtGui[43441]
#define sipNameNr_saturation 43452
#define sipName_saturation &sipStrings_QtGui[43452]
#define sipNameNr_scaledSize 43463
#define sipName_scaledSize &sipStrings_QtGui[43463]
#define sipNameNr_screenRect 43474
#define sipName_screenRect &sipStrings_QtGui[43474]
#define sipNameNr_selections 43485
#define sipName_selections &sipStrings_QtGui[43485]
#define sipNameNr_setBaseUrl 43496
#define sipName_setBaseUrl &sipStrings_QtGui[43496]
#define sipNameNr_setColorAt 43507
#define sipName_setColorAt &sipStrings_QtGui[43507]
#define sipNameNr_setColumns 43518
#define sipName_setColumns &sipStrings_QtGui[43518]
#define sipNameNr_setCreator 43529
#define sipName_setCreator &sipStrings_QtGui[43529]
#define sipNameNr_setDescent 43540
#define sipName_setDescent &sipStrings_QtGui[43540]
#define sipNameNr_setEnabled 43551
#define sipName_setEnabled &sipStrings_QtGui[43551]
#define sipNameNr_setFormats 43562
#define sipName_setFormats &sipStrings_QtGui[43562]
#define sipNameNr_setHotSpot 43573
#define sipName_setHotSpot &sipStrings_QtGui[43573]
#define sipNameNr_setKerning 43584
#define sipName_setKerning &sipStrings_QtGui[43584]
#define sipNameNr_setMargins 43595
#define sipName_setMargins &sipStrings_QtGui[43595]
#define sipNameNr_setOpacity 43606
#define sipName_setOpacity &sipStrings_QtGui[43606]
#define sipNameNr_setOptions 43617
#define sipName_setOptions &sipStrings_QtGui[43617]
#define sipNameNr_setPadding 43628
#define sipName_setPadding &sipStrings_QtGui[43628]
#define sipNameNr_setPalette 43639
#define sipName_setPalette &sipStrings_QtGui[43639]
#define sipNameNr_setPicture 43650
#define sipName_setPicture &sipStrings_QtGui[43650]
#define sipNameNr_setProfile 43661
#define sipName_setProfile &sipStrings_QtGui[43661]
#define sipNameNr_setQuality 43672
#define sipName_setQuality &sipStrings_QtGui[43672]
#define sipNameNr_setRawFont 43683
#define sipName_setRawFont &sipStrings_QtGui[43683]
#define sipNameNr_setRawMode 43694
#define sipName_setRawMode &sipStrings_QtGui[43694]
#define sipNameNr_setRawName 43705
#define sipName_setRawName &sipStrings_QtGui[43705]
#define sipNameNr_setSamples 43716
#define sipName_setSamples &sipStrings_QtGui[43716]
#define sipNameNr_setStretch 43727
#define sipName_setStretch &sipStrings_QtGui[43727]
#define sipNameNr_setSubType 43738
#define sipName_setSubType &sipStrings_QtGui[43738]
#define sipNameNr_setTabStop 43749
#define sipName_setTabStop &sipStrings_QtGui[43749]
#define sipNameNr_setTexture 43760
#define sipName_setTexture &sipStrings_QtGui[43760]
#define sipNameNr_setToolTip 43771
#define sipName_setToolTip &sipStrings_QtGui[43771]
#define sipNameNr_setVersion 43782
#define sipName_setVersion &sipStrings_QtGui[43782]
#define sipNameNr_setVisible 43793
#define sipName_setVisible &sipStrings_QtGui[43793]
#define sipNameNr_severities 43804
#define sipName_severities &sipStrings_QtGui[43804]
#define sipNameNr_shaderType 43815
#define sipName_shaderType &sipStrings_QtGui[43815]
#define sipNameNr_shareGroup 43826
#define sipName_shareGroup &sipStrings_QtGui[43826]
#define sipNameNr_shortcutId 43837
#define sipName_shortcutId &sipStrings_QtGui[43837]
#define sipNameNr_showNormal 43848
#define sipName_showNormal &sipStrings_QtGui[43848]
#define sipNameNr_simplified 43859
#define sipName_simplified &sipStrings_QtGui[43859]
#define sipNameNr_sizePixels 43870
#define sipName_sizePixels &sipStrings_QtGui[43870]
#define sipNameNr_sizePoints 43881
#define sipName_sizePoints &sipStrings_QtGui[43881]
#define sipNameNr_skipImages 43892
#define sipName_skipImages &sipStrings_QtGui[43892]
#define sipNameNr_skipPixels 43903
#define sipName_skipPixels &sipStrings_QtGui[43903]
#define sipNameNr_sourceCode 43914
#define sipName_sourceCode &sipStrings_QtGui[43914]
#define sipNameNr_sourceLeft 43925
#define sipName_sourceLeft &sipStrings_QtGui[43925]
#define sipNameNr_strokePath 43936
#define sipName_strokePath &sipStrings_QtGui[43936]
#define sipNameNr_styleHints 43947
#define sipName_styleHints &sipStrings_QtGui[43947]
#define sipNameNr_substitute 43958
#define sipName_substitute &sipStrings_QtGui[43958]
#define sipNameNr_subtracted 43969
#define sipName_subtracted &sipStrings_QtGui[43969]
#define sipNameNr_systemFont 43980
#define sipName_systemFont &sipStrings_QtGui[43980]
#define sipNameNr_takeColumn 43991
#define sipName_takeColumn &sipStrings_QtGui[43991]
#define sipNameNr_testOption 44002
#define sipName_testOption &sipStrings_QtGui[44002]
#define sipNameNr_textFormat 44013
#define sipName_textFormat &sipStrings_QtGui[44013]
#define sipNameNr_textIndent 44024
#define sipName_textIndent &sipStrings_QtGui[44024]
#define sipNameNr_textLength 44035
#define sipName_textLength &sipStrings_QtGui[44035]
#define sipNameNr_textOption 44046
#define sipName_textOption &sipStrings_QtGui[44046]
#define sipNameNr_timerEvent 44057
#define sipName_timerEvent &sipStrings_QtGui[44057]
#define sipNameNr_toMarkdown 44068
#define sipName_toMarkdown &sipStrings_QtGui[44068]
#define sipNameNr_toReversed 44079
#define sipName_toReversed &sipStrings_QtGui[44079]
#define sipNameNr_toVector2D 44090
#define sipName_toVector2D &sipStrings_QtGui[44090]
#define sipNameNr_toVector3D 44101
#define sipName_toVector3D &sipStrings_QtGui[44101]
#define sipNameNr_toVector4D 44112
#define sipName_toVector4D &sipStrings_QtGui[44112]
#define sipNameNr_topLevelAt 44123
#define sipName_topLevelAt &sipStrings_QtGui[44123]
#define sipNameNr_topPadding 44134
#define sipName_topPadding &sipStrings_QtGui[44134]
#define sipNameNr_touchEvent 44145
#define sipName_touchEvent &sipStrings_QtGui[44145]
#define sipNameNr_translated 44156
#define sipName_translated &sipStrings_QtGui[44156]
#define sipNameNr_transposed 44167
#define sipName_transposed &sipStrings_QtGui[44167]
#define sipNameNr_trueMatrix 44178
#define sipName_trueMatrix &sipStrings_QtGui[44178]
#define sipNameNr_unitsPerEm 44189
#define sipName_unitsPerEm &sipStrings_QtGui[44189]
#define sipNameNr_visibility 44200
#define sipName_visibility &sipStrings_QtGui[44200]
#define sipNameNr_wheelEvent 44211
#define sipName_wheelEvent &sipStrings_QtGui[44211]
#define sipNameNr_whitesmoke 44222
#define sipName_whitesmoke &sipStrings_QtGui[44222]
#define sipNameNr_windowIcon 44233
#define sipName_windowIcon &sipStrings_QtGui[44233]
#define sipNameNr_windowText 44244
#define sipName_windowText &sipStrings_QtGui[44244]
#define sipNameNr_yellowSize 44255
#define sipName_yellowSize &sipStrings_QtGui[44255]
#define sipNameNr_APISource 44266
#define sipName_APISource &sipStrings_QtGui[44266]
#define sipNameNr_AngelCare 44276
#define sipName_AngelCare &sipStrings_QtGui[44276]
#define sipNameNr_Animation 20124
#define sipName_Animation &sipStrings_QtGui[20124]
#define sipNameNr_AnySource 44286
#define sipName_AnySource &sipStrings_QtGui[44286]
#define sipNameNr_Attribute 3776
#define sipName_Attribute &sipStrings_QtGui[3776]
#define sipNameNr_Backspace 44296
#define sipName_Backspace &sipStrings_QtGui[44296]
#define sipNameNr_BigEndian 44306
#define sipName_BigEndian &sipStrings_QtGui[44306]
#define sipNameNr_BlueValue 44316
#define sipName_BlueValue &sipStrings_QtGui[44316]
#define sipNameNr_ByteOrder 7711
#define sipName_ByteOrder &sipStrings_QtGui[7711]
#define sipNameNr_CacheMode 18270
#define sipName_CacheMode &sipStrings_QtGui[18270]
#define sipNameNr_CacheNone 44326
#define sipName_CacheNone &sipStrings_QtGui[44326]
#define sipNameNr_CenterTab 44336
#define sipName_CenterTab &sipStrings_QtGui[44336]
#define sipNameNr_ChildCare 44346
#define sipName_ChildCare &sipStrings_QtGui[44346]
#define sipNameNr_Clipboard 31739
#define sipName_Clipboard &sipStrings_QtGui[31739]
#define sipNameNr_ColorRole 13990
#define sipName_ColorRole &sipStrings_QtGui[13990]
#define sipNameNr_Condensed 26162
#define sipName_Condensed &sipStrings_QtGui[26162]
#define sipNameNr_D32FS8X24 44356
#define sipName_D32FS8X24 &sipStrings_QtGui[44356]
#define sipNameNr_DarkGreen 44366
#define sipName_DarkGreen &sipStrings_QtGui[44366]
#define sipNameNr_DepthMode 44376
#define sipName_DepthMode &sipStrings_QtGui[44376]
#define sipNameNr_DirtyFlag 7687
#define sipName_DirtyFlag &sipStrings_QtGui[7687]
#define sipNameNr_DirtyFont 44386
#define sipName_DirtyFont &sipStrings_QtGui[44386]
#define sipNameNr_DisplayP3 44396
#define sipName_DisplayP3 &sipStrings_QtGui[44396]
#define sipNameNr_EndOfLine 22895
#define sipName_EndOfLine &sipStrings_QtGui[22895]
#define sipNameNr_EndOfWord 22911
#define sipName_EndOfWord &sipStrings_QtGui[22911]
#define sipNameNr_Envelope9 44406
#define sipName_Envelope9 &sipStrings_QtGui[44406]
#define sipNameNr_ErrorType 44416
#define sipName_ErrorType &sipStrings_QtGui[44416]
#define sipNameNr_Executive 44426
#define sipName_Executive &sipStrings_QtGui[44426]
#define sipNameNr_ExtraBold 44436
#define sipName_ExtraBold &sipStrings_QtGui[44436]
#define sipNameNr_FanFoldUS 44446
#define sipName_FanFoldUS &sipStrings_QtGui[44446]
#define sipNameNr_FindFlags 6945
#define sipName_FindFlags &sipStrings_QtGui[6945]
#define sipNameNr_FixedFont 44456
#define sipName_FixedFont &sipStrings_QtGui[44456]
#define sipNameNr_FloatLeft 44466
#define sipName_FloatLeft &sipStrings_QtGui[44466]
#define sipNameNr_FreshMilk 44476
#define sipName_FreshMilk &sipStrings_QtGui[44476]
#define sipNameNr_Grayscale 11318
#define sipName_Grayscale &sipStrings_QtGui[11318]
#define sipNameNr_HappyAcid 44486
#define sipName_HappyAcid &sipStrings_QtGui[44486]
#define sipNameNr_HeavyRain 44496
#define sipName_HeavyRain &sipStrings_QtGui[44496]
#define sipNameNr_Helvetica 44506
#define sipName_Helvetica &sipStrings_QtGui[44506]
#define sipNameNr_Highlight 44516
#define sipName_Highlight &sipStrings_QtGui[44516]
#define sipNameNr_ImageName 44526
#define sipName_ImageName &sipStrings_QtGui[44526]
#define sipNameNr_InfoFlags 783
#define sipName_InfoFlags &sipStrings_QtGui[783]
#define sipNameNr_InvertRgb 44536
#define sipName_InvertRgb &sipStrings_QtGui[44536]
#define sipNameNr_JuicyCake 44546
#define sipName_JuicyCake &sipStrings_QtGui[44546]
#define sipNameNr_JungleDay 44556
#define sipName_JungleDay &sipStrings_QtGui[44556]
#define sipNameNr_KindSteel 44566
#define sipName_KindSteel &sipStrings_QtGui[44566]
#define sipNameNr_Landscape 39015
#define sipName_Landscape &sipStrings_QtGui[39015]
#define sipNameNr_LemonGate 44576
#define sipName_LemonGate &sipStrings_QtGui[44576]
#define sipNameNr_LightBlue 44586
#define sipName_LightBlue &sipStrings_QtGui[44586]
#define sipNameNr_LightGray 44596
#define sipName_LightGray &sipStrings_QtGui[44596]
#define sipNameNr_ListStyle 44606
#define sipName_ListStyle &sipStrings_QtGui[44606]
#define sipNameNr_Luminance 44616
#define sipName_Luminance &sipStrings_QtGui[44616]
#define sipNameNr_MagicLake 44626
#define sipName_MagicLake &sipStrings_QtGui[44626]
#define sipNameNr_Malayalam 44636
#define sipName_Malayalam &sipStrings_QtGui[44636]
#define sipNameNr_MarsParty 44646
#define sipName_MarsParty &sipStrings_QtGui[44646]
#define sipNameNr_Maximized 25775
#define sipName_Maximized &sipStrings_QtGui[25775]
#define sipNameNr_MeanFruit 44656
#define sipName_MeanFruit &sipStrings_QtGui[44656]
#define sipNameNr_MindCrawl 44666
#define sipName_MindCrawl &sipStrings_QtGui[44666]
#define sipNameNr_Minimized 32691
#define sipName_Minimized &sipStrings_QtGui[32691]
#define sipNameNr_MixedCase 44676
#define sipName_MixedCase &sipStrings_QtGui[44676]
#define sipNameNr_Monospace 44686
#define sipName_Monospace &sipStrings_QtGui[44686]
#define sipNameNr_NPageSize 44696
#define sipName_NPageSize &sipStrings_QtGui[44696]
#define sipNameNr_NextBlock 44706
#define sipName_NextBlock &sipStrings_QtGui[44706]
#define sipNameNr_NextChild 44716
#define sipName_NextChild &sipStrings_QtGui[44716]
#define sipNameNr_NightCall 44726
#define sipName_NightCall &sipStrings_QtGui[44726]
#define sipNameNr_NightFade 44736
#define sipName_NightFade &sipStrings_QtGui[44736]
#define sipNameNr_NoProfile 44746
#define sipName_NoProfile &sipStrings_QtGui[44746]
#define sipNameNr_Offscreen 44756
#define sipName_Offscreen &sipStrings_QtGui[44756]
#define sipNameNr_OtherType 44766
#define sipName_OtherType &sipStrings_QtGui[44766]
#define sipNameNr_PadSpread 44776
#define sipName_PadSpread &sipStrings_QtGui[44776]
#define sipNameNr_PdmHeight 44786
#define sipName_PdmHeight &sipStrings_QtGui[44786]
#define sipNameNr_PixelType 5973
#define sipName_PixelType &sipStrings_QtGui[5973]
#define sipNameNr_PlumPlate 44796
#define sipName_PlumPlate &sipStrings_QtGui[44796]
#define sipNameNr_Prc32KBig 44806
#define sipName_Prc32KBig &sipStrings_QtGui[44806]
#define sipNameNr_Primaries 8900
#define sipName_Primaries &sipStrings_QtGui[8900]
#define sipNameNr_QFontInfo 44816
#define sipName_QFontInfo &sipStrings_QtGui[44816]
#define sipNameNr_QGlyphRun 44826
#define sipName_QGlyphRun &sipStrings_QtGui[44826]
#define sipNameNr_QGradient 44836
#define sipName_QGradient &sipStrings_QtGui[44836]
#define sipNameNr_QKeyEvent 44846
#define sipName_QKeyEvent &sipStrings_QtGui[44846]
#define sipNameNr_QPageSize 44856
#define sipName_QPageSize &sipStrings_QtGui[44856]
#define sipNameNr_QPolygonF 44866
#define sipName_QPolygonF &sipStrings_QtGui[44866]
#define sipNameNr_QTextItem 44876
#define sipName_QTextItem &sipStrings_QtGui[44876]
#define sipNameNr_QTextLine 44886
#define sipName_QTextLine &sipStrings_QtGui[44886]
#define sipNameNr_QTextList 44896
#define sipName_QTextList &sipStrings_QtGui[44896]
#define sipNameNr_QVector2D 44906
#define sipName_QVector2D &sipStrings_QtGui[44906]
#define sipNameNr_QVector3D 44916
#define sipName_QVector3D &sipStrings_QtGui[44916]
#define sipNameNr_QVector4D 44926
#define sipName_QVector4D &sipStrings_QtGui[44926]
#define sipNameNr_QuickDraw 44936
#define sipName_QuickDraw &sipStrings_QtGui[44936]
#define sipNameNr_R16_SNorm 44946
#define sipName_R16_SNorm &sipStrings_QtGui[44946]
#define sipNameNr_R16_UNorm 44956
#define sipName_R16_UNorm &sipStrings_QtGui[44956]
#define sipNameNr_RG8_SNorm 44966
#define sipName_RG8_SNorm &sipStrings_QtGui[44966]
#define sipNameNr_RG8_UNorm 44976
#define sipName_RG8_UNorm &sipStrings_QtGui[44976]
#define sipNameNr_RGB8_ETC1 44986
#define sipName_RGB8_ETC1 &sipStrings_QtGui[44986]
#define sipNameNr_RGB8_ETC2 41605
#define sipName_RGB8_ETC2 &sipStrings_QtGui[41605]
#define sipNameNr_RGBA_DXT1 44996
#define sipName_RGBA_DXT1 &sipStrings_QtGui[44996]
#define sipNameNr_RGBA_DXT3 45006
#define sipName_RGBA_DXT3 &sipStrings_QtGui[45006]
#define sipNameNr_RGBA_DXT5 45016
#define sipName_RGBA_DXT5 &sipStrings_QtGui[45016]
#define sipNameNr_RGBFormat 45026
#define sipName_RGBFormat &sipStrings_QtGui[45026]
#define sipNameNr_RangeRead 45036
#define sipName_RangeRead &sipStrings_QtGui[45036]
#define sipNameNr_ReadWrite 45046
#define sipName_ReadWrite &sipStrings_QtGui[45046]
#define sipNameNr_Rectangle 8670
#define sipName_Rectangle &sipStrings_QtGui[8670]
#define sipNameNr_RedoStack 45056
#define sipName_RedoStack &sipStrings_QtGui[45056]
#define sipNameNr_RichMetal 45066
#define sipName_RichMetal &sipStrings_QtGui[45066]
#define sipNameNr_RiverCity 45076
#define sipName_RiverCity &sipStrings_QtGui[45076]
#define sipNameNr_SRGB_DXT1 45086
#define sipName_SRGB_DXT1 &sipStrings_QtGui[45086]
#define sipNameNr_SansSerif 45096
#define sipName_SansSerif &sipStrings_QtGui[45096]
#define sipNameNr_SeaStrike 45106
#define sipName_SeaStrike &sipStrings_QtGui[45106]
#define sipNameNr_SelectAll 45116
#define sipName_SelectAll &sipStrings_QtGui[45116]
#define sipNameNr_Selection 314
#define sipName_Selection &sipStrings_QtGui[314]
#define sipNameNr_SkipWords 45126
#define sipName_SkipWords &sipStrings_QtGui[45126]
#define sipNameNr_SkyGlider 45136
#define sipName_SkyGlider &sipStrings_QtGui[45136]
#define sipNameNr_SmallCaps 45146
#define sipName_SmallCaps &sipStrings_QtGui[45146]
#define sipNameNr_SnowAgain 45156
#define sipName_SnowAgain &sipStrings_QtGui[45156]
#define sipNameNr_SoftGrass 45166
#define sipName_SoftGrass &sipStrings_QtGui[45166]
#define sipNameNr_SpikyNaga 45176
#define sipName_SpikyNaga &sipStrings_QtGui[45176]
#define sipNameNr_Statement 45186
#define sipName_Statement &sipStrings_QtGui[45186]
#define sipNameNr_StrikeOut 22090
#define sipName_StrikeOut &sipStrings_QtGui[22090]
#define sipNameNr_StyleHint 20951
#define sipName_StyleHint &sipStrings_QtGui[20951]
#define sipNameNr_SunVeggie 45196
#define sipName_SunVeggie &sipStrings_QtGui[45196]
#define sipNameNr_TeenParty 45206
#define sipName_TeenParty &sipStrings_QtGui[45206]
#define sipNameNr_Texture1D 45216
#define sipName_Texture1D &sipStrings_QtGui[45216]
#define sipNameNr_Texture3D 45226
#define sipName_Texture3D &sipStrings_QtGui[45226]
#define sipNameNr_TitleFont 45236
#define sipName_TitleFont &sipStrings_QtGui[45236]
#define sipNameNr_TxProject 45246
#define sipName_TxProject &sipStrings_QtGui[45246]
#define sipNameNr_Unchecked 45256
#define sipName_Unchecked &sipStrings_QtGui[45256]
#define sipNameNr_Underline 14150
#define sipName_Underline &sipStrings_QtGui[14150]
#define sipNameNr_UndoStack 45266
#define sipName_UndoStack &sipStrings_QtGui[45266]
#define sipNameNr_UsesAlpha 45276
#define sipName_UsesAlpha &sipStrings_QtGui[45276]
#define sipNameNr_WarmFlame 45286
#define sipName_WarmFlame &sipStrings_QtGui[45286]
#define sipNameNr_WhatsThis 36391
#define sipName_WhatsThis &sipStrings_QtGui[36391]
#define sipNameNr_WildApple 45296
#define sipName_WildApple &sipStrings_QtGui[45296]
#define sipNameNr_WordRight 45306
#define sipName_WordRight &sipStrings_QtGui[45306]
#define sipNameNr_WriteOnly 45316
#define sipName_WriteOnly &sipStrings_QtGui[45316]
#define sipNameNr_YUVLayout 7735
#define sipName_YUVLayout &sipStrings_QtGui[7735]
#define sipNameNr_ZeroValue 45326
#define sipName_ZeroValue &sipStrings_QtGui[45326]
#define sipNameNr___enter__ 45336
#define sipName___enter__ &sipStrings_QtGui[45336]
#define sipNameNr___index__ 45346
#define sipName___index__ &sipStrings_QtGui[45346]
#define sipNameNr_addPixmap 45356
#define sipName_addPixmap &sipStrings_QtGui[45356]
#define sipNameNr_addRegion 45366
#define sipName_addRegion &sipStrings_QtGui[45366]
#define sipNameNr_addShader 45376
#define sipName_addShader &sipStrings_QtGui[45376]
#define sipNameNr_aliceblue 45386
#define sipName_aliceblue &sipStrings_QtGui[45386]
#define sipNameNr_alignment 45396
#define sipName_alignment &sipStrings_QtGui[45396]
#define sipNameNr_alphaSize 45406
#define sipName_alphaSize &sipStrings_QtGui[45406]
#define sipNameNr_ambiguous 45416
#define sipName_ambiguous &sipStrings_QtGui[45416]
#define sipNameNr_appendRow 45426
#define sipName_appendRow &sipStrings_QtGui[45426]
#define sipNameNr_arcMoveTo 45436
#define sipName_arcMoveTo &sipStrings_QtGui[45436]
#define sipNameNr_blackSize 45446
#define sipName_blackSize &sipStrings_QtGui[45446]
#define sipNameNr_blockList 45456
#define sipName_blockList &sipStrings_QtGui[45456]
#define sipNameNr_burlywood 45466
#define sipName_burlywood &sipStrings_QtGui[45466]
#define sipNameNr_byteCount 45476
#define sipName_byteCount &sipStrings_QtGui[45476]
#define sipNameNr_byteOrder 45486
#define sipName_byteOrder &sipStrings_QtGui[45486]
#define sipNameNr_cacheMode 45496
#define sipName_cacheMode &sipStrings_QtGui[45496]
#define sipNameNr_cadetblue 45506
#define sipName_cadetblue &sipStrings_QtGui[45506]
#define sipNameNr_capHeight 45516
#define sipName_capHeight &sipStrings_QtGui[45516]
#define sipNameNr_chocolate 45526
#define sipName_chocolate &sipStrings_QtGui[45526]
#define sipNameNr_clearData 45536
#define sipName_clearData &sipStrings_QtGui[45536]
#define sipNameNr_clipTight 45546
#define sipName_clipTight &sipStrings_QtGui[45546]
#define sipNameNr_clipboard 45556
#define sipName_clipboard &sipStrings_QtGui[45556]
#define sipNameNr_component 45566
#define sipName_component &sipStrings_QtGui[45566]
#define sipNameNr_conjugate 45576
#define sipName_conjugate &sipStrings_QtGui[45576]
#define sipNameNr_constBits 45586
#define sipName_constBits &sipStrings_QtGui[45586]
#define sipNameNr_convertTo 45596
#define sipName_convertTo &sipStrings_QtGui[45596]
#define sipNameNr_cursorToX 45606
#define sipName_cursorToX &sipStrings_QtGui[45606]
#define sipNameNr_darkgreen 45616
#define sipName_darkgreen &sipStrings_QtGui[45616]
#define sipNameNr_darkkhaki 45626
#define sipName_darkkhaki &sipStrings_QtGui[45626]
#define sipNameNr_delimiter 45636
#define sipName_delimiter &sipStrings_QtGui[45636]
#define sipNameNr_drawChord 45646
#define sipName_drawChord &sipStrings_QtGui[45646]
#define sipNameNr_drawImage 45656
#define sipName_drawImage &sipStrings_QtGui[45656]
#define sipNameNr_drawLines 45666
#define sipName_drawLines &sipStrings_QtGui[45666]
#define sipNameNr_drawPoint 45676
#define sipName_drawPoint &sipStrings_QtGui[45676]
#define sipNameNr_drawRects 45686
#define sipName_drawRects &sipStrings_QtGui[45686]
#define sipNameNr_elementAt 45696
#define sipName_elementAt &sipStrings_QtGui[45696]
#define sipNameNr_endLayout 45706
#define sipName_endLayout &sipStrings_QtGui[45706]
#define sipNameNr_eraseRect 45716
#define sipName_eraseRect &sipStrings_QtGui[45716]
#define sipNameNr_fetchMore 45726
#define sipName_fetchMore &sipStrings_QtGui[45726]
#define sipNameNr_finalStop 45736
#define sipName_finalStop &sipStrings_QtGui[45736]
#define sipNameNr_findBlock 45746
#define sipName_findBlock &sipStrings_QtGui[45746]
#define sipNameNr_findItems 45756
#define sipName_findItems &sipStrings_QtGui[45756]
#define sipNameNr_firebrick 45766
#define sipName_firebrick &sipStrings_QtGui[45766]
#define sipNameNr_fontTable 45776
#define sipName_fontTable &sipStrings_QtGui[45776]
#define sipNameNr_frameRect 45786
#define sipName_frameRect &sipStrings_QtGui[45786]
#define sipNameNr_fromCmykF 45796
#define sipName_fromCmykF &sipStrings_QtGui[45796]
#define sipNameNr_fromImage 45806
#define sipName_fromImage &sipStrings_QtGui[45806]
#define sipNameNr_fromScale 45816
#define sipName_fromScale &sipStrings_QtGui[45816]
#define sipNameNr_fromTheme 45826
#define sipName_fromTheme &sipStrings_QtGui[45826]
#define sipNameNr_fromWinId 45836
#define sipName_fromWinId &sipStrings_QtGui[45836]
#define sipNameNr_gainsboro 45846
#define sipName_gainsboro &sipStrings_QtGui[45846]
#define sipNameNr_globalPos 45856
#define sipName_globalPos &sipStrings_QtGui[45856]
#define sipNameNr_glyphRuns 45866
#define sipName_glyphRuns &sipStrings_QtGui[45866]
#define sipNameNr_goldenrod 30857
#define sipName_goldenrod &sipStrings_QtGui[30857]
#define sipNameNr_greenSize 45876
#define sipName_greenSize &sipStrings_QtGui[45876]
#define sipNameNr_hideEvent 45886
#define sipName_hideEvent &sipStrings_QtGui[45886]
#define sipNameNr_highlight 39447
#define sipName_highlight &sipStrings_QtGui[39447]
#define sipNameNr_indianred 45896
#define sipName_indianred &sipStrings_QtGui[45896]
#define sipNameNr_insertRow 45906
#define sipName_insertRow &sipStrings_QtGui[45906]
#define sipNameNr_isCreated 45916
#define sipName_isCreated &sipStrings_QtGui[45916]
#define sipNameNr_isCurveTo 45926
#define sipName_isCurveTo &sipStrings_QtGui[45926]
#define sipNameNr_isEnabled 45936
#define sipName_isEnabled &sipStrings_QtGui[45936]
#define sipNameNr_isExposed 45946
#define sipName_isExposed &sipStrings_QtGui[45946]
#define sipNameNr_isLogging 45956
#define sipName_isLogging &sipStrings_QtGui[45956]
#define sipNameNr_isQBitmap 45966
#define sipName_isQBitmap &sipStrings_QtGui[45966]
#define sipNameNr_isScaling 45976
#define sipName_isScaling &sipStrings_QtGui[45976]
#define sipNameNr_isVisible 45986
#define sipName_isVisible &sipStrings_QtGui[45986]
#define sipNameNr_joinStyle 45996
#define sipName_joinStyle &sipStrings_QtGui[45996]
#define sipNameNr_lastBlock 46006
#define sipName_lastBlock &sipStrings_QtGui[46006]
#define sipNameNr_lastError 46016
#define sipName_lastError &sipStrings_QtGui[46016]
#define sipNameNr_lawngreen 46026
#define sipName_lawngreen &sipStrings_QtGui[46026]
#define sipNameNr_lightblue 46036
#define sipName_lightblue &sipStrings_QtGui[46036]
#define sipNameNr_lightcyan 46046
#define sipName_lightcyan &sipStrings_QtGui[46046]
#define sipNameNr_lightgray 46056
#define sipName_lightgray &sipStrings_QtGui[46056]
#define sipNameNr_lightgrey 46066
#define sipName_lightgrey &sipStrings_QtGui[46066]
#define sipNameNr_lightness 46076
#define sipName_lightness &sipStrings_QtGui[46076]
#define sipNameNr_lightpink 46086
#define sipName_lightpink &sipStrings_QtGui[46086]
#define sipNameNr_limegreen 46096
#define sipName_limegreen &sipStrings_QtGui[46096]
#define sipNameNr_lineCount 46106
#define sipName_lineCount &sipStrings_QtGui[46106]
#define sipNameNr_lineWidth 46116
#define sipName_lineWidth &sipStrings_QtGui[46116]
#define sipNameNr_loopCount 46126
#define sipName_loopCount &sipStrings_QtGui[46126]
#define sipNameNr_lostFocus 46136
#define sipName_lostFocus &sipStrings_QtGui[46136]
#define sipNameNr_mapVector 46146
#define sipName_mapVector &sipStrings_QtGui[46146]
#define sipNameNr_mimeTypes 46156
#define sipName_mimeTypes &sipStrings_QtGui[46156]
#define sipNameNr_mintcream 46166
#define sipName_mintcream &sipStrings_QtGui[46166]
#define sipNameNr_mipLevels 46176
#define sipName_mipLevels &sipStrings_QtGui[46176]
#define sipNameNr_mistyrose 46186
#define sipName_mistyrose &sipStrings_QtGui[46186]
#define sipNameNr_modifiers 46196
#define sipName_modifiers &sipStrings_QtGui[46196]
#define sipNameNr_moveEvent 46206
#define sipName_moveEvent &sipStrings_QtGui[46206]
#define sipNameNr_nearPlane 46216
#define sipName_nearPlane &sipStrings_QtGui[46216]
#define sipNameNr_normalize 46226
#define sipName_normalize &sipStrings_QtGui[46226]
#define sipNameNr_numericId 46236
#define sipName_numericId &sipStrings_QtGui[46236]
#define sipNameNr_olivedrab 46246
#define sipName_olivedrab &sipStrings_QtGui[46246]
#define sipNameNr_operation 46256
#define sipName_operation &sipStrings_QtGui[46256]
#define sipNameNr_orangered 46266
#define sipName_orangered &sipStrings_QtGui[46266]
#define sipNameNr_pageCount 46276
#define sipName_pageCount &sipStrings_QtGui[46276]
#define sipNameNr_paintRect 46286
#define sipName_paintRect &sipStrings_QtGui[46286]
#define sipNameNr_palegreen 46296
#define sipName_palegreen &sipStrings_QtGui[46296]
#define sipNameNr_peachpuff 46306
#define sipName_peachpuff &sipStrings_QtGui[46306]
#define sipNameNr_pixelSize 46316
#define sipName_pixelSize &sipStrings_QtGui[46316]
#define sipNameNr_pointSize 46326
#define sipName_pointSize &sipStrings_QtGui[46326]
#define sipNameNr_positions 46336
#define sipName_positions &sipStrings_QtGui[46336]
#define sipNameNr_primaries 46346
#define sipName_primaries &sipStrings_QtGui[46346]
#define sipNameNr_programId 46356
#define sipName_programId &sipStrings_QtGui[46356]
#define sipNameNr_pushGroup 46366
#define sipName_pushGroup &sipStrings_QtGui[46366]
#define sipNameNr_putPoints 46376
#define sipName_putPoints &sipStrings_QtGui[46376]
#define sipNameNr_rectCount 46386
#define sipName_rectCount &sipStrings_QtGui[46386]
#define sipNameNr_removeRow 46396
#define sipName_removeRow &sipStrings_QtGui[46396]
#define sipNameNr_roleNames 46406
#define sipName_roleNames &sipStrings_QtGui[46406]
#define sipNameNr_rootFrame 46416
#define sipName_rootFrame &sipStrings_QtGui[46416]
#define sipNameNr_rosybrown 46426
#define sipName_rosybrown &sipStrings_QtGui[46426]
#define sipNameNr_rowLength 46436
#define sipName_rowLength &sipStrings_QtGui[46436]
#define sipNameNr_royalblue 46446
#define sipName_royalblue &sipStrings_QtGui[46446]
#define sipNameNr_sceneRect 46456
#define sipName_sceneRect &sipStrings_QtGui[46456]
#define sipNameNr_screenPos 46466
#define sipName_screenPos &sipStrings_QtGui[46466]
#define sipNameNr_selection 46476
#define sipName_selection &sipStrings_QtGui[46476]
#define sipNameNr_setActive 46486
#define sipName_setActive &sipStrings_QtGui[46486]
#define sipNameNr_setAlphaF 46496
#define sipName_setAlphaF &sipStrings_QtGui[46496]
#define sipNameNr_setAnchor 46506
#define sipName_setAnchor &sipStrings_QtGui[46506]
#define sipNameNr_setAscent 46516
#define sipName_setAscent &sipStrings_QtGui[46516]
#define sipNameNr_setBorder 46526
#define sipName_setBorder &sipStrings_QtGui[46526]
#define sipNameNr_setBottom 46536
#define sipName_setBottom &sipStrings_QtGui[46536]
#define sipNameNr_setCenter 46546
#define sipName_setCenter &sipStrings_QtGui[46546]
#define sipNameNr_setColumn 46556
#define sipName_setColumn &sipStrings_QtGui[46556]
#define sipNameNr_setCursor 40191
#define sipName_setCursor &sipStrings_QtGui[40191]
#define sipNameNr_setDevice 46566
#define sipName_setDevice &sipStrings_QtGui[46566]
#define sipNameNr_setFamily 46576
#define sipName_setFamily &sipStrings_QtGui[46576]
#define sipNameNr_setFormat 46586
#define sipName_setFormat &sipStrings_QtGui[46586]
#define sipNameNr_setGreenF 46596
#define sipName_setGreenF &sipStrings_QtGui[46596]
#define sipNameNr_setHeight 46606
#define sipName_setHeight &sipStrings_QtGui[46606]
#define sipNameNr_setIndent 46616
#define sipName_setIndent &sipStrings_QtGui[46616]
#define sipNameNr_setIsMask 46626
#define sipName_setIsMask &sipStrings_QtGui[46626]
#define sipNameNr_setItalic 46636
#define sipName_setItalic &sipStrings_QtGui[46636]
#define sipNameNr_setLayers 46646
#define sipName_setLayers &sipStrings_QtGui[46646]
#define sipNameNr_setLocale 46656
#define sipName_setLocale &sipStrings_QtGui[46656]
#define sipNameNr_setMargin 46666
#define sipName_setMargin &sipStrings_QtGui[46666]
#define sipNameNr_setMarker 46676
#define sipName_setMarker &sipStrings_QtGui[46676]
#define sipNameNr_setMatrix 46686
#define sipName_setMatrix &sipStrings_QtGui[46686]
#define sipNameNr_setMipmap 46696
#define sipName_setMipmap &sipStrings_QtGui[46696]
#define sipNameNr_setOffset 46706
#define sipName_setOffset &sipStrings_QtGui[46706]
#define sipNameNr_setOption 46716
#define sipName_setOption &sipStrings_QtGui[46716]
#define sipNameNr_setParent 46726
#define sipName_setParent &sipStrings_QtGui[46726]
#define sipNameNr_setPaused 46736
#define sipName_setPaused &sipStrings_QtGui[46736]
#define sipNameNr_setPixmap 46746
#define sipName_setPixmap &sipStrings_QtGui[46746]
#define sipNameNr_setPoints 46756
#define sipName_setPoints &sipStrings_QtGui[46756]
#define sipNameNr_setRadius 46766
#define sipName_setRadius &sipStrings_QtGui[46766]
#define sipNameNr_setRegExp 46776
#define sipName_setRegExp &sipStrings_QtGui[46776]
#define sipNameNr_setRgba64 46786
#define sipName_setRgba64 &sipStrings_QtGui[46786]
#define sipNameNr_setScalar 46796
#define sipName_setScalar &sipStrings_QtGui[46796]
#define sipNameNr_setScreen 46806
#define sipName_setScreen &sipStrings_QtGui[46806]
#define sipNameNr_setSpread 46816
#define sipName_setSpread &sipStrings_QtGui[46816]
#define sipNameNr_setStatus 46826
#define sipName_setStatus &sipStrings_QtGui[46826]
#define sipNameNr_setStereo 46836
#define sipName_setStereo &sipStrings_QtGui[46836]
#define sipNameNr_setVector 46846
#define sipName_setVector &sipStrings_QtGui[46846]
#define sipNameNr_setWeight 46856
#define sipName_setWeight &sipStrings_QtGui[46856]
#define sipNameNr_setWidthF 46866
#define sipName_setWidthF &sipStrings_QtGui[46866]
#define sipNameNr_setWindow 46876
#define sipName_setWindow &sipStrings_QtGui[46876]
#define sipNameNr_showEvent 46886
#define sipName_showEvent &sipStrings_QtGui[46886]
#define sipNameNr_slateblue 24831
#define sipName_slateblue &sipStrings_QtGui[24831]
#define sipNameNr_slategray 27857
#define sipName_slategray &sipStrings_QtGui[27857]
#define sipNameNr_slategrey 27872
#define sipName_slategrey &sipStrings_QtGui[27872]
#define sipNameNr_sourceTop 46896
#define sipName_sourceTop &sipStrings_QtGui[46896]
#define sipNameNr_splitCell 46906
#define sipName_splitCell &sipStrings_QtGui[46906]
#define sipNameNr_statusTip 46916
#define sipName_statusTip &sipStrings_QtGui[46916]
#define sipNameNr_steelblue 27887
#define sipName_steelblue &sipStrings_QtGui[27887]
#define sipNameNr_strikeOut 46926
#define sipName_strikeOut &sipStrings_QtGui[46926]
#define sipNameNr_styleHint 46936
#define sipName_styleHint &sipStrings_QtGui[46936]
#define sipNameNr_styleName 46946
#define sipName_styleName &sipStrings_QtGui[46946]
#define sipNameNr_takeChild 46956
#define sipName_takeChild &sipStrings_QtGui[46956]
#define sipNameNr_textStart 46966
#define sipName_textStart &sipStrings_QtGui[46966]
#define sipNameNr_textWidth 46976
#define sipName_textWidth &sipStrings_QtGui[46976]
#define sipNameNr_textureId 46986
#define sipName_textureId &sipStrings_QtGui[46986]
#define sipNameNr_themeName 46996
#define sipName_themeName &sipStrings_QtGui[46996]
#define sipNameNr_timestamp 47006
#define sipName_timestamp &sipStrings_QtGui[47006]
#define sipNameNr_toPolygon 47016
#define sipName_toPolygon &sipStrings_QtGui[47016]
#define sipNameNr_toRawText 47026
#define sipName_toRawText &sipStrings_QtGui[47026]
#define sipNameNr_topBorder 47036
#define sipName_topBorder &sipStrings_QtGui[47036]
#define sipNameNr_topMargin 47046
#define sipName_topMargin &sipStrings_QtGui[47046]
#define sipNameNr_transform 47056
#define sipName_transform &sipStrings_QtGui[47056]
#define sipNameNr_translate 47066
#define sipName_translate &sipStrings_QtGui[47066]
#define sipNameNr_turquoise 24847
#define sipName_turquoise &sipStrings_QtGui[24847]
#define sipNameNr_underline 47076
#define sipName_underline &sipStrings_QtGui[47076]
#define sipNameNr_unproject 47086
#define sipName_unproject &sipStrings_QtGui[47086]
#define sipNameNr_userState 47096
#define sipName_userState &sipStrings_QtGui[47096]
#define sipNameNr_whatsThis 47106
#define sipName_whatsThis &sipStrings_QtGui[47106]
#define sipNameNr_widthChar 47116
#define sipName_widthChar &sipStrings_QtGui[47116]
#define sipNameNr_windowPos 47126
#define sipName_windowPos &sipStrings_QtGui[47126]
#define sipNameNr_windowsId 47136
#define sipName_windowsId &sipStrings_QtGui[47136]
#define sipNameNr_xToCursor 47146
#define sipName_xToCursor &sipStrings_QtGui[47146]
#define sipNameNr_yuvLayout 47156
#define sipName_yuvLayout &sipStrings_QtGui[47156]
#define sipNameNr_AdobeRgb 47166
#define sipName_AdobeRgb &sipStrings_QtGui[47166]
#define sipNameNr_Airbrush 47175
#define sipName_Airbrush &sipStrings_QtGui[47175]
#define sipNameNr_AlignTop 47184
#define sipName_AlignTop &sipStrings_QtGui[47184]
#define sipNameNr_AllDirty 47193
#define sipName_AllDirty &sipStrings_QtGui[47193]
#define sipNameNr_AmyCrisp 47202
#define sipName_AmyCrisp &sipStrings_QtGui[47202]
#define sipNameNr_AnyStyle 47211
#define sipName_AnyStyle &sipStrings_QtGui[47211]
#define sipNameNr_Armenian 47220
#define sipName_Armenian &sipStrings_QtGui[47220]
#define sipNameNr_BigMango 47229
#define sipName_BigMango &sipStrings_QtGui[47229]
#define sipNameNr_BlackSea 47238
#define sipName_BlackSea &sipStrings_QtGui[47238]
#define sipNameNr_Blessing 47247
#define sipName_Blessing &sipStrings_QtGui[47247]
#define sipNameNr_CacheAll 47256
#define sipName_CacheAll &sipStrings_QtGui[47256]
#define sipNameNr_ClipRect 19873
#define sipName_ClipRect &sipStrings_QtGui[19873]
#define sipNameNr_CssFloat 47265
#define sipName_CssFloat &sipStrings_QtGui[47265]
#define sipNameNr_Cyrillic 47274
#define sipName_Cyrillic &sipStrings_QtGui[47274]
#define sipNameNr_DarkBlue 47283
#define sipName_DarkBlue &sipStrings_QtGui[47283]
#define sipNameNr_DarkCyan 47292
#define sipName_DarkCyan &sipStrings_QtGui[47292]
#define sipNameNr_DarkGray 47301
#define sipName_DarkGray &sipStrings_QtGui[47301]
#define sipNameNr_DciP3D65 47310
#define sipName_DciP3D65 &sipStrings_QtGui[47310]
#define sipNameNr_DeepBlue 47319
#define sipName_DeepBlue &sipStrings_QtGui[47319]
#define sipNameNr_DemiBold 47328
#define sipName_DemiBold &sipStrings_QtGui[47328]
#define sipNameNr_Deselect 47337
#define sipName_Deselect &sipStrings_QtGui[47337]
#define sipNameNr_Direct2D 47346
#define sipName_Direct2D &sipStrings_QtGui[47346]
#define sipNameNr_Direct3D 47355
#define sipName_Direct3D &sipStrings_QtGui[47355]
#define sipNameNr_DirtyPen 47364
#define sipName_DirtyPen &sipStrings_QtGui[47364]
#define sipNameNr_Disabled 47373
#define sipName_Disabled &sipStrings_QtGui[47373]
#define sipNameNr_Document 9999
#define sipName_Document &sipStrings_QtGui[9999]
#define sipNameNr_Expanded 29388
#define sipName_Expanded &sipStrings_QtGui[29388]
#define sipNameNr_Features 991
#define sipName_Features &sipStrings_QtGui[991]
#define sipNameNr_FindFlag 7808
#define sipName_FindFlag &sipStrings_QtGui[7808]
#define sipNameNr_FindNext 47382
#define sipName_FindNext &sipStrings_QtGui[47382]
#define sipNameNr_Fragment 6871
#define sipName_Fragment &sipStrings_QtGui[6871]
#define sipNameNr_Geometry 7121
#define sipName_Geometry &sipStrings_QtGui[7121]
#define sipNameNr_Georgian 47391
#define sipName_Georgian &sipStrings_QtGui[47391]
#define sipNameNr_Gujarati 47400
#define sipName_Gujarati &sipStrings_QtGui[47400]
#define sipNameNr_Gurmukhi 47409
#define sipName_Gurmukhi &sipStrings_QtGui[47409]
#define sipNameNr_Inactive 47418
#define sipName_Inactive &sipStrings_QtGui[47418]
#define sipNameNr_InfoFlag 1059
#define sipName_InfoFlag &sipStrings_QtGui[1059]
#define sipNameNr_IsAnchor 47427
#define sipName_IsAnchor &sipStrings_QtGui[47427]
#define sipNameNr_ItemType 7784
#define sipName_ItemType &sipStrings_QtGui[7784]
#define sipNameNr_Japanese 47436
#define sipName_Japanese &sipStrings_QtGui[47436]
#define sipNameNr_Keyboard 47445
#define sipName_Keyboard &sipStrings_QtGui[47445]
#define sipNameNr_LadyLips 47454
#define sipName_LadyLips &sipStrings_QtGui[47454]
#define sipNameNr_Language 17749
#define sipName_Language &sipStrings_QtGui[17749]
#define sipNameNr_ListDisc 47463
#define sipName_ListDisc &sipStrings_QtGui[47463]
#define sipNameNr_LoveKiss 47472
#define sipName_LoveKiss &sipStrings_QtGui[47472]
#define sipNameNr_MagicRay 47481
#define sipName_MagicRay &sipStrings_QtGui[47481]
#define sipNameNr_Midlight 47490
#define sipName_Midlight &sipStrings_QtGui[47490]
#define sipNameNr_MoleHall 47499
#define sipName_MoleHall &sipStrings_QtGui[47499]
#define sipNameNr_MoveMode 10351
#define sipName_MoveMode &sipStrings_QtGui[10351]
#define sipNameNr_NearMoon 47508
#define sipName_NearMoon &sipStrings_QtGui[47508]
#define sipNameNr_NextCell 47517
#define sipName_NextCell &sipStrings_QtGui[47517]
#define sipNameNr_NextWord 26463
#define sipName_NextWord &sipStrings_QtGui[26463]
#define sipNameNr_NightSky 47526
#define sipName_NightSky &sipStrings_QtGui[47526]
#define sipNameNr_NoDevice 47535
#define sipName_NoDevice &sipStrings_QtGui[47535]
#define sipNameNr_NoFormat 47544
#define sipName_NoFormat &sipStrings_QtGui[47544]
#define sipNameNr_NoMarker 47553
#define sipName_NoMarker &sipStrings_QtGui[47553]
#define sipNameNr_NoObject 47562
#define sipName_NoObject &sipStrings_QtGui[47562]
#define sipNameNr_Notation 5018
#define sipName_Notation &sipStrings_QtGui[5018]
#define sipNameNr_OneValue 47571
#define sipName_OneValue &sipStrings_QtGui[47571]
#define sipNameNr_OpenGLES 42970
#define sipName_OpenGLES &sipStrings_QtGui[42970]
#define sipNameNr_Overline 25408
#define sipName_Overline &sipStrings_QtGui[25408]
#define sipNameNr_PageSize 4632
#define sipName_PageSize &sipStrings_QtGui[4632]
#define sipNameNr_PaloAlto 47580
#define sipName_PaloAlto &sipStrings_QtGui[47580]
#define sipNameNr_PdmDepth 47589
#define sipName_PdmDepth &sipStrings_QtGui[47589]
#define sipNameNr_PdmWidth 47598
#define sipName_PdmWidth &sipStrings_QtGui[47598]
#define sipNameNr_PlumBath 47607
#define sipName_PlumBath &sipStrings_QtGui[47607]
#define sipNameNr_Portrait 42981
#define sipName_Portrait &sipStrings_QtGui[42981]
#define sipNameNr_Position 4660
#define sipName_Position &sipStrings_QtGui[4660]
#define sipNameNr_Postcard 26118
#define sipName_Postcard &sipStrings_QtGui[26118]
#define sipNameNr_Pressure 17582
#define sipName_Pressure &sipStrings_QtGui[17582]
#define sipNameNr_Property 10417
#define sipName_Property &sipStrings_QtGui[10417]
#define sipNameNr_QPainter 47616
#define sipName_QPainter &sipStrings_QtGui[47616]
#define sipNameNr_QPalette 47625
#define sipName_QPalette &sipStrings_QtGui[47625]
#define sipNameNr_QPicture 47634
#define sipName_QPicture &sipStrings_QtGui[47634]
#define sipNameNr_QPolygon 47643
#define sipName_QPolygon &sipStrings_QtGui[47643]
#define sipNameNr_QRawFont 47652
#define sipName_QRawFont &sipStrings_QtGui[47652]
#define sipNameNr_QSurface 47661
#define sipName_QSurface &sipStrings_QtGui[47661]
#define sipNameNr_R8_SNorm 47670
#define sipName_R8_SNorm &sipStrings_QtGui[47670]
#define sipNameNr_R8_UNorm 47679
#define sipName_R8_UNorm &sipStrings_QtGui[47679]
#define sipNameNr_RG11B10F 23824
#define sipName_RG11B10F &sipStrings_QtGui[23824]
#define sipNameNr_RGB_DXT1 45087
#define sipName_RGB_DXT1 &sipStrings_QtGui[45087]
#define sipNameNr_RareWind 47688
#define sipName_RareWind &sipStrings_QtGui[47688]
#define sipNameNr_ReadOnly 47697
#define sipName_ReadOnly &sipStrings_QtGui[47697]
#define sipNameNr_RedValue 47706
#define sipName_RedValue &sipStrings_QtGui[47706]
#define sipNameNr_RightTab 47715
#define sipName_RightTab &sipStrings_QtGui[47715]
#define sipNameNr_Seashore 47724
#define sipName_Seashore &sipStrings_QtGui[47724]
#define sipNameNr_Selected 47733
#define sipName_Selected &sipStrings_QtGui[47733]
#define sipNameNr_Severity 3063
#define sipName_Severity &sipStrings_QtGui[3063]
#define sipNameNr_StarWine 47742
#define sipName_StarWine &sipStrings_QtGui[47742]
#define sipNameNr_Target1D 22768
#define sipName_Target1D &sipStrings_QtGui[22768]
#define sipNameNr_Target2D 22784
#define sipName_Target2D &sipStrings_QtGui[22784]
#define sipNameNr_Target3D 22800
#define sipName_Target3D &sipStrings_QtGui[22800]
#define sipNameNr_TouchPad 47751
#define sipName_TouchPad &sipStrings_QtGui[47751]
#define sipNameNr_Trailing 47760
#define sipName_Trailing &sipStrings_QtGui[47760]
#define sipNameNr_TxRotate 47769
#define sipName_TxRotate &sipStrings_QtGui[47769]
#define sipNameNr_UserType 47778
#define sipName_UserType &sipStrings_QtGui[47778]
#define sipNameNr_Velocity 20053
#define sipName_Velocity &sipStrings_QtGui[20053]
#define sipNameNr_Windowed 47787
#define sipName_Windowed &sipStrings_QtGui[47787]
#define sipNameNr_WordLeft 47796
#define sipName_WordLeft &sipStrings_QtGui[47796]
#define sipNameNr_WordWrap 47805
#define sipName_WordWrap &sipStrings_QtGui[47805]
#define sipNameNr_WrapMode 6771
#define sipName_WrapMode &sipStrings_QtGui[6771]
#define sipNameNr_YUV420SP 47814
#define sipName_YUV420SP &sipStrings_QtGui[47814]
#define sipNameNr___bool__ 47823
#define sipName___bool__ &sipStrings_QtGui[47823]
#define sipNameNr___exit__ 47832
#define sipName___exit__ &sipStrings_QtGui[47832]
#define sipNameNr___hash__ 47841
#define sipName___hash__ &sipStrings_QtGui[47841]
#define sipNameNr___iadd__ 47850
#define sipName___iadd__ &sipStrings_QtGui[47850]
#define sipNameNr___iand__ 47859
#define sipName___iand__ &sipStrings_QtGui[47859]
#define sipNameNr___imul__ 47868
#define sipName___imul__ &sipStrings_QtGui[47868]
#define sipNameNr___isub__ 47877
#define sipName___isub__ &sipStrings_QtGui[47877]
#define sipNameNr___ixor__ 47886
#define sipName___ixor__ &sipStrings_QtGui[47886]
#define sipNameNr___repr__ 47895
#define sipName___repr__ &sipStrings_QtGui[47895]
#define sipNameNr_allocate 47904
#define sipName_allocate &sipStrings_QtGui[47904]
#define sipNameNr_anchorAt 47913
#define sipName_anchorAt &sipStrings_QtGui[47913]
#define sipNameNr_baseSize 47922
#define sipName_baseSize &sipStrings_QtGui[47922]
#define sipNameNr_blueSize 47931
#define sipName_blueSize &sipStrings_QtGui[47931]
#define sipNameNr_bufferId 47940
#define sipName_bufferId &sipStrings_QtGui[47940]
#define sipNameNr_cacheKey 47949
#define sipName_cacheKey &sipStrings_QtGui[47949]
#define sipNameNr_canWrite 8528
#define sipName_canWrite &sipStrings_QtGui[8528]
#define sipNameNr_capStyle 47958
#define sipName_capStyle &sipStrings_QtGui[47958]
#define sipNameNr_capacity 47967
#define sipName_capacity &sipStrings_QtGui[47967]
#define sipNameNr_clipPath 47976
#define sipName_clipPath &sipStrings_QtGui[47976]
#define sipNameNr_clipRect 47985
#define sipName_clipRect &sipStrings_QtGui[47985]
#define sipNameNr_contains 47994
#define sipName_contains &sipStrings_QtGui[47994]
#define sipNameNr_cornsilk 48003
#define sipName_cornsilk &sipStrings_QtGui[48003]
#define sipNameNr_cyanSize 48012
#define sipName_cyanSize &sipStrings_QtGui[48012]
#define sipNameNr_darkblue 48021
#define sipName_darkblue &sipStrings_QtGui[48021]
#define sipNameNr_darkcyan 48030
#define sipName_darkcyan &sipStrings_QtGui[48030]
#define sipNameNr_darkgray 48039
#define sipName_darkgray &sipStrings_QtGui[48039]
#define sipNameNr_darkgrey 48048
#define sipName_darkgrey &sipStrings_QtGui[48048]
#define sipNameNr_decimals 48057
#define sipName_decimals &sipStrings_QtGui[48057]
#define sipNameNr_deeppink 48066
#define sipName_deeppink &sipStrings_QtGui[48066]
#define sipNameNr_document 48075
#define sipName_document &sipStrings_QtGui[48075]
#define sipNameNr_drawLine 48084
#define sipName_drawLine &sipStrings_QtGui[48084]
#define sipNameNr_drawPath 48093
#define sipName_drawPath &sipStrings_QtGui[48093]
#define sipNameNr_drawRect 48102
#define sipName_drawRect &sipStrings_QtGui[48102]
#define sipNameNr_drawText 48111
#define sipName_drawText &sipStrings_QtGui[48111]
#define sipNameNr_encoding 48120
#define sipName_encoding &sipStrings_QtGui[48120]
#define sipNameNr_endPaint 48129
#define sipName_endPaint &sipStrings_QtGui[48129]
#define sipNameNr_families 48138
#define sipName_families &sipStrings_QtGui[48138]
#define sipNameNr_farPlane 48147
#define sipName_farPlane &sipStrings_QtGui[48147]
#define sipNameNr_features 48156
#define sipName_features &sipStrings_QtGui[48156]
#define sipNameNr_fileName 48165
#define sipName_fileName &sipStrings_QtGui[48165]
#define sipNameNr_filePath 48174
#define sipName_filePath &sipStrings_QtGui[48174]
#define sipNameNr_fillPath 48183
#define sipName_fillPath &sipStrings_QtGui[48183]
#define sipNameNr_fillRect 48192
#define sipName_fillRect &sipStrings_QtGui[48192]
#define sipNameNr_fillRule 48201
#define sipName_fillRule &sipStrings_QtGui[48201]
#define sipNameNr_finished 48210
#define sipName_finished &sipStrings_QtGui[48210]
#define sipNameNr_fontInfo 48219
#define sipName_fontInfo &sipStrings_QtGui[48219]
#define sipNameNr_formatAt 48228
#define sipName_formatAt &sipStrings_QtGui[48228]
#define sipNameNr_fragment 48237
#define sipName_fragment &sipStrings_QtGui[48237]
#define sipNameNr_fromAxes 48246
#define sipName_fromAxes &sipStrings_QtGui[48246]
#define sipNameNr_fromCmyk 48255
#define sipName_fromCmyk &sipStrings_QtGui[48255]
#define sipNameNr_fromData 48264
#define sipName_fromData &sipStrings_QtGui[48264]
#define sipNameNr_fromFont 48273
#define sipName_fromFont &sipStrings_QtGui[48273]
#define sipNameNr_fromHslF 48282
#define sipName_fromHslF &sipStrings_QtGui[48282]
#define sipNameNr_fromHsvF 48291
#define sipName_fromHsvF &sipStrings_QtGui[48291]
#define sipNameNr_fromHtml 48300
#define sipName_fromHtml &sipStrings_QtGui[48300]
#define sipNameNr_fromRgbF 48309
#define sipName_fromRgbF &sipStrings_QtGui[48309]
#define sipNameNr_fromRgba 48318
#define sipName_fromRgba &sipStrings_QtGui[48318]
#define sipNameNr_fullRect 48327
#define sipName_fullRect &sipStrings_QtGui[48327]
#define sipNameNr_geometry 48336
#define sipName_geometry &sipStrings_QtGui[48336]
#define sipNameNr_getCmykF 48345
#define sipName_getCmykF &sipStrings_QtGui[48345]
#define sipNameNr_gotFocus 48354
#define sipName_gotFocus &sipStrings_QtGui[48354]
#define sipNameNr_gradient 48363
#define sipName_gradient &sipStrings_QtGui[48363]
#define sipNameNr_hasAlpha 48372
#define sipName_hasAlpha &sipStrings_QtGui[48372]
#define sipNameNr_heightMM 48381
#define sipName_heightMM &sipStrings_QtGui[48381]
#define sipNameNr_honeydew 48390
#define sipName_honeydew &sipStrings_QtGui[48390]
#define sipNameNr_iconName 48399
#define sipName_iconName &sipStrings_QtGui[48399]
#define sipNameNr_inverted 48408
#define sipName_inverted &sipStrings_QtGui[48408]
#define sipNameNr_ioDevice 48417
#define sipName_ioDevice &sipStrings_QtGui[48417]
#define sipNameNr_isActive 48426
#define sipName_isActive &sipStrings_QtGui[48426]
#define sipNameNr_isAffine 48435
#define sipName_isAffine &sipStrings_QtGui[48435]
#define sipNameNr_isAnchor 48444
#define sipName_isAnchor &sipStrings_QtGui[48444]
#define sipNameNr_isClosed 48453
#define sipName_isClosed &sipStrings_QtGui[48453]
#define sipNameNr_isCopyOf 48462
#define sipName_isCopyOf &sipStrings_QtGui[48462]
#define sipNameNr_isLineTo 48471
#define sipName_isLineTo &sipStrings_QtGui[48471]
#define sipNameNr_isLinked 48480
#define sipName_isLinked &sipStrings_QtGui[48480]
#define sipNameNr_isMoveTo 48489
#define sipName_isMoveTo &sipStrings_QtGui[48489]
#define sipNameNr_isOpaque 48498
#define sipName_isOpaque &sipStrings_QtGui[48498]
#define sipNameNr_itemData 48507
#define sipName_itemData &sipStrings_QtGui[48507]
#define sipNameNr_itemText 48516
#define sipName_itemText &sipStrings_QtGui[48516]
#define sipNameNr_iterator 12088
#define sipName_iterator &sipStrings_QtGui[12088]
#define sipNameNr_lavender 48525
#define sipName_lavender &sipStrings_QtGui[48525]
#define sipNameNr_localPos 48534
#define sipName_localPos &sipStrings_QtGui[48534]
#define sipNameNr_magentaF 48543
#define sipName_magentaF &sipStrings_QtGui[48543]
#define sipNameNr_mapRange 48552
#define sipName_mapRange &sipStrings_QtGui[48552]
#define sipNameNr_maxWidth 48561
#define sipName_maxWidth &sipStrings_QtGui[48561]
#define sipNameNr_midlight 48570
#define sipName_midlight &sipStrings_QtGui[48570]
#define sipNameNr_mimeData 48579
#define sipName_mimeData &sipStrings_QtGui[48579]
#define sipNameNr_mimeType 48588
#define sipName_mimeType &sipStrings_QtGui[48588]
#define sipNameNr_mirrored 48597
#define sipName_mirrored &sipStrings_QtGui[48597]
#define sipNameNr_mnemonic 3573
#define sipName_mnemonic &sipStrings_QtGui[3573]
#define sipNameNr_moccasin 48606
#define sipName_moccasin &sipStrings_QtGui[48606]
#define sipNameNr_modality 48615
#define sipName_modality &sipStrings_QtGui[48615]
#define sipNameNr_moveRows 43399
#define sipName_moveRows &sipStrings_QtGui[43399]
#define sipNameNr_notation 48624
#define sipName_notation &sipStrings_QtGui[48624]
#define sipNameNr_objectId 48633
#define sipName_objectId &sipStrings_QtGui[48633]
#define sipNameNr_oldState 48642
#define sipName_oldState &sipStrings_QtGui[48642]
#define sipNameNr_openFile 48651
#define sipName_openFile &sipStrings_QtGui[48651]
#define sipNameNr_optimize 48660
#define sipName_optimize &sipStrings_QtGui[48660]
#define sipNameNr_overline 48669
#define sipName_overline &sipStrings_QtGui[48669]
#define sipNameNr_pageSize 48678
#define sipName_pageSize &sipStrings_QtGui[48678]
#define sipNameNr_popGroup 48687
#define sipName_popGroup &sipStrings_QtGui[48687]
#define sipNameNr_position 48696
#define sipName_position &sipStrings_QtGui[48696]
#define sipNameNr_pressure 48705
#define sipName_pressure &sipStrings_QtGui[48705]
#define sipNameNr_previous 48714
#define sipName_previous &sipStrings_QtGui[48714]
#define sipNameNr_property 48723
#define sipName_property &sipStrings_QtGui[48723]
#define sipNameNr_rawValue 48732
#define sipName_rawValue &sipStrings_QtGui[48732]
#define sipNameNr_resizeGL 48741
#define sipName_resizeGL &sipStrings_QtGui[48741]
#define sipNameNr_resource 48750
#define sipName_resource &sipStrings_QtGui[48750]
#define sipNameNr_revision 48759
#define sipName_revision &sipStrings_QtGui[48759]
#define sipNameNr_rotation 48768
#define sipName_rotation &sipStrings_QtGui[48768]
#define sipNameNr_rowCount 48777
#define sipName_rowCount &sipStrings_QtGui[48777]
#define sipNameNr_rowStart 48786
#define sipName_rowStart &sipStrings_QtGui[48786]
#define sipNameNr_scanLine 48795
#define sipName_scanLine &sipStrings_QtGui[48795]
#define sipNameNr_scenePos 48804
#define sipName_scenePos &sipStrings_QtGui[48804]
#define sipNameNr_screenAt 48813
#define sipName_screenAt &sipStrings_QtGui[48813]
#define sipNameNr_seagreen 27963
#define sipName_seagreen &sipStrings_QtGui[27963]
#define sipNameNr_seashell 48822
#define sipName_seashell &sipStrings_QtGui[48822]
#define sipNameNr_setAlpha 48831
#define sipName_setAlpha &sipStrings_QtGui[48831]
#define sipNameNr_setAngle 48840
#define sipName_setAngle &sipStrings_QtGui[48840]
#define sipNameNr_setBlueF 48849
#define sipName_setBlueF &sipStrings_QtGui[48849]
#define sipNameNr_setBrush 48858
#define sipName_setBrush &sipStrings_QtGui[48858]
#define sipNameNr_setChild 48867
#define sipName_setChild &sipStrings_QtGui[48867]
#define sipNameNr_setCmykF 48876
#define sipName_setCmykF &sipStrings_QtGui[48876]
#define sipNameNr_setCodec 48885
#define sipName_setCodec &sipStrings_QtGui[48885]
#define sipNameNr_setColor 48894
#define sipName_setColor &sipStrings_QtGui[48894]
#define sipNameNr_setFlags 48903
#define sipName_setFlags &sipStrings_QtGui[48903]
#define sipNameNr_setGamma 48912
#define sipName_setGamma &sipStrings_QtGui[48912]
#define sipNameNr_setGreen 48921
#define sipName_setGreen &sipStrings_QtGui[48921]
#define sipNameNr_setImage 48930
#define sipName_setImage &sipStrings_QtGui[48930]
#define sipNameNr_setPixel 48939
#define sipName_setPixel &sipStrings_QtGui[48939]
#define sipNameNr_setPoint 48948
#define sipName_setPoint &sipStrings_QtGui[48948]
#define sipNameNr_setRange 48957
#define sipName_setRange &sipStrings_QtGui[48957]
#define sipNameNr_setRects 48966
#define sipName_setRects &sipStrings_QtGui[48966]
#define sipNameNr_setShape 48975
#define sipName_setShape &sipStrings_QtGui[48975]
#define sipNameNr_setSpeed 48984
#define sipName_setSpeed &sipStrings_QtGui[48984]
#define sipNameNr_setStart 48993
#define sipName_setStart &sipStrings_QtGui[48993]
#define sipNameNr_setStops 49002
#define sipName_setStops &sipStrings_QtGui[49002]
#define sipNameNr_setStyle 49011
#define sipName_setStyle &sipStrings_QtGui[49011]
#define sipNameNr_setTitle 49020
#define sipName_setTitle &sipStrings_QtGui[49020]
#define sipNameNr_setUnits 49029
#define sipName_setUnits &sipStrings_QtGui[49029]
#define sipNameNr_setValue 49038
#define sipName_setValue &sipStrings_QtGui[49038]
#define sipNameNr_setWidth 49047
#define sipName_setWidth &sipStrings_QtGui[49047]
#define sipNameNr_severity 49056
#define sipName_severity &sipStrings_QtGui[49056]
#define sipNameNr_shaderId 49065
#define sipName_shaderId &sipStrings_QtGui[49065]
#define sipNameNr_sizeHint 49074
#define sipName_sizeHint &sipStrings_QtGui[49074]
#define sipNameNr_skipRows 49083
#define sipName_skipRows &sipStrings_QtGui[49083]
#define sipNameNr_sortRole 49092
#define sipName_sortRole &sipStrings_QtGui[49092]
#define sipNameNr_startPos 49101
#define sipName_startPos &sipStrings_QtGui[49101]
#define sipNameNr_strategy 49110
#define sipName_strategy &sipStrings_QtGui[49110]
#define sipNameNr_tabArray 49119
#define sipName_tabArray &sipStrings_QtGui[49119]
#define sipNameNr_tabStops 49128
#define sipName_tabStops &sipStrings_QtGui[49128]
#define sipNameNr_takeItem 49137
#define sipName_takeItem &sipStrings_QtGui[49137]
#define sipNameNr_textKeys 49146
#define sipName_textKeys &sipStrings_QtGui[49146]
#define sipNameNr_textList 49155
#define sipName_textList &sipStrings_QtGui[49155]
#define sipNameNr_textures 49164
#define sipName_textures &sipStrings_QtGui[49164]
#define sipNameNr_toArgb32 49173
#define sipName_toArgb32 &sipStrings_QtGui[49173]
#define sipNameNr_toPointF 49182
#define sipName_toPointF &sipStrings_QtGui[49182]
#define sipNameNr_toString 49191
#define sipName_toString &sipStrings_QtGui[49191]
#define sipNameNr_uniqueId 49200
#define sipName_uniqueId &sipStrings_QtGui[49200]
#define sipNameNr_userData 49209
#define sipName_userData &sipStrings_QtGui[49209]
#define sipNameNr_validate 23680
#define sipName_validate &sipStrings_QtGui[23680]
#define sipNameNr_velocity 49218
#define sipName_velocity &sipStrings_QtGui[49218]
#define sipNameNr_vertical 49227
#define sipName_vertical &sipStrings_QtGui[49227]
#define sipNameNr_viewport 49236
#define sipName_viewport &sipStrings_QtGui[49236]
#define sipNameNr_wrapMode 49245
#define sipName_wrapMode &sipStrings_QtGui[49245]
#define sipNameNr_xChanged 49254
#define sipName_xChanged &sipStrings_QtGui[49254]
#define sipNameNr_yChanged 7096
#define sipName_yChanged &sipStrings_QtGui[7096]
#define sipNameNr_A3Extra 49263
#define sipName_A3Extra &sipStrings_QtGui[49263]
#define sipNameNr_A4Extra 49271
#define sipName_A4Extra &sipStrings_QtGui[49271]
#define sipNameNr_A4Small 49279
#define sipName_A4Small &sipStrings_QtGui[49279]
#define sipNameNr_A5Extra 49287
#define sipName_A5Extra &sipStrings_QtGui[49287]
#define sipNameNr_AnyType 49295
#define sipName_AnyType &sipStrings_QtGui[49295]
#define sipNameNr_B5Extra 49303
#define sipName_B5Extra &sipStrings_QtGui[49303]
#define sipNameNr_Bengali 49311
#define sipName_Bengali &sipStrings_QtGui[49311]
#define sipNameNr_Blitter 10176
#define sipName_Blitter &sipStrings_QtGui[10176]
#define sipNameNr_Checked 49319
#define sipName_Checked &sipStrings_QtGui[49319]
#define sipNameNr_Comm10E 49327
#define sipName_Comm10E &sipStrings_QtGui[49327]
#define sipNameNr_Compute 49335
#define sipName_Compute &sipStrings_QtGui[49335]
#define sipNameNr_Courier 49343
#define sipName_Courier &sipStrings_QtGui[49343]
#define sipNameNr_Current 38561
#define sipName_Current &sipStrings_QtGui[38561]
#define sipNameNr_Cursive 49351
#define sipName_Cursive &sipStrings_QtGui[49351]
#define sipNameNr_DarkRed 49359
#define sipName_DarkRed &sipStrings_QtGui[49359]
#define sipNameNr_DotLine 26089
#define sipName_DotLine &sipStrings_QtGui[26089]
#define sipNameNr_Element 10264
#define sipName_Element &sipStrings_QtGui[10264]
#define sipNameNr_Ellipse 38573
#define sipName_Ellipse &sipStrings_QtGui[38573]
#define sipNameNr_Fantasy 49367
#define sipName_Fantasy &sipStrings_QtGui[49367]
#define sipNameNr_Feature 1459
#define sipName_Feature &sipStrings_QtGui[1459]
#define sipNameNr_Float16 49375
#define sipName_Float16 &sipStrings_QtGui[49375]
#define sipNameNr_Float32 49383
#define sipName_Float32 &sipStrings_QtGui[49383]
#define sipNameNr_FlyHigh 49391
#define sipName_FlyHigh &sipStrings_QtGui[49391]
#define sipNameNr_Forward 49399
#define sipName_Forward &sipStrings_QtGui[49399]
#define sipNameNr_HexArgb 49407
#define sipName_HexArgb &sipStrings_QtGui[49407]
#define sipNameNr_Indexed 49415
#define sipName_Indexed &sipStrings_QtGui[49415]
#define sipNameNr_Invalid 26194
#define sipName_Invalid &sipStrings_QtGui[26194]
#define sipNameNr_Kannada 49423
#define sipName_Kannada &sipStrings_QtGui[49423]
#define sipNameNr_Leading 49431
#define sipName_Leading &sipStrings_QtGui[49431]
#define sipNameNr_LeftTab 49439
#define sipName_LeftTab &sipStrings_QtGui[49439]
#define sipNameNr_LibGLES 49447
#define sipName_LibGLES &sipStrings_QtGui[49447]
#define sipNameNr_Magenta 36929
#define sipName_Magenta &sipStrings_QtGui[36929]
#define sipNameNr_Margins 5127
#define sipName_Margins &sipStrings_QtGui[5127]
#define sipNameNr_MaxUser 49455
#define sipName_MaxUser &sipStrings_QtGui[49455]
#define sipNameNr_Myanmar 49463
#define sipName_Myanmar &sipStrings_QtGui[49463]
#define sipNameNr_Nearest 11837
#define sipName_Nearest &sipStrings_QtGui[11837]
#define sipNameNr_NewLife 49471
#define sipName_NewLife &sipStrings_QtGui[49471]
#define sipNameNr_NewYork 49479
#define sipName_NewYork &sipStrings_QtGui[49479]
#define sipNameNr_NextRow 49487
#define sipName_NextRow &sipStrings_QtGui[49487]
#define sipNameNr_NoMatch 49495
#define sipName_NoMatch &sipStrings_QtGui[49495]
#define sipNameNr_OpenGL2 49503
#define sipName_OpenGL2 &sipStrings_QtGui[49503]
#define sipNameNr_OverSun 49511
#define sipName_OverSun &sipStrings_QtGui[49511]
#define sipNameNr_PdmDpiX 49519
#define sipName_PdmDpiX &sipStrings_QtGui[49519]
#define sipNameNr_PdmDpiY 49527
#define sipName_PdmDpiY &sipStrings_QtGui[49527]
#define sipNameNr_Picture 38585
#define sipName_Picture &sipStrings_QtGui[38585]
#define sipNameNr_QAction 49535
#define sipName_QAction &sipStrings_QtGui[49535]
#define sipNameNr_QBitmap 45968
#define sipName_QBitmap &sipStrings_QtGui[45968]
#define sipNameNr_QCursor 49543
#define sipName_QCursor &sipStrings_QtGui[49543]
#define sipNameNr_QPixmap 49551
#define sipName_QPixmap &sipStrings_QtGui[49551]
#define sipNameNr_QRegion 49559
#define sipName_QRegion &sipStrings_QtGui[49559]
#define sipNameNr_QRgba64 49567
#define sipName_QRgba64 &sipStrings_QtGui[49567]
#define sipNameNr_QScreen 49575
#define sipName_QScreen &sipStrings_QtGui[49575]
#define sipNameNr_QWindow 49583
#define sipName_QWindow &sipStrings_QtGui[49583]
#define sipNameNr_Quality 29879
#define sipName_Quality &sipStrings_QtGui[29879]
#define sipNameNr_RGB10A2 27079
#define sipName_RGB10A2 &sipStrings_QtGui[27079]
#define sipNameNr_RGBA16F 49591
#define sipName_RGBA16F &sipStrings_QtGui[49591]
#define sipNameNr_RGBA16I 49599
#define sipName_RGBA16I &sipStrings_QtGui[49599]
#define sipNameNr_RGBA16U 49607
#define sipName_RGBA16U &sipStrings_QtGui[49607]
#define sipNameNr_RGBA32F 49615
#define sipName_RGBA32F &sipStrings_QtGui[49615]
#define sipNameNr_RGBA32I 49623
#define sipName_RGBA32I &sipStrings_QtGui[49623]
#define sipNameNr_RGBA32U 49631
#define sipName_RGBA32U &sipStrings_QtGui[49631]
#define sipNameNr_Refresh 49639
#define sipName_Refresh &sipStrings_QtGui[49639]
#define sipNameNr_Replace 49647
#define sipName_Replace &sipStrings_QtGui[49647]
#define sipNameNr_Running 41178
#define sipName_Running &sipStrings_QtGui[41178]
#define sipNameNr_SeaLord 49655
#define sipName_SeaLord &sipStrings_QtGui[49655]
#define sipNameNr_Sinhala 49663
#define sipName_Sinhala &sipStrings_QtGui[49663]
#define sipNameNr_Sources 3836
#define sipName_Sources &sipStrings_QtGui[3836]
#define sipNameNr_Stencil 11711
#define sipName_Stencil &sipStrings_QtGui[11711]
#define sipNameNr_Stretch 26614
#define sipName_Stretch &sipStrings_QtGui[26614]
#define sipNameNr_SubType 43741
#define sipName_SubType &sipStrings_QtGui[43741]
#define sipNameNr_Swizzle 19838
#define sipName_Swizzle &sipStrings_QtGui[19838]
#define sipNameNr_TabType 12152
#define sipName_TabType &sipStrings_QtGui[12152]
#define sipNameNr_Tabloid 49671
#define sipName_Tabloid &sipStrings_QtGui[49671]
#define sipNameNr_Tibetan 49679
#define sipName_Tibetan &sipStrings_QtGui[49679]
#define sipNameNr_TxScale 49687
#define sipName_TxScale &sipStrings_QtGui[49687]
#define sipNameNr_TxShear 49695
#define sipName_TxShear &sipStrings_QtGui[49695]
#define sipNameNr_Windows 25857
#define sipName_Windows &sipStrings_QtGui[25857]
#define sipNameNr_YUV420P 49703
#define sipName_YUV420P &sipStrings_QtGui[49703]
#define sipNameNr_ZoomOut 49711
#define sipName_ZoomOut &sipStrings_QtGui[49711]
#define sipNameNr___add__ 49719
#define sipName___add__ &sipStrings_QtGui[49719]
#define sipNameNr___and__ 49727
#define sipName___and__ &sipStrings_QtGui[49727]
#define sipNameNr___int__ 49735
#define sipName___int__ &sipStrings_QtGui[49735]
#define sipNameNr___ior__ 49743
#define sipName___ior__ &sipStrings_QtGui[49743]
#define sipNameNr___len__ 49751
#define sipName___len__ &sipStrings_QtGui[49751]
#define sipNameNr___mul__ 49759
#define sipName___mul__ &sipStrings_QtGui[49759]
#define sipNameNr___neg__ 49767
#define sipName___neg__ &sipStrings_QtGui[49767]
#define sipNameNr___sub__ 49775
#define sipName___sub__ &sipStrings_QtGui[49775]
#define sipNameNr___xor__ 49783
#define sipName___xor__ &sipStrings_QtGui[49783]
#define sipNameNr_addFile 49791
#define sipName_addFile &sipStrings_QtGui[49791]
#define sipNameNr_addPath 49799
#define sipName_addPath &sipStrings_QtGui[49799]
#define sipNameNr_addRect 49807
#define sipName_addRect &sipStrings_QtGui[49807]
#define sipNameNr_addText 49815
#define sipName_addText &sipStrings_QtGui[49815]
#define sipNameNr_adjoint 49823
#define sipName_adjoint &sipStrings_QtGui[49823]
#define sipNameNr_allGray 49831
#define sipName_allGray &sipStrings_QtGui[49831]
#define sipNameNr_atStart 49839
#define sipName_atStart &sipStrings_QtGui[49839]
#define sipNameNr_autorep 49847
#define sipName_autorep &sipStrings_QtGui[49847]
#define sipNameNr_baseUrl 49855
#define sipName_baseUrl &sipStrings_QtGui[49855]
#define sipNameNr_buffers 49863
#define sipName_buffers &sipStrings_QtGui[49863]
#define sipNameNr_buttons 49871
#define sipName_buttons &sipStrings_QtGui[49871]
#define sipNameNr_canRead 49879
#define sipName_canRead &sipStrings_QtGui[49879]
#define sipNameNr_changed 49887
#define sipName_changed &sipStrings_QtGui[49887]
#define sipNameNr_cleanup 49895
#define sipName_cleanup &sipStrings_QtGui[49895]
#define sipNameNr_columns 49903
#define sipName_columns &sipStrings_QtGui[49903]
#define sipNameNr_combine 49911
#define sipName_combine &sipStrings_QtGui[49911]
#define sipNameNr_context 49919
#define sipName_context &sipStrings_QtGui[49919]
#define sipNameNr_creator 49927
#define sipName_creator &sipStrings_QtGui[49927]
#define sipNameNr_crimson 49935
#define sipName_crimson &sipStrings_QtGui[49935]
#define sipNameNr_cubicTo 49943
#define sipName_cubicTo &sipStrings_QtGui[49943]
#define sipNameNr_darkred 49951
#define sipName_darkred &sipStrings_QtGui[49951]
#define sipNameNr_descent 49959
#define sipName_descent &sipStrings_QtGui[49959]
#define sipNameNr_destroy 49967
#define sipName_destroy &sipStrings_QtGui[49967]
#define sipNameNr_devType 49975
#define sipName_devType &sipStrings_QtGui[49975]
#define sipNameNr_devices 49983
#define sipName_devices &sipStrings_QtGui[49983]
#define sipNameNr_dimgray 49991
#define sipName_dimgray &sipStrings_QtGui[49991]
#define sipNameNr_dimgrey 49999
#define sipName_dimgrey &sipStrings_QtGui[49999]
#define sipNameNr_drawArc 50007
#define sipName_drawArc &sipStrings_QtGui[50007]
#define sipNameNr_drawPie 50015
#define sipName_drawPie &sipStrings_QtGui[50015]
#define sipNameNr_enabled 50023
#define sipName_enabled &sipStrings_QtGui[50023]
#define sipNameNr_exposed 50031
#define sipName_exposed &sipStrings_QtGui[50031]
#define sipNameNr_fontDpi 50039
#define sipName_fontDpi &sipStrings_QtGui[50039]
#define sipNameNr_formats 50047
#define sipName_formats &sipStrings_QtGui[50047]
#define sipNameNr_fromHsl 50055
#define sipName_fromHsl &sipStrings_QtGui[50055]
#define sipNameNr_fromHsv 50063
#define sipName_fromHsv &sipStrings_QtGui[50063]
#define sipNameNr_fromRgb 50071
#define sipName_fromRgb &sipStrings_QtGui[50071]
#define sipNameNr_frustum 50079
#define sipName_frustum &sipStrings_QtGui[50079]
#define sipNameNr_fuchsia 50087
#define sipName_fuchsia &sipStrings_QtGui[50087]
#define sipNameNr_getAxes 50095
#define sipName_getAxes &sipStrings_QtGui[50095]
#define sipNameNr_getCmyk 50103
#define sipName_getCmyk &sipStrings_QtGui[50103]
#define sipNameNr_getHslF 50111
#define sipName_getHslF &sipStrings_QtGui[50111]
#define sipNameNr_getHsvF 50119
#define sipName_getHsvF &sipStrings_QtGui[50119]
#define sipNameNr_getRgbF 50127
#define sipName_getRgbF &sipStrings_QtGui[50127]
#define sipNameNr_globalX 50135
#define sipName_globalX &sipStrings_QtGui[50135]
#define sipNameNr_globalY 50143
#define sipName_globalY &sipStrings_QtGui[50143]
#define sipNameNr_hitTest 50151
#define sipName_hitTest &sipStrings_QtGui[50151]
#define sipNameNr_hotSpot 50159
#define sipName_hotSpot &sipStrings_QtGui[50159]
#define sipNameNr_hotpink 50167
#define sipName_hotpink &sipStrings_QtGui[50167]
#define sipNameNr_hslHueF 50175
#define sipName_hslHueF &sipStrings_QtGui[50175]
#define sipNameNr_hsvHueF 50183
#define sipName_hsvHueF &sipStrings_QtGui[50183]
#define sipNameNr_hueSize 50191
#define sipName_hueSize &sipStrings_QtGui[50191]
#define sipNameNr_imageAt 50199
#define sipName_imageAt &sipStrings_QtGui[50199]
#define sipNameNr_indexOf 50207
#define sipName_indexOf &sipStrings_QtGui[50207]
#define sipNameNr_isBound 50215
#define sipName_isBound &sipStrings_QtGui[50215]
#define sipNameNr_isEmpty 50223
#define sipName_isEmpty &sipStrings_QtGui[50223]
#define sipNameNr_isEqual 50231
#define sipName_isEqual &sipStrings_QtGui[50231]
#define sipNameNr_isModal 50239
#define sipName_isModal &sipStrings_QtGui[50239]
#define sipNameNr_isSolid 50247
#define sipName_isSolid &sipStrings_QtGui[50247]
#define sipNameNr_isValid 50255
#define sipName_isValid &sipStrings_QtGui[50255]
#define sipNameNr_kerning 50263
#define sipName_kerning &sipStrings_QtGui[50263]
#define sipNameNr_lastPos 50271
#define sipName_lastPos &sipStrings_QtGui[50271]
#define sipNameNr_leading 50279
#define sipName_leading &sipStrings_QtGui[50279]
#define sipNameNr_lighter 15873
#define sipName_lighter &sipStrings_QtGui[15873]
#define sipNameNr_magenta 38477
#define sipName_magenta &sipStrings_QtGui[38477]
#define sipNameNr_mapRect 50287
#define sipName_mapRect &sipStrings_QtGui[50287]
#define sipNameNr_margins 50295
#define sipName_margins &sipStrings_QtGui[50295]
#define sipNameNr_matches 50303
#define sipName_matches &sipStrings_QtGui[50303]
#define sipNameNr_message 50311
#define sipName_message &sipStrings_QtGui[50311]
#define sipNameNr_newPage 50319
#define sipName_newPage &sipStrings_QtGui[50319]
#define sipNameNr_oldPosF 50327
#define sipName_oldPosF &sipStrings_QtGui[50327]
#define sipNameNr_oldSize 50335
#define sipName_oldSize &sipStrings_QtGui[50335]
#define sipNameNr_oldlace 50343
#define sipName_oldlace &sipStrings_QtGui[50343]
#define sipNameNr_opacity 50351
#define sipName_opacity &sipStrings_QtGui[50351]
#define sipNameNr_openUrl 50359
#define sipName_openUrl &sipStrings_QtGui[50359]
#define sipNameNr_options 50367
#define sipName_options &sipStrings_QtGui[50367]
#define sipNameNr_padding 50375
#define sipName_padding &sipStrings_QtGui[50375]
#define sipNameNr_paintGL 50383
#define sipName_paintGL &sipStrings_QtGui[50383]
#define sipNameNr_painter 50391
#define sipName_painter &sipStrings_QtGui[50391]
#define sipNameNr_palette 50399
#define sipName_palette &sipStrings_QtGui[50399]
#define sipNameNr_picture 50407
#define sipName_picture &sipStrings_QtGui[50407]
#define sipNameNr_prepare 50415
#define sipName_prepare &sipStrings_QtGui[50415]
#define sipNameNr_prepend 50423
#define sipName_prepend &sipStrings_QtGui[50423]
#define sipNameNr_profile 50431
#define sipName_profile &sipStrings_QtGui[50431]
#define sipNameNr_project 47088
#define sipName_project &sipStrings_QtGui[47088]
#define sipNameNr_qIsGray 50439
#define sipName_qIsGray &sipStrings_QtGui[50439]
#define sipNameNr_qRgba64 50447
#define sipName_qRgba64 &sipStrings_QtGui[50447]
#define sipNameNr_quality 50455
#define sipName_quality &sipStrings_QtGui[50455]
#define sipNameNr_queries 50463
#define sipName_queries &sipStrings_QtGui[50463]
#define sipNameNr_rawFont 50471
#define sipName_rawFont &sipStrings_QtGui[50471]
#define sipNameNr_rawMode 3244
#define sipName_rawMode &sipStrings_QtGui[3244]
#define sipNameNr_rawName 50479
#define sipName_rawName &sipStrings_QtGui[50479]
#define sipNameNr_redSize 50487
#define sipName_redSize &sipStrings_QtGui[50487]
#define sipNameNr_release 50495
#define sipName_release &sipStrings_QtGui[50495]
#define sipNameNr_replace 50503
#define sipName_replace &sipStrings_QtGui[50503]
#define sipNameNr_reserve 50511
#define sipName_reserve &sipStrings_QtGui[50511]
#define sipNameNr_resized 50519
#define sipName_resized &sipStrings_QtGui[50519]
#define sipNameNr_resolve 50527
#define sipName_resolve &sipStrings_QtGui[50527]
#define sipNameNr_restore 50535
#define sipName_restore &sipStrings_QtGui[50535]
#define sipNameNr_rowSpan 50543
#define sipName_rowSpan &sipStrings_QtGui[50543]
#define sipNameNr_samples 50551
#define sipName_samples &sipStrings_QtGui[50551]
#define sipNameNr_scaling 50559
#define sipName_scaling &sipStrings_QtGui[50559]
#define sipNameNr_screens 50567
#define sipName_screens &sipStrings_QtGui[50567]
#define sipNameNr_setBlue 50575
#define sipName_setBlue &sipStrings_QtGui[50575]
#define sipNameNr_setBold 50583
#define sipName_setBold &sipStrings_QtGui[50583]
#define sipNameNr_setCmyk 50591
#define sipName_setCmyk &sipStrings_QtGui[50591]
#define sipNameNr_setData 50599
#define sipName_setData &sipStrings_QtGui[50599]
#define sipNameNr_setFlag 50607
#define sipName_setFlag &sipStrings_QtGui[50607]
#define sipNameNr_setFont 50615
#define sipName_setFont &sipStrings_QtGui[50615]
#define sipNameNr_setHslF 50623
#define sipName_setHslF &sipStrings_QtGui[50623]
#define sipNameNr_setHsvF 50631
#define sipName_setHsvF &sipStrings_QtGui[50631]
#define sipNameNr_setHtml 50639
#define sipName_setHtml &sipStrings_QtGui[50639]
#define sipNameNr_setIcon 50647
#define sipName_setIcon &sipStrings_QtGui[50647]
#define sipNameNr_setItem 50655
#define sipName_setItem &sipStrings_QtGui[50655]
#define sipNameNr_setMask 50663
#define sipName_setMask &sipStrings_QtGui[50663]
#define sipNameNr_setMode 50671
#define sipName_setMode &sipStrings_QtGui[50671]
#define sipNameNr_setName 50679
#define sipName_setName &sipStrings_QtGui[50679]
#define sipNameNr_setRedF 50687
#define sipName_setRedF &sipStrings_QtGui[50687]
#define sipNameNr_setRgbF 50695
#define sipName_setRgbF &sipStrings_QtGui[50695]
#define sipNameNr_setRgba 50703
#define sipName_setRgba &sipStrings_QtGui[50703]
#define sipNameNr_setSize 50711
#define sipName_setSize &sipStrings_QtGui[50711]
#define sipNameNr_setTabs 50719
#define sipName_setTabs &sipStrings_QtGui[50719]
#define sipNameNr_setText 50727
#define sipName_setText &sipStrings_QtGui[50727]
#define sipNameNr_setType 50735
#define sipName_setType &sipStrings_QtGui[50735]
#define sipNameNr_shaders 50743
#define sipName_shaders &sipStrings_QtGui[50743]
#define sipNameNr_sibling 50751
#define sipName_sibling &sipStrings_QtGui[50751]
#define sipNameNr_skyblue 35561
#define sipName_skyblue &sipStrings_QtGui[35561]
#define sipNameNr_sources 50759
#define sipName_sources &sipStrings_QtGui[50759]
#define sipNameNr_started 50767
#define sipName_started &sipStrings_QtGui[50767]
#define sipNameNr_stretch 50775
#define sipName_stretch &sipStrings_QtGui[50775]
#define sipNameNr_subEnum 50783
#define sipName_subEnum &sipStrings_QtGui[50783]
#define sipNameNr_subType 50791
#define sipName_subType &sipStrings_QtGui[50791]
#define sipNameNr_surface 50799
#define sipName_surface &sipStrings_QtGui[50799]
#define sipNameNr_tabStop 50807
#define sipName_tabStop &sipStrings_QtGui[50807]
#define sipNameNr_takeRow 50815
#define sipName_takeRow &sipStrings_QtGui[50815]
#define sipNameNr_texture 50823
#define sipName_texture &sipStrings_QtGui[50823]
#define sipNameNr_thistle 50831
#define sipName_thistle &sipStrings_QtGui[50831]
#define sipNameNr_toImage 50839
#define sipName_toImage &sipStrings_QtGui[50839]
#define sipNameNr_toPoint 50847
#define sipName_toPoint &sipStrings_QtGui[50847]
#define sipNameNr_toRgb16 50855
#define sipName_toRgb16 &sipStrings_QtGui[50855]
#define sipNameNr_toolTip 50863
#define sipName_toolTip &sipStrings_QtGui[50863]
#define sipNameNr_updated 50871
#define sipName_updated &sipStrings_QtGui[50871]
#define sipNameNr_version 50879
#define sipName_version &sipStrings_QtGui[50879]
#define sipNameNr_widthMM 50887
#define sipName_widthMM &sipStrings_QtGui[50887]
#define sipNameNr_xHeight 50895
#define sipName_xHeight &sipStrings_QtGui[50895]
#define sipNameNr_yellowF 50903
#define sipName_yellowF &sipStrings_QtGui[50903]
#define sipNameNr_A4Plus 50911
#define sipName_A4Plus &sipStrings_QtGui[50911]
#define sipNameNr_Access 10155
#define sipName_Access &sipStrings_QtGui[10155]
#define sipNameNr_Action 11964
#define sipName_Action &sipStrings_QtGui[11964]
#define sipNameNr_Active 28130
#define sipName_Active &sipStrings_QtGui[28130]
#define sipNameNr_AddTab 50918
#define sipName_AddTab &sipStrings_QtGui[50918]
#define sipNameNr_Arabic 50925
#define sipName_Arabic &sipStrings_QtGui[50925]
#define sipNameNr_Binder 1427
#define sipName_Binder &sipStrings_QtGui[1427]
#define sipNameNr_Button 50932
#define sipName_Button &sipStrings_QtGui[50932]
#define sipNameNr_Cancel 50939
#define sipName_Cancel &sipStrings_QtGui[50939]
#define sipNameNr_Cicero 50946
#define sipName_Cicero &sipStrings_QtGui[50946]
#define sipNameNr_Color0 50953
#define sipName_Color0 &sipStrings_QtGui[50953]
#define sipNameNr_Color1 50960
#define sipName_Color1 &sipStrings_QtGui[50960]
#define sipNameNr_Cursor 11365
#define sipName_Cursor &sipStrings_QtGui[11365]
#define sipNameNr_Custom 50967
#define sipName_Custom &sipStrings_QtGui[50967]
#define sipNameNr_Delete 50974
#define sipName_Delete &sipStrings_QtGui[50974]
#define sipNameNr_Eraser 38154
#define sipName_Eraser &sipStrings_QtGui[38154]
#define sipNameNr_Filter 8972
#define sipName_Filter &sipStrings_QtGui[8972]
#define sipNameNr_Format 2423
#define sipName_Format &sipStrings_QtGui[2423]
#define sipNameNr_Hebrew 50981
#define sipName_Hebrew &sipStrings_QtGui[50981]
#define sipNameNr_HexRgb 50988
#define sipName_HexRgb &sipStrings_QtGui[50988]
#define sipNameNr_Hidden 50995
#define sipName_Hidden &sipStrings_QtGui[50995]
#define sipNameNr_InFlow 51002
#define sipName_InFlow &sipStrings_QtGui[51002]
#define sipNameNr_Italic 32260
#define sipName_Italic &sipStrings_QtGui[32260]
#define sipNameNr_JisB10 51009
#define sipName_JisB10 &sipStrings_QtGui[51009]
#define sipNameNr_Korean 51016
#define sipName_Korean &sipStrings_QtGui[51016]
#define sipNameNr_Ledger 51023
#define sipName_Ledger &sipStrings_QtGui[51023]
#define sipNameNr_Letter 51030
#define sipName_Letter &sipStrings_QtGui[51030]
#define sipNameNr_Linear 13813
#define sipName_Linear &sipStrings_QtGui[13813]
#define sipNameNr_Medium 51037
#define sipName_Medium &sipStrings_QtGui[51037]
#define sipNameNr_NoMove 51044
#define sipName_NoMove &sipStrings_QtGui[51044]
#define sipNameNr_NoRole 51051
#define sipName_NoRole &sipStrings_QtGui[51051]
#define sipNameNr_NoWrap 51058
#define sipName_NoWrap &sipStrings_QtGui[51058]
#define sipNameNr_Normal 36702
#define sipName_Normal &sipStrings_QtGui[36702]
#define sipNameNr_OldHat 51065
#define sipName_OldHat &sipStrings_QtGui[51065]
#define sipNameNr_OpenGL 9777
#define sipName_OpenGL &sipStrings_QtGui[9777]
#define sipNameNr_OpenVG 51072
#define sipName_OpenVG &sipStrings_QtGui[51072]
#define sipNameNr_Origin 3155
#define sipName_Origin &sipStrings_QtGui[3155]
#define sipNameNr_Paused 46739
#define sipName_Paused &sipStrings_QtGui[46739]
#define sipNameNr_Prc16K 51079
#define sipName_Prc16K &sipStrings_QtGui[51079]
#define sipNameNr_Prc32K 51086
#define sipName_Prc32K &sipStrings_QtGui[51086]
#define sipNameNr_Preset 18201
#define sipName_Preset &sipStrings_QtGui[18201]
#define sipNameNr_QBrush 51093
#define sipName_QBrush &sipStrings_QtGui[51093]
#define sipNameNr_QColor 51100
#define sipName_QColor &sipStrings_QtGui[51100]
#define sipNameNr_QImage 51107
#define sipName_QImage &sipStrings_QtGui[51107]
#define sipNameNr_QMovie 51114
#define sipName_QMovie &sipStrings_QtGui[51114]
#define sipNameNr_Quarto 51121
#define sipName_Quarto &sipStrings_QtGui[51121]
#define sipNameNr_R5G6B5 30510
#define sipName_R5G6B5 &sipStrings_QtGui[30510]
#define sipNameNr_RGB16F 51128
#define sipName_RGB16F &sipStrings_QtGui[51128]
#define sipNameNr_RGB16I 51135
#define sipName_RGB16I &sipStrings_QtGui[51135]
#define sipNameNr_RGB16U 51142
#define sipName_RGB16U &sipStrings_QtGui[51142]
#define sipNameNr_RGB32F 51149
#define sipName_RGB32F &sipStrings_QtGui[51149]
#define sipNameNr_RGB32I 51156
#define sipName_RGB32I &sipStrings_QtGui[51156]
#define sipNameNr_RGB32U 51163
#define sipName_RGB32U &sipStrings_QtGui[51163]
#define sipNameNr_RGB5A1 30524
#define sipName_RGB5A1 &sipStrings_QtGui[30524]
#define sipNameNr_RGB9E5 51170
#define sipName_RGB9E5 &sipStrings_QtGui[51170]
#define sipNameNr_RGBA8I 51177
#define sipName_RGBA8I &sipStrings_QtGui[51177]
#define sipNameNr_RGBA8U 51184
#define sipName_RGBA8U &sipStrings_QtGui[51184]
#define sipNameNr_Raster 51191
#define sipName_Raster &sipStrings_QtGui[51191]
#define sipNameNr_Reason 5820
#define sipName_Reason &sipStrings_QtGui[5820]
#define sipNameNr_Repeat 18075
#define sipName_Repeat &sipStrings_QtGui[18075]
#define sipNameNr_SaveAs 51198
#define sipName_SaveAs &sipStrings_QtGui[51198]
#define sipNameNr_Shadow 51205
#define sipName_Shadow &sipStrings_QtGui[51205]
#define sipNameNr_Source 4522
#define sipName_Source &sipStrings_QtGui[4522]
#define sipNameNr_Spread 18219
#define sipName_Spread &sipStrings_QtGui[18219]
#define sipNameNr_Stacks 10375
#define sipName_Stacks &sipStrings_QtGui[10375]
#define sipNameNr_Stylus 26915
#define sipName_Stylus &sipStrings_QtGui[26915]
#define sipNameNr_SuperA 51212
#define sipName_SuperA &sipStrings_QtGui[51212]
#define sipNameNr_SuperB 51219
#define sipName_SuperB &sipStrings_QtGui[51219]
#define sipNameNr_Symbol 51226
#define sipName_Symbol &sipStrings_QtGui[51226]
#define sipNameNr_Syriac 51233
#define sipName_Syriac &sipStrings_QtGui[51233]
#define sipNameNr_System 3721
#define sipName_System &sipStrings_QtGui[3721]
#define sipNameNr_Target 3095
#define sipName_Target &sipStrings_QtGui[3095]
#define sipNameNr_Telugu 51240
#define sipName_Telugu &sipStrings_QtGui[51240]
#define sipNameNr_Thaana 51247
#define sipName_Thaana &sipStrings_QtGui[51247]
#define sipNameNr_TxNone 51254
#define sipName_TxNone &sipStrings_QtGui[51254]
#define sipNameNr_UInt16 51261
#define sipName_UInt16 &sipStrings_QtGui[51261]
#define sipNameNr_UInt32 51268
#define sipName_UInt32 &sipStrings_QtGui[51268]
#define sipNameNr_Vertex 51275
#define sipName_Vertex &sipStrings_QtGui[51275]
#define sipNameNr_Weight 29936
#define sipName_Weight &sipStrings_QtGui[29936]
#define sipNameNr_Window 15798
#define sipName_Window &sipStrings_QtGui[15798]
#define sipNameNr_YUV411 51282
#define sipName_YUV411 &sipStrings_QtGui[51282]
#define sipNameNr_YUV422 51289
#define sipName_YUV422 &sipStrings_QtGui[51289]
#define sipNameNr_YUV444 51296
#define sipName_YUV444 &sipStrings_QtGui[51296]
#define sipNameNr_Yellow 40409
#define sipName_Yellow &sipStrings_QtGui[40409]
#define sipNameNr_ZoomIn 51303
#define sipName_ZoomIn &sipStrings_QtGui[51303]
#define sipNameNr___eq__ 51310
#define sipName___eq__ &sipStrings_QtGui[51310]
#define sipNameNr___ge__ 51317
#define sipName___ge__ &sipStrings_QtGui[51317]
#define sipNameNr___gt__ 51324
#define sipName___gt__ &sipStrings_QtGui[51324]
#define sipNameNr___le__ 51331
#define sipName___le__ &sipStrings_QtGui[51331]
#define sipNameNr___lt__ 51338
#define sipName___lt__ &sipStrings_QtGui[51338]
#define sipNameNr___ne__ 51345
#define sipName___ne__ &sipStrings_QtGui[51345]
#define sipNameNr___or__ 51352
#define sipName___or__ &sipStrings_QtGui[51352]
#define sipNameNr_accept 51359
#define sipName_accept &sipStrings_QtGui[51359]
#define sipNameNr_action 51366
#define sipName_action &sipStrings_QtGui[51366]
#define sipNameNr_alpha8 51373
#define sipName_alpha8 &sipStrings_QtGui[51373]
#define sipNameNr_alphaF 51380
#define sipName_alphaF &sipStrings_QtGui[51380]
#define sipNameNr_anchor 51387
#define sipName_anchor &sipStrings_QtGui[51387]
#define sipNameNr_append 51394
#define sipName_append &sipStrings_QtGui[51394]
#define sipNameNr_ascent 51401
#define sipName_ascent &sipStrings_QtGui[51401]
#define sipNameNr_before 51408
#define sipName_before &sipStrings_QtGui[51408]
#define sipNameNr_bisque 51415
#define sipName_bisque &sipStrings_QtGui[51415]
#define sipNameNr_bitmap 51422
#define sipName_bitmap &sipStrings_QtGui[51422]
#define sipNameNr_blackF 51429
#define sipName_blackF &sipStrings_QtGui[51429]
#define sipNameNr_border 51436
#define sipName_border &sipStrings_QtGui[51436]
#define sipNameNr_bottom 51443
#define sipName_bottom &sipStrings_QtGui[51443]
#define sipNameNr_button 51450
#define sipName_button &sipStrings_QtGui[51450]
#define sipNameNr_cancel 51457
#define sipName_cancel &sipStrings_QtGui[51457]
#define sipNameNr_cellAt 51464
#define sipName_cellAt &sipStrings_QtGui[51464]
#define sipNameNr_center 51471
#define sipName_center &sipStrings_QtGui[51471]
#define sipNameNr_closed 51478
#define sipName_closed &sipStrings_QtGui[51478]
#define sipNameNr_column 51485
#define sipName_column &sipStrings_QtGui[51485]
#define sipNameNr_commit 51492
#define sipName_commit &sipStrings_QtGui[51492]
#define sipNameNr_create 51499
#define sipName_create &sipStrings_QtGui[51499]
#define sipNameNr_cursor 51506
#define sipName_cursor &sipStrings_QtGui[51506]
#define sipNameNr_darker 51513
#define sipName_darker &sipStrings_QtGui[51513]
#define sipNameNr_detach 51520
#define sipName_detach &sipStrings_QtGui[51520]
#define sipNameNr_device 51527
#define sipName_device &sipStrings_QtGui[51527]
#define sipNameNr_factor 51534
#define sipName_factor &sipStrings_QtGui[51534]
#define sipNameNr_family 51541
#define sipName_family &sipStrings_QtGui[51541]
#define sipNameNr_filter 51548
#define sipName_filter &sipStrings_QtGui[51548]
#define sipNameNr_format 24626
#define sipName_format &sipStrings_QtGui[24626]
#define sipNameNr_getHsl 51555
#define sipName_getHsl &sipStrings_QtGui[51555]
#define sipNameNr_getHsv 51562
#define sipName_getHsv &sipStrings_QtGui[51562]
#define sipNameNr_getRgb 51569
#define sipName_getRgb &sipStrings_QtGui[51569]
#define sipNameNr_green8 51576
#define sipName_green8 &sipStrings_QtGui[51576]
#define sipNameNr_greenF 51583
#define sipName_greenF &sipStrings_QtGui[51583]
#define sipNameNr_handle 51590
#define sipName_handle &sipStrings_QtGui[51590]
#define sipNameNr_height 51597
#define sipName_height &sipStrings_QtGui[51597]
#define sipNameNr_hslHue 51604
#define sipName_hslHue &sipStrings_QtGui[51604]
#define sipNameNr_hsvHue 51611
#define sipName_hsvHue &sipStrings_QtGui[51611]
#define sipNameNr_ignore 51618
#define sipName_ignore &sipStrings_QtGui[51618]
#define sipNameNr_inFont 51625
#define sipName_inFont &sipStrings_QtGui[51625]
#define sipNameNr_indent 51632
#define sipName_indent &sipStrings_QtGui[51632]
#define sipNameNr_indigo 51639
#define sipName_indigo &sipStrings_QtGui[51639]
#define sipNameNr_insert 51646
#define sipName_insert &sipStrings_QtGui[51646]
#define sipNameNr_isMask 51653
#define sipName_isMask &sipStrings_QtGui[51653]
#define sipNameNr_isNull 51660
#define sipName_isNull &sipStrings_QtGui[51660]
#define sipNameNr_italic 51667
#define sipName_italic &sipStrings_QtGui[51667]
#define sipNameNr_layers 51674
#define sipName_layers &sipStrings_QtGui[51674]
#define sipNameNr_layout 51681
#define sipName_layout &sipStrings_QtGui[51681]
#define sipNameNr_length 51688
#define sipName_length &sipStrings_QtGui[51688]
#define sipNameNr_lineAt 51695
#define sipName_lineAt &sipStrings_QtGui[51695]
#define sipNameNr_lineTo 51702
#define sipName_lineTo &sipStrings_QtGui[51702]
#define sipNameNr_locale 51709
#define sipName_locale &sipStrings_QtGui[51709]
#define sipNameNr_lookAt 51716
#define sipName_lookAt &sipStrings_QtGui[51716]
#define sipNameNr_margin 51723
#define sipName_margin &sipStrings_QtGui[51723]
#define sipNameNr_marker 51730
#define sipName_marker &sipStrings_QtGui[51730]
#define sipNameNr_maroon 51737
#define sipName_maroon &sipStrings_QtGui[51737]
#define sipNameNr_matrix 51744
#define sipName_matrix &sipStrings_QtGui[51744]
#define sipNameNr_metric 51751
#define sipName_metric &sipStrings_QtGui[51751]
#define sipNameNr_mipmap 51758
#define sipName_mipmap &sipStrings_QtGui[51758]
#define sipNameNr_moveTo 51765
#define sipName_moveTo &sipStrings_QtGui[51765]
#define sipNameNr_normal 51772
#define sipName_normal &sipStrings_QtGui[51772]
#define sipNameNr_notify 51779
#define sipName_notify &sipStrings_QtGui[51779]
#define sipNameNr_object 51786
#define sipName_object &sipStrings_QtGui[51786]
#define sipNameNr_offset 51793
#define sipName_offset &sipStrings_QtGui[51793]
#define sipNameNr_oldPos 51800
#define sipName_oldPos &sipStrings_QtGui[51800]
#define sipNameNr_option 51807
#define sipName_option &sipStrings_QtGui[51807]
#define sipNameNr_orange 42367
#define sipName_orange &sipStrings_QtGui[42367]
#define sipNameNr_orchid 35692
#define sipName_orchid &sipStrings_QtGui[35692]
#define sipNameNr_parent 31434
#define sipName_parent &sipStrings_QtGui[31434]
#define sipNameNr_pixmap 51814
#define sipName_pixmap &sipStrings_QtGui[51814]
#define sipNameNr_print_ 51821
#define sipName_print_ &sipStrings_QtGui[51821]
#define sipNameNr_purple 35705
#define sipName_purple &sipStrings_QtGui[35705]
#define sipNameNr_qAlpha 51828
#define sipName_qAlpha &sipStrings_QtGui[51828]
#define sipNameNr_qGreen 51835
#define sipName_qGreen &sipStrings_QtGui[51835]
#define sipNameNr_quadTo 51842
#define sipName_quadTo &sipStrings_QtGui[51842]
#define sipNameNr_radius 51849
#define sipName_radius &sipStrings_QtGui[51849]
#define sipNameNr_raise_ 51856
#define sipName_raise_ &sipStrings_QtGui[51856]
#define sipNameNr_reason 51863
#define sipName_reason &sipStrings_QtGui[51863]
#define sipNameNr_rebind 51870
#define sipName_rebind &sipStrings_QtGui[51870]
#define sipNameNr_regExp 51877
#define sipName_regExp &sipStrings_QtGui[51877]
#define sipNameNr_region 51884
#define sipName_region &sipStrings_QtGui[51884]
#define sipNameNr_remove 51891
#define sipName_remove &sipStrings_QtGui[51891]
#define sipNameNr_resize 51898
#define sipName_resize &sipStrings_QtGui[51898]
#define sipNameNr_revert 51905
#define sipName_revert &sipStrings_QtGui[51905]
#define sipNameNr_rgba64 51912
#define sipName_rgba64 &sipStrings_QtGui[51912]
#define sipNameNr_rotate 51919
#define sipName_rotate &sipStrings_QtGui[51919]
#define sipNameNr_rowEnd 51926
#define sipName_rowEnd &sipStrings_QtGui[51926]
#define sipNameNr_salmon 39114
#define sipName_salmon &sipStrings_QtGui[39114]
#define sipNameNr_scalar 51933
#define sipName_scalar &sipStrings_QtGui[51933]
#define sipNameNr_scaleX 51940
#define sipName_scaleX &sipStrings_QtGui[51940]
#define sipNameNr_scaleY 51947
#define sipName_scaleY &sipStrings_QtGui[51947]
#define sipNameNr_scaled 51954
#define sipName_scaled &sipStrings_QtGui[51954]
#define sipNameNr_screen 44759
#define sipName_screen &sipStrings_QtGui[44759]
#define sipNameNr_scroll 51961
#define sipName_scroll &sipStrings_QtGui[51961]
#define sipNameNr_select 47339
#define sipName_select &sipStrings_QtGui[47339]
#define sipNameNr_setHsl 51968
#define sipName_setHsl &sipStrings_QtGui[51968]
#define sipNameNr_setHsv 51975
#define sipName_setHsv &sipStrings_QtGui[51975]
#define sipNameNr_setPen 51982
#define sipName_setPen &sipStrings_QtGui[51982]
#define sipNameNr_setPos 51989
#define sipName_setPos &sipStrings_QtGui[51989]
#define sipNameNr_setRed 51996
#define sipName_setRed &sipStrings_QtGui[51996]
#define sipNameNr_setRgb 52003
#define sipName_setRgb &sipStrings_QtGui[52003]
#define sipNameNr_setRow 52010
#define sipName_setRow &sipStrings_QtGui[52010]
#define sipNameNr_setTop 52017
#define sipName_setTop &sipStrings_QtGui[52017]
#define sipNameNr_shadow 52024
#define sipName_shadow &sipStrings_QtGui[52024]
#define sipNameNr_shares 52031
#define sipName_shares &sipStrings_QtGui[52031]
#define sipNameNr_sienna 52038
#define sipName_sienna &sipStrings_QtGui[52038]
#define sipNameNr_silver 52045
#define sipName_silver &sipStrings_QtGui[52045]
#define sipNameNr_source 16102
#define sipName_source &sipStrings_QtGui[16102]
#define sipNameNr_spread 52052
#define sipName_spread &sipStrings_QtGui[52052]
#define sipNameNr_stacks 52059
#define sipName_stacks &sipStrings_QtGui[52059]
#define sipNameNr_status 52066
#define sipName_status &sipStrings_QtGui[52066]
#define sipNameNr_stereo 52073
#define sipName_stereo &sipStrings_QtGui[52073]
#define sipNameNr_stride 52080
#define sipName_stride &sipStrings_QtGui[52080]
#define sipNameNr_styles 52087
#define sipName_styles &sipStrings_QtGui[52087]
#define sipNameNr_submit 52094
#define sipName_submit &sipStrings_QtGui[52094]
#define sipNameNr_target 52101
#define sipName_target &sipStrings_QtGui[52101]
#define sipNameNr_toCmyk 52108
#define sipName_toCmyk &sipStrings_QtGui[52108]
#define sipNameNr_toHtml 52115
#define sipName_toHtml &sipStrings_QtGui[52115]
#define sipNameNr_tomato 52122
#define sipName_tomato &sipStrings_QtGui[52122]
#define sipNameNr_united 52129
#define sipName_united &sipStrings_QtGui[52129]
#define sipNameNr_update 52136
#define sipName_update &sipStrings_QtGui[52136]
#define sipNameNr_valueF 52143
#define sipName_valueF &sipStrings_QtGui[52143]
#define sipNameNr_vector 52150
#define sipName_vector &sipStrings_QtGui[52150]
#define sipNameNr_violet 42147
#define sipName_violet &sipStrings_QtGui[42147]
#define sipNameNr_weight 52157
#define sipName_weight &sipStrings_QtGui[52157]
#define sipNameNr_widthF 52164
#define sipName_widthF &sipStrings_QtGui[52164]
#define sipNameNr_window 52171
#define sipName_window &sipStrings_QtGui[52171]
#define sipNameNr_yellow 12615
#define sipName_yellow &sipStrings_QtGui[12615]
#define sipNameNr_Alpha 19462
#define sipName_Alpha &sipStrings_QtGui[19462]
#define sipNameNr_AnsiA 52178
#define sipName_AnsiA &sipStrings_QtGui[52178]
#define sipNameNr_AnsiB 52184
#define sipName_AnsiB &sipStrings_QtGui[52184]
#define sipNameNr_AnsiC 52190
#define sipName_AnsiC &sipStrings_QtGui[52190]
#define sipNameNr_AnsiD 52196
#define sipName_AnsiD &sipStrings_QtGui[52196]
#define sipNameNr_AnsiE 52202
#define sipName_AnsiE &sipStrings_QtGui[52202]
#define sipNameNr_ArchA 52208
#define sipName_ArchA &sipStrings_QtGui[52208]
#define sipNameNr_ArchB 52214
#define sipName_ArchB &sipStrings_QtGui[52214]
#define sipNameNr_ArchC 52220
#define sipName_ArchC &sipStrings_QtGui[52220]
#define sipNameNr_ArchD 52226
#define sipName_ArchD &sipStrings_QtGui[52226]
#define sipNameNr_ArchE 52232
#define sipName_ArchE &sipStrings_QtGui[52232]
#define sipNameNr_AtEnd 52238
#define sipName_AtEnd &sipStrings_QtGui[52238]
#define sipNameNr_Black 52244
#define sipName_Black &sipStrings_QtGui[52244]
#define sipNameNr_Click 52250
#define sipName_Click &sipStrings_QtGui[52250]
#define sipNameNr_Close 52256
#define sipName_Close &sipStrings_QtGui[52256]
#define sipNameNr_D24S8 34562
#define sipName_D24S8 &sipStrings_QtGui[34562]
#define sipNameNr_Depth 35069
#define sipName_Depth &sipStrings_QtGui[35069]
#define sipNameNr_Didot 52262
#define sipName_Didot &sipStrings_QtGui[52262]
#define sipNameNr_Flags 787
#define sipName_Flags &sipStrings_QtGui[787]
#define sipNameNr_Folio 52268
#define sipName_Folio &sipStrings_QtGui[52268]
#define sipNameNr_Gamma 16616
#define sipName_Gamma &sipStrings_QtGui[16616]
#define sipNameNr_Greek 52274
#define sipName_Greek &sipStrings_QtGui[52274]
#define sipNameNr_Green 34484
#define sipName_Green &sipStrings_QtGui[34484]
#define sipNameNr_Int16 51262
#define sipName_Int16 &sipStrings_QtGui[51262]
#define sipNameNr_Int32 51269
#define sipName_Int32 &sipStrings_QtGui[51269]
#define sipNameNr_JisB0 52280
#define sipName_JisB0 &sipStrings_QtGui[52280]
#define sipNameNr_JisB1 52286
#define sipName_JisB1 &sipStrings_QtGui[52286]
#define sipNameNr_JisB2 52292
#define sipName_JisB2 &sipStrings_QtGui[52292]
#define sipNameNr_JisB3 52298
#define sipName_JisB3 &sipStrings_QtGui[52298]
#define sipNameNr_JisB4 52304
#define sipName_JisB4 &sipStrings_QtGui[52304]
#define sipNameNr_JisB5 52310
#define sipName_JisB5 &sipStrings_QtGui[52310]
#define sipNameNr_JisB6 52316
#define sipName_JisB6 &sipStrings_QtGui[52316]
#define sipNameNr_JisB7 52322
#define sipName_JisB7 &sipStrings_QtGui[52322]
#define sipNameNr_JisB8 52328
#define sipName_JisB8 &sipStrings_QtGui[52328]
#define sipNameNr_JisB9 52334
#define sipName_JisB9 &sipStrings_QtGui[52334]
#define sipNameNr_Khmer 52340
#define sipName_Khmer &sipStrings_QtGui[52340]
#define sipNameNr_Latin 52346
#define sipName_Latin &sipStrings_QtGui[52346]
#define sipNameNr_Legal 15324
#define sipName_Legal &sipStrings_QtGui[15324]
#define sipNameNr_LibGL 52352
#define sipName_LibGL &sipStrings_QtGui[52352]
#define sipNameNr_Light 5665
#define sipName_Light &sipStrings_QtGui[5665]
#define sipNameNr_Mouse 40784
#define sipName_Mouse &sipStrings_QtGui[40784]
#define sipNameNr_Ogham 52358
#define sipName_Ogham &sipStrings_QtGui[52358]
#define sipNameNr_Oriya 52364
#define sipName_Oriya &sipStrings_QtGui[52364]
#define sipNameNr_Other 52370
#define sipName_Other &sipStrings_QtGui[52370]
#define sipNameNr_Paste 52376
#define sipName_Paste &sipStrings_QtGui[52376]
#define sipNameNr_Point 7883
#define sipName_Point &sipStrings_QtGui[7883]
#define sipNameNr_Print 52382
#define sipName_Print &sipStrings_QtGui[52382]
#define sipNameNr_QDrag 52388
#define sipName_QDrag &sipStrings_QtGui[52388]
#define sipNameNr_QFont 52394
#define sipName_QFont &sipStrings_QtGui[52394]
#define sipNameNr_QIcon 52400
#define sipName_QIcon &sipStrings_QtGui[52400]
#define sipNameNr_RG16F 52406
#define sipName_RG16F &sipStrings_QtGui[52406]
#define sipNameNr_RG16I 52412
#define sipName_RG16I &sipStrings_QtGui[52412]
#define sipNameNr_RG16U 52418
#define sipName_RG16U &sipStrings_QtGui[52418]
#define sipNameNr_RG32F 52424
#define sipName_RG32F &sipStrings_QtGui[52424]
#define sipNameNr_RG32I 52430
#define sipName_RG32I &sipStrings_QtGui[52430]
#define sipNameNr_RG32U 52436
#define sipName_RG32U &sipStrings_QtGui[52436]
#define sipNameNr_RG3B2 38119
#define sipName_RG3B2 &sipStrings_QtGui[38119]
#define sipNameNr_RGB8I 52442
#define sipName_RGB8I &sipStrings_QtGui[52442]
#define sipNameNr_RGB8U 52448
#define sipName_RGB8U &sipStrings_QtGui[52448]
#define sipNameNr_RGBA4 34549
#define sipName_RGBA4 &sipStrings_QtGui[34549]
#define sipNameNr_Right 31365
#define sipName_Right &sipStrings_QtGui[31365]
#define sipNameNr_Runic 52454
#define sipName_Runic &sipStrings_QtGui[52454]
#define sipNameNr_SRGB8 52460
#define sipName_SRGB8 &sipStrings_QtGui[52460]
#define sipNameNr_Serif 45100
#define sipName_Serif &sipStrings_QtGui[45100]
#define sipNameNr_Start 21924
#define sipName_Start &sipStrings_QtGui[21924]
#define sipNameNr_State 6055
#define sipName_State &sipStrings_QtGui[6055]
#define sipNameNr_Style 2078
#define sipName_Style &sipStrings_QtGui[2078]
#define sipNameNr_Tamil 52466
#define sipName_Tamil &sipStrings_QtGui[52466]
#define sipNameNr_Times 52472
#define sipName_Times &sipStrings_QtGui[52472]
#define sipNameNr_Token 52478
#define sipName_Token &sipStrings_QtGui[52478]
#define sipNameNr_Types 1028
#define sipName_Types &sipStrings_QtGui[1028]
#define sipNameNr_UInt8 52484
#define sipName_UInt8 &sipStrings_QtGui[52484]
#define sipNameNr_White 33873
#define sipName_White &sipStrings_QtGui[33873]
#define sipNameNr_alert 52490
#define sipName_alert &sipStrings_QtGui[52490]
#define sipNameNr_alpha 52496
#define sipName_alpha &sipStrings_QtGui[52496]
#define sipNameNr_angle 8674
#define sipName_angle &sipStrings_QtGui[8674]
#define sipNameNr_arcTo 52502
#define sipName_arcTo &sipStrings_QtGui[52502]
#define sipNameNr_atEnd 52508
#define sipName_atEnd &sipStrings_QtGui[52508]
#define sipNameNr_azure 52514
#define sipName_azure &sipStrings_QtGui[52514]
#define sipNameNr_begin 52520
#define sipName_begin &sipStrings_QtGui[52520]
#define sipNameNr_beige 52526
#define sipName_beige &sipStrings_QtGui[52526]
#define sipNameNr_black 52532
#define sipName_black &sipStrings_QtGui[52532]
#define sipNameNr_block 52538
#define sipName_block &sipStrings_QtGui[52538]
#define sipNameNr_blue8 52544
#define sipName_blue8 &sipStrings_QtGui[52544]
#define sipNameNr_blueF 52550
#define sipName_blueF &sipStrings_QtGui[52550]
#define sipNameNr_brown 39523
#define sipName_brown &sipStrings_QtGui[39523]
#define sipNameNr_brush 47178
#define sipName_brush &sipStrings_QtGui[47178]
#define sipNameNr_buddy 52556
#define sipName_buddy &sipStrings_QtGui[52556]
#define sipNameNr_child 52562
#define sipName_child &sipStrings_QtGui[52562]
#define sipNameNr_clear 52568
#define sipName_clear &sipStrings_QtGui[52568]
#define sipNameNr_clone 52574
#define sipName_clone &sipStrings_QtGui[52574]
#define sipNameNr_close 52580
#define sipName_close &sipStrings_QtGui[52580]
#define sipNameNr_codec 52586
#define sipName_codec &sipStrings_QtGui[52586]
#define sipNameNr_color 52592
#define sipName_color &sipStrings_QtGui[52592]
#define sipNameNr_coral 43072
#define sipName_coral &sipStrings_QtGui[43072]
#define sipNameNr_count 52598
#define sipName_count &sipStrings_QtGui[52598]
#define sipNameNr_cyanF 52604
#define sipName_cyanF &sipStrings_QtGui[52604]
#define sipNameNr_delim 52610
#define sipName_delim &sipStrings_QtGui[52610]
#define sipNameNr_depth 52616
#define sipName_depth &sipStrings_QtGui[52616]
#define sipNameNr_error 52622
#define sipName_error &sipStrings_QtGui[52622]
#define sipNameNr_event 52628
#define sipName_event &sipStrings_QtGui[52628]
#define sipNameNr_exec_ 52634
#define sipName_exec_ &sipStrings_QtGui[52634]
#define sipNameNr_faces 52640
#define sipName_faces &sipStrings_QtGui[52640]
#define sipNameNr_first 52646
#define sipName_first &sipStrings_QtGui[52646]
#define sipNameNr_fixup 52652
#define sipName_fixup &sipStrings_QtGui[52652]
#define sipNameNr_flags 52658
#define sipName_flags &sipStrings_QtGui[52658]
#define sipNameNr_flush 52664
#define sipName_flush &sipStrings_QtGui[52664]
#define sipNameNr_gamma 52670
#define sipName_gamma &sipStrings_QtGui[52670]
#define sipNameNr_green 19336
#define sipName_green &sipStrings_QtGui[19336]
#define sipNameNr_hints 52676
#define sipName_hints &sipStrings_QtGui[52676]
#define sipNameNr_image 52682
#define sipName_image &sipStrings_QtGui[52682]
#define sipNameNr_index 52688
#define sipName_index &sipStrings_QtGui[52688]
#define sipNameNr_ivory 52694
#define sipName_ivory &sipStrings_QtGui[52694]
#define sipNameNr_khaki 45630
#define sipName_khaki &sipStrings_QtGui[45630]
#define sipNameNr_light 39451
#define sipName_light &sipStrings_QtGui[39451]
#define sipNameNr_linen 52700
#define sipName_linen &sipStrings_QtGui[52700]
#define sipNameNr_lower 52706
#define sipName_lower &sipStrings_QtGui[52706]
#define sipNameNr_match 52712
#define sipName_match &sipStrings_QtGui[52712]
#define sipNameNr_merge 52718
#define sipName_merge &sipStrings_QtGui[52718]
#define sipNameNr_model 52724
#define sipName_model &sipStrings_QtGui[52724]
#define sipNameNr_nlerp 52730
#define sipName_nlerp &sipStrings_QtGui[52730]
#define sipNameNr_olive 52736
#define sipName_olive &sipStrings_QtGui[52736]
#define sipNameNr_order 10816
#define sipName_order &sipStrings_QtGui[10816]
#define sipNameNr_ortho 52742
#define sipName_ortho &sipStrings_QtGui[52742]
#define sipNameNr_paint 52748
#define sipName_paint &sipStrings_QtGui[52748]
#define sipNameNr_phase 52754
#define sipName_phase &sipStrings_QtGui[52754]
#define sipNameNr_pixel 52760
#define sipName_pixel &sipStrings_QtGui[52760]
#define sipNameNr_point 52766
#define sipName_point &sipStrings_QtGui[52766]
#define sipNameNr_print 52772
#define sipName_print &sipStrings_QtGui[52772]
#define sipNameNr_qBlue 52778
#define sipName_qBlue &sipStrings_QtGui[52778]
#define sipNameNr_qGray 52784
#define sipName_qGray &sipStrings_QtGui[52784]
#define sipNameNr_qRgba 52790
#define sipName_qRgba &sipStrings_QtGui[52790]
#define sipNameNr_rects 52796
#define sipName_rects &sipStrings_QtGui[52796]
#define sipNameNr_reset 18202
#define sipName_reset &sipStrings_QtGui[18202]
#define sipNameNr_right 52802
#define sipName_right &sipStrings_QtGui[52802]
#define sipNameNr_scale 11322
#define sipName_scale &sipStrings_QtGui[11322]
#define sipNameNr_shape 52808
#define sipName_shape &sipStrings_QtGui[52808]
#define sipNameNr_shear 52814
#define sipName_shear &sipStrings_QtGui[52814]
#define sipNameNr_sizes 52820
#define sipName_sizes &sipStrings_QtGui[52820]
#define sipNameNr_slerp 52826
#define sipName_slerp &sipStrings_QtGui[52826]
#define sipNameNr_speed 52832
#define sipName_speed &sipStrings_QtGui[52832]
#define sipNameNr_start 52838
#define sipName_start &sipStrings_QtGui[52838]
#define sipNameNr_state 25267
#define sipName_state &sipStrings_QtGui[25267]
#define sipNameNr_stops 52844
#define sipName_stops &sipStrings_QtGui[52844]
#define sipNameNr_style 52850
#define sipName_style &sipStrings_QtGui[52850]
#define sipNameNr_title 52856
#define sipName_title &sipStrings_QtGui[52856]
#define sipNameNr_toHsl 52862
#define sipName_toHsl &sipStrings_QtGui[52862]
#define sipNameNr_toHsv 52868
#define sipName_toHsv &sipStrings_QtGui[52868]
#define sipNameNr_toRgb 37543
#define sipName_toRgb &sipStrings_QtGui[37543]
#define sipNameNr_types 52874
#define sipName_types &sipStrings_QtGui[52874]
#define sipNameNr_units 52880
#define sipName_units &sipStrings_QtGui[52880]
#define sipNameNr_unmap 52886
#define sipName_unmap &sipStrings_QtGui[52886]
#define sipNameNr_valid 26196
#define sipName_valid &sipStrings_QtGui[26196]
#define sipNameNr_value 52892
#define sipName_value &sipStrings_QtGui[52892]
#define sipNameNr_wheat 52898
#define sipName_wheat &sipStrings_QtGui[52898]
#define sipNameNr_white 34718
#define sipName_white &sipStrings_QtGui[34718]
#define sipNameNr_width 52904
#define sipName_width &sipStrings_QtGui[52904]
#define sipNameNr_winId 52910
#define sipName_winId &sipStrings_QtGui[52910]
#define sipNameNr_write 52916
#define sipName_write &sipStrings_QtGui[52916]
#define sipNameNr_xTilt 52922
#define sipName_xTilt &sipStrings_QtGui[52922]
#define sipNameNr_xored 52928
#define sipName_xored &sipStrings_QtGui[52928]
#define sipNameNr_yTilt 52934
#define sipName_yTilt &sipStrings_QtGui[52934]
#define sipNameNr_Area 28762
#define sipName_Area &sipStrings_QtGui[28762]
#define sipNameNr_BGRA 52940
#define sipName_BGRA &sipStrings_QtGui[52940]
#define sipNameNr_Back 52945
#define sipName_Back &sipStrings_QtGui[52945]
#define sipNameNr_Base 29210
#define sipName_Base &sipStrings_QtGui[29210]
#define sipNameNr_Blue 37484
#define sipName_Blue &sipStrings_QtGui[37484]
#define sipNameNr_Bold 44441
#define sipName_Bold &sipStrings_QtGui[44441]
#define sipNameNr_CMYK 52950
#define sipName_CMYK &sipStrings_QtGui[52950]
#define sipNameNr_Cmyk 21840
#define sipName_Cmyk &sipStrings_QtGui[21840]
#define sipNameNr_Copy 37004
#define sipName_Copy &sipStrings_QtGui[37004]
#define sipNameNr_Cyan 47296
#define sipName_Cyan &sipStrings_QtGui[47296]
#define sipNameNr_D32F 52955
#define sipName_D32F &sipStrings_QtGui[52955]
#define sipNameNr_Dark 37520
#define sipName_Dark &sipStrings_QtGui[37520]
#define sipNameNr_Down 52960
#define sipName_Down &sipStrings_QtGui[52960]
#define sipNameNr_Edge 23588
#define sipName_Edge &sipStrings_QtGui[23588]
#define sipNameNr_Find 52965
#define sipName_Find &sipStrings_QtGui[52965]
#define sipNameNr_Flag 1063
#define sipName_Flag &sipStrings_QtGui[1063]
#define sipNameNr_Gray 44601
#define sipName_Gray &sipStrings_QtGui[44601]
#define sipNameNr_IMC1 52970
#define sipName_IMC1 &sipStrings_QtGui[52970]
#define sipNameNr_IMC2 52975
#define sipName_IMC2 &sipStrings_QtGui[52975]
#define sipNameNr_IMC3 52980
#define sipName_IMC3 &sipStrings_QtGui[52980]
#define sipNameNr_IMC4 52985
#define sipName_IMC4 &sipStrings_QtGui[52985]
#define sipNameNr_Inch 14755
#define sipName_Inch &sipStrings_QtGui[14755]
#define sipNameNr_Int8 52485
#define sipName_Int8 &sipStrings_QtGui[52485]
#define sipNameNr_Left 20837
#define sipName_Left &sipStrings_QtGui[20837]
#define sipNameNr_Link 52990
#define sipName_Link &sipStrings_QtGui[52990]
#define sipNameNr_Mode 1297
#define sipName_Mode &sipStrings_QtGui[1297]
#define sipNameNr_NV12 52995
#define sipName_NV12 &sipStrings_QtGui[52995]
#define sipNameNr_NV21 53000
#define sipName_NV21 &sipStrings_QtGui[53000]
#define sipNameNr_Name 6420
#define sipName_Name &sipStrings_QtGui[6420]
#define sipNameNr_Nega 53005
#define sipName_Nega &sipStrings_QtGui[53005]
#define sipNameNr_Note 53010
#define sipName_Note &sipStrings_QtGui[53010]
#define sipNameNr_Open 53015
#define sipName_Open &sipStrings_QtGui[53015]
#define sipNameNr_Pica 53020
#define sipName_Pica &sipStrings_QtGui[53020]
#define sipNameNr_Puck 53025
#define sipName_Puck &sipStrings_QtGui[53025]
#define sipNameNr_QPen 53030
#define sipName_QPen &sipStrings_QtGui[53030]
#define sipNameNr_Quit 53035
#define sipName_Quit &sipStrings_QtGui[53035]
#define sipNameNr_R16F 53040
#define sipName_R16F &sipStrings_QtGui[53040]
#define sipNameNr_R16I 53045
#define sipName_R16I &sipStrings_QtGui[53045]
#define sipNameNr_R16U 53050
#define sipName_R16U &sipStrings_QtGui[53050]
#define sipNameNr_R32F 53055
#define sipName_R32F &sipStrings_QtGui[53055]
#define sipNameNr_R32I 53060
#define sipName_R32I &sipStrings_QtGui[53060]
#define sipNameNr_R32U 53065
#define sipName_R32U &sipStrings_QtGui[53065]
#define sipNameNr_RG8I 53070
#define sipName_RG8I &sipStrings_QtGui[53070]
#define sipNameNr_RG8U 53075
#define sipName_RG8U &sipStrings_QtGui[53075]
#define sipNameNr_RGBA 53080
#define sipName_RGBA &sipStrings_QtGui[53080]
#define sipNameNr_Redo 53085
#define sipName_Redo &sipStrings_QtGui[53085]
#define sipNameNr_Ruby 53090
#define sipName_Ruby &sipStrings_QtGui[53090]
#define sipNameNr_SRgb 53095
#define sipName_SRgb &sipStrings_QtGui[53095]
#define sipNameNr_Save 53100
#define sipName_Save &sipStrings_QtGui[53100]
#define sipNameNr_Size 4636
#define sipName_Size &sipStrings_QtGui[4636]
#define sipNameNr_Spec 34004
#define sipName_Spec &sipStrings_QtGui[34004]
#define sipNameNr_Text 12470
#define sipName_Text &sipStrings_QtGui[12470]
#define sipNameNr_Thai 53105
#define sipName_Thai &sipStrings_QtGui[53105]
#define sipNameNr_Thin 53110
#define sipName_Thin &sipStrings_QtGui[53110]
#define sipNameNr_Type 280
#define sipName_Type &sipStrings_QtGui[280]
#define sipNameNr_UYVY 53115
#define sipName_UYVY &sipStrings_QtGui[53115]
#define sipNameNr_Undo 53120
#define sipName_Undo &sipStrings_QtGui[53120]
#define sipNameNr_Unit 11798
#define sipName_Unit &sipStrings_QtGui[11798]
#define sipNameNr_User 49458
#define sipName_User &sipStrings_QtGui[49458]
#define sipNameNr_YUYV 53125
#define sipName_YUYV &sipStrings_QtGui[53125]
#define sipNameNr_YV12 53130
#define sipName_YV12 &sipStrings_QtGui[53130]
#define sipNameNr_aqua 53135
#define sipName_aqua &sipStrings_QtGui[53135]
#define sipNameNr_axis 53140
#define sipName_axis &sipStrings_QtGui[53140]
#define sipNameNr_base 29952
#define sipName_base &sipStrings_QtGui[29952]
#define sipNameNr_bind 51872
#define sipName_bind &sipStrings_QtGui[51872]
#define sipNameNr_bits 53145
#define sipName_bits &sipStrings_QtGui[53145]
#define sipNameNr_blit 53150
#define sipName_blit &sipStrings_QtGui[53150]
#define sipNameNr_blue 24836
#define sipName_blue &sipStrings_QtGui[24836]
#define sipNameNr_bold 53155
#define sipName_bold &sipStrings_QtGui[53155]
#define sipNameNr_clip 53160
#define sipName_clip &sipStrings_QtGui[53160]
#define sipNameNr_copy 53165
#define sipName_copy &sipStrings_QtGui[53165]
#define sipNameNr_cyan 46051
#define sipName_cyan &sipStrings_QtGui[46051]
#define sipNameNr_dark 53170
#define sipName_dark &sipStrings_QtGui[53170]
#define sipNameNr_data 9641
#define sipName_data &sipStrings_QtGui[9641]
#define sipNameNr_draw 53175
#define sipName_draw &sipStrings_QtGui[53175]
#define sipNameNr_edge 53180
#define sipName_edge &sipStrings_QtGui[53180]
#define sipNameNr_exec 53185
#define sipName_exec &sipStrings_QtGui[53185]
#define sipNameNr_file 431
#define sipName_file &sipStrings_QtGui[431]
#define sipNameNr_fill 53190
#define sipName_fill &sipStrings_QtGui[53190]
#define sipNameNr_find 53195
#define sipName_find &sipStrings_QtGui[53195]
#define sipNameNr_font 53200
#define sipName_font &sipStrings_QtGui[53200]
#define sipNameNr_from 53205
#define sipName_from &sipStrings_QtGui[53205]
#define sipNameNr_gold 53210
#define sipName_gold &sipStrings_QtGui[53210]
#define sipNameNr_gray 27862
#define sipName_gray &sipStrings_QtGui[27862]
#define sipNameNr_grey 27877
#define sipName_grey &sipStrings_QtGui[27877]
#define sipNameNr_hide 53215
#define sipName_hide &sipStrings_QtGui[53215]
#define sipNameNr_hotX 53220
#define sipName_hotX &sipStrings_QtGui[53220]
#define sipNameNr_hotY 53225
#define sipName_hotY &sipStrings_QtGui[53225]
#define sipNameNr_href 53230
#define sipName_href &sipStrings_QtGui[53230]
#define sipNameNr_hueF 53235
#define sipName_hueF &sipStrings_QtGui[53235]
#define sipNameNr_icon 53240
#define sipName_icon &sipStrings_QtGui[53240]
#define sipNameNr_item 53245
#define sipName_item &sipStrings_QtGui[53245]
#define sipNameNr_join 53250
#define sipName_join &sipStrings_QtGui[53250]
#define sipNameNr_key2 53255
#define sipName_key2 &sipStrings_QtGui[53255]
#define sipNameNr_key3 53260
#define sipName_key3 &sipStrings_QtGui[53260]
#define sipNameNr_key4 53265
#define sipName_key4 &sipStrings_QtGui[53265]
#define sipNameNr_last 53270
#define sipName_last &sipStrings_QtGui[53270]
#define sipNameNr_left 53275
#define sipName_left &sipStrings_QtGui[53275]
#define sipNameNr_lime 53280
#define sipName_lime &sipStrings_QtGui[53280]
#define sipNameNr_link 53285
#define sipName_link &sipStrings_QtGui[53285]
#define sipNameNr_load 53290
#define sipName_load &sipStrings_QtGui[53290]
#define sipNameNr_mask 53295
#define sipName_mask &sipStrings_QtGui[53295]
#define sipNameNr_mode 53300
#define sipName_mode &sipStrings_QtGui[53300]
#define sipNameNr_name 53305
#define sipName_name &sipStrings_QtGui[53305]
#define sipNameNr_navy 53310
#define sipName_navy &sipStrings_QtGui[53310]
#define sipNameNr_next 53315
#define sipName_next &sipStrings_QtGui[53315]
#define sipNameNr_peru 53320
#define sipName_peru &sipStrings_QtGui[53320]
#define sipNameNr_pink 46091
#define sipName_pink &sipStrings_QtGui[46091]
#define sipNameNr_play 53325
#define sipName_play &sipStrings_QtGui[53325]
#define sipNameNr_plum 53330
#define sipName_plum &sipStrings_QtGui[53330]
#define sipNameNr_posF 53335
#define sipName_posF &sipStrings_QtGui[53335]
#define sipNameNr_qRed 53340
#define sipName_qRed &sipStrings_QtGui[53340]
#define sipNameNr_qRgb 53345
#define sipName_qRgb &sipStrings_QtGui[53345]
#define sipNameNr_read 18221
#define sipName_read &sipStrings_QtGui[18221]
#define sipNameNr_rect 53350
#define sipName_rect &sipStrings_QtGui[53350]
#define sipNameNr_red8 53355
#define sipName_red8 &sipStrings_QtGui[53355]
#define sipNameNr_redF 53360
#define sipName_redF &sipStrings_QtGui[53360]
#define sipNameNr_redo 53365
#define sipName_redo &sipStrings_QtGui[53365]
#define sipNameNr_rgba 53370
#define sipName_rgba &sipStrings_QtGui[53370]
#define sipNameNr_role 53375
#define sipName_role &sipStrings_QtGui[53375]
#define sipNameNr_rows 53380
#define sipName_rows &sipStrings_QtGui[53380]
#define sipNameNr_save 53385
#define sipName_save &sipStrings_QtGui[53385]
#define sipNameNr_setW 53390
#define sipName_setW &sipStrings_QtGui[53390]
#define sipNameNr_setX 53395
#define sipName_setX &sipStrings_QtGui[53395]
#define sipNameNr_setY 53400
#define sipName_setY &sipStrings_QtGui[53400]
#define sipNameNr_setZ 53405
#define sipName_setZ &sipStrings_QtGui[53405]
#define sipNameNr_show 53410
#define sipName_show &sipStrings_QtGui[53410]
#define sipNameNr_size 20075
#define sipName_size &sipStrings_QtGui[20075]
#define sipNameNr_snow 53415
#define sipName_snow &sipStrings_QtGui[53415]
#define sipNameNr_sort 53420
#define sipName_sort &sipStrings_QtGui[53420]
#define sipNameNr_span 53425
#define sipName_span &sipStrings_QtGui[53425]
#define sipNameNr_spec 53430
#define sipName_spec &sipStrings_QtGui[53430]
#define sipNameNr_stop 53435
#define sipName_stop &sipStrings_QtGui[53435]
#define sipNameNr_swap 53440
#define sipName_swap &sipStrings_QtGui[53440]
#define sipNameNr_sync 53445
#define sipName_sync &sipStrings_QtGui[53445]
#define sipNameNr_tabs 53450
#define sipName_tabs &sipStrings_QtGui[53450]
#define sipNameNr_teal 53455
#define sipName_teal &sipStrings_QtGui[53455]
#define sipNameNr_text 240
#define sipName_text &sipStrings_QtGui[240]
#define sipNameNr_type 22180
#define sipName_type &sipStrings_QtGui[22180]
#define sipNameNr_undo 53460
#define sipName_undo &sipStrings_QtGui[53460]
#define sipNameNr_A10 53465
#define sipName_A10 &sipStrings_QtGui[53465]
#define sipNameNr_All 17952
#define sipName_All &sipStrings_QtGui[17952]
#define sipNameNr_Any 53469
#define sipName_Any &sipStrings_QtGui[53469]
#define sipNameNr_B10 51012
#define sipName_B10 &sipStrings_QtGui[51012]
#define sipNameNr_BGR 53473
#define sipName_BGR &sipStrings_QtGui[53473]
#define sipNameNr_C5E 53477
#define sipName_C5E &sipStrings_QtGui[53477]
#define sipNameNr_Cut 53481
#define sipName_Cut &sipStrings_QtGui[53481]
#define sipNameNr_D16 53485
#define sipName_D16 &sipStrings_QtGui[53485]
#define sipNameNr_D24 53489
#define sipName_D24 &sipStrings_QtGui[53489]
#define sipNameNr_D32 53493
#define sipName_D32 &sipStrings_QtGui[53493]
#define sipNameNr_DLE 53497
#define sipName_DLE &sipStrings_QtGui[53497]
#define sipNameNr_End 36046
#define sipName_End &sipStrings_QtGui[36046]
#define sipNameNr_HSL 53501
#define sipName_HSL &sipStrings_QtGui[53501]
#define sipNameNr_HSV 53505
#define sipName_HSV &sipStrings_QtGui[53505]
#define sipNameNr_Hsl 25173
#define sipName_Hsl &sipStrings_QtGui[25173]
#define sipNameNr_Hsv 25189
#define sipName_Hsv &sipStrings_QtGui[25189]
#define sipNameNr_Key 5901
#define sipName_Key &sipStrings_QtGui[5901]
#define sipNameNr_Lao 53509
#define sipName_Lao &sipStrings_QtGui[53509]
#define sipNameNr_Mid 53513
#define sipName_Mid &sipStrings_QtGui[53513]
#define sipNameNr_New 53517
#define sipName_New &sipStrings_QtGui[53517]
#define sipNameNr_Nko 53521
#define sipName_Nko &sipStrings_QtGui[53521]
#define sipNameNr_Off 53525
#define sipName_Off &sipStrings_QtGui[53525]
#define sipNameNr_Pdf 53529
#define sipName_Pdf &sipStrings_QtGui[53529]
#define sipNameNr_Pen 10026
#define sipName_Pen &sipStrings_QtGui[10026]
#define sipNameNr_R8I 53533
#define sipName_R8I &sipStrings_QtGui[53533]
#define sipNameNr_R8U 53537
#define sipName_R8U &sipStrings_QtGui[53537]
#define sipNameNr_RGB 53541
#define sipName_RGB &sipStrings_QtGui[53541]
#define sipNameNr_Red 41776
#define sipName_Red &sipStrings_QtGui[41776]
#define sipNameNr_Rgb 32879
#define sipName_Rgb &sipStrings_QtGui[32879]
#define sipNameNr_SVG 53545
#define sipName_SVG &sipStrings_QtGui[53545]
#define sipNameNr_Svg 11925
#define sipName_Svg &sipStrings_QtGui[11925]
#define sipNameNr_Tab 21093
#define sipName_Tab &sipStrings_QtGui[21093]
#define sipNameNr_X11 53549
#define sipName_X11 &sipStrings_QtGui[53549]
#define sipNameNr_Y16 53553
#define sipName_Y16 &sipStrings_QtGui[53553]
#define sipNameNr_YUV 53557
#define sipName_YUV &sipStrings_QtGui[53557]
#define sipNameNr_add 53561
#define sipName_add &sipStrings_QtGui[53561]
#define sipNameNr_cap 53565
#define sipName_cap &sipStrings_QtGui[53565]
#define sipNameNr_end 15611
#define sipName_end &sipStrings_QtGui[15611]
#define sipNameNr_hue 53569
#define sipName_hue &sipStrings_QtGui[53569]
#define sipNameNr_key 53573
#define sipName_key &sipStrings_QtGui[53573]
#define sipNameNr_log 53577
#define sipName_log &sipStrings_QtGui[53577]
#define sipNameNr_m11 53581
#define sipName_m11 &sipStrings_QtGui[53581]
#define sipNameNr_m12 53585
#define sipName_m12 &sipStrings_QtGui[53585]
#define sipNameNr_m13 53589
#define sipName_m13 &sipStrings_QtGui[53589]
#define sipNameNr_m21 53593
#define sipName_m21 &sipStrings_QtGui[53593]
#define sipNameNr_m22 53597
#define sipName_m22 &sipStrings_QtGui[53597]
#define sipNameNr_m23 53601
#define sipName_m23 &sipStrings_QtGui[53601]
#define sipNameNr_m31 53605
#define sipName_m31 &sipStrings_QtGui[53605]
#define sipNameNr_m32 53609
#define sipName_m32 &sipStrings_QtGui[53609]
#define sipNameNr_m33 53613
#define sipName_m33 &sipStrings_QtGui[53613]
#define sipNameNr_map 24421
#define sipName_map &sipStrings_QtGui[24421]
#define sipNameNr_mid 53617
#define sipName_mid &sipStrings_QtGui[53617]
#define sipNameNr_pen 53016
#define sipName_pen &sipStrings_QtGui[53016]
#define sipNameNr_pos 53621
#define sipName_pos &sipStrings_QtGui[53621]
#define sipNameNr_red 24869
#define sipName_red &sipStrings_QtGui[24869]
#define sipNameNr_rgb 49411
#define sipName_rgb &sipStrings_QtGui[49411]
#define sipNameNr_row 53625
#define sipName_row &sipStrings_QtGui[53625]
#define sipNameNr_tan 49683
#define sipName_tan &sipStrings_QtGui[49683]
#define sipNameNr_tip 53629
#define sipName_tip &sipStrings_QtGui[53629]
#define sipNameNr_top 1824
#define sipName_top &sipStrings_QtGui[1824]
#define sipNameNr_url 53633
#define sipName_url &sipStrings_QtGui[53633]
#define sipNameNr_A0 53637
#define sipName_A0 &sipStrings_QtGui[53637]
#define sipNameNr_A1 30528
#define sipName_A1 &sipStrings_QtGui[30528]
#define sipNameNr_A2 27084
#define sipName_A2 &sipStrings_QtGui[27084]
#define sipNameNr_A3 53640
#define sipName_A3 &sipStrings_QtGui[53640]
#define sipNameNr_A4 34552
#define sipName_A4 &sipStrings_QtGui[34552]
#define sipNameNr_A5 53643
#define sipName_A5 &sipStrings_QtGui[53643]
#define sipNameNr_A6 53646
#define sipName_A6 &sipStrings_QtGui[53646]
#define sipNameNr_A7 53649
#define sipName_A7 &sipStrings_QtGui[53649]
#define sipNameNr_A8 34578
#define sipName_A8 &sipStrings_QtGui[34578]
#define sipNameNr_A9 53652
#define sipName_A9 &sipStrings_QtGui[53652]
#define sipNameNr_B0 52283
#define sipName_B0 &sipStrings_QtGui[52283]
#define sipNameNr_B1 52289
#define sipName_B1 &sipStrings_QtGui[52289]
#define sipNameNr_B2 38122
#define sipName_B2 &sipStrings_QtGui[38122]
#define sipNameNr_B3 52301
#define sipName_B3 &sipStrings_QtGui[52301]
#define sipNameNr_B4 40600
#define sipName_B4 &sipStrings_QtGui[40600]
#define sipNameNr_B5 30514
#define sipName_B5 &sipStrings_QtGui[30514]
#define sipNameNr_B6 40622
#define sipName_B6 &sipStrings_QtGui[40622]
#define sipNameNr_B7 52325
#define sipName_B7 &sipStrings_QtGui[52325]
#define sipNameNr_B8 52331
#define sipName_B8 &sipStrings_QtGui[52331]
#define sipNameNr_B9 52337
#define sipName_B9 &sipStrings_QtGui[52337]
#define sipNameNr_On 53655
#define sipName_On &sipStrings_QtGui[53655]
#define sipNameNr_Qt 53658
#define sipName_Qt &sipStrings_QtGui[53658]
#define sipNameNr_RG 53661
#define sipName_RG &sipStrings_QtGui[53661]
#define sipNameNr_S8 34565
#define sipName_S8 &sipStrings_QtGui[34565]
#define sipNameNr_Up 53664
#define sipName_Up &sipStrings_QtGui[53664]
#define sipNameNr_Y8 53667
#define sipName_Y8 &sipStrings_QtGui[53667]
#define sipNameNr_at 2427
#define sipName_at &sipStrings_QtGui[2427]
#define sipNameNr_dx 53670
#define sipName_dx &sipStrings_QtGui[53670]
#define sipNameNr_dy 52559
#define sipName_dy &sipStrings_QtGui[52559]
#define sipNameNr_id 17809
#define sipName_id &sipStrings_QtGui[17809]
#define sipNameNr_on 321
#define sipName_on &sipStrings_QtGui[321]
#define sipNameNr_sh 5375
#define sipName_sh &sipStrings_QtGui[5375]
#define sipNameNr_sw 53673
#define sipName_sw &sipStrings_QtGui[53673]
#define sipNameNr_sx 53676
#define sipName_sx &sipStrings_QtGui[53676]
#define sipNameNr_sy 49372
#define sipName_sy &sipStrings_QtGui[49372]
#define sipNameNr_n 322
#define sipName_n &sipStrings_QtGui[322]
#define sipNameNr_w 12620
#define sipName_w &sipStrings_QtGui[12620]
#define sipNameNr_x 13376
#define sipName_x &sipStrings_QtGui[13376]
#define sipNameNr_y 102
#define sipName_y &sipStrings_QtGui[102]
#define sipNameNr_z 53679
#define sipName_z &sipStrings_QtGui[53679]

#define sipMalloc                   sipAPI_QtGui->api_malloc
#define sipFree                     sipAPI_QtGui->api_free
#define sipBuildResult              sipAPI_QtGui->api_build_result
#define sipCallMethod               sipAPI_QtGui->api_call_method
#define sipCallProcedureMethod      sipAPI_QtGui->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtGui->api_call_error_handler
#define sipParseResultEx            sipAPI_QtGui->api_parse_result_ex
#define sipParseResult              sipAPI_QtGui->api_parse_result
#define sipParseArgs                sipAPI_QtGui->api_parse_args
#define sipParseKwdArgs             sipAPI_QtGui->api_parse_kwd_args
#define sipParsePair                sipAPI_QtGui->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtGui->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtGui->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtGui->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtGui->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtGui->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtGui->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtGui->api_add_exception
#define sipNoFunction               sipAPI_QtGui->api_no_function
#define sipNoMethod                 sipAPI_QtGui->api_no_method
#define sipAbstractMethod           sipAPI_QtGui->api_abstract_method
#define sipBadClass                 sipAPI_QtGui->api_bad_class
#define sipBadCatcherResult         sipAPI_QtGui->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtGui->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtGui->api_bad_operator_arg
#define sipTrace                    sipAPI_QtGui->api_trace
#define sipTransferBack             sipAPI_QtGui->api_transfer_back
#define sipTransferTo               sipAPI_QtGui->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtGui->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtGui->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtGui->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtGui->api_voidptr_type
#define sipGetPyObject              sipAPI_QtGui->api_get_pyobject
#define sipGetAddress               sipAPI_QtGui->api_get_address
#define sipGetMixinAddress          sipAPI_QtGui->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtGui->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtGui->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtGui->api_call_hook
#define sipEndThread                sipAPI_QtGui->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtGui->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtGui->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtGui->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtGui->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtGui->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtGui->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtGui->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtGui->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtGui->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtGui->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtGui->api_convert_to_bool
#define sipReleaseType              sipAPI_QtGui->api_release_type
#define sipConvertFromType          sipAPI_QtGui->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtGui->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtGui->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtGui->api_convert_from_enum
#define sipGetState                 sipAPI_QtGui->api_get_state
#define sipExportSymbol             sipAPI_QtGui->api_export_symbol
#define sipImportSymbol             sipAPI_QtGui->api_import_symbol
#define sipFindType                 sipAPI_QtGui->api_find_type
#define sipBytes_AsChar             sipAPI_QtGui->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtGui->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtGui->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtGui->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtGui->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtGui->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtGui->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtGui->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtGui->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtGui->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtGui->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtGui->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtGui->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtGui->api_deprecated
#define sipGetReference             sipAPI_QtGui->api_get_reference
#define sipKeepReference            sipAPI_QtGui->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtGui->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtGui->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtGui->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtGui->api_type_scope
#define sipResolveTypedef           sipAPI_QtGui->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtGui->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtGui->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtGui->api_init_mixin
#define sipExportModule             sipAPI_QtGui->api_export_module
#define sipInitModule               sipAPI_QtGui->api_init_module
#define sipGetInterpreter           sipAPI_QtGui->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtGui->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtGui->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtGui->api_py_type_dict
#define sipPyTypeName               sipAPI_QtGui->api_py_type_name
#define sipGetCFunction             sipAPI_QtGui->api_get_c_function
#define sipGetMethod                sipAPI_QtGui->api_get_method
#define sipFromMethod               sipAPI_QtGui->api_from_method
#define sipGetDate                  sipAPI_QtGui->api_get_date
#define sipFromDate                 sipAPI_QtGui->api_from_date
#define sipGetDateTime              sipAPI_QtGui->api_get_datetime
#define sipFromDateTime             sipAPI_QtGui->api_from_datetime
#define sipGetTime                  sipAPI_QtGui->api_get_time
#define sipFromTime                 sipAPI_QtGui->api_from_time
#define sipIsUserType               sipAPI_QtGui->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtGui->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtGui->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtGui->api_unicode_write
#define sipUnicodeData              sipAPI_QtGui->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtGui->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtGui->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtGui->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtGui->api_is_derived_class
#define sipGetUserObject            sipAPI_QtGui->api_get_user_object
#define sipSetUserObject            sipAPI_QtGui->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtGui->api_register_event_handler
#define sipConvertToArray           sipAPI_QtGui->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtGui->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtGui->api_enable_gc
#define sipPrintObject              sipAPI_QtGui->api_print_object
#define sipLong_AsChar              sipAPI_QtGui->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtGui->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtGui->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtGui->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtGui->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtGui->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtGui->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtGui->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtGui->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtGui->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtGui->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtGui->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtGui->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtGui->api_register_exit_notifier
#define sipPyTypeDictRef            sipAPI_QtGui->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtGui->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtGui->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtGui->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtGui->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtGui->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtGui->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtGui->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtGui->api_connect_rx
#define sipConvertRx                sipAPI_QtGui->api_convert_rx
#define sipDisconnectRx             sipAPI_QtGui->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtGui->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtGui->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtGui->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtGui->api_same_slot
#define sipSaveSlot                 sipAPI_QtGui->api_save_slot
#define sipVisitSlot                sipAPI_QtGui->api_visit_slot
#define sipIsPyMethod               sipAPI_QtGui->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtGui[];

#define sipType_QAbstractTextDocumentLayout sipExportedTypes_QtGui[1]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout;

#define sipType_QAbstractTextDocumentLayout_Selection sipExportedTypes_QtGui[3]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout_Selection;

#define sipType_QAbstractTextDocumentLayout_PaintContext sipExportedTypes_QtGui[2]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout_PaintContext;

#define sipType_QTextObjectInterface sipExportedTypes_QtGui[341]

extern sipClassTypeDef sipTypeDef_QtGui_QTextObjectInterface;

#define sipType_QBackingStore sipExportedTypes_QtGui[6]

extern sipClassTypeDef sipTypeDef_QtGui_QBackingStore;

#define sipType_QPaintDevice sipExportedTypes_QtGui[198]

#define sipType_QPaintDevice_PaintDeviceMetric sipExportedTypes_QtGui[199]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintDevice;

#define sipType_QPixmap sipExportedTypes_QtGui[238]

extern sipClassTypeDef sipTypeDef_QtGui_QPixmap;

#define sipType_QBitmap sipExportedTypes_QtGui[7]

extern sipClassTypeDef sipTypeDef_QtGui_QBitmap;

#define sipType_QColor sipExportedTypes_QtGui[12]

#define sipType_QColor_NameFormat sipExportedTypes_QtGui[13]

#define sipType_QColor_Spec sipExportedTypes_QtGui[14]

extern sipClassTypeDef sipTypeDef_QtGui_QColor;

#define sipType_QColorConstants sipExportedTypes_QtGui[15]

extern sipClassTypeDef sipTypeDef_QtGui_QColorConstants;

#define sipType_QColorConstants_Svg sipExportedTypes_QtGui[16]

extern sipClassTypeDef sipTypeDef_QtGui_QColorConstants_Svg;

#define sipType_QBrush sipExportedTypes_QtGui[8]

extern sipClassTypeDef sipTypeDef_QtGui_QBrush;

#define sipType_QGradient sipExportedTypes_QtGui[56]

#define sipType_QGradient_Preset sipExportedTypes_QtGui[58]

#define sipType_QGradient_Spread sipExportedTypes_QtGui[59]

#define sipType_QGradient_Type sipExportedTypes_QtGui[60]

#define sipType_QGradient_CoordinateMode sipExportedTypes_QtGui[57]

extern sipClassTypeDef sipTypeDef_QtGui_QGradient;

#define sipType_QLinearGradient sipExportedTypes_QtGui[97]

extern sipClassTypeDef sipTypeDef_QtGui_QLinearGradient;

#define sipType_QRadialGradient sipExportedTypes_QtGui[247]

extern sipClassTypeDef sipTypeDef_QtGui_QRadialGradient;

#define sipType_QConicalGradient sipExportedTypes_QtGui[22]

extern sipClassTypeDef sipTypeDef_QtGui_QConicalGradient;

#define sipType_QClipboard sipExportedTypes_QtGui[9]

#define sipType_QClipboard_Mode sipExportedTypes_QtGui[10]

extern sipClassTypeDef sipTypeDef_QtGui_QClipboard;

#define sipType_QColorSpace sipExportedTypes_QtGui[17]

#define sipType_QColorSpace_TransferFunction sipExportedTypes_QtGui[20]

#define sipType_QColorSpace_Primaries sipExportedTypes_QtGui[19]

#define sipType_QColorSpace_NamedColorSpace sipExportedTypes_QtGui[18]

extern sipClassTypeDef sipTypeDef_QtGui_QColorSpace;

#define sipType_QColorTransform sipExportedTypes_QtGui[21]

extern sipClassTypeDef sipTypeDef_QtGui_QColorTransform;

#define sipType_QCursor sipExportedTypes_QtGui[25]

extern sipClassTypeDef sipTypeDef_QtGui_QCursor;

#define sipType_QDesktopServices sipExportedTypes_QtGui[26]

extern sipClassTypeDef sipTypeDef_QtGui_QDesktopServices;

#define sipType_QDrag sipExportedTypes_QtGui[29]

extern sipClassTypeDef sipTypeDef_QtGui_QDrag;

#define sipType_QInputEvent sipExportedTypes_QtGui[84]

extern sipClassTypeDef sipTypeDef_QtGui_QInputEvent;

#define sipType_QMouseEvent sipExportedTypes_QtGui[125]

extern sipClassTypeDef sipTypeDef_QtGui_QMouseEvent;

#define sipType_QHoverEvent sipExportedTypes_QtGui[64]

extern sipClassTypeDef sipTypeDef_QtGui_QHoverEvent;

#define sipType_QWheelEvent sipExportedTypes_QtGui[379]

extern sipClassTypeDef sipTypeDef_QtGui_QWheelEvent;

#define sipType_QTabletEvent sipExportedTypes_QtGui[284]

#define sipType_QTabletEvent_PointerType sipExportedTypes_QtGui[285]

#define sipType_QTabletEvent_TabletDevice sipExportedTypes_QtGui[286]

extern sipClassTypeDef sipTypeDef_QtGui_QTabletEvent;

#define sipType_QKeyEvent sipExportedTypes_QtGui[92]

extern sipClassTypeDef sipTypeDef_QtGui_QKeyEvent;

#define sipType_QFocusEvent sipExportedTypes_QtGui[37]

extern sipClassTypeDef sipTypeDef_QtGui_QFocusEvent;

#define sipType_QPaintEvent sipExportedTypes_QtGui[209]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEvent;

#define sipType_QMoveEvent sipExportedTypes_QtGui[126]

extern sipClassTypeDef sipTypeDef_QtGui_QMoveEvent;

#define sipType_QResizeEvent sipExportedTypes_QtGui[257]

extern sipClassTypeDef sipTypeDef_QtGui_QResizeEvent;

#define sipType_QCloseEvent sipExportedTypes_QtGui[11]

extern sipClassTypeDef sipTypeDef_QtGui_QCloseEvent;

#define sipType_QIconDragEvent sipExportedTypes_QtGui[68]

extern sipClassTypeDef sipTypeDef_QtGui_QIconDragEvent;

#define sipType_QShowEvent sipExportedTypes_QtGui[265]

extern sipClassTypeDef sipTypeDef_QtGui_QShowEvent;

#define sipType_QHideEvent sipExportedTypes_QtGui[63]

extern sipClassTypeDef sipTypeDef_QtGui_QHideEvent;

#define sipType_QContextMenuEvent sipExportedTypes_QtGui[23]

#define sipType_QContextMenuEvent_Reason sipExportedTypes_QtGui[24]

extern sipClassTypeDef sipTypeDef_QtGui_QContextMenuEvent;

#define sipType_QInputMethodEvent sipExportedTypes_QtGui[87]

#define sipType_QInputMethodEvent_AttributeType sipExportedTypes_QtGui[89]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodEvent;

#define sipType_QInputMethodEvent_Attribute sipExportedTypes_QtGui[88]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodEvent_Attribute;

#define sipType_QInputMethodQueryEvent sipExportedTypes_QtGui[90]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodQueryEvent;

#define sipType_QDropEvent sipExportedTypes_QtGui[33]

extern sipClassTypeDef sipTypeDef_QtGui_QDropEvent;

#define sipType_QDragMoveEvent sipExportedTypes_QtGui[32]

extern sipClassTypeDef sipTypeDef_QtGui_QDragMoveEvent;

#define sipType_QDragEnterEvent sipExportedTypes_QtGui[30]

extern sipClassTypeDef sipTypeDef_QtGui_QDragEnterEvent;

#define sipType_QDragLeaveEvent sipExportedTypes_QtGui[31]

extern sipClassTypeDef sipTypeDef_QtGui_QDragLeaveEvent;

#define sipType_QHelpEvent sipExportedTypes_QtGui[62]

extern sipClassTypeDef sipTypeDef_QtGui_QHelpEvent;

#define sipType_QStatusTipEvent sipExportedTypes_QtGui[271]

extern sipClassTypeDef sipTypeDef_QtGui_QStatusTipEvent;

#define sipType_QWhatsThisClickedEvent sipExportedTypes_QtGui[378]

extern sipClassTypeDef sipTypeDef_QtGui_QWhatsThisClickedEvent;

#define sipType_QActionEvent sipExportedTypes_QtGui[5]

extern sipClassTypeDef sipTypeDef_QtGui_QActionEvent;

#define sipType_QFileOpenEvent sipExportedTypes_QtGui[36]

extern sipClassTypeDef sipTypeDef_QtGui_QFileOpenEvent;

#define sipType_QShortcutEvent sipExportedTypes_QtGui[264]

extern sipClassTypeDef sipTypeDef_QtGui_QShortcutEvent;

#define sipType_QWindowStateChangeEvent sipExportedTypes_QtGui[383]

extern sipClassTypeDef sipTypeDef_QtGui_QWindowStateChangeEvent;

#define sipType_QTouchEvent sipExportedTypes_QtGui[356]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchEvent;

#define sipType_QTouchEvent_TouchPoint sipExportedTypes_QtGui[357]

#define sipType_QTouchEvent_TouchPoint_InfoFlag sipExportedTypes_QtGui[358]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchEvent_TouchPoint;

#define sipType_QTouchEvent_TouchPoint_InfoFlags sipExportedTypes_QtGui[359]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchEvent_TouchPoint_InfoFlags;

#define sipType_QExposeEvent sipExportedTypes_QtGui[35]

extern sipClassTypeDef sipTypeDef_QtGui_QExposeEvent;

#define sipType_QScrollPrepareEvent sipExportedTypes_QtGui[262]

extern sipClassTypeDef sipTypeDef_QtGui_QScrollPrepareEvent;

#define sipType_QScrollEvent sipExportedTypes_QtGui[260]

#define sipType_QScrollEvent_ScrollState sipExportedTypes_QtGui[261]

extern sipClassTypeDef sipTypeDef_QtGui_QScrollEvent;

#define sipType_QEnterEvent sipExportedTypes_QtGui[34]

extern sipClassTypeDef sipTypeDef_QtGui_QEnterEvent;

#define sipType_QAction sipExportedTypes_QtGui[4]

#define sipType_QNativeGestureEvent sipExportedTypes_QtGui[130]

extern sipClassTypeDef sipTypeDef_QtGui_QNativeGestureEvent;

#define sipType_QPlatformSurfaceEvent sipExportedTypes_QtGui[241]

#define sipType_QPlatformSurfaceEvent_SurfaceEventType sipExportedTypes_QtGui[242]

extern sipClassTypeDef sipTypeDef_QtGui_QPlatformSurfaceEvent;

#define sipType_QPointingDeviceUniqueId sipExportedTypes_QtGui[243]

extern sipClassTypeDef sipTypeDef_QtGui_QPointingDeviceUniqueId;

#define sipType_QFont sipExportedTypes_QtGui[38]

#define sipType_QFont_HintingPreference sipExportedTypes_QtGui[40]

#define sipType_QFont_SpacingType sipExportedTypes_QtGui[41]

#define sipType_QFont_Capitalization sipExportedTypes_QtGui[39]

#define sipType_QFont_Stretch sipExportedTypes_QtGui[42]

#define sipType_QFont_Style sipExportedTypes_QtGui[43]

#define sipType_QFont_Weight sipExportedTypes_QtGui[46]

#define sipType_QFont_StyleStrategy sipExportedTypes_QtGui[45]

#define sipType_QFont_StyleHint sipExportedTypes_QtGui[44]

extern sipClassTypeDef sipTypeDef_QtGui_QFont;

#define sipType_QFontDatabase sipExportedTypes_QtGui[47]

#define sipType_QFontDatabase_SystemFont sipExportedTypes_QtGui[48]

#define sipType_QFontDatabase_WritingSystem sipExportedTypes_QtGui[49]

extern sipClassTypeDef sipTypeDef_QtGui_QFontDatabase;

#define sipType_QFontInfo sipExportedTypes_QtGui[50]

extern sipClassTypeDef sipTypeDef_QtGui_QFontInfo;

#define sipType_QFontMetrics sipExportedTypes_QtGui[51]

extern sipClassTypeDef sipTypeDef_QtGui_QFontMetrics;

#define sipType_QFontMetricsF sipExportedTypes_QtGui[52]

extern sipClassTypeDef sipTypeDef_QtGui_QFontMetricsF;

#define sipType_QMatrix4x3 sipExportedTypes_QtGui[123]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x3;

#define sipType_QMatrix4x2 sipExportedTypes_QtGui[122]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x2;

#define sipType_QMatrix3x4 sipExportedTypes_QtGui[121]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x4;

#define sipType_QMatrix3x3 sipExportedTypes_QtGui[120]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x3;

#define sipType_QMatrix3x2 sipExportedTypes_QtGui[119]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x2;

#define sipType_QMatrix2x4 sipExportedTypes_QtGui[118]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x4;

#define sipType_QMatrix2x3 sipExportedTypes_QtGui[117]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x3;

#define sipType_QMatrix2x2 sipExportedTypes_QtGui[116]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x2;

#define sipType_QGlyphRun sipExportedTypes_QtGui[53]

#define sipType_QGlyphRun_GlyphRunFlag sipExportedTypes_QtGui[54]

extern sipClassTypeDef sipTypeDef_QtGui_QGlyphRun;

#define sipType_QGlyphRun_GlyphRunFlags sipExportedTypes_QtGui[55]

extern sipClassTypeDef sipTypeDef_QtGui_QGlyphRun_GlyphRunFlags;

#define sipType_QGuiApplication sipExportedTypes_QtGui[61]

extern sipClassTypeDef sipTypeDef_QtGui_QGuiApplication;

#define sipType_QIcon sipExportedTypes_QtGui[65]

#define sipType_QIcon_State sipExportedTypes_QtGui[67]

#define sipType_QIcon_Mode sipExportedTypes_QtGui[66]

extern sipClassTypeDef sipTypeDef_QtGui_QIcon;

#define sipType_QIconEngine sipExportedTypes_QtGui[69]

#define sipType_QIconEngine_IconEngineHook sipExportedTypes_QtGui[71]

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine;

#define sipType_QIconEngine_AvailableSizesArgument sipExportedTypes_QtGui[70]

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine_AvailableSizesArgument;

#define sipType_QIconEngine_ScaledPixmapArgument sipExportedTypes_QtGui[72]

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine_ScaledPixmapArgument;

#define sipType_QImage sipExportedTypes_QtGui[73]

#define sipType_QImage_Format sipExportedTypes_QtGui[74]

#define sipType_QImage_InvertMode sipExportedTypes_QtGui[75]

extern sipClassTypeDef sipTypeDef_QtGui_QImage;

#define sipType_QImageIOHandler sipExportedTypes_QtGui[76]

#define sipType_QImageIOHandler_Transformation sipExportedTypes_QtGui[78]

#define sipType_QImageIOHandler_ImageOption sipExportedTypes_QtGui[77]

extern sipClassTypeDef sipTypeDef_QtGui_QImageIOHandler;

#define sipType_QImageIOHandler_Transformations sipExportedTypes_QtGui[79]

extern sipClassTypeDef sipTypeDef_QtGui_QImageIOHandler_Transformations;

#define sipType_QImageReader sipExportedTypes_QtGui[80]

#define sipType_QImageReader_ImageReaderError sipExportedTypes_QtGui[81]

extern sipClassTypeDef sipTypeDef_QtGui_QImageReader;

#define sipType_QImageWriter sipExportedTypes_QtGui[82]

#define sipType_QImageWriter_ImageWriterError sipExportedTypes_QtGui[83]

extern sipClassTypeDef sipTypeDef_QtGui_QImageWriter;

#define sipType_QInputMethod sipExportedTypes_QtGui[85]

#define sipType_QInputMethod_Action sipExportedTypes_QtGui[86]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethod;

#define sipType_QKeySequence sipExportedTypes_QtGui[93]

#define sipType_QKeySequence_StandardKey sipExportedTypes_QtGui[96]

#define sipType_QKeySequence_SequenceMatch sipExportedTypes_QtGui[95]

#define sipType_QKeySequence_SequenceFormat sipExportedTypes_QtGui[94]

extern sipClassTypeDef sipTypeDef_QtGui_QKeySequence;

#define sipType_QMatrix4x4 sipExportedTypes_QtGui[124]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x4;

#define sipType_QMovie sipExportedTypes_QtGui[127]

#define sipType_QMovie_CacheMode sipExportedTypes_QtGui[128]

#define sipType_QMovie_MovieState sipExportedTypes_QtGui[129]

extern sipClassTypeDef sipTypeDef_QtGui_QMovie;

#define sipType_QSurface sipExportedTypes_QtGui[273]

#define sipType_QSurface_SurfaceType sipExportedTypes_QtGui[275]

#define sipType_QSurface_SurfaceClass sipExportedTypes_QtGui[274]

extern sipClassTypeDef sipTypeDef_QtGui_QSurface;

#define sipType_QOffscreenSurface sipExportedTypes_QtGui[131]

extern sipClassTypeDef sipTypeDef_QtGui_QOffscreenSurface;

#define sipType_QOpenGLBuffer sipExportedTypes_QtGui[132]

#define sipType_QOpenGLBuffer_RangeAccessFlag sipExportedTypes_QtGui[134]

#define sipType_QOpenGLBuffer_Access sipExportedTypes_QtGui[133]

#define sipType_QOpenGLBuffer_UsagePattern sipExportedTypes_QtGui[137]

#define sipType_QOpenGLBuffer_Type sipExportedTypes_QtGui[136]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLBuffer;

#define sipType_QOpenGLBuffer_RangeAccessFlags sipExportedTypes_QtGui[135]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLBuffer_RangeAccessFlags;

#define sipType_QOpenGLContextGroup sipExportedTypes_QtGui[140]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLContextGroup;

#define sipType_QOpenGLContext sipExportedTypes_QtGui[138]

#define sipType_QOpenGLContext_OpenGLModuleType sipExportedTypes_QtGui[139]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLContext;

#define sipType_QOpenGLVersionProfile sipExportedTypes_QtGui[181]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLVersionProfile;

#define sipType_QOpenGLDebugMessage sipExportedTypes_QtGui[143]

#define sipType_QOpenGLDebugMessage_Severity sipExportedTypes_QtGui[145]

#define sipType_QOpenGLDebugMessage_Type sipExportedTypes_QtGui[148]

#define sipType_QOpenGLDebugMessage_Source sipExportedTypes_QtGui[146]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage;

#define sipType_QOpenGLDebugMessage_Sources sipExportedTypes_QtGui[147]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage_Sources;

#define sipType_QOpenGLDebugMessage_Types sipExportedTypes_QtGui[149]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage_Types;

#define sipType_QOpenGLDebugMessage_Severities sipExportedTypes_QtGui[144]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage_Severities;

#define sipType_QOpenGLDebugLogger sipExportedTypes_QtGui[141]

#define sipType_QOpenGLDebugLogger_LoggingMode sipExportedTypes_QtGui[142]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugLogger;

#define sipType_QOpenGLFramebufferObject sipExportedTypes_QtGui[150]

#define sipType_QOpenGLFramebufferObject_FramebufferRestorePolicy sipExportedTypes_QtGui[152]

#define sipType_QOpenGLFramebufferObject_Attachment sipExportedTypes_QtGui[151]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLFramebufferObject;

#define sipType_QOpenGLFramebufferObjectFormat sipExportedTypes_QtGui[153]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLFramebufferObjectFormat;

#define sipType_QOpenGLPaintDevice sipExportedTypes_QtGui[154]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLPaintDevice;

#define sipType_QOpenGLPixelTransferOptions sipExportedTypes_QtGui[155]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLPixelTransferOptions;

#define sipType_QOpenGLShader sipExportedTypes_QtGui[156]

#define sipType_QOpenGLShader_ShaderTypeBit sipExportedTypes_QtGui[158]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLShader;

#define sipType_QOpenGLShader_ShaderType sipExportedTypes_QtGui[157]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLShader_ShaderType;

#define sipType_QOpenGLShaderProgram sipExportedTypes_QtGui[159]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLShaderProgram;

#define sipType_QOpenGLTexture sipExportedTypes_QtGui[160]

#define sipType_QOpenGLTexture_ComparisonMode sipExportedTypes_QtGui[163]

#define sipType_QOpenGLTexture_ComparisonFunction sipExportedTypes_QtGui[162]

#define sipType_QOpenGLTexture_CoordinateDirection sipExportedTypes_QtGui[164]

#define sipType_QOpenGLTexture_WrapMode sipExportedTypes_QtGui[178]

#define sipType_QOpenGLTexture_Filter sipExportedTypes_QtGui[169]

#define sipType_QOpenGLTexture_DepthStencilMode sipExportedTypes_QtGui[166]

#define sipType_QOpenGLTexture_SwizzleValue sipExportedTypes_QtGui[174]

#define sipType_QOpenGLTexture_SwizzleComponent sipExportedTypes_QtGui[173]

#define sipType_QOpenGLTexture_Feature sipExportedTypes_QtGui[167]

#define sipType_QOpenGLTexture_PixelType sipExportedTypes_QtGui[172]

#define sipType_QOpenGLTexture_PixelFormat sipExportedTypes_QtGui[171]

#define sipType_QOpenGLTexture_CubeMapFace sipExportedTypes_QtGui[165]

#define sipType_QOpenGLTexture_TextureFormat sipExportedTypes_QtGui[176]

#define sipType_QOpenGLTexture_TextureUnitReset sipExportedTypes_QtGui[177]

#define sipType_QOpenGLTexture_MipMapGeneration sipExportedTypes_QtGui[170]

#define sipType_QOpenGLTexture_BindingTarget sipExportedTypes_QtGui[161]

#define sipType_QOpenGLTexture_Target sipExportedTypes_QtGui[175]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTexture;

#define sipType_QOpenGLTexture_Features sipExportedTypes_QtGui[168]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTexture_Features;

#define sipType_QOpenGLTextureBlitter sipExportedTypes_QtGui[179]

#define sipType_QOpenGLTextureBlitter_Origin sipExportedTypes_QtGui[180]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTextureBlitter;

#define sipType_QAbstractOpenGLFunctions sipExportedTypes_QtGui[0]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractOpenGLFunctions;

#define sipType_QOpenGLVertexArrayObject sipExportedTypes_QtGui[182]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLVertexArrayObject;

#define sipType_QOpenGLVertexArrayObject_Binder sipExportedTypes_QtGui[183]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLVertexArrayObject_Binder;

#define sipType_QWindow sipExportedTypes_QtGui[380]

#define sipType_QWindow_Visibility sipExportedTypes_QtGui[382]

#define sipType_QWindow_AncestorMode sipExportedTypes_QtGui[381]

extern sipClassTypeDef sipTypeDef_QtGui_QWindow;

#define sipType_QPaintDeviceWindow sipExportedTypes_QtGui[200]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintDeviceWindow;

#define sipType_QOpenGLWindow sipExportedTypes_QtGui[184]

#define sipType_QOpenGLWindow_UpdateBehavior sipExportedTypes_QtGui[185]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLWindow;

#define sipType_QPagedPaintDevice sipExportedTypes_QtGui[194]

#define sipType_QPagedPaintDevice_PdfVersion sipExportedTypes_QtGui[197]

#define sipType_QPagedPaintDevice_PageSize sipExportedTypes_QtGui[196]

extern sipClassTypeDef sipTypeDef_QtGui_QPagedPaintDevice;

#define sipType_QPagedPaintDevice_Margins sipExportedTypes_QtGui[195]

extern sipClassTypeDef sipTypeDef_QtGui_QPagedPaintDevice_Margins;

#define sipType_QPageLayout sipExportedTypes_QtGui[186]

#define sipType_QPageLayout_Mode sipExportedTypes_QtGui[187]

#define sipType_QPageLayout_Orientation sipExportedTypes_QtGui[188]

#define sipType_QPageLayout_Unit sipExportedTypes_QtGui[189]

extern sipClassTypeDef sipTypeDef_QtGui_QPageLayout;

#define sipType_QPageSize sipExportedTypes_QtGui[190]

#define sipType_QPageSize_SizeMatchPolicy sipExportedTypes_QtGui[192]

#define sipType_QPageSize_Unit sipExportedTypes_QtGui[193]

#define sipType_QPageSize_PageSizeId sipExportedTypes_QtGui[191]

extern sipClassTypeDef sipTypeDef_QtGui_QPageSize;

#define sipType_QPainter sipExportedTypes_QtGui[210]

#define sipType_QPainter_PixmapFragmentHint sipExportedTypes_QtGui[213]

#define sipType_QPainter_CompositionMode sipExportedTypes_QtGui[211]

#define sipType_QPainter_RenderHint sipExportedTypes_QtGui[215]

extern sipClassTypeDef sipTypeDef_QtGui_QPainter;

#define sipType_QPainter_RenderHints sipExportedTypes_QtGui[216]

extern sipClassTypeDef sipTypeDef_QtGui_QPainter_RenderHints;

#define sipType_QPainter_PixmapFragment sipExportedTypes_QtGui[212]

extern sipClassTypeDef sipTypeDef_QtGui_QPainter_PixmapFragment;

#define sipType_QPainter_PixmapFragmentHints sipExportedTypes_QtGui[214]

extern sipClassTypeDef sipTypeDef_QtGui_QPainter_PixmapFragmentHints;

#define sipType_QTextItem sipExportedTypes_QtGui[326]

#define sipType_QTextItem_RenderFlag sipExportedTypes_QtGui[327]

extern sipClassTypeDef sipTypeDef_QtGui_QTextItem;

#define sipType_QTextItem_RenderFlags sipExportedTypes_QtGui[328]

extern sipClassTypeDef sipTypeDef_QtGui_QTextItem_RenderFlags;

#define sipType_QPaintEngine sipExportedTypes_QtGui[201]

#define sipType_QPaintEngine_Type sipExportedTypes_QtGui[207]

#define sipType_QPaintEngine_PolygonDrawMode sipExportedTypes_QtGui[206]

#define sipType_QPaintEngine_DirtyFlag sipExportedTypes_QtGui[202]

#define sipType_QPaintEngine_PaintEngineFeature sipExportedTypes_QtGui[204]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngine;

#define sipType_QPaintEngine_PaintEngineFeatures sipExportedTypes_QtGui[205]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngine_PaintEngineFeatures;

#define sipType_QPaintEngine_DirtyFlags sipExportedTypes_QtGui[203]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngine_DirtyFlags;

#define sipType_QPaintEngineState sipExportedTypes_QtGui[208]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngineState;

#define sipType_QPainterPath sipExportedTypes_QtGui[217]

#define sipType_QPainterPath_ElementType sipExportedTypes_QtGui[219]

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPath;

#define sipType_QPainterPath_Element sipExportedTypes_QtGui[218]

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPath_Element;

#define sipType_QPainterPathStroker sipExportedTypes_QtGui[220]

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPathStroker;

#define sipType_QPalette sipExportedTypes_QtGui[223]

#define sipType_QPalette_ColorRole sipExportedTypes_QtGui[225]

#define sipType_QPalette_ColorGroup sipExportedTypes_QtGui[224]

extern sipClassTypeDef sipTypeDef_QtGui_QPalette;

#define sipType_QPdfWriter sipExportedTypes_QtGui[226]

extern sipClassTypeDef sipTypeDef_QtGui_QPdfWriter;

#define sipType_QPen sipExportedTypes_QtGui[227]

extern sipClassTypeDef sipTypeDef_QtGui_QPen;

#define sipType_QPicture sipExportedTypes_QtGui[228]

extern sipClassTypeDef sipTypeDef_QtGui_QPicture;

#define sipType_QPictureIO sipExportedTypes_QtGui[229]

extern sipClassTypeDef sipTypeDef_QtGui_QPictureIO;

#define sipType_QPixelFormat sipExportedTypes_QtGui[230]

#define sipType_QPixelFormat_ByteOrder sipExportedTypes_QtGui[234]

#define sipType_QPixelFormat_YUVLayout sipExportedTypes_QtGui[237]

#define sipType_QPixelFormat_TypeInterpretation sipExportedTypes_QtGui[236]

#define sipType_QPixelFormat_AlphaPremultiplied sipExportedTypes_QtGui[232]

#define sipType_QPixelFormat_AlphaPosition sipExportedTypes_QtGui[231]

#define sipType_QPixelFormat_AlphaUsage sipExportedTypes_QtGui[233]

#define sipType_QPixelFormat_ColorModel sipExportedTypes_QtGui[235]

extern sipClassTypeDef sipTypeDef_QtGui_QPixelFormat;

#define sipType_QPixmapCache sipExportedTypes_QtGui[239]

extern sipClassTypeDef sipTypeDef_QtGui_QPixmapCache;

#define sipType_QPixmapCache_Key sipExportedTypes_QtGui[240]

extern sipClassTypeDef sipTypeDef_QtGui_QPixmapCache_Key;

#define sipType_QPolygon sipExportedTypes_QtGui[244]

extern sipClassTypeDef sipTypeDef_QtGui_QPolygon;

#define sipType_QPolygonF sipExportedTypes_QtGui[245]

extern sipClassTypeDef sipTypeDef_QtGui_QPolygonF;

#define sipType_QQuaternion sipExportedTypes_QtGui[246]

extern sipClassTypeDef sipTypeDef_QtGui_QQuaternion;

#define sipType_QRasterWindow sipExportedTypes_QtGui[248]

extern sipClassTypeDef sipTypeDef_QtGui_QRasterWindow;

#define sipType_QRawFont sipExportedTypes_QtGui[249]

#define sipType_QRawFont_LayoutFlag sipExportedTypes_QtGui[251]

#define sipType_QRawFont_AntialiasingType sipExportedTypes_QtGui[250]

extern sipClassTypeDef sipTypeDef_QtGui_QRawFont;

#define sipType_QRawFont_LayoutFlags sipExportedTypes_QtGui[252]

extern sipClassTypeDef sipTypeDef_QtGui_QRawFont_LayoutFlags;

#define sipType_QRegion sipExportedTypes_QtGui[254]

#define sipType_QRegion_RegionType sipExportedTypes_QtGui[255]

extern sipClassTypeDef sipTypeDef_QtGui_QRegion;

#define sipType_QRgba64 sipExportedTypes_QtGui[258]

extern sipClassTypeDef sipTypeDef_QtGui_QRgba64;

#define sipType_QScreen sipExportedTypes_QtGui[259]

extern sipClassTypeDef sipTypeDef_QtGui_QScreen;

#define sipType_QStandardItemModel sipExportedTypes_QtGui[268]

extern sipClassTypeDef sipTypeDef_QtGui_QStandardItemModel;

#define sipType_QStandardItem sipExportedTypes_QtGui[266]

#define sipType_QStandardItem_ItemType sipExportedTypes_QtGui[267]

extern sipClassTypeDef sipTypeDef_QtGui_QStandardItem;

#define sipType_QStaticText sipExportedTypes_QtGui[269]

#define sipType_QStaticText_PerformanceHint sipExportedTypes_QtGui[270]

extern sipClassTypeDef sipTypeDef_QtGui_QStaticText;

#define sipType_QStyleHints sipExportedTypes_QtGui[272]

extern sipClassTypeDef sipTypeDef_QtGui_QStyleHints;

#define sipType_QSurfaceFormat sipExportedTypes_QtGui[276]

#define sipType_QSurfaceFormat_ColorSpace sipExportedTypes_QtGui[277]

#define sipType_QSurfaceFormat_OpenGLContextProfile sipExportedTypes_QtGui[280]

#define sipType_QSurfaceFormat_RenderableType sipExportedTypes_QtGui[281]

#define sipType_QSurfaceFormat_SwapBehavior sipExportedTypes_QtGui[282]

#define sipType_QSurfaceFormat_FormatOption sipExportedTypes_QtGui[278]

extern sipClassTypeDef sipTypeDef_QtGui_QSurfaceFormat;

#define sipType_QSurfaceFormat_FormatOptions sipExportedTypes_QtGui[279]

extern sipClassTypeDef sipTypeDef_QtGui_QSurfaceFormat_FormatOptions;

#define sipType_QSyntaxHighlighter sipExportedTypes_QtGui[283]

extern sipClassTypeDef sipTypeDef_QtGui_QSyntaxHighlighter;

#define sipType_QTextCursor sipExportedTypes_QtGui[298]

#define sipType_QTextCursor_SelectionType sipExportedTypes_QtGui[301]

#define sipType_QTextCursor_MoveOperation sipExportedTypes_QtGui[300]

#define sipType_QTextCursor_MoveMode sipExportedTypes_QtGui[299]

extern sipClassTypeDef sipTypeDef_QtGui_QTextCursor;


extern sipClassTypeDef sipTypeDef_QtGui_Qt;

#define sipType_QTextDocument sipExportedTypes_QtGui[302]

#define sipType_QTextDocument_MarkdownFeature sipExportedTypes_QtGui[305]

#define sipType_QTextDocument_Stacks sipExportedTypes_QtGui[309]

#define sipType_QTextDocument_ResourceType sipExportedTypes_QtGui[308]

#define sipType_QTextDocument_FindFlag sipExportedTypes_QtGui[303]

#define sipType_QTextDocument_MetaInformation sipExportedTypes_QtGui[307]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocument;

#define sipType_QTextDocument_FindFlags sipExportedTypes_QtGui[304]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocument_FindFlags;

#define sipType_QTextDocument_MarkdownFeatures sipExportedTypes_QtGui[306]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocument_MarkdownFeatures;

#define sipType_QTextDocumentFragment sipExportedTypes_QtGui[310]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocumentFragment;

#define sipType_QTextDocumentWriter sipExportedTypes_QtGui[311]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocumentWriter;

#define sipType_QTextLength sipExportedTypes_QtGui[332]

#define sipType_QTextLength_Type sipExportedTypes_QtGui[333]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLength;

#define sipType_QTextFormat sipExportedTypes_QtGui[312]

#define sipType_QTextFormat_Property sipExportedTypes_QtGui[317]

#define sipType_QTextFormat_PageBreakFlag sipExportedTypes_QtGui[315]

#define sipType_QTextFormat_ObjectTypes sipExportedTypes_QtGui[314]

#define sipType_QTextFormat_FormatType sipExportedTypes_QtGui[313]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFormat;

#define sipType_QTextFormat_PageBreakFlags sipExportedTypes_QtGui[316]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFormat_PageBreakFlags;

#define sipType_QTextCharFormat sipExportedTypes_QtGui[294]

#define sipType_QTextCharFormat_FontPropertiesInheritanceBehavior sipExportedTypes_QtGui[295]

#define sipType_QTextCharFormat_UnderlineStyle sipExportedTypes_QtGui[296]

#define sipType_QTextCharFormat_VerticalAlignment sipExportedTypes_QtGui[297]

extern sipClassTypeDef sipTypeDef_QtGui_QTextCharFormat;

#define sipType_QTextBlockFormat sipExportedTypes_QtGui[289]

#define sipType_QTextBlockFormat_MarkerType sipExportedTypes_QtGui[291]

#define sipType_QTextBlockFormat_LineHeightTypes sipExportedTypes_QtGui[290]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockFormat;

#define sipType_QTextListFormat sipExportedTypes_QtGui[338]

#define sipType_QTextListFormat_Style sipExportedTypes_QtGui[339]

extern sipClassTypeDef sipTypeDef_QtGui_QTextListFormat;

#define sipType_QTextImageFormat sipExportedTypes_QtGui[324]

extern sipClassTypeDef sipTypeDef_QtGui_QTextImageFormat;

#define sipType_QTextFrameFormat sipExportedTypes_QtGui[321]

#define sipType_QTextFrameFormat_BorderStyle sipExportedTypes_QtGui[322]

#define sipType_QTextFrameFormat_Position sipExportedTypes_QtGui[323]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrameFormat;

#define sipType_QTextTableFormat sipExportedTypes_QtGui[351]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableFormat;

#define sipType_QTextTableCellFormat sipExportedTypes_QtGui[350]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableCellFormat;

#define sipType_QTextInlineObject sipExportedTypes_QtGui[325]

extern sipClassTypeDef sipTypeDef_QtGui_QTextInlineObject;

#define sipType_QTextLayout sipExportedTypes_QtGui[329]

#define sipType_QTextLayout_CursorMode sipExportedTypes_QtGui[330]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLayout;

#define sipType_QTextLayout_FormatRange sipExportedTypes_QtGui[331]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLayout_FormatRange;

#define sipType_QTextLine sipExportedTypes_QtGui[334]

#define sipType_QTextLine_CursorPosition sipExportedTypes_QtGui[335]

#define sipType_QTextLine_Edge sipExportedTypes_QtGui[336]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLine;

#define sipType_QTextObject sipExportedTypes_QtGui[340]

extern sipClassTypeDef sipTypeDef_QtGui_QTextObject;

#define sipType_QTextBlockGroup sipExportedTypes_QtGui[292]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockGroup;

#define sipType_QTextList sipExportedTypes_QtGui[337]

extern sipClassTypeDef sipTypeDef_QtGui_QTextList;

#define sipType_QTextFrame sipExportedTypes_QtGui[319]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrame;

#define sipType_QTextFrame_iterator sipExportedTypes_QtGui[320]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrame_iterator;

#define sipType_QTextBlock sipExportedTypes_QtGui[287]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlock;

#define sipType_QTextBlock_iterator sipExportedTypes_QtGui[288]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlock_iterator;

#define sipType_QTextFragment sipExportedTypes_QtGui[318]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFragment;

#define sipType_QTextBlockUserData sipExportedTypes_QtGui[293]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockUserData;

#define sipType_QTextOption sipExportedTypes_QtGui[342]

#define sipType_QTextOption_TabType sipExportedTypes_QtGui[346]

#define sipType_QTextOption_Flag sipExportedTypes_QtGui[343]

#define sipType_QTextOption_WrapMode sipExportedTypes_QtGui[347]

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption;

#define sipType_QTextOption_Flags sipExportedTypes_QtGui[344]

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption_Flags;

#define sipType_QTextOption_Tab sipExportedTypes_QtGui[345]

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption_Tab;

#define sipType_QTextTableCell sipExportedTypes_QtGui[349]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableCell;

#define sipType_QTextTable sipExportedTypes_QtGui[348]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTable;

#define sipType_QTouchDevice sipExportedTypes_QtGui[352]

#define sipType_QTouchDevice_CapabilityFlag sipExportedTypes_QtGui[354]

#define sipType_QTouchDevice_DeviceType sipExportedTypes_QtGui[355]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchDevice;

#define sipType_QTouchDevice_Capabilities sipExportedTypes_QtGui[353]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchDevice_Capabilities;

#define sipType_QTransform sipExportedTypes_QtGui[360]

#define sipType_QTransform_TransformationType sipExportedTypes_QtGui[361]

extern sipClassTypeDef sipTypeDef_QtGui_QTransform;

#define sipType_QValidator sipExportedTypes_QtGui[362]

#define sipType_QValidator_State sipExportedTypes_QtGui[363]

extern sipClassTypeDef sipTypeDef_QtGui_QValidator;

#define sipType_QIntValidator sipExportedTypes_QtGui[91]

extern sipClassTypeDef sipTypeDef_QtGui_QIntValidator;

#define sipType_QDoubleValidator sipExportedTypes_QtGui[27]

#define sipType_QDoubleValidator_Notation sipExportedTypes_QtGui[28]

extern sipClassTypeDef sipTypeDef_QtGui_QDoubleValidator;

#define sipType_QRegExpValidator sipExportedTypes_QtGui[253]

extern sipClassTypeDef sipTypeDef_QtGui_QRegExpValidator;

#define sipType_QRegularExpressionValidator sipExportedTypes_QtGui[256]

extern sipClassTypeDef sipTypeDef_QtGui_QRegularExpressionValidator;

#define sipType_QVector2D sipExportedTypes_QtGui[364]

extern sipClassTypeDef sipTypeDef_QtGui_QVector2D;

#define sipType_QVector3D sipExportedTypes_QtGui[365]

extern sipClassTypeDef sipTypeDef_QtGui_QVector3D;

#define sipType_QVector4D sipExportedTypes_QtGui[366]

extern sipClassTypeDef sipTypeDef_QtGui_QVector4D;

#define sipType_QList_0111QTouchDevice sipExportedTypes_QtGui[113]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0111QTouchDevice;

#define sipType_QList_0101QTextFrame sipExportedTypes_QtGui[110]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QTextFrame;

#define sipType_QList_0100QTextBlock sipExportedTypes_QtGui[109]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextBlock;

#define sipType_QList_0100QGlyphRun sipExportedTypes_QtGui[99]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QGlyphRun;

#define sipType_QVector_0100QTextLayout_FormatRange sipExportedTypes_QtGui[373]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QTextLayout_FormatRange;

#define sipType_QList_0100QTextLayout_FormatRange sipExportedTypes_QtGui[111]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextLayout_FormatRange;

#define sipType_QList_0100QTextOption_Tab sipExportedTypes_QtGui[112]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextOption_Tab;

#define sipType_QVector_0100QTextLength sipExportedTypes_QtGui[374]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QTextLength;

#define sipType_QVector_0100QTextFormat sipExportedTypes_QtGui[372]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QTextFormat;

#define sipType_QList_0101QStandardItem sipExportedTypes_QtGui[108]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QStandardItem;

#define sipType_QVector_0100QRect sipExportedTypes_QtGui[370]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QRect;

#define sipType_QVector_0100QPoint sipExportedTypes_QtGui[369]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QPoint;

#define sipType_QList_0100QPolygonF sipExportedTypes_QtGui[105]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QPolygonF;

#define sipType_QList_0101QOpenGLShader sipExportedTypes_QtGui[104]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QOpenGLShader;

#define sipType_QVector_0100QSize sipExportedTypes_QtGui[371]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QSize;

#define sipType_QList_0100QOpenGLDebugMessage sipExportedTypes_QtGui[103]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QOpenGLDebugMessage;

#define sipType_QSet_0100QByteArray sipExportedTypes_QtGui[263]

extern sipMappedTypeDef sipTypeDef_QtGui_QSet_0100QByteArray;

#define sipType_QList_0101QOpenGLContext sipExportedTypes_QtGui[102]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QOpenGLContext;

#define sipType_QList_0100QKeySequence sipExportedTypes_QtGui[101]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QKeySequence;

#define sipType_QList_0101QScreen sipExportedTypes_QtGui[106]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QScreen;

#define sipType_QList_0100QTouchEvent_TouchPoint sipExportedTypes_QtGui[114]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTouchEvent_TouchPoint;

#define sipType_QList_0100QInputMethodEvent_Attribute sipExportedTypes_QtGui[100]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QInputMethodEvent_Attribute;

#define sipType_QList_0100QSize sipExportedTypes_QtGui[107]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QSize;

#define sipType_QVector_0100QAbstractTextDocumentLayout_Selection sipExportedTypes_QtGui[367]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QAbstractTextDocumentLayout_Selection;

#define sipType_QList_0101QWindow sipExportedTypes_QtGui[115]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QWindow;

#define sipType_QVector_0600QPair_2400_0100QColor sipExportedTypes_QtGui[368]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0600QPair_2400_0100QColor;

#define sipType_QVector_2400 sipExportedTypes_QtGui[376]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_2400;

#define sipType_QVector_2200 sipExportedTypes_QtGui[375]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_2200;

#define sipType_QVector_1900 sipExportedTypes_QtGui[377]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_1900;

#define sipType_QList_0100QFontDatabase_WritingSystem sipExportedTypes_QtGui[98]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QFontDatabase_WritingSystem;

#define sipType_QPair_2200_2200 sipExportedTypes_QtGui[222]

extern sipMappedTypeDef sipTypeDef_QtGui_QPair_2200_2200;

#define sipType_QPair_0100QOpenGLTexture_Filter_0100QOpenGLTexture_Filter sipExportedTypes_QtGui[221]

extern sipMappedTypeDef sipTypeDef_QtGui_QPair_0100QOpenGLTexture_Filter_0100QOpenGLTexture_Filter;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtGui;
extern sipExportedModuleDef sipModuleAPI_QtGui;
extern sipTypeDef *sipExportedTypes_QtGui[];

#if !defined(sipType_Qt)
#define sipType_Qt sipImportedTypes_QtGui_QtCore[42].it_td
#endif

#define sipType_Qt_HighDpiScaleFactorRoundingPolicy sipImportedTypes_QtGui_QtCore[59].it_td

#define sipType_Qt_TabFocusBehavior sipImportedTypes_QtGui_QtCore[83].it_td

#define sipType_Qt_MouseEventSource sipImportedTypes_QtGui_QtCore[72].it_td

#define sipType_Qt_ScrollPhase sipImportedTypes_QtGui_QtCore[80].it_td

#define sipType_Qt_NativeGestureType sipImportedTypes_QtGui_QtCore[73].it_td

#define sipType_Qt_ApplicationState sipImportedTypes_QtGui_QtCore[44].it_td

#define sipType_Qt_HitTestAccuracy sipImportedTypes_QtGui_QtCore[60].it_td

#define sipType_Qt_WhiteSpaceMode sipImportedTypes_QtGui_QtCore[89].it_td

#define sipType_Qt_ScreenOrientation sipImportedTypes_QtGui_QtCore[78].it_td

#define sipType_Qt_CursorMoveStyle sipImportedTypes_QtGui_QtCore[51].it_td

#define sipType_Qt_TouchPointState sipImportedTypes_QtGui_QtCore[86].it_td

#define sipType_Qt_SizeMode sipImportedTypes_QtGui_QtCore[81].it_td

#define sipType_Qt_Axis sipImportedTypes_QtGui_QtCore[46].it_td

#define sipType_Qt_MaskMode sipImportedTypes_QtGui_QtCore[67].it_td

#define sipType_Qt_WindowModality sipImportedTypes_QtGui_QtCore[91].it_td

#define sipType_Qt_CheckState sipImportedTypes_QtGui_QtCore[49].it_td

#define sipType_Qt_DropAction sipImportedTypes_QtGui_QtCore[53].it_td

#define sipType_Qt_LayoutDirection sipImportedTypes_QtGui_QtCore[66].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtGui_QtCore[63].it_td

#define sipType_Qt_FocusReason sipImportedTypes_QtGui_QtCore[57].it_td

#define sipType_Qt_TransformationMode sipImportedTypes_QtGui_QtCore[88].it_td

#define sipType_Qt_ClipOperation sipImportedTypes_QtGui_QtCore[50].it_td

#define sipType_Qt_FillRule sipImportedTypes_QtGui_QtCore[56].it_td

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtGui_QtCore[45].it_td

#define sipType_Qt_TextFormat sipImportedTypes_QtGui_QtCore[85].it_td

#define sipType_Qt_CursorShape sipImportedTypes_QtGui_QtCore[52].it_td

#define sipType_Qt_BrushStyle sipImportedTypes_QtGui_QtCore[48].it_td

#define sipType_Qt_PenJoinStyle sipImportedTypes_QtGui_QtCore[76].it_td

#define sipType_Qt_PenCapStyle sipImportedTypes_QtGui_QtCore[75].it_td

#define sipType_Qt_PenStyle sipImportedTypes_QtGui_QtCore[77].it_td

#define sipType_Qt_BGMode sipImportedTypes_QtGui_QtCore[47].it_td

#define sipType_Qt_WindowState sipImportedTypes_QtGui_QtCore[92].it_td

#define sipType_Qt_WindowType sipImportedTypes_QtGui_QtCore[94].it_td

#define sipType_Qt_TextElideMode sipImportedTypes_QtGui_QtCore[84].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtGui_QtCore[82].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtGui_QtCore[74].it_td

#define sipType_Qt_MouseButton sipImportedTypes_QtGui_QtCore[69].it_td

#define sipType_Qt_GlobalColor sipImportedTypes_QtGui_QtCore[58].it_td

#define sipType_Qt_KeyboardModifiers sipImportedTypes_QtGui_QtCore[65].it_td

#define sipType_Qt_MouseButtons sipImportedTypes_QtGui_QtCore[70].it_td

#define sipType_Qt_Alignment sipImportedTypes_QtGui_QtCore[43].it_td

#define sipType_Qt_WindowFlags sipImportedTypes_QtGui_QtCore[90].it_td

#define sipType_Qt_WindowStates sipImportedTypes_QtGui_QtCore[93].it_td

#define sipType_Qt_ImageConversionFlags sipImportedTypes_QtGui_QtCore[61].it_td

#define sipType_Qt_InputMethodQueries sipImportedTypes_QtGui_QtCore[62].it_td

#define sipType_Qt_DropActions sipImportedTypes_QtGui_QtCore[54].it_td

#define sipType_Qt_ItemFlags sipImportedTypes_QtGui_QtCore[64].it_td

#define sipType_Qt_MatchFlags sipImportedTypes_QtGui_QtCore[68].it_td

#define sipType_Qt_TouchPointStates sipImportedTypes_QtGui_QtCore[87].it_td

#define sipType_Qt_ScreenOrientations sipImportedTypes_QtGui_QtCore[79].it_td

#define sipType_Qt_Edges sipImportedTypes_QtGui_QtCore[55].it_td

#define sipType_Qt_MouseEventFlags sipImportedTypes_QtGui_QtCore[71].it_td

#define sipType_QObject sipImportedTypes_QtGui_QtCore[25].it_td

#define sipType_QModelIndex sipImportedTypes_QtGui_QtCore[24].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtGui_QtCore[0].it_td

#define sipType_QIODevice sipImportedTypes_QtGui_QtCore[10].it_td

#define sipType_QByteArray sipImportedTypes_QtGui_QtCore[1].it_td

#define sipType_QCoreApplication sipImportedTypes_QtGui_QtCore[4].it_td

#define sipType_QEvent sipImportedTypes_QtGui_QtCore[6].it_td

#define sipType_QEvent_Type sipImportedTypes_QtGui_QtCore[7].it_td

#define sipType_QTimerEvent sipImportedTypes_QtGui_QtCore[38].it_td

#define sipType_QChildEvent sipImportedTypes_QtGui_QtCore[3].it_td

#define sipType_QDataStream sipImportedTypes_QtGui_QtCore[5].it_td

#define sipType_QFile sipImportedTypes_QtGui_QtCore[8].it_td

#define sipType_QIODevice_OpenMode sipImportedTypes_QtGui_QtCore[11].it_td

#define sipType_QLine sipImportedTypes_QtGui_QtCore[12].it_td

#define sipType_QLineF sipImportedTypes_QtGui_QtCore[13].it_td

#define sipType_QLocale sipImportedTypes_QtGui_QtCore[18].it_td

#define sipType_QMargins sipImportedTypes_QtGui_QtCore[20].it_td

#define sipType_QMarginsF sipImportedTypes_QtGui_QtCore[21].it_td

#define sipType_QMetaMethod sipImportedTypes_QtGui_QtCore[22].it_td

#define sipType_QMimeData sipImportedTypes_QtGui_QtCore[23].it_td

#define sipType_QPoint sipImportedTypes_QtGui_QtCore[27].it_td

#define sipType_QPointF sipImportedTypes_QtGui_QtCore[28].it_td

#define sipType_QRect sipImportedTypes_QtGui_QtCore[29].it_td

#define sipType_QRectF sipImportedTypes_QtGui_QtCore[30].it_td

#define sipType_QRegExp sipImportedTypes_QtGui_QtCore[31].it_td

#define sipType_QRegularExpression sipImportedTypes_QtGui_QtCore[32].it_td

#define sipType_QSize sipImportedTypes_QtGui_QtCore[33].it_td

#define sipType_QSizeF sipImportedTypes_QtGui_QtCore[34].it_td

#define sipType_QTextCodec sipImportedTypes_QtGui_QtCore[37].it_td

#define sipType_QUrl sipImportedTypes_QtGui_QtCore[39].it_td

#define sipType_QVariant sipImportedTypes_QtGui_QtCore[40].it_td

#define sipType_QVector_0100QPointF sipImportedTypes_QtGui_QtCore[41].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtGui_QtCore[9].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtGui_QtCore[19].it_td

#define sipType_QList_0100QByteArray sipImportedTypes_QtGui_QtCore[14].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtGui_QtCore[15].it_td

#define sipType_QPair_1800_1800 sipImportedTypes_QtGui_QtCore[26].it_td

#define sipType_QStringList sipImportedTypes_QtGui_QtCore[36].it_td

#define sipType_QList_2400 sipImportedTypes_QtGui_QtCore[17].it_td

#define sipType_QList_1800 sipImportedTypes_QtGui_QtCore[16].it_td

#define sipType_QString sipImportedTypes_QtGui_QtCore[35].it_td

#define sipType_QChar sipImportedTypes_QtGui_QtCore[2].it_td

#define sipType_quintptr sipImportedTypes_QtGui_QtCore[95].it_td
extern sipImportedTypeDef sipImportedTypes_QtGui_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtGui_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtGui_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtGui_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtGui_qt_metacast;
#line 173 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qfontmetrics.sip"
// Used by QFontMetrics and QFontMetricsF.
int *qtgui_tabarray(PyObject *l);
#line 321 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qguiapplication.sip"
// Imports from QtCore.
typedef void (*pyqt5_qtgui_cleanup_qobjects_t)();
extern pyqt5_qtgui_cleanup_qobjects_t pyqt5_qtgui_cleanup_qobjects;

typedef char **(*pyqt5_qtgui_from_argv_list_t)(PyObject *, int &);
extern pyqt5_qtgui_from_argv_list_t pyqt5_qtgui_from_argv_list;

typedef void (*pyqt5_qtgui_update_argv_list_t)(PyObject *, int, char **);
extern pyqt5_qtgui_update_argv_list_t pyqt5_qtgui_update_argv_list;
#line 268 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qimage.sip"
const char **QtGui_ListToArray(PyObject *lst);
void QtGui_DeleteArray(const char **arr);
#line 216 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qmatrix4x4.sip"
// Helpers for the matrix classes.
typedef float PYQT_FLOAT;

sipErrorState qtgui_matrixParseIndex(PyObject *tup, int nr_rows,
        int nr_columns, int *row, int *column);
sipErrorState qtgui_matrixDataFromSequence(PyObject *seq, int nr_values,
        PYQT_FLOAT *values);
sipErrorState qtgui_matrixDataAsList(int nr_values, const PYQT_FLOAT *values,
        PyObject **list);
#line 335 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qopenglshaderprogram.sip"
#include "qpyopengl_api.h"
#line 256 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qtextobject.sip"
PyObject *qtgui_wrap_ancestors(QObject *obj, const sipTypeDef *td);
#line 10333 "/usr/src/debug/python3-pyqt5/5.15.10/QtGui/sipAPIQtGui.h"

#endif
