/*
 * Internal module API header file.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtCoreAPI_H
#define _QtCoreAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#define PY_SSIZE_T_CLEAN

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QCommandLineParser__OptionsAfterPositionalArgumentsMode 0
#define sipName_QCommandLineParser__OptionsAfterPositionalArgumentsMode &sipStrings_QtCore[0]
#define sipNameNr_QCommandLineParser__SingleDashWordOptionMode 56
#define sipName_QCommandLineParser__SingleDashWordOptionMode &sipStrings_QtCore[56]
#define sipNameNr_AA_SynthesizeMouseForUnhandledTabletEvents 101
#define sipName_AA_SynthesizeMouseForUnhandledTabletEvents &sipStrings_QtCore[101]
#define sipNameNr_144 144
#define sipName_144 &sipStrings_QtCore[144]
#define sipNameNr_QXmlStreamReader__ReadElementTextBehaviour 187
#define sipName_QXmlStreamReader__ReadElementTextBehaviour &sipStrings_QtCore[187]
#define sipNameNr_AA_SynthesizeMouseForUnhandledTouchEvents 230
#define sipName_AA_SynthesizeMouseForUnhandledTouchEvents &sipStrings_QtCore[230]
#define sipNameNr_AA_SynthesizeTouchForUnhandledMouseEvents 272
#define sipName_AA_SynthesizeTouchForUnhandledMouseEvents &sipStrings_QtCore[272]
#define sipNameNr_AA_UseStyleSheetPropagationInWidgetStyles 314
#define sipName_AA_UseStyleSheetPropagationInWidgetStyles &sipStrings_QtCore[314]
#define sipNameNr_AA_DontCheckOpenGLContextThreadAffinity 356
#define sipName_AA_DontCheckOpenGLContextThreadAffinity &sipStrings_QtCore[356]
#define sipNameNr_396 396
#define sipName_396 &sipStrings_QtCore[396]
#define sipNameNr_StateMachineChildModeSetToParallelError 436
#define sipName_StateMachineChildModeSetToParallelError &sipStrings_QtCore[436]
#define sipNameNr_QSystemSemaphore__SystemSemaphoreError 476
#define sipName_QSystemSemaphore__SystemSemaphoreError &sipStrings_QtCore[476]
#define sipNameNr_515 515
#define sipName_515 &sipStrings_QtCore[515]
#define sipNameNr_SouthGeorgiaAndTheSouthSandwichIslands 554
#define sipName_SouthGeorgiaAndTheSouthSandwichIslands &sipStrings_QtCore[554]
#define sipNameNr_setOptionsAfterPositionalArgumentsMode 593
#define sipName_setOptionsAfterPositionalArgumentsMode &sipStrings_QtCore[593]
#define sipNameNr_QAbstractItemModel__CheckIndexOptions 632
#define sipName_QAbstractItemModel__CheckIndexOptions &sipStrings_QtCore[632]
#define sipNameNr_QLocale__FloatingPointPrecisionOption 670
#define sipName_QLocale__FloatingPointPrecisionOption &sipStrings_QtCore[670]
#define sipNameNr_QAbstractItemModel__CheckIndexOption 708
#define sipName_QAbstractItemModel__CheckIndexOption &sipStrings_QtCore[708]
#define sipNameNr_QAbstractItemModel__LayoutChangeHint 745
#define sipName_QAbstractItemModel__LayoutChangeHint &sipStrings_QtCore[745]
#define sipNameNr_QTextBoundaryFinder__BoundaryReasons 782
#define sipName_QTextBoundaryFinder__BoundaryReasons &sipStrings_QtCore[782]
#define sipNameNr_819 819
#define sipName_819 &sipStrings_QtCore[819]
#define sipNameNr_Qt__HighDpiScaleFactorRoundingPolicy 856
#define sipName_Qt__HighDpiScaleFactorRoundingPolicy &sipStrings_QtCore[856]
#define sipNameNr_MaximizeUsingFullscreenGeometryHint 893
#define sipName_MaximizeUsingFullscreenGeometryHint &sipStrings_QtCore[893]
#define sipNameNr_OptionsAfterPositionalArgumentsMode 20
#define sipName_OptionsAfterPositionalArgumentsMode &sipStrings_QtCore[20]
#define sipNameNr_QAbstractEventDispatcher__TimerInfo 929
#define sipName_QAbstractEventDispatcher__TimerInfo &sipStrings_QtCore[929]
#define sipNameNr_QAbstractTransition__TransitionType 965
#define sipName_QAbstractTransition__TransitionType &sipStrings_QtCore[965]
#define sipNameNr_QCborStreamReader__StringResultCode 1001
#define sipName_QCborStreamReader__StringResultCode &sipStrings_QtCore[1001]
#define sipNameNr_QDataStream__FloatingPointPrecision 1037
#define sipName_QDataStream__FloatingPointPrecision &sipStrings_QtCore[1037]
#define sipNameNr_QItemSelectionModel__SelectionFlags 1073
#define sipName_QItemSelectionModel__SelectionFlags &sipStrings_QtCore[1073]
#define sipNameNr_QTextBoundaryFinder__BoundaryReason 1109
#define sipName_QTextBoundaryFinder__BoundaryReason &sipStrings_QtCore[1109]
#define sipNameNr_AA_DontShowShortcutsInContextMenus 1145
#define sipName_AA_DontShowShortcutsInContextMenus &sipStrings_QtCore[1145]
#define sipNameNr_MouseEventSynthesizedByApplication 1180
#define sipName_MouseEventSynthesizedByApplication &sipStrings_QtCore[1180]
#define sipNameNr_NoCommonAncestorForTransitionError 1215
#define sipName_NoCommonAncestorForTransitionError &sipStrings_QtCore[1215]
#define sipNameNr_QAbstractAnimation__DeletionPolicy 1250
#define sipName_QAbstractAnimation__DeletionPolicy &sipStrings_QtCore[1250]
#define sipNameNr_QItemSelectionModel__SelectionFlag 1285
#define sipName_QItemSelectionModel__SelectionFlag &sipStrings_QtCore[1285]
#define sipNameNr_QRegularExpression__PatternOptions 1320
#define sipName_QRegularExpression__PatternOptions &sipStrings_QtCore[1320]
#define sipNameNr_WA_ContentsMarginsRespectsSafeArea 1355
#define sipName_WA_ContentsMarginsRespectsSafeArea &sipStrings_QtCore[1355]
#define sipNameNr_WA_TouchPadAcceptSingleTouchEvents 1390
#define sipName_WA_TouchPadAcceptSingleTouchEvents &sipStrings_QtCore[1390]
#define sipNameNr_AA_DisableWindowContextHelpButton 1425
#define sipName_AA_DisableWindowContextHelpButton &sipStrings_QtCore[1425]
#define sipNameNr_AA_DontCreateNativeWidgetSiblings 1459
#define sipName_AA_DontCreateNativeWidgetSiblings &sipStrings_QtCore[1459]
#define sipNameNr_DontCheckSubjectStringMatchOption 1493
#define sipName_DontCheckSubjectStringMatchOption &sipStrings_QtCore[1493]
#define sipNameNr_NoDefaultStateInHistoryStateError 1527
#define sipName_NoDefaultStateInHistoryStateError &sipStrings_QtCore[1527]
#define sipNameNr_QRegularExpression__PatternOption 1561
#define sipName_QRegularExpression__PatternOption &sipStrings_QtCore[1561]
#define sipNameNr_QTextBoundaryFinder__BoundaryType 1595
#define sipName_QTextBoundaryFinder__BoundaryType &sipStrings_QtCore[1595]
#define sipNameNr_WA_X11NetWmWindowTypeDropDownMenu 1629
#define sipName_WA_X11NetWmWindowTypeDropDownMenu &sipStrings_QtCore[1629]
#define sipNameNr_WA_X11NetWmWindowTypeNotification 1663
#define sipName_WA_X11NetWmWindowTypeNotification &sipStrings_QtCore[1663]
#define sipNameNr_AA_MSWindowsUseDirect3DByDefault 1697
#define sipName_AA_MSWindowsUseDirect3DByDefault &sipStrings_QtCore[1697]
#define sipNameNr_ApplicationLayoutDirectionChange 1730
#define sipName_ApplicationLayoutDirectionChange &sipStrings_QtCore[1730]
#define sipNameNr_HighDpiScaleFactorRoundingPolicy 860
#define sipName_HighDpiScaleFactorRoundingPolicy &sipStrings_QtCore[860]
#define sipNameNr_IgnoredGesturesPropagateToParent 1763
#define sipName_IgnoredGesturesPropagateToParent &sipStrings_QtCore[1763]
#define sipNameNr_NavigationModeCursorForceVisible 1796
#define sipName_NavigationModeCursorForceVisible &sipStrings_QtCore[1796]
#define sipNameNr_NonClientAreaMouseButtonDblClick 1829
#define sipName_NonClientAreaMouseButtonDblClick &sipStrings_QtCore[1829]
#define sipNameNr_QByteArray__Base64DecodingStatus 1862
#define sipName_QByteArray__Base64DecodingStatus &sipStrings_QtCore[1862]
#define sipNameNr_QRegularExpression__MatchOptions 1895
#define sipName_QRegularExpression__MatchOptions &sipStrings_QtCore[1895]
#define sipNameNr_QSharedMemory__SharedMemoryError 1928
#define sipName_QSharedMemory__SharedMemoryError &sipStrings_QtCore[1928]
#define sipNameNr_QStandardPaths__StandardLocation 1961
#define sipName_QStandardPaths__StandardLocation &sipStrings_QtCore[1961]
#define sipNameNr_QUrl__ComponentFormattingOptions 1994
#define sipName_QUrl__ComponentFormattingOptions &sipStrings_QtCore[1994]
#define sipNameNr_QUrl__UserInputResolutionOptions 2027
#define sipName_QUrl__UserInputResolutionOptions &sipStrings_QtCore[2027]
#define sipNameNr_UnitedStatesMinorOutlyingIslands 2060
#define sipName_UnitedStatesMinorOutlyingIslands &sipStrings_QtCore[2060]
#define sipNameNr_recursiveFilteringEnabledChanged 2093
#define sipName_recursiveFilteringEnabledChanged &sipStrings_QtCore[2093]
#define sipNameNr_AA_DisableNativeVirtualKeyboard 2126
#define sipName_AA_DisableNativeVirtualKeyboard &sipStrings_QtCore[2126]
#define sipNameNr_DontAutomaticallyOptimizeOption 2158
#define sipName_DontAutomaticallyOptimizeOption &sipStrings_QtCore[2158]
#define sipNameNr_NavigationModeKeypadDirectional 2190
#define sipName_NavigationModeKeypadDirectional &sipStrings_QtCore[2190]
#define sipNameNr_NonClientAreaMouseButtonRelease 2222
#define sipName_NonClientAreaMouseButtonRelease &sipStrings_QtCore[2222]
#define sipNameNr_QDeadlineTimer__ForeverConstant 2254
#define sipName_QDeadlineTimer__ForeverConstant &sipStrings_QtCore[2254]
#define sipNameNr_QOperatingSystemVersion__OSType 2286
#define sipName_QOperatingSystemVersion__OSType &sipStrings_QtCore[2286]
#define sipNameNr_QRegularExpression__MatchOption 2318
#define sipName_QRegularExpression__MatchOption &sipStrings_QtCore[2318]
#define sipNameNr_QRegularExpressionMatchIterator 2350
#define sipName_QRegularExpressionMatchIterator &sipStrings_QtCore[2350]
#define sipNameNr_QTextStream__RealNumberNotation 2382
#define sipName_QTextStream__RealNumberNotation &sipStrings_QtCore[2382]
#define sipNameNr_QUrl__ComponentFormattingOption 2414
#define sipName_QUrl__ComponentFormattingOption &sipStrings_QtCore[2414]
#define sipNameNr_QUrl__UserInputResolutionOption 2446
#define sipName_QUrl__UserInputResolutionOption &sipStrings_QtCore[2446]
#define sipNameNr_2478 2478
#define sipName_2478 &sipStrings_QtCore[2478]
#define sipNameNr_AA_CompressHighFrequencyEvents 2510
#define sipName_AA_CompressHighFrequencyEvents &sipStrings_QtCore[2510]
#define sipNameNr_QEventLoop__ProcessEventsFlags 2541
#define sipName_QEventLoop__ProcessEventsFlags &sipStrings_QtCore[2541]
#define sipNameNr_2572 2572
#define sipName_2572 &sipStrings_QtCore[2572]
#define sipNameNr_2603 2603
#define sipName_2603 &sipStrings_QtCore[2603]
#define sipNameNr_QXmlStreamNamespaceDeclaration 2634
#define sipName_QXmlStreamNamespaceDeclaration &sipStrings_QtCore[2634]
#define sipNameNr_WA_X11NetWmWindowTypePopupMenu 2665
#define sipName_WA_X11NetWmWindowTypePopupMenu &sipStrings_QtCore[2665]
#define sipNameNr_GraphicsSceneMouseDoubleClick 2696
#define sipName_GraphicsSceneMouseDoubleClick &sipStrings_QtCore[2696]
#define sipNameNr_IncludeTrailingZeroesAfterDot 2726
#define sipName_IncludeTrailingZeroesAfterDot &sipStrings_QtCore[2726]
#define sipNameNr_MouseEventSynthesizedBySystem 2756
#define sipName_MouseEventSynthesizedBySystem &sipStrings_QtCore[2756]
#define sipNameNr_NonClientAreaMouseButtonPress 2786
#define sipName_NonClientAreaMouseButtonPress &sipStrings_QtCore[2786]
#define sipNameNr_QAbstractAnimation__Direction 2816
#define sipName_QAbstractAnimation__Direction &sipStrings_QtCore[2816]
#define sipNameNr_QCryptographicHash__Algorithm 2846
#define sipName_QCryptographicHash__Algorithm &sipStrings_QtCore[2846]
#define sipNameNr_QEventLoop__ProcessEventsFlag 2876
#define sipName_QEventLoop__ProcessEventsFlag &sipStrings_QtCore[2876]
#define sipNameNr_QJsonDocument__DataValidation 2906
#define sipName_QJsonDocument__DataValidation &sipStrings_QtCore[2906]
#define sipNameNr_QLibraryInfo__LibraryLocation 2936
#define sipName_QLibraryInfo__LibraryLocation &sipStrings_QtCore[2936]
#define sipNameNr_QLocale__CurrencySymbolFormat 2966
#define sipName_QLocale__CurrencySymbolFormat &sipStrings_QtCore[2966]
#define sipNameNr_QReadWriteLock__RecursionMode 2996
#define sipName_QReadWriteLock__RecursionMode &sipStrings_QtCore[2996]
#define sipNameNr_QRegularExpression__MatchType 3026
#define sipName_QRegularExpression__MatchType &sipStrings_QtCore[3026]
#define sipNameNr_QStandardPaths__LocateOptions 3056
#define sipName_QStandardPaths__LocateOptions &sipStrings_QtCore[3056]
#define sipNameNr_QXmlStreamNotationDeclaration 3086
#define sipName_QXmlStreamNotationDeclaration &sipStrings_QtCore[3086]
#define sipNameNr_WindowOverridesSystemGestures 3116
#define sipName_WindowOverridesSystemGestures &sipStrings_QtCore[3116]
#define sipNameNr_addExtraNamespaceDeclarations 3146
#define sipName_addExtraNamespaceDeclarations &sipStrings_QtCore[3146]
#define sipNameNr_FloatingPointPrecisionOption 679
#define sipName_FloatingPointPrecisionOption &sipStrings_QtCore[679]
#define sipNameNr_InvertedLandscapeOrientation 3176
#define sipName_InvertedLandscapeOrientation &sipStrings_QtCore[3176]
#define sipNameNr_MSWindowsFixedSizeDialogHint 3205
#define sipName_MSWindowsFixedSizeDialogHint &sipStrings_QtCore[3205]
#define sipNameNr_MouseEventCreatedDoubleClick 3234
#define sipName_MouseEventCreatedDoubleClick &sipStrings_QtCore[3234]
#define sipNameNr_NavigationModeKeypadTabOrder 3263
#define sipName_NavigationModeKeypadTabOrder &sipStrings_QtCore[3263]
#define sipNameNr_ParseAsCompactedShortOptions 3292
#define sipName_ParseAsCompactedShortOptions &sipStrings_QtCore[3292]
#define sipNameNr_QByteArray__FromBase64Result 3321
#define sipName_QByteArray__FromBase64Result &sipStrings_QtCore[3321]
#define sipNameNr_QConcatenateTablesProxyModel 3350
#define sipName_QConcatenateTablesProxyModel &sipStrings_QtCore[3350]
#define sipNameNr_QFileDevice__FileHandleFlags 3379
#define sipName_QFileDevice__FileHandleFlags &sipStrings_QtCore[3379]
#define sipNameNr_3408 3408
#define sipName_3408 &sipStrings_QtCore[3408]
#define sipNameNr_QProcess__ProcessChannelMode 3437
#define sipName_QProcess__ProcessChannelMode &sipStrings_QtCore[3437]
#define sipNameNr_QStandardPaths__LocateOption 3466
#define sipName_QStandardPaths__LocateOption &sipStrings_QtCore[3466]
#define sipNameNr_QStateMachine__EventPriority 3495
#define sipName_QStateMachine__EventPriority &sipStrings_QtCore[3495]
#define sipNameNr_QSystemSemaphore__AccessMode 3524
#define sipName_QSystemSemaphore__AccessMode &sipStrings_QtCore[3524]
#define sipNameNr_RejectTrailingZeroesAfterDot 3553
#define sipName_RejectTrailingZeroesAfterDot &sipStrings_QtCore[3553]
#define sipNameNr_SaintVincentAndTheGrenadines 3582
#define sipName_SaintVincentAndTheGrenadines &sipStrings_QtCore[3582]
#define sipNameNr_WA_DontCreateNativeAncestors 3611
#define sipName_WA_DontCreateNativeAncestors &sipStrings_QtCore[3611]
#define sipNameNr_WA_NoChildEventsFromChildren 3640
#define sipName_WA_NoChildEventsFromChildren &sipStrings_QtCore[3640]
#define sipNameNr_WA_TransparentForMouseEvents 3669
#define sipName_WA_TransparentForMouseEvents &sipStrings_QtCore[3669]
#define sipNameNr_WA_X11NetWmWindowTypeDesktop 3698
#define sipName_WA_X11NetWmWindowTypeDesktop &sipStrings_QtCore[3698]
#define sipNameNr_WA_X11NetWmWindowTypeToolBar 3727
#define sipName_WA_X11NetWmWindowTypeToolBar &sipStrings_QtCore[3727]
#define sipNameNr_WA_X11NetWmWindowTypeToolTip 3756
#define sipName_WA_X11NetWmWindowTypeToolTip &sipStrings_QtCore[3756]
#define sipNameNr_WA_X11NetWmWindowTypeUtility 3785
#define sipName_WA_X11NetWmWindowTypeUtility &sipStrings_QtCore[3785]
#define sipNameNr_addExtraNamespaceDeclaration 3814
#define sipName_addExtraNamespaceDeclaration &sipStrings_QtCore[3814]
#define sipNameNr_filterCaseSensitivityChanged 3843
#define sipName_filterCaseSensitivityChanged &sipStrings_QtCore[3843]
#define sipNameNr_setRecursiveFilteringEnabled 3872
#define sipName_setRecursiveFilteringEnabled &sipStrings_QtCore[3872]
#define sipNameNr_AbortOnBase64DecodingErrors 3901
#define sipName_AbortOnBase64DecodingErrors &sipStrings_QtCore[3901]
#define sipNameNr_ApplicationWindowIconChange 3929
#define sipName_ApplicationWindowIconChange &sipStrings_QtCore[3929]
#define sipNameNr_BritishIndianOceanTerritory 3957
#define sipName_BritishIndianOceanTerritory &sipStrings_QtCore[3957]
#define sipNameNr_ExtendedPatternSyntaxOption 3985
#define sipName_ExtendedPatternSyntaxOption &sipStrings_QtCore[3985]
#define sipNameNr_InscriptionalParthianScript 4013
#define sipName_InscriptionalParthianScript &sipStrings_QtCore[4013]
#define sipNameNr_InvertedPortraitOrientation 4041
#define sipName_InvertedPortraitOrientation &sipStrings_QtCore[4041]
#define sipNameNr_Key_Dead_Abovereversedcomma 4069
#define sipName_Key_Dead_Abovereversedcomma &sipStrings_QtCore[4069]
#define sipNameNr_Key_Dead_Longsolidusoverlay 4097
#define sipName_Key_Dead_Longsolidusoverlay &sipStrings_QtCore[4097]
#define sipNameNr_LatinAmericaAndTheCaribbean 4125
#define sipName_LatinAmericaAndTheCaribbean &sipStrings_QtCore[4125]
#define sipNameNr_PrematureEndOfDocumentError 4153
#define sipName_PrematureEndOfDocumentError &sipStrings_QtCore[4153]
#define sipNameNr_QDirIterator__IteratorFlags 4181
#define sipName_QDirIterator__IteratorFlags &sipStrings_QtCore[4181]
#define sipNameNr_QDynamicPropertyChangeEvent 4209
#define sipName_QDynamicPropertyChangeEvent &sipStrings_QtCore[4209]
#define sipNameNr_QFileDevice__FileHandleFlag 4237
#define sipName_QFileDevice__FileHandleFlag &sipStrings_QtCore[4237]
#define sipNameNr_QFileDevice__MemoryMapFlags 4265
#define sipName_QFileDevice__MemoryMapFlags &sipStrings_QtCore[4265]
#define sipNameNr_QJsonParseError__ParseError 4293
#define sipName_QJsonParseError__ParseError &sipStrings_QtCore[4293]
#define sipNameNr_4321 4321
#define sipName_4321 &sipStrings_QtCore[4321]
#define sipNameNr_QStateMachine__WrappedEvent 4349
#define sipName_QStateMachine__WrappedEvent &sipStrings_QtCore[4349]
#define sipNameNr_QTextCodec__ConversionFlags 4377
#define sipName_QTextCodec__ConversionFlags &sipStrings_QtCore[4377]
#define sipNameNr_QTextStream__FieldAlignment 4405
#define sipName_QTextStream__FieldAlignment &sipStrings_QtCore[4405]
#define sipNameNr_QXmlStreamEntityDeclaration 4433
#define sipName_QXmlStreamEntityDeclaration &sipStrings_QtCore[4433]
#define sipNameNr_QXmlStreamReader__TokenType 4461
#define sipName_QXmlStreamReader__TokenType &sipStrings_QtCore[4461]
#define sipNameNr_RejectLeadingZeroInExponent 4489
#define sipName_RejectLeadingZeroInExponent &sipStrings_QtCore[4489]
#define sipNameNr_WA_X11NetWmWindowTypeDialog 4517
#define sipName_WA_X11NetWmWindowTypeDialog &sipStrings_QtCore[4517]
#define sipNameNr_WA_X11NetWmWindowTypeSplash 4545
#define sipName_WA_X11NetWmWindowTypeSplash &sipStrings_QtCore[4545]
#define sipNameNr_WindowContextHelpButtonHint 4573
#define sipName_WindowContextHelpButtonHint &sipStrings_QtCore[4573]
#define sipNameNr_isRecursiveFilteringEnabled 4601
#define sipName_isRecursiveFilteringEnabled &sipStrings_QtCore[4601]
#define sipNameNr_processingInstructionTarget 4629
#define sipName_processingInstructionTarget &sipStrings_QtCore[4629]
#define sipNameNr_setSingleDashWordOptionMode 4657
#define sipName_setSingleDashWordOptionMode &sipStrings_QtCore[4657]
#define sipNameNr_wildcardToRegularExpression 4685
#define sipName_wildcardToRegularExpression &sipStrings_QtCore[4685]
#define sipNameNr_AA_ImmediateWidgetCreation 4713
#define sipName_AA_ImmediateWidgetCreation &sipStrings_QtCore[4713]
#define sipNameNr_AnatolianHieroglyphsScript 4740
#define sipName_AnatolianHieroglyphsScript &sipStrings_QtCore[4740]
#define sipNameNr_ComponentFormattingOptions 2000
#define sipName_ComponentFormattingOptions &sipStrings_QtCore[2000]
#define sipNameNr_DontStartGestureOnChildren 4767
#define sipName_DontStartGestureOnChildren &sipStrings_QtCore[4767]
#define sipNameNr_DotMatchesEverythingOption 4794
#define sipName_DotMatchesEverythingOption &sipStrings_QtCore[4794]
#define sipNameNr_IgnoreBase64DecodingErrors 4821
#define sipName_IgnoreBase64DecodingErrors &sipStrings_QtCore[4821]
#define sipNameNr_InscriptionalPahlaviScript 4848
#define sipName_InscriptionalPahlaviScript &sipStrings_QtCore[4848]
#define sipNameNr_IntersectsItemBoundingRect 4875
#define sipName_IntersectsItemBoundingRect &sipStrings_QtCore[4875]
#define sipNameNr_KeepAspectRatioByExpanding 4902
#define sipName_KeepAspectRatioByExpanding &sipStrings_QtCore[4902]
#define sipNameNr_Key_Dead_Aboveverticalline 4929
#define sipName_Key_Dead_Aboveverticalline &sipStrings_QtCore[4929]
#define sipNameNr_Key_Dead_Belowverticalline 4956
#define sipName_Key_Dead_Belowverticalline &sipStrings_QtCore[4956]
#define sipNameNr_Key_KeyboardBrightnessDown 4983
#define sipName_Key_KeyboardBrightnessDown &sipStrings_QtCore[4983]
#define sipNameNr_MacWindowToolBarButtonHint 5010
#define sipName_MacWindowToolBarButtonHint &sipStrings_QtCore[5010]
#define sipNameNr_OptimizeOnFirstUsageOption 5037
#define sipName_OptimizeOnFirstUsageOption &sipStrings_QtCore[5037]
#define sipNameNr_ParseAsPositionalArguments 5064
#define sipName_ParseAsPositionalArguments &sipStrings_QtCore[5064]
#define sipNameNr_PartialPreferCompleteMatch 5091
#define sipName_PartialPreferCompleteMatch &sipStrings_QtCore[5091]
#define sipNameNr_QAbstractNativeEventFilter 5118
#define sipName_QAbstractNativeEventFilter &sipStrings_QtCore[5118]
#define sipNameNr_QDirIterator__IteratorFlag 5145
#define sipName_QDirIterator__IteratorFlag &sipStrings_QtCore[5145]
#define sipNameNr_QHistoryState__HistoryType 5172
#define sipName_QHistoryState__HistoryType &sipStrings_QtCore[5172]
#define sipNameNr_5199 5199
#define sipName_5199 &sipStrings_QtCore[5199]
#define sipNameNr_5226 5226
#define sipName_5226 &sipStrings_QtCore[5226]
#define sipNameNr_QLocale__MeasurementSystem 5253
#define sipName_QLocale__MeasurementSystem &sipStrings_QtCore[5253]
#define sipNameNr_QMessageAuthenticationCode 5280
#define sipName_QMessageAuthenticationCode &sipStrings_QtCore[5280]
#define sipNameNr_QProcess__InputChannelMode 5307
#define sipName_QProcess__InputChannelMode &sipStrings_QtCore[5307]
#define sipNameNr_QStateMachine__SignalEvent 5334
#define sipName_QStateMachine__SignalEvent &sipStrings_QtCore[5334]
#define sipNameNr_QTextCodec__ConversionFlag 5361
#define sipName_QTextCodec__ConversionFlag &sipStrings_QtCore[5361]
#define sipNameNr_QTextCodec__ConverterState 5388
#define sipName_QTextCodec__ConverterState &sipStrings_QtCore[5388]
#define sipNameNr_Qt__ItemSelectionOperation 5415
#define sipName_Qt__ItemSelectionOperation &sipStrings_QtCore[5415]
#define sipNameNr_SvalbardAndJanMayenIslands 5442
#define sipName_SvalbardAndJanMayenIslands &sipStrings_QtCore[5442]
#define sipNameNr_UseUnicodePropertiesOption 5469
#define sipName_UseUnicodePropertiesOption &sipStrings_QtCore[5469]
#define sipNameNr_UserInputResolutionOptions 2033
#define sipName_UserInputResolutionOptions &sipStrings_QtCore[2033]
#define sipNameNr_WA_MacAlwaysShowToolWindow 5496
#define sipName_WA_MacAlwaysShowToolWindow &sipStrings_QtCore[5496]
#define sipNameNr_WA_WState_ExplicitShowHide 5523
#define sipName_WA_WState_ExplicitShowHide &sipStrings_QtCore[5523]
#define sipNameNr_WA_X11NetWmWindowTypeCombo 5550
#define sipName_WA_X11NetWmWindowTypeCombo &sipStrings_QtCore[5550]
#define sipNameNr_WidgetWithChildrenShortcut 5577
#define sipName_WidgetWithChildrenShortcut &sipStrings_QtCore[5577]
#define sipNameNr_WindowFullscreenButtonHint 5604
#define sipName_WindowFullscreenButtonHint &sipStrings_QtCore[5604]
#define sipNameNr_X11BypassWindowManagerHint 5631
#define sipName_X11BypassWindowManagerHint &sipStrings_QtCore[5631]
#define sipNameNr_defaultQueryValueDelimiter 5658
#define sipName_defaultQueryValueDelimiter &sipStrings_QtCore[5658]
#define sipNameNr_mimeTypeForFileNameAndData 5685
#define sipName_mimeTypeForFileNameAndData &sipStrings_QtCore[5685]
#define sipNameNr_setFilterRegularExpression 5712
#define sipName_setFilterRegularExpression &sipStrings_QtCore[5712]
#define sipNameNr_sortCaseSensitivityChanged 5739
#define sipName_sortCaseSensitivityChanged &sipStrings_QtCore[5739]
#define sipNameNr_writeProcessingInstruction 5766
#define sipName_writeProcessingInstruction &sipStrings_QtCore[5766]
#define sipNameNr_AA_DisableShaderDiskCache 5793
#define sipName_AA_DisableShaderDiskCache &sipStrings_QtCore[5793]
#define sipNameNr_AA_MacDontSwapCtrlAndMeta 5819
#define sipName_AA_MacDontSwapCtrlAndMeta &sipStrings_QtCore[5819]
#define sipNameNr_AccessibleDescriptionRole 5845
#define sipName_AccessibleDescriptionRole &sipStrings_QtCore[5845]
#define sipNameNr_BypassGraphicsProxyWidget 5871
#define sipName_BypassGraphicsProxyWidget &sipStrings_QtCore[5871]
#define sipNameNr_ComponentFormattingOption 2420
#define sipName_ComponentFormattingOption &sipStrings_QtCore[2420]
#define sipNameNr_DataSizeTraditionalFormat 5897
#define sipName_DataSizeTraditionalFormat &sipStrings_QtCore[5897]
#define sipNameNr_DemocraticRepublicOfCongo 5923
#define sipName_DemocraticRepublicOfCongo &sipStrings_QtCore[5923]
#define sipNameNr_DemocraticRepublicOfKorea 5949
#define sipName_DemocraticRepublicOfKorea &sipStrings_QtCore[5949]
#define sipNameNr_EgyptianHieroglyphsScript 5975
#define sipName_EgyptianHieroglyphsScript &sipStrings_QtCore[5975]
#define sipNameNr_ExportExternalSymbolsHint 6001
#define sipName_ExportExternalSymbolsHint &sipStrings_QtCore[6001]
#define sipNameNr_FrenchSouthernTerritories 6027
#define sipName_FrenchSouthernTerritories &sipStrings_QtCore[6027]
#define sipNameNr_GraphicsSceneMouseRelease 6053
#define sipName_GraphicsSceneMouseRelease &sipStrings_QtCore[6053]
#define sipNameNr_ImhDialableCharactersOnly 6079
#define sipName_ImhDialableCharactersOnly &sipStrings_QtCore[6079]
#define sipNameNr_Key_Dead_Semivoiced_Sound 6105
#define sipName_Key_Dead_Semivoiced_Sound &sipStrings_QtCore[6105]
#define sipNameNr_LinksAccessibleByKeyboard 6131
#define sipName_LinksAccessibleByKeyboard &sipStrings_QtCore[6131]
#define sipNameNr_MouseEventSynthesizedByQt 6157
#define sipName_MouseEventSynthesizedByQt &sipStrings_QtCore[6157]
#define sipNameNr_OmitLeadingZeroInExponent 6183
#define sipName_OmitLeadingZeroInExponent &sipStrings_QtCore[6183]
#define sipNameNr_QAbstractAnimation__State 6209
#define sipName_QAbstractAnimation__State &sipStrings_QtCore[6209]
#define sipNameNr_QByteArray__Base64Options 6235
#define sipName_QByteArray__Base64Options &sipStrings_QtCore[6235]
#define sipNameNr_QCommandLineOption__Flags 6261
#define sipName_QCommandLineOption__Flags &sipStrings_QtCore[6261]
#define sipNameNr_QJsonDocument__JsonFormat 6287
#define sipName_QJsonDocument__JsonFormat &sipStrings_QtCore[6287]
#define sipNameNr_6313 6313
#define sipName_6313 &sipStrings_QtCore[6313]
#define sipNameNr_QSequentialAnimationGroup 6339
#define sipName_QSequentialAnimationGroup &sipStrings_QtCore[6339]
#define sipNameNr_QSharedMemory__AccessMode 6365
#define sipName_QSharedMemory__AccessMode &sipStrings_QtCore[6365]
#define sipNameNr_QUrl__UrlFormattingOption 6391
#define sipName_QUrl__UrlFormattingOption &sipStrings_QtCore[6391]
#define sipNameNr_RequestSoftwareInputPanel 6417
#define sipName_RequestSoftwareInputPanel &sipStrings_QtCore[6417]
#define sipNameNr_StandardMoroccanTamazight 6443
#define sipName_StandardMoroccanTamazight &sipStrings_QtCore[6443]
#define sipNameNr_TextIncludeTrailingSpaces 6469
#define sipName_TextIncludeTrailingSpaces &sipStrings_QtCore[6469]
#define sipNameNr_UnitedStatesVirginIslands 6495
#define sipName_UnitedStatesVirginIslands &sipStrings_QtCore[6495]
#define sipNameNr_UserInputResolutionOption 2452
#define sipName_UserInputResolutionOption &sipStrings_QtCore[2452]
#define sipNameNr_WA_InputMethodTransparent 6521
#define sipName_WA_InputMethodTransparent &sipStrings_QtCore[6521]
#define sipNameNr_WA_NoChildEventsForParent 6547
#define sipName_WA_NoChildEventsForParent &sipStrings_QtCore[6547]
#define sipNameNr_WA_X11NetWmWindowTypeDock 6573
#define sipName_WA_X11NetWmWindowTypeDock &sipStrings_QtCore[6573]
#define sipNameNr_WA_X11NetWmWindowTypeMenu 6599
#define sipName_WA_X11NetWmWindowTypeMenu &sipStrings_QtCore[6599]
#define sipNameNr_WindowTransparentForInput 6625
#define sipName_WindowTransparentForInput &sipStrings_QtCore[6625]
#define sipNameNr_changePersistentIndexList 6651
#define sipName_changePersistentIndexList &sipStrings_QtCore[6651]
#define sipNameNr_columnIntersectsSelection 6677
#define sipName_columnIntersectsSelection &sipStrings_QtCore[6677]
#define sipNameNr_defaultQueryPairDelimiter 6703
#define sipName_defaultQueryPairDelimiter &sipStrings_QtCore[6703]
#define sipNameNr_processingInstructionData 6729
#define sipName_processingInstructionData &sipStrings_QtCore[6729]
#define sipNameNr_setApplicationDescription 6755
#define sipName_setApplicationDescription &sipStrings_QtCore[6755]
#define sipNameNr_setFloatingPointPrecision 6781
#define sipName_setFloatingPointPrecision &sipStrings_QtCore[6781]
#define sipNameNr_AA_DisableHighDpiScaling 6807
#define sipName_AA_DisableHighDpiScaling &sipStrings_QtCore[6807]
#define sipNameNr_AA_DisableSessionManager 6832
#define sipName_AA_DisableSessionManager &sipStrings_QtCore[6832]
#define sipNameNr_ApplicationPaletteChange 6857
#define sipName_ApplicationPaletteChange &sipStrings_QtCore[6857]
#define sipNameNr_BlockingQueuedConnection 6882
#define sipName_BlockingQueuedConnection &sipStrings_QtCore[6882]
#define sipNameNr_CanadianAboriginalScript 6907
#define sipName_CanadianAboriginalScript &sipStrings_QtCore[6907]
#define sipNameNr_ContainsItemBoundingRect 6932
#define sipName_ContainsItemBoundingRect &sipStrings_QtCore[6932]
#define sipNameNr_ErrorOnUnexpectedElement 6957
#define sipName_ErrorOnUnexpectedElement &sipStrings_QtCore[6957]
#define sipNameNr_GraphicsSceneContextMenu 6982
#define sipName_GraphicsSceneContextMenu &sipStrings_QtCore[6982]
#define sipNameNr_ImInputItemClipRectangle 7007
#define sipName_ImInputItemClipRectangle &sipStrings_QtCore[7007]
#define sipNameNr_InvertedGreedinessOption 7032
#define sipName_InvertedGreedinessOption &sipStrings_QtCore[7032]
#define sipNameNr_Key_Dead_Belowcircumflex 7057
#define sipName_Key_Dead_Belowcircumflex &sipStrings_QtCore[7057]
#define sipNameNr_Key_KeyboardBrightnessUp 7082
#define sipName_Key_KeyboardBrightnessUp &sipStrings_QtCore[7082]
#define sipNameNr_Key_MediaTogglePlayPause 7107
#define sipName_Key_MediaTogglePlayPause &sipStrings_QtCore[7107]
#define sipNameNr_MouseEventNotSynthesized 7132
#define sipName_MouseEventNotSynthesized &sipStrings_QtCore[7132]
#define sipNameNr_NavigationModeCursorAuto 7157
#define sipName_NavigationModeCursorAuto &sipStrings_QtCore[7157]
#define sipNameNr_QAbstractEventDispatcher 7182
#define sipName_QAbstractEventDispatcher &sipStrings_QtCore[7182]
#define sipNameNr_QByteArray__Base64Option 7207
#define sipName_QByteArray__Base64Option &sipStrings_QtCore[7207]
#define sipNameNr_QCommandLineOption__Flag 7232
#define sipName_QCommandLineOption__Flag &sipStrings_QtCore[7232]
#define sipNameNr_QElapsedTimer__ClockType 7257
#define sipName_QElapsedTimer__ClockType &sipStrings_QtCore[7257]
#define sipNameNr_QFileDevice__Permissions 7282
#define sipName_QFileDevice__Permissions &sipStrings_QtCore[7282]
#define sipNameNr_QLocale__DataSizeFormats 7307
#define sipName_QLocale__DataSizeFormats &sipStrings_QtCore[7307]
#define sipNameNr_QMimeDatabase__MatchMode 7332
#define sipName_QMimeDatabase__MatchMode &sipStrings_QtCore[7332]
#define sipNameNr_QProcess__ProcessChannel 7357
#define sipName_QProcess__ProcessChannel &sipStrings_QtCore[7357]
#define sipNameNr_QTextStream__NumberFlags 7382
#define sipName_QTextStream__NumberFlags &sipStrings_QtCore[7382]
#define sipNameNr_QXmlStreamEntityResolver 7407
#define sipName_QXmlStreamEntityResolver &sipStrings_QtCore[7407]
#define sipNameNr_Qt__ApplicationAttribute 7432
#define sipName_Qt__ApplicationAttribute &sipStrings_QtCore[7432]
#define sipNameNr_Qt__ImageConversionFlags 7457
#define sipName_Qt__ImageConversionFlags &sipStrings_QtCore[7457]
#define sipNameNr_Qt__TextInteractionFlags 7482
#define sipName_Qt__TextInteractionFlags &sipStrings_QtCore[7482]
#define sipNameNr_ReadElementTextBehaviour 205
#define sipName_ReadElementTextBehaviour &sipStrings_QtCore[205]
#define sipNameNr_SingleDashWordOptionMode 76
#define sipName_SingleDashWordOptionMode &sipStrings_QtCore[76]
#define sipNameNr_TextSelectableByKeyboard 7507
#define sipName_TextSelectableByKeyboard &sipStrings_QtCore[7507]
#define sipNameNr_ToolButtonTextBesideIcon 7532
#define sipName_ToolButtonTextBesideIcon &sipStrings_QtCore[7532]
#define sipNameNr_TraditionalChineseScript 7557
#define sipName_TraditionalChineseScript &sipStrings_QtCore[7557]
#define sipNameNr_WA_NoX11EventCompression 7582
#define sipName_WA_NoX11EventCompression &sipStrings_QtCore[7582]
#define sipNameNr_WA_ShowWithoutActivating 7607
#define sipName_WA_ShowWithoutActivating &sipStrings_QtCore[7607]
#define sipNameNr_WA_TranslucentBackground 7632
#define sipName_WA_TranslucentBackground &sipStrings_QtCore[7632]
#define sipNameNr_WA_X11NetWmWindowTypeDND 7657
#define sipName_WA_X11NetWmWindowTypeDND &sipStrings_QtCore[7657]
#define sipNameNr_WindowDoesNotAcceptFocus 7682
#define sipName_WindowDoesNotAcceptFocus &sipStrings_QtCore[7682]
#define sipNameNr_WindowMaximizeButtonHint 7707
#define sipName_WindowMaximizeButtonHint &sipStrings_QtCore[7707]
#define sipNameNr_WindowMinimizeButtonHint 7732
#define sipName_WindowMinimizeButtonHint &sipStrings_QtCore[7732]
#define sipNameNr_clearPositionalArguments 7757
#define sipName_clearPositionalArguments &sipStrings_QtCore[7757]
#define sipNameNr_columnsAboutToBeInserted 7782
#define sipName_columnsAboutToBeInserted &sipStrings_QtCore[7782]
#define sipNameNr_defaultTransitionChanged 7807
#define sipName_defaultTransitionChanged &sipStrings_QtCore[7807]
#define sipNameNr_dynamicSortFilterChanged 7832
#define sipName_dynamicSortFilterChanged &sipStrings_QtCore[7832]
#define sipNameNr_fromMSecsSinceStartOfDay 7857
#define sipName_fromMSecsSinceStartOfDay &sipStrings_QtCore[7857]
#define sipNameNr_installNativeEventFilter 7882
#define sipName_installNativeEventFilter &sipStrings_QtCore[7882]
#define sipNameNr_setFilterCaseSensitivity 7907
#define sipName_setFilterCaseSensitivity &sipStrings_QtCore[7907]
#define sipNameNr_setGenerateByteOrderMark 7932
#define sipName_setGenerateByteOrderMark &sipStrings_QtCore[7932]
#define sipNameNr_setStandardOutputProcess 7957
#define sipName_setStandardOutputProcess &sipStrings_QtCore[7957]
#define sipNameNr_unregisterSocketNotifier 7982
#define sipName_unregisterSocketNotifier &sipStrings_QtCore[7982]
#define sipNameNr_windowsIdToDefaultIanaId 8007
#define sipName_windowsIdToDefaultIanaId &sipStrings_QtCore[8007]
#define sipNameNr_AA_CompressTabletEvents 8032
#define sipName_AA_CompressTabletEvents &sipStrings_QtCore[8032]
#define sipNameNr_AA_DontShowIconsInMenus 8056
#define sipName_AA_DontShowIconsInMenus &sipStrings_QtCore[8056]
#define sipNameNr_AA_DontUseNativeDialogs 8080
#define sipName_AA_DontUseNativeDialogs &sipStrings_QtCore[8080]
#define sipNameNr_AA_DontUseNativeMenuBar 8104
#define sipName_AA_DontUseNativeMenuBar &sipStrings_QtCore[8104]
#define sipNameNr_AA_EnableHighDpiScaling 8128
#define sipName_AA_EnableHighDpiScaling &sipStrings_QtCore[8128]
#define sipNameNr_AA_MacPluginApplication 8152
#define sipName_AA_MacPluginApplication &sipStrings_QtCore[8152]
#define sipNameNr_ActiveWindowFocusReason 8176
#define sipName_ActiveWindowFocusReason &sipStrings_QtCore[8176]
#define sipNameNr_BypassWindowManagerHint 5634
#define sipName_BypassWindowManagerHint &sipStrings_QtCore[5634]
#define sipNameNr_CaucasianAlbanianScript 8200
#define sipName_CaucasianAlbanianScript &sipStrings_QtCore[8200]
#define sipNameNr_CentralMoroccoTamazight 8224
#define sipName_CentralMoroccoTamazight &sipStrings_QtCore[8224]
#define sipNameNr_CloseSoftwareInputPanel 8248
#define sipName_CloseSoftwareInputPanel &sipStrings_QtCore[8248]
#define sipNameNr_FindChildrenRecursively 8272
#define sipName_FindChildrenRecursively &sipStrings_QtCore[8272]
#define sipNameNr_GraphicsSceneHoverEnter 8296
#define sipName_GraphicsSceneHoverEnter &sipStrings_QtCore[8296]
#define sipNameNr_GraphicsSceneHoverLeave 8320
#define sipName_GraphicsSceneHoverLeave &sipStrings_QtCore[8320]
#define sipNameNr_GraphicsSceneMousePress 8344
#define sipName_GraphicsSceneMousePress &sipStrings_QtCore[8344]
#define sipNameNr_HeardAndMcDonaldIslands 8368
#define sipName_HeardAndMcDonaldIslands &sipStrings_QtCore[8368]
#define sipNameNr_ImhFormattedNumbersOnly 8392
#define sipName_ImhFormattedNumbersOnly &sipStrings_QtCore[8392]
#define sipNameNr_Key_Dead_Belowdiaeresis 8416
#define sipName_Key_Dead_Belowdiaeresis &sipStrings_QtCore[8416]
#define sipNameNr_ManichaeanMiddlePersian 8440
#define sipName_ManichaeanMiddlePersian &sipStrings_QtCore[8440]
#define sipNameNr_PartialPreferFirstMatch 8464
#define sipName_PartialPreferFirstMatch &sipStrings_QtCore[8464]
#define sipNameNr_QCalendar__YearMonthDay 8488
#define sipName_QCalendar__YearMonthDay &sipStrings_QtCore[8488]
#define sipNameNr_QCborStreamReader__Type 8512
#define sipName_QCborStreamReader__Type &sipStrings_QtCore[8512]
#define sipNameNr_QFileDevice__Permission 8536
#define sipName_QFileDevice__Permission &sipStrings_QtCore[8536]
#define sipNameNr_8560 8560
#define sipName_8560 &sipStrings_QtCore[8560]
#define sipNameNr_QIODevice__OpenModeFlag 8584
#define sipName_QIODevice__OpenModeFlag &sipStrings_QtCore[8584]
#define sipNameNr_QLocale__DataSizeFormat 8608
#define sipName_QLocale__DataSizeFormat &sipStrings_QtCore[8608]
#define sipNameNr_QLocale__QuotationStyle 8632
#define sipName_QLocale__QuotationStyle &sipStrings_QtCore[8632]
#define sipNameNr_QMetaMethod__MethodType 8656
#define sipName_QMetaMethod__MethodType &sipStrings_QtCore[8656]
#define sipNameNr_QMetaObject__Connection 8680
#define sipName_QMetaObject__Connection &sipStrings_QtCore[8680]
#define sipNameNr_QOperatingSystemVersion 8704
#define sipName_QOperatingSystemVersion &sipStrings_QtCore[8704]
#define sipNameNr_QParallelAnimationGroup 8728
#define sipName_QParallelAnimationGroup &sipStrings_QtCore[8728]
#define sipNameNr_QRegularExpressionMatch 8752
#define sipName_QRegularExpressionMatch &sipStrings_QtCore[8752]
#define sipNameNr_QTextStream__NumberFlag 8776
#define sipName_QTextStream__NumberFlag &sipStrings_QtCore[8776]
#define sipNameNr_QUrl__FormattingOptions 8800
#define sipName_QUrl__FormattingOptions &sipStrings_QtCore[8800]
#define sipNameNr_QXmlStreamReader__Error 8824
#define sipName_QXmlStreamReader__Error &sipStrings_QtCore[8824]
#define sipNameNr_Qt__ImageConversionFlag 8848
#define sipName_Qt__ImageConversionFlag &sipStrings_QtCore[8848]
#define sipNameNr_Qt__TextInteractionFlag 8872
#define sipName_Qt__TextInteractionFlag &sipStrings_QtCore[8872]
#define sipNameNr_SimplifiedChineseScript 8896
#define sipName_SimplifiedChineseScript &sipStrings_QtCore[8896]
#define sipNameNr_TextJustificationForced 8920
#define sipName_TextJustificationForced &sipStrings_QtCore[8920]
#define sipNameNr_ToolButtonTextUnderIcon 8944
#define sipName_ToolButtonTextUnderIcon &sipStrings_QtCore[8944]
#define sipNameNr_WA_ForceUpdatesDisabled 8968
#define sipName_WA_ForceUpdatesDisabled &sipStrings_QtCore[8968]
#define sipNameNr_WA_LayoutUsesWidgetRect 8992
#define sipName_WA_LayoutUsesWidgetRect &sipStrings_QtCore[8992]
#define sipNameNr_WA_MSWindowsUseDirect3D 9016
#define sipName_WA_MSWindowsUseDirect3D &sipStrings_QtCore[9016]
#define sipNameNr_WA_WState_ConfigPending 9040
#define sipName_WA_WState_ConfigPending &sipStrings_QtCore[9040]
#define sipNameNr_WA_WState_OwnSizePolicy 9064
#define sipName_WA_WState_OwnSizePolicy &sipStrings_QtCore[9064]
#define sipNameNr_WhiteSpaceModeUndefined 9088
#define sipName_WhiteSpaceModeUndefined &sipStrings_QtCore[9088]
#define sipNameNr_WindowMinMaxButtonsHint 9112
#define sipName_WindowMinMaxButtonsHint &sipStrings_QtCore[9112]
#define sipNameNr_WindowStaysOnBottomHint 9136
#define sipName_WindowStaysOnBottomHint &sipStrings_QtCore[9136]
#define sipNameNr_columnsAboutToBeRemoved 9160
#define sipName_columnsAboutToBeRemoved &sipStrings_QtCore[9160]
#define sipNameNr_currentAnimationChanged 9184
#define sipName_currentAnimationChanged &sipStrings_QtCore[9184]
#define sipNameNr_filterRegularExpression 9208
#define sipName_filterRegularExpression &sipStrings_QtCore[9208]
#define sipNameNr_isInterruptionRequested 9232
#define sipName_isInterruptionRequested &sipStrings_QtCore[9232]
#define sipNameNr_isProcessingInstruction 9256
#define sipName_isProcessingInstruction &sipStrings_QtCore[9256]
#define sipNameNr_qSetRealNumberPrecision 9280
#define sipName_qSetRealNumberPrecision &sipStrings_QtCore[9280]
#define sipNameNr_qUnregisterResourceData 9304
#define sipName_qUnregisterResourceData &sipStrings_QtCore[9304]
#define sipNameNr_readyReadStandardOutput 9328
#define sipName_readyReadStandardOutput &sipStrings_QtCore[9328]
#define sipNameNr_removeNativeEventFilter 9352
#define sipName_removeNativeEventFilter &sipStrings_QtCore[9352]
#define sipNameNr_resolveUndeclaredEntity 9376
#define sipName_resolveUndeclaredEntity &sipStrings_QtCore[9376]
#define sipNameNr_setAutoFormattingIndent 9400
#define sipName_setAutoFormattingIndent &sipStrings_QtCore[9400]
#define sipNameNr_setEntityExpansionLimit 9424
#define sipName_setEntityExpansionLimit &sipStrings_QtCore[9424]
#define sipNameNr_setPreciseRemainingTime 9448
#define sipName_setPreciseRemainingTime &sipStrings_QtCore[9448]
#define sipNameNr_AA_ShareOpenGLContexts 9472
#define sipName_AA_ShareOpenGLContexts &sipStrings_QtCore[9472]
#define sipNameNr_AnchorHorizontalCenter 9495
#define sipName_AnchorHorizontalCenter &sipStrings_QtCore[9495]
#define sipNameNr_ApplicationDeactivated 9518
#define sipName_ApplicationDeactivated &sipStrings_QtCore[9518]
#define sipNameNr_ApplicationStateChange 9541
#define sipName_ApplicationStateChange &sipStrings_QtCore[9541]
#define sipNameNr_CentralAfricanRepublic 9564
#define sipName_CentralAfricanRepublic &sipStrings_QtCore[9564]
#define sipNameNr_ConicalGradientPattern 9587
#define sipName_ConicalGradientPattern &sipStrings_QtCore[9587]
#define sipNameNr_DefaultLocaleShortDate 9610
#define sipName_DefaultLocaleShortDate &sipStrings_QtCore[9610]
#define sipNameNr_ExcludeSocketNotifiers 9633
#define sipName_ExcludeSocketNotifiers &sipStrings_QtCore[9633]
#define sipNameNr_ExcludeUserInputEvents 9656
#define sipName_ExcludeUserInputEvents &sipStrings_QtCore[9656]
#define sipNameNr_FileMetadataChangeTime 9679
#define sipName_FileMetadataChangeTime &sipStrings_QtCore[9679]
#define sipNameNr_FindDirectChildrenOnly 9702
#define sipName_FindDirectChildrenOnly &sipStrings_QtCore[9702]
#define sipNameNr_FloatingPointPrecision 1050
#define sipName_FloatingPointPrecision &sipStrings_QtCore[1050]
#define sipNameNr_ForwardedOutputChannel 9725
#define sipName_ForwardedOutputChannel &sipStrings_QtCore[9725]
#define sipNameNr_GraphicsSceneDragEnter 9748
#define sipName_GraphicsSceneDragEnter &sipStrings_QtCore[9748]
#define sipNameNr_GraphicsSceneDragLeave 9771
#define sipName_GraphicsSceneDragLeave &sipStrings_QtCore[9771]
#define sipNameNr_GraphicsSceneHoverMove 9794
#define sipName_GraphicsSceneHoverMove &sipStrings_QtCore[9794]
#define sipNameNr_GraphicsSceneMouseMove 9817
#define sipName_GraphicsSceneMouseMove &sipStrings_QtCore[9817]
#define sipNameNr_ImhEmailCharactersOnly 9840
#define sipName_ImhEmailCharactersOnly &sipStrings_QtCore[9840]
#define sipNameNr_ItemSelectionOperation 5419
#define sipName_ItemSelectionOperation &sipStrings_QtCore[5419]
#define sipNameNr_Key_Dead_Capital_Schwa 9863
#define sipName_Key_Dead_Capital_Schwa &sipStrings_QtCore[9863]
#define sipNameNr_Key_Dead_Invertedbreve 9886
#define sipName_Key_Dead_Invertedbreve &sipStrings_QtCore[9886]
#define sipNameNr_Key_KeyboardLightOnOff 9909
#define sipName_Key_KeyboardLightOnOff &sipStrings_QtCore[9909]
#define sipNameNr_LibraryExecutablesPath 9932
#define sipName_LibraryExecutablesPath &sipStrings_QtCore[9932]
#define sipNameNr_LinksAccessibleByMouse 9955
#define sipName_LinksAccessibleByMouse &sipStrings_QtCore[9955]
#define sipNameNr_MatchRegularExpression 9978
#define sipName_MatchRegularExpression &sipStrings_QtCore[9978]
#define sipNameNr_NoDropShadowWindowHint 10001
#define sipName_NoDropShadowWindowHint &sipStrings_QtCore[10001]
#define sipNameNr_NonClientAreaMouseMove 10024
#define sipName_NonClientAreaMouseMove &sipStrings_QtCore[10024]
#define sipNameNr_NorthernMarianaIslands 10047
#define sipName_NorthernMarianaIslands &sipStrings_QtCore[10047]
#define sipNameNr_PalestinianTerritories 10070
#define sipName_PalestinianTerritories &sipStrings_QtCore[10070]
#define sipNameNr_PeoplesRepublicOfCongo 10093
#define sipName_PeoplesRepublicOfCongo &sipStrings_QtCore[10093]
#define sipNameNr_QDataStream__ByteOrder 10116
#define sipName_QDataStream__ByteOrder &sipStrings_QtCore[10116]
#define sipNameNr_QFileDevice__FileError 10139
#define sipName_QFileDevice__FileError &sipStrings_QtCore[10139]
#define sipNameNr_QGenericReturnArgument 10162
#define sipName_QGenericReturnArgument &sipStrings_QtCore[10162]
#define sipNameNr_10185 10185
#define sipName_10185 &sipStrings_QtCore[10185]
#define sipNameNr_10208 10208
#define sipName_10208 &sipStrings_QtCore[10208]
#define sipNameNr_QLocale__NumberOptions 10231
#define sipName_QLocale__NumberOptions &sipStrings_QtCore[10231]
#define sipNameNr_QProcess__ProcessError 10254
#define sipName_QProcess__ProcessError &sipStrings_QtCore[10254]
#define sipNameNr_QProcess__ProcessState 10277
#define sipName_QProcess__ProcessState &sipStrings_QtCore[10277]
#define sipNameNr_QRegExp__PatternSyntax 10300
#define sipName_QRegExp__PatternSyntax &sipStrings_QtCore[10300]
#define sipNameNr_QResource__Compression 10323
#define sipName_QResource__Compression &sipStrings_QtCore[10323]
#define sipNameNr_QTextStreamManipulator 10346
#define sipName_QTextStreamManipulator &sipStrings_QtCore[10346]
#define sipNameNr_Qt__InputMethodQueries 10369
#define sipName_Qt__InputMethodQueries &sipStrings_QtCore[10369]
#define sipNameNr_Qt__ScreenOrientations 10392
#define sipName_Qt__ScreenOrientations &sipStrings_QtCore[10392]
#define sipNameNr_Qt__TransformationMode 10415
#define sipName_Qt__TransformationMode &sipStrings_QtCore[10415]
#define sipNameNr_Qt__WindowFrameSection 10438
#define sipName_Qt__WindowFrameSection &sipStrings_QtCore[10438]
#define sipNameNr_ReceivePartialGestures 10461
#define sipName_ReceivePartialGestures &sipStrings_QtCore[10461]
#define sipNameNr_SaintPierreAndMiquelon 10484
#define sipName_SaintPierreAndMiquelon &sipStrings_QtCore[10484]
#define sipNameNr_SmartZoomNativeGesture 10507
#define sipName_SmartZoomNativeGesture &sipStrings_QtCore[10507]
#define sipNameNr_TextBrowserInteraction 10530
#define sipName_TextBrowserInteraction &sipStrings_QtCore[10530]
#define sipNameNr_UnexpectedElementError 10553
#define sipName_UnexpectedElementError &sipStrings_QtCore[10553]
#define sipNameNr_WA_KeyboardFocusChange 10576
#define sipName_WA_KeyboardFocusChange &sipStrings_QtCore[10576]
#define sipNameNr_WA_WState_CompressKeys 10599
#define sipName_WA_WState_CompressKeys &sipStrings_QtCore[10599]
#define sipNameNr_WA_WState_InPaintEvent 10622
#define sipName_WA_WState_InPaintEvent &sipStrings_QtCore[10622]
#define sipNameNr_WA_X11DoNotAcceptFocus 10645
#define sipName_WA_X11DoNotAcceptFocus &sipStrings_QtCore[10645]
#define sipNameNr_WallisAndFutunaIslands 10668
#define sipName_WallisAndFutunaIslands &sipStrings_QtCore[10668]
#define sipNameNr_applicationDescription 10691
#define sipName_applicationDescription &sipStrings_QtCore[10691]
#define sipNameNr_currentCpuArchitecture 10714
#define sipName_currentCpuArchitecture &sipStrings_QtCore[10714]
#define sipNameNr_currentMSecsSinceEpoch 10737
#define sipName_currentMSecsSinceEpoch &sipStrings_QtCore[10737]
#define sipNameNr_floatingPointPrecision 10760
#define sipName_floatingPointPrecision &sipStrings_QtCore[10760]
#define sipNameNr_layoutAboutToBeChanged 10783
#define sipName_layoutAboutToBeChanged &sipStrings_QtCore[10783]
#define sipNameNr_mapSelectionFromSource 10806
#define sipName_mapSelectionFromSource &sipStrings_QtCore[10806]
#define sipNameNr_qInstallMessageHandler 10829
#define sipName_qInstallMessageHandler &sipStrings_QtCore[10829]
#define sipNameNr_readyReadStandardError 10852
#define sipName_readyReadStandardError &sipStrings_QtCore[10852]
#define sipNameNr_registerSocketNotifier 7984
#define sipName_registerSocketNotifier &sipStrings_QtCore[7984]
#define sipNameNr_removeDefaultAnimation 10875
#define sipName_removeDefaultAnimation &sipStrings_QtCore[10875]
#define sipNameNr_rowIntersectsSelection 10898
#define sipName_rowIntersectsSelection &sipStrings_QtCore[10898]
#define sipNameNr_setCurrentWriteChannel 10921
#define sipName_setCurrentWriteChannel &sipStrings_QtCore[10921]
#define sipNameNr_setDirectWriteFallback 10944
#define sipName_setDirectWriteFallback &sipStrings_QtCore[10944]
#define sipNameNr_setGlobalRestorePolicy 10967
#define sipName_setGlobalRestorePolicy &sipStrings_QtCore[10967]
#define sipNameNr_setNamespaceProcessing 10990
#define sipName_setNamespaceProcessing &sipStrings_QtCore[10990]
#define sipNameNr_setRealNumberPrecision 11013
#define sipName_setRealNumberPrecision &sipStrings_QtCore[11013]
#define sipNameNr_setSortCaseSensitivity 11036
#define sipName_setSortCaseSensitivity &sipStrings_QtCore[11036]
#define sipNameNr_sortLocaleAwareChanged 11059
#define sipName_sortLocaleAwareChanged &sipStrings_QtCore[11059]
#define sipNameNr_unregisterResourceData 11082
#define sipName_unregisterResourceData &sipStrings_QtCore[11082]
#define sipNameNr_AA_ForceRasterWidgets 11105
#define sipName_AA_ForceRasterWidgets &sipStrings_QtCore[11105]
#define sipNameNr_ApplicationDeactivate 11127
#define sipName_ApplicationDeactivate &sipStrings_QtCore[11127]
#define sipNameNr_ApplicationFontChange 11149
#define sipName_ApplicationFontChange &sipStrings_QtCore[11149]
#define sipNameNr_CaseInsensitiveOption 11171
#define sipName_CaseInsensitiveOption &sipStrings_QtCore[11171]
#define sipNameNr_DefaultLocaleLongDate 11193
#define sipName_DefaultLocaleLongDate &sipStrings_QtCore[11193]
#define sipNameNr_DontRestoreProperties 11215
#define sipName_DontRestoreProperties &sipStrings_QtCore[11215]
#define sipNameNr_DynamicPropertyChange 11237
#define sipName_DynamicPropertyChange &sipStrings_QtCore[11237]
#define sipNameNr_FloatingPointShortest 11259
#define sipName_FloatingPointShortest &sipStrings_QtCore[11259]
#define sipNameNr_ForwardedErrorChannel 11281
#define sipName_ForwardedErrorChannel &sipStrings_QtCore[11281]
#define sipNameNr_ForwardedInputChannel 11303
#define sipName_ForwardedInputChannel &sipStrings_QtCore[11303]
#define sipNameNr_GenericConfigLocation 11325
#define sipName_GenericConfigLocation &sipStrings_QtCore[11325]
#define sipNameNr_GraphicsSceneDragMove 11347
#define sipName_GraphicsSceneDragMove &sipStrings_QtCore[11347]
#define sipNameNr_HanWithBopomofoScript 11369
#define sipName_HanWithBopomofoScript &sipStrings_QtCore[11369]
#define sipNameNr_IllegalEscapeSequence 11391
#define sipName_IllegalEscapeSequence &sipStrings_QtCore[11391]
#define sipNameNr_ImhExclusiveInputMask 11413
#define sipName_ImhExclusiveInputMask &sipStrings_QtCore[11413]
#define sipNameNr_ImperialAramaicScript 11435
#define sipName_ImperialAramaicScript &sipStrings_QtCore[11435]
#define sipNameNr_Key_Dead_Voiced_Sound 11457
#define sipName_Key_Dead_Voiced_Sound &sipStrings_QtCore[11457]
#define sipNameNr_Key_Hiragana_Katakana 11479
#define sipName_Key_Hiragana_Katakana &sipStrings_QtCore[11479]
#define sipNameNr_Key_MonBrightnessDown 11501
#define sipName_Key_MonBrightnessDown &sipStrings_QtCore[11501]
#define sipNameNr_Key_MultipleCandidate 11523
#define sipName_Key_MultipleCandidate &sipStrings_QtCore[11523]
#define sipNameNr_Key_PreviousCandidate 11545
#define sipName_Key_PreviousCandidate &sipStrings_QtCore[11545]
#define sipNameNr_LayoutDirectionChange 1741
#define sipName_LayoutDirectionChange &sipStrings_QtCore[1741]
#define sipNameNr_LinearGradientPattern 11567
#define sipName_LinearGradientPattern &sipStrings_QtCore[11567]
#define sipNameNr_LoadArchiveMemberHint 11589
#define sipName_LoadArchiveMemberHint &sipStrings_QtCore[11589]
#define sipNameNr_MeroiticCursiveScript 11611
#define sipName_MeroiticCursiveScript &sipStrings_QtCore[11611]
#define sipNameNr_MissingValueSeparator 11633
#define sipName_MissingValueSeparator &sipStrings_QtCore[11633]
#define sipNameNr_NormalizePathSegments 11655
#define sipName_NormalizePathSegments &sipStrings_QtCore[11655]
#define sipNameNr_OldNorthArabianScript 11677
#define sipName_OldNorthArabianScript &sipStrings_QtCore[11677]
#define sipNameNr_OldSouthArabianScript 11699
#define sipName_OldSouthArabianScript &sipStrings_QtCore[11699]
#define sipNameNr_PollardPhoneticScript 11721
#define sipName_PollardPhoneticScript &sipStrings_QtCore[11721]
#define sipNameNr_ProcessingInstruction 5771
#define sipName_ProcessingInstruction &sipStrings_QtCore[5771]
#define sipNameNr_QFileDevice__FileTime 11743
#define sipName_QFileDevice__FileTime &sipStrings_QtCore[11743]
#define sipNameNr_11765 11765
#define sipName_11765 &sipStrings_QtCore[11765]
#define sipNameNr_QLineF__IntersectType 11787
#define sipName_QLineF__IntersectType &sipStrings_QtCore[11787]
#define sipNameNr_QLocale__NumberOption 11809
#define sipName_QLocale__NumberOption &sipStrings_QtCore[11809]
#define sipNameNr_QMutex__RecursionMode 11831
#define sipName_QMutex__RecursionMode &sipStrings_QtCore[11831]
#define sipNameNr_QObjectCleanupHandler 11853
#define sipName_QObjectCleanupHandler &sipStrings_QtCore[11853]
#define sipNameNr_QPersistentModelIndex 11875
#define sipName_QPersistentModelIndex &sipStrings_QtCore[11875]
#define sipNameNr_11897 11897
#define sipName_11897 &sipStrings_QtCore[11897]
#define sipNameNr_QSocketNotifier__Type 11919
#define sipName_QSocketNotifier__Type &sipStrings_QtCore[11919]
#define sipNameNr_QSortFilterProxyModel 11941
#define sipName_QSortFilterProxyModel &sipStrings_QtCore[11941]
#define sipNameNr_QState__RestorePolicy 11963
#define sipName_QState__RestorePolicy &sipStrings_QtCore[11963]
#define sipNameNr_QTimeLine__CurveShape 11985
#define sipName_QTimeLine__CurveShape &sipStrings_QtCore[11985]
#define sipNameNr_QTimeZone__OffsetData 12007
#define sipName_QTimeZone__OffsetData &sipStrings_QtCore[12007]
#define sipNameNr_Qt__ApplicationStates 12029
#define sipName_Qt__ApplicationStates &sipStrings_QtCore[12029]
#define sipNameNr_Qt__ContextMenuPolicy 12051
#define sipName_Qt__ContextMenuPolicy &sipStrings_QtCore[12051]
#define sipNameNr_Qt__ItemSelectionMode 12073
#define sipName_Qt__ItemSelectionMode &sipStrings_QtCore[12073]
#define sipNameNr_Qt__KeyboardModifiers 12095
#define sipName_Qt__KeyboardModifiers &sipStrings_QtCore[12095]
#define sipNameNr_Qt__NativeGestureType 12117
#define sipName_Qt__NativeGestureType &sipStrings_QtCore[12117]
#define sipNameNr_Qt__ScreenOrientation 12139
#define sipName_Qt__ScreenOrientation &sipStrings_QtCore[12139]
#define sipNameNr_RadialGradientPattern 12161
#define sipName_RadialGradientPattern &sipStrings_QtCore[12161]
#define sipNameNr_ResolveAllSymbolsHint 12183
#define sipName_ResolveAllSymbolsHint &sipStrings_QtCore[12183]
#define sipNameNr_SystemLocaleShortDate 12205
#define sipName_SystemLocaleShortDate &sipStrings_QtCore[12205]
#define sipNameNr_TextEditorInteraction 12227
#define sipName_TextEditorInteraction &sipStrings_QtCore[12227]
#define sipNameNr_TextSelectableByMouse 12249
#define sipName_TextSelectableByMouse &sipStrings_QtCore[12249]
#define sipNameNr_ToolButtonFollowStyle 12271
#define sipName_ToolButtonFollowStyle &sipStrings_QtCore[12271]
#define sipNameNr_TurksAndCaicosIslands 12293
#define sipName_TurksAndCaicosIslands &sipStrings_QtCore[12293]
#define sipNameNr_UnboundedIntersection 12315
#define sipName_UnboundedIntersection &sipStrings_QtCore[12315]
#define sipNameNr_WA_AlwaysShowToolTips 12337
#define sipName_WA_AlwaysShowToolTips &sipStrings_QtCore[12337]
#define sipNameNr_WA_InputMethodEnabled 12359
#define sipName_WA_InputMethodEnabled &sipStrings_QtCore[12359]
#define sipNameNr_WA_LayoutOnEntireRect 12381
#define sipName_WA_LayoutOnEntireRect &sipStrings_QtCore[12381]
#define sipNameNr_WA_MacFrameworkScaled 12403
#define sipName_WA_MacFrameworkScaled &sipStrings_QtCore[12403]
#define sipNameNr_WA_NoMousePropagation 12425
#define sipName_WA_NoMousePropagation &sipStrings_QtCore[12425]
#define sipNameNr_WA_NoSystemBackground 12447
#define sipName_WA_NoSystemBackground &sipStrings_QtCore[12447]
#define sipNameNr_WA_PendingResizeEvent 12469
#define sipName_WA_PendingResizeEvent &sipStrings_QtCore[12469]
#define sipNameNr_WA_SetLayoutDirection 12491
#define sipName_WA_SetLayoutDirection &sipStrings_QtCore[12491]
#define sipNameNr_WindowCloseButtonHint 12513
#define sipName_WindowCloseButtonHint &sipStrings_QtCore[12513]
#define sipNameNr_WindowShadeButtonHint 12535
#define sipName_WindowShadeButtonHint &sipStrings_QtCore[12535]
#define sipNameNr_addCubicBezierSegment 12557
#define sipName_addCubicBezierSegment &sipStrings_QtCore[12557]
#define sipNameNr_addPositionalArgument 12579
#define sipName_addPositionalArgument &sipStrings_QtCore[12579]
#define sipNameNr_changePersistentIndex 12601
#define sipName_changePersistentIndex &sipStrings_QtCore[12601]
#define sipNameNr_columnsAboutToBeMoved 12623
#define sipName_columnsAboutToBeMoved &sipStrings_QtCore[12623]
#define sipNameNr_currentSecsSinceEpoch 12645
#define sipName_currentSecsSinceEpoch &sipStrings_QtCore[12645]
#define sipNameNr_filterCaseSensitivity 12667
#define sipName_filterCaseSensitivity &sipStrings_QtCore[12667]
#define sipNameNr_generateByteOrderMark 12689
#define sipName_generateByteOrderMark &sipStrings_QtCore[12689]
#define sipNameNr_isTimeZoneIdAvailable 12711
#define sipName_isTimeZoneIdAvailable &sipStrings_QtCore[12711]
#define sipNameNr_nameFiltersFromString 12733
#define sipName_nameFiltersFromString &sipStrings_QtCore[12733]
#define sipNameNr_namespaceDeclarations 12755
#define sipName_namespaceDeclarations &sipStrings_QtCore[12755]
#define sipNameNr_pyqtSetPickleProtocol 12777
#define sipName_pyqtSetPickleProtocol &sipStrings_QtCore[12777]
#define sipNameNr_qRegisterResourceData 12799
#define sipName_qRegisterResourceData &sipStrings_QtCore[12799]
#define sipNameNr_readAllStandardOutput 12821
#define sipName_readAllStandardOutput &sipStrings_QtCore[12821]
#define sipNameNr_relativePropertyIndex 12843
#define sipName_relativePropertyIndex &sipStrings_QtCore[12843]
#define sipNameNr_rowsAboutToBeInserted 12865
#define sipName_rowsAboutToBeInserted &sipStrings_QtCore[12865]
#define sipNameNr_setApplicationVersion 12887
#define sipName_setApplicationVersion &sipStrings_QtCore[12887]
#define sipNameNr_setAtomicSyncRequired 12909
#define sipName_setAtomicSyncRequired &sipStrings_QtCore[12909]
#define sipNameNr_setCurrentReadChannel 12931
#define sipName_setCurrentReadChannel &sipStrings_QtCore[12931]
#define sipNameNr_setFileNameAndVersion 12953
#define sipName_setFileNameAndVersion &sipStrings_QtCore[12953]
#define sipNameNr_setOrganizationDomain 12975
#define sipName_setOrganizationDomain &sipStrings_QtCore[12975]
#define sipNameNr_setProcessChannelMode 12997
#define sipName_setProcessChannelMode &sipStrings_QtCore[12997]
#define sipNameNr_setProcessEnvironment 13019
#define sipName_setProcessEnvironment &sipStrings_QtCore[13019]
#define sipNameNr_setRealNumberNotation 13041
#define sipName_setRealNumberNotation &sipStrings_QtCore[13041]
#define sipNameNr_setStandardOutputFile 13063
#define sipName_setStandardOutputFile &sipStrings_QtCore[13063]
#define sipNameNr_setTerminationEnabled 13085
#define sipName_setTerminationEnabled &sipStrings_QtCore[13085]
#define sipNameNr_standaloneWeekDayName 13107
#define sipName_standaloneWeekDayName &sipStrings_QtCore[13107]
#define sipNameNr_writeDefaultNamespace 13129
#define sipName_writeDefaultNamespace &sipStrings_QtCore[13129]
#define sipNameNr_AA_PluginApplication 13151
#define sipName_AA_PluginApplication &sipStrings_QtCore[13151]
#define sipNameNr_AA_UseHighDpiPixmaps 13172
#define sipName_AA_UseHighDpiPixmaps &sipStrings_QtCore[13172]
#define sipNameNr_AA_UseSoftwareOpenGL 13193
#define sipName_AA_UseSoftwareOpenGL &sipStrings_QtCore[13193]
#define sipNameNr_AlignAccountingStyle 13214
#define sipName_AlignAccountingStyle &sipStrings_QtCore[13214]
#define sipNameNr_AlignHorizontal_Mask 13235
#define sipName_AlignHorizontal_Mask &sipStrings_QtCore[13235]
#define sipNameNr_AmericanSignLanguage 13256
#define sipName_AmericanSignLanguage &sipStrings_QtCore[13256]
#define sipNameNr_AnchorVerticalCenter 13277
#define sipName_AnchorVerticalCenter &sipStrings_QtCore[13277]
#define sipNameNr_AndroidJellyBean_MR1 13298
#define sipName_AndroidJellyBean_MR1 &sipStrings_QtCore[13298]
#define sipNameNr_AndroidJellyBean_MR2 13319
#define sipName_AndroidJellyBean_MR2 &sipStrings_QtCore[13319]
#define sipNameNr_AppLocalDataLocation 13340
#define sipName_AppLocalDataLocation &sipStrings_QtCore[13340]
#define sipNameNr_ApplicationActivated 13361
#define sipName_ApplicationActivated &sipStrings_QtCore[13361]
#define sipNameNr_ApplicationAttribute 7436
#define sipName_ApplicationAttribute &sipStrings_QtCore[7436]
#define sipNameNr_ApplicationSuspended 13382
#define sipName_ApplicationSuspended &sipStrings_QtCore[13382]
#define sipNameNr_ApplicationsLocation 13403
#define sipName_ApplicationsLocation &sipStrings_QtCore[13403]
#define sipNameNr_Base64DecodingStatus 1874
#define sipName_Base64DecodingStatus &sipStrings_QtCore[1874]
#define sipNameNr_BosniaAndHerzegowina 13424
#define sipName_BosniaAndHerzegowina &sipStrings_QtCore[13424]
#define sipNameNr_BottomDockWidgetArea 13445
#define sipName_BottomDockWidgetArea &sipStrings_QtCore[13445]
#define sipNameNr_BritishVirginIslands 13466
#define sipName_BritishVirginIslands &sipStrings_QtCore[13466]
#define sipNameNr_ConvertInvalidToNull 13487
#define sipName_ConvertInvalidToNull &sipStrings_QtCore[13487]
#define sipNameNr_CurrencySymbolFormat 2975
#define sipName_CurrencySymbolFormat &sipStrings_QtCore[2975]
#define sipNameNr_DefaultNumberOptions 13508
#define sipName_DefaultNumberOptions &sipStrings_QtCore[13508]
#define sipNameNr_FileModificationTime 13529
#define sipName_FileModificationTime &sipStrings_QtCore[13529]
#define sipNameNr_GenericCacheLocation 13550
#define sipName_GenericCacheLocation &sipStrings_QtCore[13550]
#define sipNameNr_ImageConversionFlags 7461
#define sipName_ImageConversionFlags &sipStrings_QtCore[7461]
#define sipNameNr_ImhUrlCharactersOnly 13571
#define sipName_ImhUrlCharactersOnly &sipStrings_QtCore[13571]
#define sipNameNr_IncludeChildElements 13592
#define sipName_IncludeChildElements &sipStrings_QtCore[13592]
#define sipNameNr_InitialSortOrderRole 13613
#define sipName_InitialSortOrderRole &sipStrings_QtCore[13613]
#define sipNameNr_ItemNeverHasChildren 13634
#define sipName_ItemNeverHasChildren &sipStrings_QtCore[13634]
#define sipNameNr_Key_ApplicationRight 13655
#define sipName_Key_ApplicationRight &sipStrings_QtCore[13655]
#define sipNameNr_Key_BrightnessAdjust 13676
#define sipName_Key_BrightnessAdjust &sipStrings_QtCore[13676]
#define sipNameNr_Key_Dead_Belowmacron 13697
#define sipName_Key_Dead_Belowmacron &sipStrings_QtCore[13697]
#define sipNameNr_Key_Dead_Doubleacute 13718
#define sipName_Key_Dead_Doubleacute &sipStrings_QtCore[13718]
#define sipNameNr_Key_Dead_Doublegrave 13739
#define sipName_Key_Dead_Doublegrave &sipStrings_QtCore[13739]
#define sipNameNr_Key_Dead_Small_Schwa 13760
#define sipName_Key_Dead_Small_Schwa &sipStrings_QtCore[13760]
#define sipNameNr_Key_Hangul_PostHanja 13781
#define sipName_Key_Hangul_PostHanja &sipStrings_QtCore[13781]
#define sipNameNr_Key_LastNumberRedial 13802
#define sipName_Key_LastNumberRedial &sipStrings_QtCore[13802]
#define sipNameNr_Key_ToggleCallHangup 13823
#define sipName_Key_ToggleCallHangup &sipStrings_QtCore[13823]
#define sipNameNr_KeyboardLayoutChange 13844
#define sipName_KeyboardLayoutChange &sipStrings_QtCore[13844]
#define sipNameNr_KeyboardModifierMask 13865
#define sipName_KeyboardModifierMask &sipStrings_QtCore[13865]
#define sipNameNr_LandscapeOrientation 3184
#define sipName_LandscapeOrientation &sipStrings_QtCore[3184]
#define sipNameNr_MissingNameSeparator 13886
#define sipName_MissingNameSeparator &sipStrings_QtCore[13886]
#define sipNameNr_PersistentModelIndex 11876
#define sipName_PersistentModelIndex &sipStrings_QtCore[11876]
#define sipNameNr_PsalterPahlaviScript 13907
#define sipName_PsalterPahlaviScript &sipStrings_QtCore[13907]
#define sipNameNr_QDataStream__Version 13928
#define sipName_QDataStream__Version &sipStrings_QtCore[13928]
#define sipNameNr_QDate__MonthNameType 13949
#define sipName_QDate__MonthNameType &sipStrings_QtCore[13949]
#define sipNameNr_QDateTime__YearRange 13970
#define sipName_QDateTime__YearRange &sipStrings_QtCore[13970]
#define sipNameNr_13991 13991
#define sipName_13991 &sipStrings_QtCore[13991]
#define sipNameNr_QLockFile__LockError 14012
#define sipName_QLockFile__LockError &sipStrings_QtCore[14012]
#define sipNameNr_QMetaType__TypeFlags 14033
#define sipName_QMetaType__TypeFlags &sipStrings_QtCore[14033]
#define sipNameNr_QProcess__ExitStatus 14054
#define sipName_QProcess__ExitStatus &sipStrings_QtCore[14054]
#define sipNameNr_QStateMachine__Error 14075
#define sipName_QStateMachine__Error &sipStrings_QtCore[14075]
#define sipNameNr_QTimeLine__Direction 14096
#define sipName_QTimeLine__Direction &sipStrings_QtCore[14096]
#define sipNameNr_QTransposeProxyModel 14117
#define sipName_QTransposeProxyModel &sipStrings_QtCore[14117]
#define sipNameNr_QXmlStreamAttributes 14138
#define sipName_QXmlStreamAttributes &sipStrings_QtCore[14138]
#define sipNameNr_Qt__ApplicationState 14159
#define sipName_Qt__ApplicationState &sipStrings_QtCore[14159]
#define sipNameNr_Qt__CoordinateSystem 14180
#define sipName_Qt__CoordinateSystem &sipStrings_QtCore[14180]
#define sipNameNr_Qt__FindChildOptions 14201
#define sipName_Qt__FindChildOptions &sipStrings_QtCore[14201]
#define sipNameNr_Qt__InputMethodHints 14222
#define sipName_Qt__InputMethodHints &sipStrings_QtCore[14222]
#define sipNameNr_Qt__InputMethodQuery 14243
#define sipName_Qt__InputMethodQuery &sipStrings_QtCore[14243]
#define sipNameNr_Qt__KeyboardModifier 14264
#define sipName_Qt__KeyboardModifier &sipStrings_QtCore[14264]
#define sipNameNr_Qt__MouseEventSource 14285
#define sipName_Qt__MouseEventSource &sipStrings_QtCore[14285]
#define sipNameNr_Qt__TabFocusBehavior 14306
#define sipName_Qt__TabFocusBehavior &sipStrings_QtCore[14306]
#define sipNameNr_Qt__TouchPointStates 14327
#define sipName_Qt__TouchPointStates &sipStrings_QtCore[14327]
#define sipNameNr_RejectGroupSeparator 14348
#define sipName_RejectGroupSeparator &sipStrings_QtCore[14348]
#define sipNameNr_SmoothTransformation 14369
#define sipName_SmoothTransformation &sipStrings_QtCore[14369]
#define sipNameNr_SystemLocaleLongDate 14390
#define sipName_SystemLocaleLongDate &sipStrings_QtCore[14390]
#define sipNameNr_SystemSemaphoreError 494
#define sipName_SystemSemaphoreError &sipStrings_QtCore[494]
#define sipNameNr_TabFocusListControls 14411
#define sipName_TabFocusListControls &sipStrings_QtCore[14411]
#define sipNameNr_TabFocusTextControls 14432
#define sipName_TabFocusTextControls &sipStrings_QtCore[14432]
#define sipNameNr_TabletEnterProximity 14453
#define sipName_TabletEnterProximity &sipStrings_QtCore[14453]
#define sipNameNr_TabletLeaveProximity 14474
#define sipName_TabletLeaveProximity &sipStrings_QtCore[14474]
#define sipNameNr_TabletTrackingChange 14495
#define sipName_TabletTrackingChange &sipStrings_QtCore[14495]
#define sipNameNr_TextInteractionFlags 7486
#define sipName_TextInteractionFlags &sipStrings_QtCore[7486]
#define sipNameNr_ThresholdAlphaDither 14516
#define sipName_ThresholdAlphaDither &sipStrings_QtCore[14516]
#define sipNameNr_TimeCriticalPriority 14537
#define sipName_TimeCriticalPriority &sipStrings_QtCore[14537]
#define sipNameNr_TouchPointStationary 14558
#define sipName_TouchPointStationary &sipStrings_QtCore[14558]
#define sipNameNr_TraditionalHanScript 14579
#define sipName_TraditionalHanScript &sipStrings_QtCore[14579]
#define sipNameNr_WA_AcceptTouchEvents 14600
#define sipName_WA_AcceptTouchEvents &sipStrings_QtCore[14600]
#define sipNameNr_WA_MacNoClickThrough 14621
#define sipName_WA_MacNoClickThrough &sipStrings_QtCore[14621]
#define sipNameNr_WA_MacOpaqueSizeGrip 14642
#define sipName_WA_MacOpaqueSizeGrip &sipStrings_QtCore[14642]
#define sipNameNr_WA_WState_Reparented 14663
#define sipName_WA_WState_Reparented &sipStrings_QtCore[14663]
#define sipNameNr_WA_WindowPropagation 14684
#define sipName_WA_WindowPropagation &sipStrings_QtCore[14684]
#define sipNameNr_WindowStaysOnTopHint 14705
#define sipName_WindowStaysOnTopHint &sipStrings_QtCore[14705]
#define sipNameNr_WindowSystemMenuHint 14726
#define sipName_WindowSystemMenuHint &sipStrings_QtCore[14726]
#define sipNameNr_autoFormattingIndent 14747
#define sipName_autoFormattingIndent &sipStrings_QtCore[14747]
#define sipNameNr_availableTimeZoneIds 14768
#define sipName_availableTimeZoneIds &sipStrings_QtCore[14768]
#define sipNameNr_buildCpuArchitecture 14789
#define sipName_buildCpuArchitecture &sipStrings_QtCore[14789]
#define sipNameNr_compressionAlgorithm 14810
#define sipName_compressionAlgorithm &sipStrings_QtCore[14810]
#define sipNameNr_currentColumnChanged 14831
#define sipName_currentColumnChanged &sipStrings_QtCore[14831]
#define sipNameNr_dynamicPropertyNames 14852
#define sipName_dynamicPropertyNames &sipStrings_QtCore[14852]
#define sipNameNr_emitSelectionChanged 14873
#define sipName_emitSelectionChanged &sipStrings_QtCore[14873]
#define sipNameNr_entityExpansionLimit 14894
#define sipName_entityExpansionLimit &sipStrings_QtCore[14894]
#define sipNameNr_fromNativeSeparators 14915
#define sipName_fromNativeSeparators &sipStrings_QtCore[14915]
#define sipNameNr_isAtomicSyncRequired 14936
#define sipName_isAtomicSyncRequired &sipStrings_QtCore[14936]
#define sipNameNr_isStandaloneDocument 14957
#define sipName_isStandaloneDocument &sipStrings_QtCore[14957]
#define sipNameNr_isTransactionStarted 14978
#define sipName_isTransactionStarted &sipStrings_QtCore[14978]
#define sipNameNr_mapSelectionToSource 14999
#define sipName_mapSelectionToSource &sipStrings_QtCore[14999]
#define sipNameNr_mimeTypesForFileName 15020
#define sipName_mimeTypesForFileName &sipStrings_QtCore[15020]
#define sipNameNr_msecsSinceStartOfDay 15041
#define sipName_msecsSinceStartOfDay &sipStrings_QtCore[15041]
#define sipNameNr_notationDeclarations 15062
#define sipName_notationDeclarations &sipStrings_QtCore[15062]
#define sipNameNr_pyqtRestoreInputHook 15083
#define sipName_pyqtRestoreInputHook &sipStrings_QtCore[15083]
#define sipNameNr_qEnvironmentVariable 15104
#define sipName_qEnvironmentVariable &sipStrings_QtCore[15104]
#define sipNameNr_readAllStandardError 15125
#define sipName_readAllStandardError &sipStrings_QtCore[15125]
#define sipNameNr_readNextStartElement 15146
#define sipName_readNextStartElement &sipStrings_QtCore[15146]
#define sipNameNr_registerResourceData 9307
#define sipName_registerResourceData &sipStrings_QtCore[9307]
#define sipNameNr_rowsAboutToBeRemoved 15167
#define sipName_rowsAboutToBeRemoved &sipStrings_QtCore[15167]
#define sipNameNr_setAutoDetectUnicode 15188
#define sipName_setAutoDetectUnicode &sipStrings_QtCore[15188]
#define sipNameNr_setDefaultTransition 15209
#define sipName_setDefaultTransition &sipStrings_QtCore[15209]
#define sipNameNr_setDynamicSortFilter 15230
#define sipName_setDynamicSortFilter &sipStrings_QtCore[15230]
#define sipNameNr_setFilterFixedString 15251
#define sipName_setFilterFixedString &sipStrings_QtCore[15251]
#define sipNameNr_setIgnorePunctuation 15272
#define sipName_setIgnorePunctuation &sipStrings_QtCore[15272]
#define sipNameNr_setStandardErrorFile 15293
#define sipName_setStandardErrorFile &sipStrings_QtCore[15293]
#define sipNameNr_setStandardInputFile 15314
#define sipName_setStandardInputFile &sipStrings_QtCore[15314]
#define sipNameNr_supportedDragActions 15335
#define sipName_supportedDragActions &sipStrings_QtCore[15335]
#define sipNameNr_supportedDropActions 15356
#define sipName_supportedDropActions &sipStrings_QtCore[15356]
#define sipNameNr_timeZoneAbbreviation 15377
#define sipName_timeZoneAbbreviation &sipStrings_QtCore[15377]
#define sipNameNr_writeEntityReference 15398
#define sipName_writeEntityReference &sipStrings_QtCore[15398]
#define sipNameNr_AA_UseDesktopOpenGL 15419
#define sipName_AA_UseDesktopOpenGL &sipStrings_QtCore[15419]
#define sipNameNr_AnchoredMatchOption 15439
#define sipName_AnchoredMatchOption &sipStrings_QtCore[15439]
#define sipNameNr_AncientNorthArabian 15459
#define sipName_AncientNorthArabian &sipStrings_QtCore[15459]
#define sipNameNr_AndroidLollipop_MR1 15479
#define sipName_AndroidLollipop_MR1 &sipStrings_QtCore[15479]
#define sipNameNr_ApplicationActivate 15499
#define sipName_ApplicationActivate &sipStrings_QtCore[15499]
#define sipNameNr_ApplicationInactive 15519
#define sipName_ApplicationInactive &sipStrings_QtCore[15519]
#define sipNameNr_ApplicationShortcut 15539
#define sipName_ApplicationShortcut &sipStrings_QtCore[15539]
#define sipNameNr_ArdhamagadhiPrakrit 15559
#define sipName_ArdhamagadhiPrakrit &sipStrings_QtCore[15559]
#define sipNameNr_BackgroundColorRole 15579
#define sipName_BackgroundColorRole &sipStrings_QtCore[15579]
#define sipNameNr_BoundedIntersection 15599
#define sipName_BoundedIntersection &sipStrings_QtCore[15599]
#define sipNameNr_CurrencyDisplayName 15619
#define sipName_CurrencyDisplayName &sipStrings_QtCore[15619]
#define sipNameNr_CustomizeWindowHint 15639
#define sipName_CustomizeWindowHint &sipStrings_QtCore[15639]
#define sipNameNr_DockWidgetArea_Mask 15659
#define sipName_DockWidgetArea_Mask &sipStrings_QtCore[15659]
#define sipNameNr_FramelessWindowHint 15679
#define sipName_FramelessWindowHint &sipStrings_QtCore[15679]
#define sipNameNr_GenericDataLocation 15699
#define sipName_GenericDataLocation &sipStrings_QtCore[15699]
#define sipNameNr_GraphicsSceneResize 15719
#define sipName_GraphicsSceneResize &sipStrings_QtCore[15719]
#define sipNameNr_GroupSwitchModifier 15739
#define sipName_GroupSwitchModifier &sipStrings_QtCore[15739]
#define sipNameNr_ImMaximumTextLength 15759
#define sipName_ImMaximumTextLength &sipStrings_QtCore[15759]
#define sipNameNr_ImPreferredLanguage 15779
#define sipName_ImPreferredLanguage &sipStrings_QtCore[15779]
#define sipNameNr_ImageConversionFlag 8852
#define sipName_ImageConversionFlag &sipStrings_QtCore[8852]
#define sipNameNr_ImhNoPredictiveText 15799
#define sipName_ImhNoPredictiveText &sipStrings_QtCore[15799]
#define sipNameNr_IntersectsItemShape 15819
#define sipName_IntersectsItemShape &sipStrings_QtCore[15819]
#define sipNameNr_ItemIsUserCheckable 15839
#define sipName_ItemIsUserCheckable &sipStrings_QtCore[15839]
#define sipNameNr_Key_ApplicationLeft 15859
#define sipName_Key_ApplicationLeft &sipStrings_QtCore[15859]
#define sipNameNr_Key_AudioCycleTrack 15879
#define sipName_Key_AudioCycleTrack &sipStrings_QtCore[15879]
#define sipNameNr_Key_AudioRandomPlay 15899
#define sipName_Key_AudioRandomPlay &sipStrings_QtCore[15899]
#define sipNameNr_Key_Dead_Abovecomma 15919
#define sipName_Key_Dead_Abovecomma &sipStrings_QtCore[15919]
#define sipNameNr_Key_Dead_Belowbreve 15939
#define sipName_Key_Dead_Belowbreve &sipStrings_QtCore[15939]
#define sipNameNr_Key_Dead_Belowcomma 15959
#define sipName_Key_Dead_Belowcomma &sipStrings_QtCore[15959]
#define sipNameNr_Key_Dead_Belowtilde 15979
#define sipName_Key_Dead_Belowtilde &sipStrings_QtCore[15979]
#define sipNameNr_Key_Dead_Circumflex 15999
#define sipName_Key_Dead_Circumflex &sipStrings_QtCore[15999]
#define sipNameNr_Key_Hangul_PreHanja 16019
#define sipName_Key_Hangul_PreHanja &sipStrings_QtCore[16019]
#define sipNameNr_Key_MonBrightnessUp 16039
#define sipName_Key_MonBrightnessUp &sipStrings_QtCore[16039]
#define sipNameNr_Key_SingleCandidate 16059
#define sipName_Key_SingleCandidate &sipStrings_QtCore[16059]
#define sipNameNr_Key_Zenkaku_Hankaku 16079
#define sipName_Key_Zenkaku_Hankaku &sipStrings_QtCore[16079]
#define sipNameNr_LayoutDirectionAuto 16099
#define sipName_LayoutDirectionAuto &sipStrings_QtCore[16099]
#define sipNameNr_ManagedInputChannel 16119
#define sipName_ManagedInputChannel &sipStrings_QtCore[16119]
#define sipNameNr_MouseButtonDblClick 1842
#define sipName_MouseButtonDblClick &sipStrings_QtCore[1842]
#define sipNameNr_MouseTrackingChange 16139
#define sipName_MouseTrackingChange &sipStrings_QtCore[16139]
#define sipNameNr_NoInitialStateError 16159
#define sipName_NoInitialStateError &sipStrings_QtCore[16159]
#define sipNameNr_NormalEventPriority 16179
#define sipName_NormalEventPriority &sipStrings_QtCore[16179]
#define sipNameNr_ParentAboutToChange 16199
#define sipName_ParentAboutToChange &sipStrings_QtCore[16199]
#define sipNameNr_PortraitOrientation 4049
#define sipName_PortraitOrientation &sipStrings_QtCore[4049]
#define sipNameNr_QAbstractProxyModel 16219
#define sipName_QAbstractProxyModel &sipStrings_QtCore[16219]
#define sipNameNr_QAbstractTableModel 16239
#define sipName_QAbstractTableModel &sipStrings_QtCore[16239]
#define sipNameNr_QAbstractTransition 16259
#define sipName_QAbstractTransition &sipStrings_QtCore[16259]
#define sipNameNr_QDataStream__Status 16279
#define sipName_QDataStream__Status &sipStrings_QtCore[16279]
#define sipNameNr_QIODevice__OpenMode 16299
#define sipName_QIODevice__OpenMode &sipStrings_QtCore[16299]
#define sipNameNr_QIdentityProxyModel 16319
#define sipName_QIdentityProxyModel &sipStrings_QtCore[16319]
#define sipNameNr_QItemSelectionModel 16339
#define sipName_QItemSelectionModel &sipStrings_QtCore[16339]
#define sipNameNr_QItemSelectionRange 16359
#define sipName_QItemSelectionRange &sipStrings_QtCore[16359]
#define sipNameNr_QLibrary__LoadHints 16379
#define sipName_QLibrary__LoadHints &sipStrings_QtCore[16379]
#define sipNameNr_16399 16399
#define sipName_16399 &sipStrings_QtCore[16399]
#define sipNameNr_QLocale__FormatType 16419
#define sipName_QLocale__FormatType &sipStrings_QtCore[16419]
#define sipNameNr_QMetaMethod__Access 16439
#define sipName_QMetaMethod__Access &sipStrings_QtCore[16439]
#define sipNameNr_QMetaType__TypeFlag 16459
#define sipName_QMetaType__TypeFlag &sipStrings_QtCore[16459]
#define sipNameNr_QProcessEnvironment 16479
#define sipName_QProcessEnvironment &sipStrings_QtCore[16479]
#define sipNameNr_QTextBoundaryFinder 16499
#define sipName_QTextBoundaryFinder &sipStrings_QtCore[16499]
#define sipNameNr_QTextStream__Status 16519
#define sipName_QTextStream__Status &sipStrings_QtCore[16519]
#define sipNameNr_QTimeZone__NameType 16539
#define sipName_QTimeZone__NameType &sipStrings_QtCore[16539]
#define sipNameNr_QTimeZone__TimeType 16559
#define sipName_QTimeZone__TimeType &sipStrings_QtCore[16559]
#define sipNameNr_QUuid__StringFormat 16579
#define sipName_QUuid__StringFormat &sipStrings_QtCore[16579]
#define sipNameNr_QXmlStreamAttribute 16599
#define sipName_QXmlStreamAttribute &sipStrings_QtCore[16599]
#define sipNameNr_Qt__AspectRatioMode 16619
#define sipName_Qt__AspectRatioMode &sipStrings_QtCore[16619]
#define sipNameNr_Qt__CaseSensitivity 16639
#define sipName_Qt__CaseSensitivity &sipStrings_QtCore[16639]
#define sipNameNr_Qt__CursorMoveStyle 16659
#define sipName_Qt__CursorMoveStyle &sipStrings_QtCore[16659]
#define sipNameNr_Qt__DockWidgetAreas 16679
#define sipName_Qt__DockWidgetAreas &sipStrings_QtCore[16679]
#define sipNameNr_Qt__FindChildOption 16699
#define sipName_Qt__FindChildOption &sipStrings_QtCore[16699]
#define sipNameNr_Qt__HitTestAccuracy 16719
#define sipName_Qt__HitTestAccuracy &sipStrings_QtCore[16719]
#define sipNameNr_Qt__InputMethodHint 16739
#define sipName_Qt__InputMethodHint &sipStrings_QtCore[16739]
#define sipNameNr_Qt__LayoutDirection 16759
#define sipName_Qt__LayoutDirection &sipStrings_QtCore[16759]
#define sipNameNr_Qt__MouseEventFlags 16779
#define sipName_Qt__MouseEventFlags &sipStrings_QtCore[16779]
#define sipNameNr_Qt__ScrollBarPolicy 16799
#define sipName_Qt__ScrollBarPolicy &sipStrings_QtCore[16799]
#define sipNameNr_Qt__ShortcutContext 16819
#define sipName_Qt__ShortcutContext &sipStrings_QtCore[16819]
#define sipNameNr_Qt__ToolButtonStyle 16839
#define sipName_Qt__ToolButtonStyle &sipStrings_QtCore[16839]
#define sipNameNr_Qt__TouchPointState 16859
#define sipName_Qt__TouchPointState &sipStrings_QtCore[16859]
#define sipNameNr_Qt__WidgetAttribute 16879
#define sipName_Qt__WidgetAttribute &sipStrings_QtCore[16879]
#define sipNameNr_RightDockWidgetArea 16899
#define sipName_RightDockWidgetArea &sipStrings_QtCore[16899]
#define sipNameNr_RotateNativeGesture 16919
#define sipName_RotateNativeGesture &sipStrings_QtCore[16919]
#define sipNameNr_ShortcutFocusReason 16939
#define sipName_ShortcutFocusReason &sipStrings_QtCore[16939]
#define sipNameNr_SimplifiedHanScript 16959
#define sipName_SimplifiedHanScript &sipStrings_QtCore[16959]
#define sipNameNr_StateMachineWrapped 16979
#define sipName_StateMachineWrapped &sipStrings_QtCore[16979]
#define sipNameNr_TabFocusAllControls 16999
#define sipName_TabFocusAllControls &sipStrings_QtCore[16999]
#define sipNameNr_TerminationByNumber 17019
#define sipName_TerminationByNumber &sipStrings_QtCore[17019]
#define sipNameNr_TextInteractionFlag 8876
#define sipName_TextInteractionFlag &sipStrings_QtCore[8876]
#define sipNameNr_UrlFormattingOption 6397
#define sipName_UrlFormattingOption &sipStrings_QtCore[6397]
#define sipNameNr_WA_AlwaysStackOnTop 17039
#define sipName_WA_AlwaysStackOnTop &sipStrings_QtCore[17039]
#define sipNameNr_WA_DontShowOnScreen 17059
#define sipName_WA_DontShowOnScreen &sipStrings_QtCore[17059]
#define sipNameNr_WA_MacShowFocusRect 17079
#define sipName_WA_MacShowFocusRect &sipStrings_QtCore[17079]
#define sipNameNr_WA_OpaquePaintEvent 17099
#define sipName_WA_OpaquePaintEvent &sipStrings_QtCore[17099]
#define sipNameNr_WA_PendingMoveEvent 17119
#define sipName_WA_PendingMoveEvent &sipStrings_QtCore[17119]
#define sipNameNr_WA_StyleSheetTarget 17139
#define sipName_WA_StyleSheetTarget &sipStrings_QtCore[17139]
#define sipNameNr_WA_StyledBackground 17159
#define sipName_WA_StyledBackground &sipStrings_QtCore[17159]
#define sipNameNr_WA_TintedBackground 17179
#define sipName_WA_TintedBackground &sipStrings_QtCore[17179]
#define sipNameNr_WA_X11OpenGLOverlay 17199
#define sipName_WA_X11OpenGLOverlay &sipStrings_QtCore[17199]
#define sipNameNr_addDefaultAnimation 17219
#define sipName_addDefaultAnimation &sipStrings_QtCore[17219]
#define sipNameNr_applicationFilePath 17239
#define sipName_applicationFilePath &sipStrings_QtCore[17239]
#define sipNameNr_channelBytesWritten 17259
#define sipName_channelBytesWritten &sipStrings_QtCore[17259]
#define sipNameNr_createSeparatedList 17279
#define sipName_createSeparatedList &sipStrings_QtCore[17279]
#define sipNameNr_currentWriteChannel 17299
#define sipName_currentWriteChannel &sipStrings_QtCore[17299]
#define sipNameNr_defaultStateChanged 17319
#define sipName_defaultStateChanged &sipStrings_QtCore[17319]
#define sipNameNr_directWriteFallback 17339
#define sipName_directWriteFallback &sipStrings_QtCore[17339]
#define sipNameNr_filterAcceptsColumn 17359
#define sipName_filterAcceptsColumn &sipStrings_QtCore[17359]
#define sipNameNr_fromMSecsSinceEpoch 17379
#define sipName_fromMSecsSinceEpoch &sipStrings_QtCore[17379]
#define sipNameNr_fromPercentEncoding 17399
#define sipName_fromPercentEncoding &sipStrings_QtCore[17399]
#define sipNameNr_globalRestorePolicy 17419
#define sipName_globalRestorePolicy &sipStrings_QtCore[17419]
#define sipNameNr_initialStateChanged 17439
#define sipName_initialStateChanged &sipStrings_QtCore[17439]
#define sipNameNr_maximumMonthsInYear 17459
#define sipName_maximumMonthsInYear &sipStrings_QtCore[17459]
#define sipNameNr_modelAboutToBeReset 17479
#define sipName_modelAboutToBeReset &sipStrings_QtCore[17479]
#define sipNameNr_msecsSinceReference 17499
#define sipName_msecsSinceReference &sipStrings_QtCore[17499]
#define sipNameNr_namespaceProcessing 17519
#define sipName_namespaceProcessing &sipStrings_QtCore[17519]
#define sipNameNr_normalizedSignature 17539
#define sipName_normalizedSignature &sipStrings_QtCore[17539]
#define sipNameNr_parentContainerType 17559
#define sipName_parentContainerType &sipStrings_QtCore[17559]
#define sipNameNr_persistentIndexList 17579
#define sipName_persistentIndexList &sipStrings_QtCore[17579]
#define sipNameNr_positionalArguments 17599
#define sipName_positionalArguments &sipStrings_QtCore[17599]
#define sipNameNr_pyqtRemoveInputHook 17619
#define sipName_pyqtRemoveInputHook &sipStrings_QtCore[17619]
#define sipNameNr_queryValueDelimiter 17639
#define sipName_queryValueDelimiter &sipStrings_QtCore[17639]
#define sipNameNr_readChannelFinished 17659
#define sipName_readChannelFinished &sipStrings_QtCore[17659]
#define sipNameNr_realNumberPrecision 17679
#define sipName_realNumberPrecision &sipStrings_QtCore[17679]
#define sipNameNr_removeAllQueryItems 17699
#define sipName_removeAllQueryItems &sipStrings_QtCore[17699]
#define sipNameNr_removeStaleLockFile 17719
#define sipName_removeStaleLockFile &sipStrings_QtCore[17719]
#define sipNameNr_requestInterruption 17739
#define sipName_requestInterruption &sipStrings_QtCore[17739]
#define sipNameNr_rollbackTransaction 17759
#define sipName_rollbackTransaction &sipStrings_QtCore[17759]
#define sipNameNr_senderObjectChanged 17779
#define sipName_senderObjectChanged &sipStrings_QtCore[17779]
#define sipNameNr_setFallbacksEnabled 17799
#define sipName_setFallbacksEnabled &sipStrings_QtCore[17799]
#define sipNameNr_setInputChannelMode 17819
#define sipName_setInputChannelMode &sipStrings_QtCore[17819]
#define sipNameNr_setOrganizationName 17839
#define sipName_setOrganizationName &sipStrings_QtCore[17839]
#define sipNameNr_setWorkingDirectory 17859
#define sipName_setWorkingDirectory &sipStrings_QtCore[17859]
#define sipNameNr_sortCaseSensitivity 17879
#define sipName_sortCaseSensitivity &sipStrings_QtCore[17879]
#define sipNameNr_standaloneMonthName 17899
#define sipName_standaloneMonthName &sipStrings_QtCore[17899]
#define sipNameNr_targetStatesChanged 17919
#define sipName_targetStatesChanged &sipStrings_QtCore[17919]
#define sipNameNr_waitForBytesWritten 17939
#define sipName_waitForBytesWritten &sipStrings_QtCore[17939]
#define sipNameNr_AccessibleTextRole 17959
#define sipName_AccessibleTextRole &sipStrings_QtCore[17959]
#define sipNameNr_ActionsContextMenu 17978
#define sipName_ActionsContextMenu &sipStrings_QtCore[17978]
#define sipNameNr_AlignVertical_Mask 17997
#define sipName_AlignVertical_Mask &sipStrings_QtCore[17997]
#define sipNameNr_AllDockWidgetAreas 18016
#define sipName_AllDockWidgetAreas &sipStrings_QtCore[18016]
#define sipNameNr_AlternateQuotation 18035
#define sipName_AlternateQuotation &sipStrings_QtCore[18035]
#define sipNameNr_AndroidMarshmallow 18054
#define sipName_AndroidMarshmallow &sipStrings_QtCore[18054]
#define sipNameNr_BacktabFocusReason 18073
#define sipName_BacktabFocusReason &sipStrings_QtCore[18073]
#define sipNameNr_BeginNativeGesture 18092
#define sipName_BeginNativeGesture &sipStrings_QtCore[18092]
#define sipNameNr_BottomRightSection 18111
#define sipName_BottomRightSection &sipStrings_QtCore[18111]
#define sipNameNr_ContentsRectChange 18130
#define sipName_ContentsRectChange &sipStrings_QtCore[18130]
#define sipNameNr_DefaultContextMenu 18149
#define sipName_DefaultContextMenu &sipStrings_QtCore[18149]
#define sipNameNr_DiffuseAlphaDither 18168
#define sipName_DiffuseAlphaDither &sipStrings_QtCore[18168]
#define sipNameNr_EnterWhatsThisMode 18187
#define sipName_EnterWhatsThisMode &sipStrings_QtCore[18187]
#define sipNameNr_ExternalTransition 18206
#define sipName_ExternalTransition &sipStrings_QtCore[18206]
#define sipNameNr_FastTransformation 18225
#define sipName_FastTransformation &sipStrings_QtCore[18225]
#define sipNameNr_FocusAboutToChange 18244
#define sipName_FocusAboutToChange &sipStrings_QtCore[18244]
#define sipNameNr_GraphicsSceneWheel 18263
#define sipName_GraphicsSceneWheel &sipStrings_QtCore[18263]
#define sipNameNr_HieroglyphicLuwian 18282
#define sipName_HieroglyphicLuwian &sipStrings_QtCore[18282]
#define sipNameNr_HorizontalSortHint 18301
#define sipName_HorizontalSortHint &sipStrings_QtCore[18301]
#define sipNameNr_IllegalInputLength 18320
#define sipName_IllegalInputLength &sipStrings_QtCore[18320]
#define sipNameNr_ImAbsolutePosition 18339
#define sipName_ImAbsolutePosition &sipStrings_QtCore[18339]
#define sipNameNr_ImCurrentSelection 18358
#define sipName_ImCurrentSelection &sipStrings_QtCore[18358]
#define sipNameNr_ImTextBeforeCursor 18377
#define sipName_ImTextBeforeCursor &sipStrings_QtCore[18377]
#define sipNameNr_ImhNoAutoUppercase 18396
#define sipName_ImhNoAutoUppercase &sipStrings_QtCore[18396]
#define sipNameNr_ImhPreferLowercase 18415
#define sipName_ImhPreferLowercase &sipStrings_QtCore[18415]
#define sipNameNr_ImhPreferUppercase 18434
#define sipName_ImhPreferUppercase &sipStrings_QtCore[18434]
#define sipNameNr_InputMethodQueries 10373
#define sipName_InputMethodQueries &sipStrings_QtCore[10373]
#define sipNameNr_InternalTransition 18453
#define sipName_InternalTransition &sipStrings_QtCore[18453]
#define sipNameNr_ItemIsAutoTristate 18472
#define sipName_ItemIsAutoTristate &sipStrings_QtCore[18472]
#define sipNameNr_ItemIsUserTristate 18491
#define sipName_ItemIsUserTristate &sipStrings_QtCore[18491]
#define sipNameNr_KeepTrailingEquals 18510
#define sipName_KeepTrailingEquals &sipStrings_QtCore[18510]
#define sipNameNr_Key_ContrastAdjust 18529
#define sipName_Key_ContrastAdjust &sipStrings_QtCore[18529]
#define sipNameNr_Key_Dead_Abovering 18548
#define sipName_Key_Dead_Abovering &sipStrings_QtCore[18548]
#define sipNameNr_Key_Dead_Belowring 18567
#define sipName_Key_Dead_Belowring &sipStrings_QtCore[18567]
#define sipNameNr_Key_Dead_Diaeresis 18586
#define sipName_Key_Dead_Diaeresis &sipStrings_QtCore[18586]
#define sipNameNr_Key_Hangul_Special 18605
#define sipName_Key_Hangul_Special &sipStrings_QtCore[18605]
#define sipNameNr_Key_TouchpadToggle 18624
#define sipName_Key_TouchpadToggle &sipStrings_QtCore[18624]
#define sipNameNr_Key_guillemotright 18643
#define sipName_Key_guillemotright &sipStrings_QtCore[18643]
#define sipNameNr_Key_periodcentered 18662
#define sipName_Key_periodcentered &sipStrings_QtCore[18662]
#define sipNameNr_LeaveWhatsThisMode 18681
#define sipName_LeaveWhatsThisMode &sipStrings_QtCore[18681]
#define sipNameNr_LeftDockWidgetArea 18700
#define sipName_LeftDockWidgetArea &sipStrings_QtCore[18700]
#define sipNameNr_LogicalCoordinates 18719
#define sipName_LogicalCoordinates &sipStrings_QtCore[18719]
#define sipNameNr_MatchCaseSensitive 18738
#define sipName_MatchCaseSensitive &sipStrings_QtCore[18738]
#define sipNameNr_MendeKikakuiScript 18757
#define sipName_MendeKikakuiScript &sipStrings_QtCore[18757]
#define sipNameNr_MenuBarFocusReason 18776
#define sipName_MenuBarFocusReason &sipStrings_QtCore[18776]
#define sipNameNr_MouseButtonRelease 2235
#define sipName_MouseButtonRelease &sipStrings_QtCore[2235]
#define sipNameNr_NavigationModeNone 18795
#define sipName_NavigationModeNone &sipStrings_QtCore[18795]
#define sipNameNr_NoFormatConversion 18814
#define sipName_NoFormatConversion &sipStrings_QtCore[18814]
#define sipNameNr_NoLayoutChangeHint 18833
#define sipName_NoLayoutChangeHint &sipStrings_QtCore[18833]
#define sipNameNr_NotWellFormedError 18852
#define sipName_NotWellFormedError &sipStrings_QtCore[18852]
#define sipNameNr_OldHungarianScript 18871
#define sipName_OldHungarianScript &sipStrings_QtCore[18871]
#define sipNameNr_OmitGroupSeparator 18890
#define sipName_OmitGroupSeparator &sipStrings_QtCore[18890]
#define sipNameNr_OmitTrailingEquals 18909
#define sipName_OmitTrailingEquals &sipStrings_QtCore[18909]
#define sipNameNr_OrderedAlphaDither 18928
#define sipName_OrderedAlphaDither &sipStrings_QtCore[18928]
#define sipNameNr_ParseAsLongOptions 18947
#define sipName_ParseAsLongOptions &sipStrings_QtCore[18947]
#define sipNameNr_PerformanceCounter 18966
#define sipName_PerformanceCounter &sipStrings_QtCore[18966]
#define sipNameNr_PointingHandCursor 18985
#define sipName_PointingHandCursor &sipStrings_QtCore[18985]
#define sipNameNr_PreventContextMenu 19004
#define sipName_PreventContextMenu &sipStrings_QtCore[19004]
#define sipNameNr_PrimaryOrientation 19023
#define sipName_PrimaryOrientation &sipStrings_QtCore[19023]
#define sipNameNr_ProcessChannelMode 3447
#define sipName_ProcessChannelMode &sipStrings_QtCore[3447]
#define sipNameNr_ProcessEventsFlags 2553
#define sipName_ProcessEventsFlags &sipStrings_QtCore[2553]
#define sipNameNr_QAbstractAnimation 19042
#define sipName_QAbstractAnimation &sipStrings_QtCore[19042]
#define sipNameNr_QAbstractItemModel 19061
#define sipName_QAbstractItemModel &sipStrings_QtCore[19061]
#define sipNameNr_QAbstractListModel 19080
#define sipName_QAbstractListModel &sipStrings_QtCore[19080]
#define sipNameNr_QCommandLineOption 19099
#define sipName_QCommandLineOption &sipStrings_QtCore[19099]
#define sipNameNr_QCommandLineParser 19118
#define sipName_QCommandLineParser &sipStrings_QtCore[19118]
#define sipNameNr_QCryptographicHash 19137
#define sipName_QCryptographicHash &sipStrings_QtCore[19137]
#define sipNameNr_QEasingCurve__Type 19156
#define sipName_QEasingCurve__Type &sipStrings_QtCore[19156]
#define sipNameNr_QFileSystemWatcher 19175
#define sipName_QFileSystemWatcher &sipStrings_QtCore[19175]
#define sipNameNr_QLibrary__LoadHint 19194
#define sipName_QLibrary__LoadHint &sipStrings_QtCore[19194]
#define sipNameNr_19213 19213
#define sipName_19213 &sipStrings_QtCore[19213]
#define sipNameNr_19232 19232
#define sipName_19232 &sipStrings_QtCore[19232]
#define sipNameNr_QMessageLogContext 19251
#define sipName_QMessageLogContext &sipStrings_QtCore[19251]
#define sipNameNr_QPropertyAnimation 19270
#define sipName_QPropertyAnimation &sipStrings_QtCore[19270]
#define sipNameNr_QRegExp__CaretMode 19289
#define sipName_QRegExp__CaretMode &sipStrings_QtCore[19289]
#define sipNameNr_QRegularExpression 19308
#define sipName_QRegularExpression &sipStrings_QtCore[19308]
#define sipNameNr_QSemaphoreReleaser 19327
#define sipName_QSemaphoreReleaser &sipStrings_QtCore[19327]
#define sipNameNr_Qt__ConnectionType 19346
#define sipName_Qt__ConnectionType &sipStrings_QtCore[19346]
#define sipNameNr_Qt__DockWidgetArea 19365
#define sipName_Qt__DockWidgetArea &sipStrings_QtCore[19365]
#define sipNameNr_Qt__MouseEventFlag 19384
#define sipName_Qt__MouseEventFlag &sipStrings_QtCore[19384]
#define sipNameNr_Qt__NavigationMode 19403
#define sipName_Qt__NavigationMode &sipStrings_QtCore[19403]
#define sipNameNr_Qt__WhiteSpaceMode 19422
#define sipName_Qt__WhiteSpaceMode &sipStrings_QtCore[19422]
#define sipNameNr_Qt__WindowModality 19441
#define sipName_Qt__WindowModality &sipStrings_QtCore[19441]
#define sipNameNr_RealNumberNotation 2395
#define sipName_RealNumberNotation &sipStrings_QtCore[2395]
#define sipNameNr_SaintKittsAndNevis 19460
#define sipName_SaintKittsAndNevis &sipStrings_QtCore[19460]
#define sipNameNr_SaoTomeAndPrincipe 19479
#define sipName_SaoTomeAndPrincipe &sipStrings_QtCore[19479]
#define sipNameNr_ScientificNotation 19498
#define sipName_ScientificNotation &sipStrings_QtCore[19498]
#define sipNameNr_ScreenOrientations 10396
#define sipName_ScreenOrientations &sipStrings_QtCore[10396]
#define sipNameNr_ScrollBarAlwaysOff 19517
#define sipName_ScrollBarAlwaysOff &sipStrings_QtCore[19517]
#define sipNameNr_StateMachineSignal 19536
#define sipName_StateMachineSignal &sipStrings_QtCore[19536]
#define sipNameNr_StripTrailingSlash 19555
#define sipName_StripTrailingSlash &sipStrings_QtCore[19555]
#define sipNameNr_SwipeNativeGesture 19574
#define sipName_SwipeNativeGesture &sipStrings_QtCore[19574]
#define sipNameNr_SyrianArabRepublic 19593
#define sipName_SyrianArabRepublic &sipStrings_QtCore[19593]
#define sipNameNr_ToolButtonIconOnly 19612
#define sipName_ToolButtonIconOnly &sipStrings_QtCore[19612]
#define sipNameNr_ToolButtonTextOnly 19631
#define sipName_ToolButtonTextOnly &sipStrings_QtCore[19631]
#define sipNameNr_TouchPointReleased 19650
#define sipName_TouchPointReleased &sipStrings_QtCore[19650]
#define sipNameNr_TransformationMode 10419
#define sipName_TransformationMode &sipStrings_QtCore[10419]
#define sipNameNr_UnitedArabEmirates 19669
#define sipName_UnitedArabEmirates &sipStrings_QtCore[19669]
#define sipNameNr_UnterminatedObject 19688
#define sipName_UnterminatedObject &sipStrings_QtCore[19688]
#define sipNameNr_UnterminatedString 19707
#define sipName_UnterminatedString &sipStrings_QtCore[19707]
#define sipNameNr_VarangKshitiScript 19726
#define sipName_VarangKshitiScript &sipStrings_QtCore[19726]
#define sipNameNr_WA_CustomWhatsThis 19745
#define sipName_WA_CustomWhatsThis &sipStrings_QtCore[19745]
#define sipNameNr_WA_GrabbedShortcut 19764
#define sipName_WA_GrabbedShortcut &sipStrings_QtCore[19764]
#define sipNameNr_WA_MacBrushedMetal 19783
#define sipName_WA_MacBrushedMetal &sipStrings_QtCore[19783]
#define sipNameNr_WA_MacVariableSize 19802
#define sipName_WA_MacVariableSize &sipStrings_QtCore[19802]
#define sipNameNr_WA_UpdatesDisabled 19821
#define sipName_WA_UpdatesDisabled &sipStrings_QtCore[19821]
#define sipNameNr_WA_WState_Polished 19840
#define sipName_WA_WState_Polished &sipStrings_QtCore[19840]
#define sipNameNr_WindowFrameSection 10442
#define sipName_WindowFrameSection &sipStrings_QtCore[10442]
#define sipNameNr_allQueryItemValues 19859
#define sipName_allQueryItemValues &sipStrings_QtCore[19859]
#define sipNameNr_applicationDirPath 19878
#define sipName_applicationDirPath &sipStrings_QtCore[19878]
#define sipNameNr_applicationVersion 19897
#define sipName_applicationVersion &sipStrings_QtCore[19897]
#define sipNameNr_availableCalendars 19916
#define sipName_availableCalendars &sipStrings_QtCore[19916]
#define sipNameNr_beginInsertColumns 19935
#define sipName_beginInsertColumns &sipStrings_QtCore[19935]
#define sipNameNr_beginRemoveColumns 19954
#define sipName_beginRemoveColumns &sipStrings_QtCore[19954]
#define sipNameNr_cancelDelayedEvent 19973
#define sipName_cancelDelayedEvent &sipStrings_QtCore[19973]
#define sipNameNr_connectSlotsByName 19992
#define sipName_connectSlotsByName &sipStrings_QtCore[19992]
#define sipNameNr_convertFromUnicode 20011
#define sipName_convertFromUnicode &sipStrings_QtCore[20011]
#define sipNameNr_currentDateTimeUtc 20030
#define sipName_currentDateTimeUtc &sipStrings_QtCore[20030]
#define sipNameNr_currentLoopChanged 20049
#define sipName_currentLoopChanged &sipStrings_QtCore[20049]
#define sipNameNr_currentReadChannel 20068
#define sipName_currentReadChannel &sipStrings_QtCore[20068]
#define sipNameNr_daylightTimeOffset 20087
#define sipName_daylightTimeOffset &sipStrings_QtCore[20087]
#define sipNameNr_entityDeclarations 20106
#define sipName_entityDeclarations &sipStrings_QtCore[20106]
#define sipNameNr_fromBase64Encoding 20125
#define sipName_fromBase64Encoding &sipStrings_QtCore[20125]
#define sipNameNr_fromSecsSinceEpoch 20144
#define sipName_fromSecsSinceEpoch &sipStrings_QtCore[20144]
#define sipNameNr_historyTypeChanged 20163
#define sipName_historyTypeChanged &sipStrings_QtCore[20163]
#define sipNameNr_indexOfConstructor 20182
#define sipName_indexOfConstructor &sipStrings_QtCore[20182]
#define sipNameNr_installEventFilter 20201
#define sipName_installEventFilter &sipStrings_QtCore[20201]
#define sipNameNr_maximumDaysInMonth 20220
#define sipName_maximumDaysInMonth &sipStrings_QtCore[20220]
#define sipNameNr_metadataChangeTime 20239
#define sipName_metadataChangeTime &sipStrings_QtCore[20239]
#define sipNameNr_minimumDaysInMonth 20258
#define sipName_minimumDaysInMonth &sipStrings_QtCore[20258]
#define sipNameNr_namedCaptureGroups 20277
#define sipName_namedCaptureGroups &sipStrings_QtCore[20277]
#define sipNameNr_nativeLanguageName 20296
#define sipName_nativeLanguageName &sipStrings_QtCore[20296]
#define sipNameNr_organizationDomain 20315
#define sipName_organizationDomain &sipStrings_QtCore[20315]
#define sipNameNr_patternErrorOffset 20334
#define sipName_patternErrorOffset &sipStrings_QtCore[20334]
#define sipNameNr_previousTransition 20353
#define sipName_previousTransition &sipStrings_QtCore[20353]
#define sipNameNr_processChannelMode 20372
#define sipName_processChannelMode &sipStrings_QtCore[20372]
#define sipNameNr_processEnvironment 20391
#define sipName_processEnvironment &sipStrings_QtCore[20391]
#define sipNameNr_propertiesAssigned 20410
#define sipName_propertiesAssigned &sipStrings_QtCore[20410]
#define sipNameNr_pyqtPickleProtocol 20429
#define sipName_pyqtPickleProtocol &sipStrings_QtCore[20429]
#define sipNameNr_qRemovePostRoutine 20448
#define sipName_qRemovePostRoutine &sipStrings_QtCore[20448]
#define sipNameNr_qSetMessagePattern 20467
#define sipName_qSetMessagePattern &sipStrings_QtCore[20467]
#define sipNameNr_queryPairDelimiter 20486
#define sipName_queryPairDelimiter &sipStrings_QtCore[20486]
#define sipNameNr_realNumberNotation 20505
#define sipName_realNumberNotation &sipStrings_QtCore[20505]
#define sipNameNr_remainingTimeNSecs 20524
#define sipName_remainingTimeNSecs &sipStrings_QtCore[20524]
#define sipNameNr_removePostedEvents 20543
#define sipName_removePostedEvents &sipStrings_QtCore[20543]
#define sipNameNr_rowsAboutToBeMoved 20562
#define sipName_rowsAboutToBeMoved &sipStrings_QtCore[20562]
#define sipNameNr_setApplicationName 20581
#define sipName_setApplicationName &sipStrings_QtCore[20581]
#define sipNameNr_setCaseSensitivity 20600
#define sipName_setCaseSensitivity &sipStrings_QtCore[20600]
#define sipNameNr_setEventDispatcher 20619
#define sipName_setEventDispatcher &sipStrings_QtCore[20619]
#define sipNameNr_setFilterKeyColumn 20638
#define sipName_setFilterKeyColumn &sipStrings_QtCore[20638]
#define sipNameNr_setMSecsSinceEpoch 20657
#define sipName_setMSecsSinceEpoch &sipStrings_QtCore[20657]
#define sipNameNr_setPreciseDeadline 20676
#define sipName_setPreciseDeadline &sipStrings_QtCore[20676]
#define sipNameNr_setQueryDelimiters 20695
#define sipName_setQueryDelimiters &sipStrings_QtCore[20695]
#define sipNameNr_setQuitLockEnabled 20714
#define sipName_setQuitLockEnabled &sipStrings_QtCore[20714]
#define sipNameNr_setSortLocaleAware 20733
#define sipName_setSortLocaleAware &sipStrings_QtCore[20733]
#define sipNameNr_setTestModeEnabled 20752
#define sipName_setTestModeEnabled &sipStrings_QtCore[20752]
#define sipNameNr_setTextModeEnabled 20771
#define sipName_setTextModeEnabled &sipStrings_QtCore[20771]
#define sipNameNr_skipCurrentElement 20790
#define sipName_skipCurrentElement &sipStrings_QtCore[20790]
#define sipNameNr_sourceModelChanged 20809
#define sipName_sourceModelChanged &sipStrings_QtCore[20809]
#define sipNameNr_standardTimeOffset 20828
#define sipName_standardTimeOffset &sipStrings_QtCore[20828]
#define sipNameNr_targetStateChanged 20847
#define sipName_targetStateChanged &sipStrings_QtCore[20847]
#define sipNameNr_toNativeSeparators 20866
#define sipName_toNativeSeparators &sipStrings_QtCore[20866]
#define sipNameNr_toPreviousBoundary 20885
#define sipName_toPreviousBoundary &sipStrings_QtCore[20885]
#define sipNameNr_unknownOptionNames 20904
#define sipName_unknownOptionNames &sipStrings_QtCore[20904]
#define sipNameNr_unregisterResource 20923
#define sipName_unregisterResource &sipStrings_QtCore[20923]
#define sipNameNr_updateCurrentValue 20942
#define sipName_updateCurrentValue &sipStrings_QtCore[20942]
#define sipNameNr_windowsIdToIanaIds 20961
#define sipName_windowsIdToIanaIds &sipStrings_QtCore[20961]
#define sipNameNr_writeStartDocument 20980
#define sipName_writeStartDocument &sipStrings_QtCore[20980]
#define sipNameNr_yieldCurrentThread 20999
#define sipName_yieldCurrentThread &sipStrings_QtCore[20999]
#define sipNameNr_AA_X11InitThreads 21018
#define sipName_AA_X11InitThreads &sipStrings_QtCore[21018]
#define sipNameNr_AndroidNougat_MR1 21036
#define sipName_AndroidNougat_MR1 &sipStrings_QtCore[21036]
#define sipNameNr_AntiguaAndBarbuda 21054
#define sipName_AntiguaAndBarbuda &sipStrings_QtCore[21054]
#define sipNameNr_AppConfigLocation 21072
#define sipName_AppConfigLocation &sipStrings_QtCore[21072]
#define sipNameNr_ApplicationActive 21090
#define sipName_ApplicationActive &sipStrings_QtCore[21090]
#define sipNameNr_ApplicationHidden 21108
#define sipName_ApplicationHidden &sipStrings_QtCore[21108]
#define sipNameNr_ApplicationStates 12033
#define sipName_ApplicationStates &sipStrings_QtCore[12033]
#define sipNameNr_Base64UrlEncoding 21126
#define sipName_Base64UrlEncoding &sipStrings_QtCore[21126]
#define sipNameNr_BottomLeftSection 21144
#define sipName_BottomLeftSection &sipStrings_QtCore[21144]
#define sipNameNr_BottomRightCorner 21162
#define sipName_BottomRightCorner &sipStrings_QtCore[21162]
#define sipNameNr_BottomToolBarArea 21180
#define sipName_BottomToolBarArea &sipStrings_QtCore[21180]
#define sipNameNr_CheckIndexOptions 652
#define sipName_CheckIndexOptions &sipStrings_QtCore[652]
#define sipNameNr_ContainsItemShape 21198
#define sipName_ContainsItemShape &sipStrings_QtCore[21198]
#define sipNameNr_ContextMenuPolicy 12055
#define sipName_ContextMenuPolicy &sipStrings_QtCore[12055]
#define sipNameNr_CustomContextMenu 21216
#define sipName_CustomContextMenu &sipStrings_QtCore[21216]
#define sipNameNr_DataSizeIecFormat 21234
#define sipName_DataSizeIecFormat &sipStrings_QtCore[21234]
#define sipNameNr_DefaultConversion 21252
#define sipName_DefaultConversion &sipStrings_QtCore[21252]
#define sipNameNr_DefaultResolution 21270
#define sipName_DefaultResolution &sipStrings_QtCore[21270]
#define sipNameNr_DeleteWhenStopped 21288
#define sipName_DeleteWhenStopped &sipStrings_QtCore[21288]
#define sipNameNr_DeviceCoordinates 21306
#define sipName_DeviceCoordinates &sipStrings_QtCore[21306]
#define sipNameNr_DocumentationPath 21324
#define sipName_DocumentationPath &sipStrings_QtCore[21324]
#define sipNameNr_DocumentsLocation 21342
#define sipName_DocumentsLocation &sipStrings_QtCore[21342]
#define sipNameNr_DominicanRepublic 21360
#define sipName_DominicanRepublic &sipStrings_QtCore[21360]
#define sipNameNr_DontCaptureOption 21378
#define sipName_DontCaptureOption &sipStrings_QtCore[21378]
#define sipNameNr_ExpectedBase64url 21396
#define sipName_ExpectedBase64url &sipStrings_QtCore[21396]
#define sipNameNr_FormattingOptions 2009
#define sipName_FormattingOptions &sipStrings_QtCore[2009]
#define sipNameNr_ForwardedChannels 21414
#define sipName_ForwardedChannels &sipStrings_QtCore[21414]
#define sipNameNr_GraphicsSceneDrop 21432
#define sipName_GraphicsSceneDrop &sipStrings_QtCore[21432]
#define sipNameNr_GraphicsSceneHelp 21450
#define sipName_GraphicsSceneHelp &sipStrings_QtCore[21450]
#define sipNameNr_GraphicsSceneMove 21468
#define sipName_GraphicsSceneMove &sipStrings_QtCore[21468]
#define sipNameNr_HighEventPriority 21486
#define sipName_HighEventPriority &sipStrings_QtCore[21486]
#define sipNameNr_IgnoreAspectRatio 21504
#define sipName_IgnoreAspectRatio &sipStrings_QtCore[21504]
#define sipNameNr_IllegalSimpleType 21522
#define sipName_IllegalSimpleType &sipStrings_QtCore[21522]
#define sipNameNr_IllegalUTF8String 21540
#define sipName_IllegalUTF8String &sipStrings_QtCore[21540]
#define sipNameNr_ImAnchorRectangle 21558
#define sipName_ImAnchorRectangle &sipStrings_QtCore[21558]
#define sipNameNr_ImCursorRectangle 21576
#define sipName_ImCursorRectangle &sipStrings_QtCore[21576]
#define sipNameNr_ImSurroundingText 21594
#define sipName_ImSurroundingText &sipStrings_QtCore[21594]
#define sipNameNr_ImTextAfterCursor 21612
#define sipName_ImTextAfterCursor &sipStrings_QtCore[21612]
#define sipNameNr_InvalidUtf8String 21630
#define sipName_InvalidUtf8String &sipStrings_QtCore[21630]
#define sipNameNr_ItemIsDragEnabled 21648
#define sipName_ItemIsDragEnabled &sipStrings_QtCore[21648]
#define sipNameNr_ItemIsDropEnabled 21666
#define sipName_ItemIsDropEnabled &sipStrings_QtCore[21666]
#define sipNameNr_ItemSelectionMode 12077
#define sipName_ItemSelectionMode &sipStrings_QtCore[12077]
#define sipNameNr_Key_Dead_Abovedot 21684
#define sipName_Key_Dead_Abovedot &sipStrings_QtCore[21684]
#define sipNameNr_Key_Dead_Belowdot 21702
#define sipName_Key_Dead_Belowdot &sipStrings_QtCore[21702]
#define sipNameNr_Key_Dead_Currency 21720
#define sipName_Key_Dead_Currency &sipStrings_QtCore[21720]
#define sipNameNr_Key_Hangul_Jeonja 21738
#define sipName_Key_Hangul_Jeonja &sipStrings_QtCore[21738]
#define sipNameNr_Key_Hangul_Romaja 21756
#define sipName_Key_Hangul_Romaja &sipStrings_QtCore[21756]
#define sipNameNr_Key_MediaPrevious 21774
#define sipName_Key_MediaPrevious &sipStrings_QtCore[21774]
#define sipNameNr_Key_MicVolumeDown 21792
#define sipName_Key_MicVolumeDown &sipStrings_QtCore[21792]
#define sipNameNr_Key_RotateWindows 21810
#define sipName_Key_RotateWindows &sipStrings_QtCore[21810]
#define sipNameNr_Key_guillemotleft 21828
#define sipName_Key_guillemotleft &sipStrings_QtCore[21828]
#define sipNameNr_Key_threequarters 21846
#define sipName_Key_threequarters &sipStrings_QtCore[21846]
#define sipNameNr_Key_threesuperior 21864
#define sipName_Key_threesuperior &sipStrings_QtCore[21864]
#define sipNameNr_KeyboardModifiers 12099
#define sipName_KeyboardModifiers &sipStrings_QtCore[12099]
#define sipNameNr_MeasurementSystem 5262
#define sipName_MeasurementSystem &sipStrings_QtCore[5262]
#define sipNameNr_MeiteiMayekScript 21882
#define sipName_MeiteiMayekScript &sipStrings_QtCore[21882]
#define sipNameNr_NativeGestureType 12121
#define sipName_NativeGestureType &sipStrings_QtCore[12121]
#define sipNameNr_NeedsConstruction 21900
#define sipName_NeedsConstruction &sipStrings_QtCore[21900]
#define sipNameNr_NoOpaqueDetection 21918
#define sipName_NoOpaqueDetection &sipStrings_QtCore[21918]
#define sipNameNr_NoTextInteraction 21936
#define sipName_NoTextInteraction &sipStrings_QtCore[21936]
#define sipNameNr_OrientationChange 21954
#define sipName_OrientationChange &sipStrings_QtCore[21954]
#define sipNameNr_PahawhHmongScript 21972
#define sipName_PahawhHmongScript &sipStrings_QtCore[21972]
#define sipNameNr_PreventUnloadHint 21990
#define sipName_PreventUnloadHint &sipStrings_QtCore[21990]
#define sipNameNr_ProcessEventsFlag 2888
#define sipName_ProcessEventsFlag &sipStrings_QtCore[2888]
#define sipNameNr_QByteArrayMatcher 22008
#define sipName_QByteArrayMatcher &sipStrings_QtCore[22008]
#define sipNameNr_QCalendar__System 22026
#define sipName_QCalendar__System &sipStrings_QtCore[22026]
#define sipNameNr_QCborStreamReader 22044
#define sipName_QCborStreamReader &sipStrings_QtCore[22044]
#define sipNameNr_QCborStreamWriter 22062
#define sipName_QCborStreamWriter &sipStrings_QtCore[22062]
#define sipNameNr_22080 22080
#define sipName_22080 &sipStrings_QtCore[22080]
#define sipNameNr_QLocale__Language 22098
#define sipName_QLocale__Language &sipStrings_QtCore[22098]
#define sipNameNr_QSettings__Format 22116
#define sipName_QSettings__Format &sipStrings_QtCore[22116]
#define sipNameNr_QSettings__Status 22134
#define sipName_QSettings__Status &sipStrings_QtCore[22134]
#define sipNameNr_QSignalTransition 22152
#define sipName_QSignalTransition &sipStrings_QtCore[22152]
#define sipNameNr_QState__ChildMode 22170
#define sipName_QState__ChildMode &sipStrings_QtCore[22170]
#define sipNameNr_QT_TRANSLATE_NOOP 22188
#define sipName_QT_TRANSLATE_NOOP &sipStrings_QtCore[22188]
#define sipNameNr_QThread__Priority 22206
#define sipName_QThread__Priority &sipStrings_QtCore[22206]
#define sipNameNr_QUrl__ParsingMode 22224
#define sipName_QUrl__ParsingMode &sipStrings_QtCore[22224]
#define sipNameNr_QVariantAnimation 22242
#define sipName_QVariantAnimation &sipStrings_QtCore[22242]
#define sipNameNr_Qt__AlignmentFlag 22260
#define sipName_Qt__AlignmentFlag &sipStrings_QtCore[22260]
#define sipNameNr_Qt__ClipOperation 22278
#define sipName_Qt__ClipOperation &sipStrings_QtCore[22278]
#define sipNameNr_Qt__EventPriority 22296
#define sipName_Qt__EventPriority &sipStrings_QtCore[22296]
#define sipNameNr_Qt__TextElideMode 22314
#define sipName_Qt__TextElideMode &sipStrings_QtCore[22314]
#define sipNameNr_RegularExpression 4695
#define sipName_RegularExpression &sipStrings_QtCore[4695]
#define sipNameNr_RestoreProperties 11219
#define sipName_RestoreProperties &sipStrings_QtCore[11219]
#define sipNameNr_RussianFederation 22332
#define sipName_RussianFederation &sipStrings_QtCore[22332]
#define sipNameNr_ScreenOrientation 12143
#define sipName_ScreenOrientation &sipStrings_QtCore[12143]
#define sipNameNr_ScrollBarAlwaysOn 22350
#define sipName_ScrollBarAlwaysOn &sipStrings_QtCore[22350]
#define sipNameNr_ScrollBarAsNeeded 22368
#define sipName_ScrollBarAsNeeded &sipStrings_QtCore[22368]
#define sipNameNr_SharedMemoryError 1943
#define sipName_SharedMemoryError &sipStrings_QtCore[1943]
#define sipNameNr_SignWritingScript 22386
#define sipName_SignWritingScript &sipStrings_QtCore[22386]
#define sipNameNr_SkipChildElements 22404
#define sipName_SkipChildElements &sipStrings_QtCore[22404]
#define sipNameNr_SoraSompengScript 22422
#define sipName_SoraSompengScript &sipStrings_QtCore[22422]
#define sipNameNr_StandardQuotation 22440
#define sipName_StandardQuotation &sipStrings_QtCore[22440]
#define sipNameNr_SylotiNagriScript 22458
#define sipName_SylotiNagriScript &sipStrings_QtCore[22458]
#define sipNameNr_TapAndHoldGesture 22476
#define sipName_TapAndHoldGesture &sipStrings_QtCore[22476]
#define sipNameNr_TextAlignmentRole 22494
#define sipName_TextAlignmentRole &sipStrings_QtCore[22494]
#define sipNameNr_TopDockWidgetArea 22512
#define sipName_TopDockWidgetArea &sipStrings_QtCore[22512]
#define sipNameNr_TouchPointPressed 22530
#define sipName_TouchPointPressed &sipStrings_QtCore[22530]
#define sipNameNr_TrinidadAndTobago 22548
#define sipName_TrinidadAndTobago &sipStrings_QtCore[22548]
#define sipNameNr_UI_AnimateToolBox 22566
#define sipName_UI_AnimateToolBox &sipStrings_QtCore[22566]
#define sipNameNr_UI_AnimateTooltip 22584
#define sipName_UI_AnimateTooltip &sipStrings_QtCore[22584]
#define sipNameNr_UnterminatedArray 22602
#define sipName_UnterminatedArray &sipStrings_QtCore[22602]
#define sipNameNr_WA_AttributeCount 22620
#define sipName_WA_AttributeCount &sipStrings_QtCore[22620]
#define sipNameNr_WA_KeyCompression 22638
#define sipName_WA_KeyCompression &sipStrings_QtCore[22638]
#define sipNameNr_WA_OutsideWSRange 22656
#define sipName_WA_OutsideWSRange &sipStrings_QtCore[22656]
#define sipNameNr_WA_PaintUnclipped 22674
#define sipName_WA_PaintUnclipped &sipStrings_QtCore[22674]
#define sipNameNr_WA_StaticContents 22692
#define sipName_WA_StaticContents &sipStrings_QtCore[22692]
#define sipNameNr_WA_TabletTracking 22710
#define sipName_WA_TabletTracking &sipStrings_QtCore[22710]
#define sipNameNr_WA_WState_Created 22728
#define sipName_WA_WState_Created &sipStrings_QtCore[22728]
#define sipNameNr_WA_WState_Visible 22746
#define sipName_WA_WState_Visible &sipStrings_QtCore[22746]
#define sipNameNr_WA_WindowModified 22764
#define sipName_WA_WindowModified &sipStrings_QtCore[22764]
#define sipNameNr_WaitForMoreEvents 22782
#define sipName_WaitForMoreEvents &sipStrings_QtCore[22782]
#define sipNameNr_WindowStateChange 22800
#define sipName_WindowStateChange &sipStrings_QtCore[22800]
#define sipNameNr_WindowTitleChange 22818
#define sipName_WindowTitleChange &sipStrings_QtCore[22818]
#define sipNameNr_ZoomNativeGesture 10512
#define sipName_ZoomNativeGesture &sipStrings_QtCore[10512]
#define sipNameNr_activeThreadCount 22836
#define sipName_activeThreadCount &sipStrings_QtCore[22836]
#define sipNameNr_autoDetectUnicode 22854
#define sipName_autoDetectUnicode &sipStrings_QtCore[22854]
#define sipNameNr_canonicalFilePath 22872
#define sipName_canonicalFilePath &sipStrings_QtCore[22872]
#define sipNameNr_clearCurrentIndex 22890
#define sipName_clearCurrentIndex &sipStrings_QtCore[22890]
#define sipNameNr_closeWriteChannel 22908
#define sipName_closeWriteChannel &sipStrings_QtCore[22908]
#define sipNameNr_commitTransaction 22926
#define sipName_commitTransaction &sipStrings_QtCore[22926]
#define sipNameNr_currentRowChanged 22944
#define sipName_currentRowChanged &sipStrings_QtCore[22944]
#define sipNameNr_defaultAnimations 22962
#define sipName_defaultAnimations &sipStrings_QtCore[22962]
#define sipNameNr_defaultTransition 22980
#define sipName_defaultTransition &sipStrings_QtCore[22980]
#define sipNameNr_dynamicSortFilter 22998
#define sipName_dynamicSortFilter &sipStrings_QtCore[22998]
#define sipNameNr_errorStateChanged 23016
#define sipName_errorStateChanged &sipStrings_QtCore[23016]
#define sipNameNr_filterNativeEvent 23034
#define sipName_filterNativeEvent &sipStrings_QtCore[23034]
#define sipNameNr_filterRoleChanged 23052
#define sipName_filterRoleChanged &sipStrings_QtCore[23052]
#define sipNameNr_formattedDataSize 23070
#define sipName_formattedDataSize &sipStrings_QtCore[23070]
#define sipNameNr_headerDataChanged 23088
#define sipName_headerDataChanged &sipStrings_QtCore[23088]
#define sipNameNr_ianaIdToWindowsId 23106
#define sipName_ianaIdToWindowsId &sipStrings_QtCore[23106]
#define sipNameNr_ignorePunctuation 23124
#define sipName_ignorePunctuation &sipStrings_QtCore[23124]
#define sipNameNr_indexOfEnumerator 23142
#define sipName_indexOfEnumerator &sipStrings_QtCore[23142]
#define sipNameNr_installTranslator 23160
#define sipName_installTranslator &sipStrings_QtCore[23160]
#define sipNameNr_isCriticalEnabled 23178
#define sipName_isCriticalEnabled &sipStrings_QtCore[23178]
#define sipNameNr_isEntityReference 23196
#define sipName_isEntityReference &sipStrings_QtCore[23196]
#define sipNameNr_isNegativeInteger 23214
#define sipName_isNegativeInteger &sipStrings_QtCore[23214]
#define sipNameNr_isQuitLockEnabled 23232
#define sipName_isQuitLockEnabled &sipStrings_QtCore[23232]
#define sipNameNr_isSignalConnected 23250
#define sipName_isSignalConnected &sipStrings_QtCore[23250]
#define sipNameNr_isSortLocaleAware 23268
#define sipName_isSortLocaleAware &sipStrings_QtCore[23268]
#define sipNameNr_isTextModeEnabled 23286
#define sipName_isTextModeEnabled &sipStrings_QtCore[23286]
#define sipNameNr_isUnsignedInteger 23304
#define sipName_isUnsignedInteger &sipStrings_QtCore[23304]
#define sipNameNr_lastCapturedIndex 23322
#define sipName_lastCapturedIndex &sipStrings_QtCore[23322]
#define sipNameNr_measurementSystem 23340
#define sipName_measurementSystem &sipStrings_QtCore[23340]
#define sipNameNr_metaObjectForType 23358
#define sipName_metaObjectForType &sipStrings_QtCore[23358]
#define sipNameNr_nativeCountryName 23376
#define sipName_nativeCountryName &sipStrings_QtCore[23376]
#define sipNameNr_nativeEventFilter 23394
#define sipName_nativeEventFilter &sipStrings_QtCore[23394]
#define sipNameNr_notifySignalIndex 23412
#define sipName_notifySignalIndex &sipStrings_QtCore[23412]
#define sipNameNr_objectNameChanged 23430
#define sipName_objectNameChanged &sipStrings_QtCore[23430]
#define sipNameNr_prettyProductName 23448
#define sipName_prettyProductName &sipStrings_QtCore[23448]
#define sipNameNr_qFormatLogMessage 23466
#define sipName_qFormatLogMessage &sipStrings_QtCore[23466]
#define sipNameNr_registerEventType 23484
#define sipName_registerEventType &sipStrings_QtCore[23484]
#define sipNameNr_regularExpression 23502
#define sipName_regularExpression &sipStrings_QtCore[23502]
#define sipNameNr_removeEventFilter 23520
#define sipName_removeEventFilter &sipStrings_QtCore[23520]
#define sipNameNr_removeLibraryPath 23538
#define sipName_removeLibraryPath &sipStrings_QtCore[23538]
#define sipNameNr_removeRecursively 23556
#define sipName_removeRecursively &sipStrings_QtCore[23556]
#define sipNameNr_removeSourceModel 23574
#define sipName_removeSourceModel &sipStrings_QtCore[23574]
#define sipNameNr_resetInternalData 23592
#define sipName_resetInternalData &sipStrings_QtCore[23592]
#define sipNameNr_senderSignalIndex 23610
#define sipName_senderSignalIndex &sipStrings_QtCore[23610]
#define sipNameNr_setAutoFormatting 23628
#define sipName_setAutoFormatting &sipStrings_QtCore[23628]
#define sipNameNr_setCodecForLocale 23646
#define sipName_setCodecForLocale &sipStrings_QtCore[23646]
#define sipNameNr_setEntityResolver 23664
#define sipName_setEntityResolver &sipStrings_QtCore[23664]
#define sipNameNr_setExtraSelectors 23682
#define sipName_setExtraSelectors &sipStrings_QtCore[23682]
#define sipNameNr_setFieldAlignment 23700
#define sipName_setFieldAlignment &sipStrings_QtCore[23700]
#define sipNameNr_setFilterWildcard 23718
#define sipName_setFilterWildcard &sipStrings_QtCore[23718]
#define sipNameNr_setMaxThreadCount 23736
#define sipName_setMaxThreadCount &sipStrings_QtCore[23736]
#define sipNameNr_setPatternOptions 23754
#define sipName_setPatternOptions &sipStrings_QtCore[23754]
#define sipNameNr_setSecsSinceEpoch 23772
#define sipName_setSecsSinceEpoch &sipStrings_QtCore[23772]
#define sipNameNr_setTransitionType 23790
#define sipName_setTransitionType &sipStrings_QtCore[23790]
#define sipNameNr_setUpdateInterval 23808
#define sipName_setUpdateInterval &sipStrings_QtCore[23808]
#define sipNameNr_setupChildProcess 23826
#define sipName_setupChildProcess &sipStrings_QtCore[23826]
#define sipNameNr_sip_simplewrapper 23844
#define sipName_sip_simplewrapper &sipStrings_QtCore[23844]
#define sipNameNr_standaloneDayName 23862
#define sipName_standaloneDayName &sipStrings_QtCore[23862]
#define sipNameNr_standardLocations 23880
#define sipName_standardLocations &sipStrings_QtCore[23880]
#define sipNameNr_suffixForFileName 23898
#define sipName_suffixForFileName &sipStrings_QtCore[23898]
#define sipNameNr_systemEnvironment 23916
#define sipName_systemEnvironment &sipStrings_QtCore[23916]
#define sipNameNr_toMSecsSinceEpoch 23934
#define sipName_toMSecsSinceEpoch &sipStrings_QtCore[23934]
#define sipNameNr_toPercentEncoding 23952
#define sipName_toPercentEncoding &sipStrings_QtCore[23952]
#define sipNameNr_toUnsignedInteger 23970
#define sipName_toUnsignedInteger &sipStrings_QtCore[23970]
#define sipNameNr_updateCurrentTime 23988
#define sipName_updateCurrentTime &sipStrings_QtCore[23988]
#define sipNameNr_writeChannelCount 24006
#define sipName_writeChannelCount &sipStrings_QtCore[24006]
#define sipNameNr_writeCurrentToken 24024
#define sipName_writeCurrentToken &sipStrings_QtCore[24024]
#define sipNameNr_writeEmptyElement 24042
#define sipName_writeEmptyElement &sipStrings_QtCore[24042]
#define sipNameNr_writeQVariantHash 24060
#define sipName_writeQVariantHash &sipStrings_QtCore[24060]
#define sipNameNr_writeQVariantList 24078
#define sipName_writeQVariantList &sipStrings_QtCore[24078]
#define sipNameNr_writeStartElement 24096
#define sipName_writeStartElement &sipStrings_QtCore[24096]
#define sipNameNr_AA_NativeWindows 24114
#define sipName_AA_NativeWindows &sipStrings_QtCore[24114]
#define sipNameNr_ActivationChange 24131
#define sipName_ActivationChange &sipStrings_QtCore[24131]
#define sipNameNr_AndroidJellyBean 24148
#define sipName_AndroidJellyBean &sipStrings_QtCore[24148]
#define sipNameNr_ApplicationModal 24165
#define sipName_ApplicationModal &sipStrings_QtCore[24165]
#define sipNameNr_ApplicationState 14163
#define sipName_ApplicationState &sipStrings_QtCore[14163]
#define sipNameNr_BottomLeftCorner 24182
#define sipName_BottomLeftCorner &sipStrings_QtCore[24182]
#define sipNameNr_BreakOpportunity 24199
#define sipName_BreakOpportunity &sipStrings_QtCore[24199]
#define sipNameNr_BypassValidation 24216
#define sipName_BypassValidation &sipStrings_QtCore[24216]
#define sipNameNr_CheckIndexOption 728
#define sipName_CheckIndexOption &sipStrings_QtCore[728]
#define sipNameNr_ClassicalMandaic 24233
#define sipName_ClassicalMandaic &sipStrings_QtCore[24233]
#define sipNameNr_ClippertonIsland 24250
#define sipName_ClippertonIsland &sipStrings_QtCore[24250]
#define sipNameNr_ClosedHandCursor 24267
#define sipName_ClosedHandCursor &sipStrings_QtCore[24267]
#define sipNameNr_CongoBrazzaville 24284
#define sipName_CongoBrazzaville &sipStrings_QtCore[24284]
#define sipNameNr_CoordinateSystem 14184
#define sipName_CoordinateSystem &sipStrings_QtCore[14184]
#define sipNameNr_DataSizeSIFormat 24301
#define sipName_DataSizeSIFormat &sipStrings_QtCore[24301]
#define sipNameNr_DevanagariScript 24318
#define sipName_DevanagariScript &sipStrings_QtCore[24318]
#define sipNameNr_DiagCrossPattern 24335
#define sipName_DiagCrossPattern &sipStrings_QtCore[24335]
#define sipNameNr_DirectConnection 24352
#define sipName_DirectConnection &sipStrings_QtCore[24352]
#define sipNameNr_DocumentTooLarge 24369
#define sipName_DocumentTooLarge &sipStrings_QtCore[24369]
#define sipNameNr_DownloadLocation 24386
#define sipName_DownloadLocation &sipStrings_QtCore[24386]
#define sipNameNr_EncodeDelimiters 24403
#define sipName_EncodeDelimiters &sipStrings_QtCore[24403]
#define sipNameNr_EndNativeGesture 24420
#define sipName_EndNativeGesture &sipStrings_QtCore[24420]
#define sipNameNr_EnterKeyPrevious 24437
#define sipName_EnterKeyPrevious &sipStrings_QtCore[24437]
#define sipNameNr_EquatorialGuinea 24454
#define sipName_EquatorialGuinea &sipStrings_QtCore[24454]
#define sipNameNr_FindChildOptions 14205
#define sipName_FindChildOptions &sipStrings_QtCore[14205]
#define sipNameNr_FromBase64Result 3333
#define sipName_FromBase64Result &sipStrings_QtCore[3333]
#define sipNameNr_GlagoliticScript 24471
#define sipName_GlagoliticScript &sipStrings_QtCore[24471]
#define sipNameNr_IllegalCharacter 24488
#define sipName_IllegalCharacter &sipStrings_QtCore[24488]
#define sipNameNr_ImAnchorPosition 24505
#define sipName_ImAnchorPosition &sipStrings_QtCore[24505]
#define sipNameNr_ImCursorPosition 24522
#define sipName_ImCursorPosition &sipStrings_QtCore[24522]
#define sipNameNr_ImhLowercaseOnly 24539
#define sipName_ImhLowercaseOnly &sipStrings_QtCore[24539]
#define sipNameNr_ImhNoTextHandles 24556
#define sipName_ImhNoTextHandles &sipStrings_QtCore[24556]
#define sipNameNr_ImhPreferNumbers 24573
#define sipName_ImhPreferNumbers &sipStrings_QtCore[24573]
#define sipNameNr_ImhSensitiveData 24590
#define sipName_ImhSensitiveData &sipStrings_QtCore[24590]
#define sipNameNr_ImhUppercaseOnly 24607
#define sipName_ImhUppercaseOnly &sipStrings_QtCore[24607]
#define sipNameNr_ImperialUKSystem 24624
#define sipName_ImperialUKSystem &sipStrings_QtCore[24624]
#define sipNameNr_ImperialUSSystem 24641
#define sipName_ImperialUSSystem &sipStrings_QtCore[24641]
#define sipNameNr_InputChannelMode 5317
#define sipName_InputChannelMode &sipStrings_QtCore[5317]
#define sipNameNr_InputMethodHints 14226
#define sipName_InputMethodHints &sipStrings_QtCore[14226]
#define sipNameNr_InputMethodQuery 14247
#define sipName_InputMethodQuery &sipStrings_QtCore[14247]
#define sipNameNr_InputOutputError 24658
#define sipName_InputOutputError &sipStrings_QtCore[24658]
#define sipNameNr_ItemIsSelectable 24675
#define sipName_ItemIsSelectable &sipStrings_QtCore[24675]
#define sipNameNr_Key_AudioForward 24692
#define sipName_Key_AudioForward &sipStrings_QtCore[24692]
#define sipNameNr_Key_BracketRight 24709
#define sipName_Key_BracketRight &sipStrings_QtCore[24709]
#define sipNameNr_Key_Dead_Cedilla 24726
#define sipName_Key_Dead_Cedilla &sipStrings_QtCore[24726]
#define sipNameNr_Key_Dead_Lowline 24743
#define sipName_Key_Dead_Lowline &sipStrings_QtCore[24743]
#define sipNameNr_Key_Hangul_Banja 24760
#define sipName_Key_Hangul_Banja &sipStrings_QtCore[24760]
#define sipNameNr_Key_Hangul_Hanja 24777
#define sipName_Key_Hangul_Hanja &sipStrings_QtCore[24777]
#define sipNameNr_Key_Hangul_Start 24794
#define sipName_Key_Hangul_Start &sipStrings_QtCore[24794]
#define sipNameNr_Key_nobreakspace 24811
#define sipName_Key_nobreakspace &sipStrings_QtCore[24811]
#define sipNameNr_Key_questiondown 24828
#define sipName_Key_questiondown &sipStrings_QtCore[24828]
#define sipNameNr_KeyboardModifier 14268
#define sipName_KeyboardModifier &sipStrings_QtCore[14268]
#define sipNameNr_KharoshthiScript 24845
#define sipName_KharoshthiScript &sipStrings_QtCore[24845]
#define sipNameNr_LargeFloweryMiao 24862
#define sipName_LargeFloweryMiao &sipStrings_QtCore[24862]
#define sipNameNr_LayoutChangeHint 765
#define sipName_LayoutChangeHint &sipStrings_QtCore[765]
#define sipNameNr_LogicalMoveStyle 24879
#define sipName_LogicalMoveStyle &sipStrings_QtCore[24879]
#define sipNameNr_LowEventPriority 24896
#define sipName_LowEventPriority &sipStrings_QtCore[24896]
#define sipNameNr_MachAbsoluteTime 24913
#define sipName_MachAbsoluteTime &sipStrings_QtCore[24913]
#define sipNameNr_ManichaeanScript 24930
#define sipName_ManichaeanScript &sipStrings_QtCore[24930]
#define sipNameNr_MapPrivateOption 24947
#define sipName_MapPrivateOption &sipStrings_QtCore[24947]
#define sipNameNr_MatchFixedString 24964
#define sipName_MatchFixedString &sipStrings_QtCore[24964]
#define sipNameNr_MouseButtonPress 2799
#define sipName_MouseButtonPress &sipStrings_QtCore[2799]
#define sipNameNr_MouseEventSource 14289
#define sipName_MouseEventSource &sipStrings_QtCore[14289]
#define sipNameNr_MouseFocusReason 24981
#define sipName_MouseFocusReason &sipStrings_QtCore[24981]
#define sipNameNr_NeedsDestruction 24998
#define sipName_NeedsDestruction &sipStrings_QtCore[24998]
#define sipNameNr_NoDockWidgetArea 25015
#define sipName_NoDockWidgetArea &sipStrings_QtCore[25015]
#define sipNameNr_NorwegianNynorsk 25032
#define sipName_NorwegianNynorsk &sipStrings_QtCore[25032]
#define sipNameNr_OldPersianScript 25049
#define sipName_OldPersianScript &sipStrings_QtCore[25049]
#define sipNameNr_OtherFocusReason 25066
#define sipName_OtherFocusReason &sipStrings_QtCore[25066]
#define sipNameNr_PYQT_VERSION_STR 25083
#define sipName_PYQT_VERSION_STR &sipStrings_QtCore[25083]
#define sipNameNr_PanNativeGesture 25100
#define sipName_PanNativeGesture &sipStrings_QtCore[25100]
#define sipNameNr_PartiallyChecked 25117
#define sipName_PartiallyChecked &sipStrings_QtCore[25117]
#define sipNameNr_PermissionDenied 25134
#define sipName_PermissionDenied &sipStrings_QtCore[25134]
#define sipNameNr_PermissionsError 25151
#define sipName_PermissionsError &sipStrings_QtCore[25151]
#define sipNameNr_PhoenicianScript 25168
#define sipName_PhoenicianScript &sipStrings_QtCore[25168]
#define sipNameNr_PicturesLocation 25185
#define sipName_PicturesLocation &sipStrings_QtCore[25185]
#define sipNameNr_PointerToQObject 25202
#define sipName_PointerToQObject &sipStrings_QtCore[25202]
#define sipNameNr_PopupFocusReason 25219
#define sipName_PopupFocusReason &sipStrings_QtCore[25219]
#define sipNameNr_QCborError__Code 25236
#define sipName_QCborError__Code &sipStrings_QtCore[25236]
#define sipNameNr_QCollatorSortKey 25253
#define sipName_QCollatorSortKey &sipStrings_QtCore[25253]
#define sipNameNr_QCoreApplication 25270
#define sipName_QCoreApplication &sipStrings_QtCore[25270]
#define sipNameNr_QEventLoopLocker 25287
#define sipName_QEventLoopLocker &sipStrings_QtCore[25287]
#define sipNameNr_QEventTransition 25304
#define sipName_QEventTransition &sipStrings_QtCore[25304]
#define sipNameNr_QGenericArgument 25321
#define sipName_QGenericArgument &sipStrings_QtCore[25321]
#define sipNameNr_QJsonValue__Type 25338
#define sipName_QJsonValue__Type &sipStrings_QtCore[25338]
#define sipNameNr_25355 25355
#define sipName_25355 &sipStrings_QtCore[25355]
#define sipNameNr_25372 25372
#define sipName_25372 &sipStrings_QtCore[25372]
#define sipNameNr_QLocale__Country 25389
#define sipName_QLocale__Country &sipStrings_QtCore[25389]
#define sipNameNr_QLoggingCategory 25406
#define sipName_QLoggingCategory &sipStrings_QtCore[25406]
#define sipNameNr_QRandomGenerator 25423
#define sipName_QRandomGenerator &sipStrings_QtCore[25423]
#define sipNameNr_QSettings__Scope 25440
#define sipName_QSettings__Scope &sipStrings_QtCore[25440]
#define sipNameNr_QStringListModel 25457
#define sipName_QStringListModel &sipStrings_QtCore[25457]
#define sipNameNr_QSysInfo__Endian 25474
#define sipName_QSysInfo__Endian &sipStrings_QtCore[25474]
#define sipNameNr_QSystemSemaphore 25491
#define sipName_QSystemSemaphore &sipStrings_QtCore[25491]
#define sipNameNr_QTimeLine__State 25508
#define sipName_QTimeLine__State &sipStrings_QtCore[25508]
#define sipNameNr_25525 25525
#define sipName_25525 &sipStrings_QtCore[25525]
#define sipNameNr_25542 25542
#define sipName_25542 &sipStrings_QtCore[25542]
#define sipNameNr_QXmlStreamReader 25559
#define sipName_QXmlStreamReader &sipStrings_QtCore[25559]
#define sipNameNr_QXmlStreamWriter 25576
#define sipName_QXmlStreamWriter &sipStrings_QtCore[25576]
#define sipNameNr_Qt__ChecksumType 25593
#define sipName_Qt__ChecksumType &sipStrings_QtCore[25593]
#define sipNameNr_Qt__EnterKeyType 25610
#define sipName_Qt__EnterKeyType &sipStrings_QtCore[25610]
#define sipNameNr_Qt__GestureFlags 25627
#define sipName_Qt__GestureFlags &sipStrings_QtCore[25627]
#define sipNameNr_Qt__GestureState 25644
#define sipName_Qt__GestureState &sipStrings_QtCore[25644]
#define sipNameNr_Qt__ItemDataRole 25661
#define sipName_Qt__ItemDataRole &sipStrings_QtCore[25661]
#define sipNameNr_Qt__MouseButtons 25678
#define sipName_Qt__MouseButtons &sipStrings_QtCore[25678]
#define sipNameNr_Qt__Orientations 25695
#define sipName_Qt__Orientations &sipStrings_QtCore[25695]
#define sipNameNr_Qt__PenJoinStyle 25712
#define sipName_Qt__PenJoinStyle &sipStrings_QtCore[25712]
#define sipNameNr_Qt__ToolBarAreas 25729
#define sipName_Qt__ToolBarAreas &sipStrings_QtCore[25729]
#define sipNameNr_Qt__WindowStates 25746
#define sipName_Qt__WindowStates &sipStrings_QtCore[25746]
#define sipNameNr_QueuedConnection 6890
#define sipName_QueuedConnection &sipStrings_QtCore[6890]
#define sipNameNr_ReplaceSelection 25763
#define sipName_ReplaceSelection &sipStrings_QtCore[25763]
#define sipNameNr_RightToolBarArea 25780
#define sipName_RightToolBarArea &sipStrings_QtCore[25780]
#define sipNameNr_RoundPreferFloor 25797
#define sipName_RoundPreferFloor &sipStrings_QtCore[25797]
#define sipNameNr_SaurashtraScript 25814
#define sipName_SaurashtraScript &sipStrings_QtCore[25814]
#define sipNameNr_SeparateChannels 25831
#define sipName_SeparateChannels &sipStrings_QtCore[25831]
#define sipNameNr_ShortOptionStyle 25848
#define sipName_ShortOptionStyle &sipStrings_QtCore[25848]
#define sipNameNr_ShortcutOverride 25865
#define sipName_ShortcutOverride &sipStrings_QtCore[25865]
#define sipNameNr_StandaloneFormat 25882
#define sipName_StandaloneFormat &sipStrings_QtCore[25882]
#define sipNameNr_StandardLocation 1977
#define sipName_StandardLocation &sipStrings_QtCore[1977]
#define sipNameNr_StringResultCode 1020
#define sipName_StringResultCode &sipStrings_QtCore[1020]
#define sipNameNr_SystemLocaleDate 25899
#define sipName_SystemLocaleDate &sipStrings_QtCore[25899]
#define sipNameNr_TabFocusBehavior 14310
#define sipName_TabFocusBehavior &sipStrings_QtCore[14310]
#define sipNameNr_TargetMoveAction 25916
#define sipName_TargetMoveAction &sipStrings_QtCore[25916]
#define sipNameNr_TextHideMnemonic 25933
#define sipName_TextHideMnemonic &sipStrings_QtCore[25933]
#define sipNameNr_TextShowMnemonic 25950
#define sipName_TextShowMnemonic &sipStrings_QtCore[25950]
#define sipNameNr_TextWrapAnywhere 25967
#define sipName_TextWrapAnywhere &sipStrings_QtCore[25967]
#define sipNameNr_ToolBarArea_Mask 25984
#define sipName_ToolBarArea_Mask &sipStrings_QtCore[25984]
#define sipNameNr_TouchPointStates 14331
#define sipName_TouchPointStates &sipStrings_QtCore[14331]
#define sipNameNr_TranslationsPath 26001
#define sipName_TranslationsPath &sipStrings_QtCore[26001]
#define sipNameNr_UncodedLanguages 26018
#define sipName_UncodedLanguages &sipStrings_QtCore[26018]
#define sipNameNr_UniqueConnection 26035
#define sipName_UniqueConnection &sipStrings_QtCore[26035]
#define sipNameNr_UnspecifiedError 26052
#define sipName_UnspecifiedError &sipStrings_QtCore[26052]
#define sipNameNr_VaticanCityState 26069
#define sipName_VaticanCityState &sipStrings_QtCore[26069]
#define sipNameNr_VerticalSortHint 26086
#define sipName_VerticalSortHint &sipStrings_QtCore[26086]
#define sipNameNr_WA_DeleteOnClose 26103
#define sipName_WA_DeleteOnClose &sipStrings_QtCore[26103]
#define sipNameNr_WA_ForceDisabled 26120
#define sipName_WA_ForceDisabled &sipStrings_QtCore[26120]
#define sipNameNr_WA_MacMetalStyle 26137
#define sipName_WA_MacMetalStyle &sipStrings_QtCore[26137]
#define sipNameNr_WA_MacNormalSize 26154
#define sipName_WA_MacNormalSize &sipStrings_QtCore[26154]
#define sipNameNr_WA_MouseTracking 26171
#define sipName_WA_MouseTracking &sipStrings_QtCore[26171]
#define sipNameNr_WA_NoMouseReplay 26188
#define sipName_WA_NoMouseReplay &sipStrings_QtCore[26188]
#define sipNameNr_WA_PaintOnScreen 26205
#define sipName_WA_PaintOnScreen &sipStrings_QtCore[26205]
#define sipNameNr_WA_PendingUpdate 26222
#define sipName_WA_PendingUpdate &sipStrings_QtCore[26222]
#define sipNameNr_WA_SetWindowIcon 26239
#define sipName_WA_SetWindowIcon &sipStrings_QtCore[26239]
#define sipNameNr_WA_WState_Hidden 26256
#define sipName_WA_WState_Hidden &sipStrings_QtCore[26256]
#define sipNameNr_WhatsThisClicked 26273
#define sipName_WhatsThisClicked &sipStrings_QtCore[26273]
#define sipNameNr_WhiteSpaceNoWrap 26290
#define sipName_WhiteSpaceNoWrap &sipStrings_QtCore[26290]
#define sipNameNr_WhiteSpaceNormal 26307
#define sipName_WhiteSpaceNormal &sipStrings_QtCore[26307]
#define sipNameNr_WindowDeactivate 26324
#define sipName_WindowDeactivate &sipStrings_QtCore[26324]
#define sipNameNr_WindowFullScreen 26341
#define sipName_WindowFullScreen &sipStrings_QtCore[26341]
#define sipNameNr_WindowIconChange 3940
#define sipName_WindowIconChange &sipStrings_QtCore[3940]
#define sipNameNr_X11ExcludeTimers 26358
#define sipName_X11ExcludeTimers &sipStrings_QtCore[26358]
#define sipNameNr_abortTransaction 26375
#define sipName_abortTransaction &sipStrings_QtCore[26375]
#define sipNameNr_absoluteFilePath 26392
#define sipName_absoluteFilePath &sipStrings_QtCore[26392]
#define sipNameNr_addVersionOption 26409
#define sipName_addVersionOption &sipStrings_QtCore[26409]
#define sipNameNr_beginMoveColumns 26426
#define sipName_beginMoveColumns &sipStrings_QtCore[26426]
#define sipNameNr_channelReadyRead 26443
#define sipName_channelReadyRead &sipStrings_QtCore[26443]
#define sipNameNr_checkConnectArgs 26460
#define sipName_checkConnectArgs &sipStrings_QtCore[26460]
#define sipNameNr_childModeChanged 26477
#define sipName_childModeChanged &sipStrings_QtCore[26477]
#define sipNameNr_closeReadChannel 26494
#define sipName_closeReadChannel &sipStrings_QtCore[26494]
#define sipNameNr_completeBaseName 26511
#define sipName_completeBaseName &sipStrings_QtCore[26511]
#define sipNameNr_compressionLevel 26528
#define sipName_compressionLevel &sipStrings_QtCore[26528]
#define sipNameNr_constructorCount 26545
#define sipName_constructorCount &sipStrings_QtCore[26545]
#define sipNameNr_convertToUnicode 26562
#define sipName_convertToUnicode &sipStrings_QtCore[26562]
#define sipNameNr_createNativeFile 26579
#define sipName_createNativeFile &sipStrings_QtCore[26579]
#define sipNameNr_currentAnimation 26596
#define sipName_currentAnimation &sipStrings_QtCore[26596]
#define sipNameNr_dateTimeToString 26613
#define sipName_dateTimeToString &sipStrings_QtCore[26613]
#define sipNameNr_directionChanged 26630
#define sipName_directionChanged &sipStrings_QtCore[26630]
#define sipNameNr_directoryChanged 26647
#define sipName_directoryChanged &sipStrings_QtCore[26647]
#define sipNameNr_disconnectNotify 26664
#define sipName_disconnectNotify &sipStrings_QtCore[26664]
#define sipNameNr_documentEncoding 26681
#define sipName_documentEncoding &sipStrings_QtCore[26681]
#define sipNameNr_endInsertColumns 26698
#define sipName_endInsertColumns &sipStrings_QtCore[26698]
#define sipNameNr_endRemoveColumns 26715
#define sipName_endRemoveColumns &sipStrings_QtCore[26715]
#define sipNameNr_enumeratorOffset 26732
#define sipName_enumeratorOffset &sipStrings_QtCore[26732]
#define sipNameNr_fallbacksEnabled 26749
#define sipName_fallbacksEnabled &sipStrings_QtCore[26749]
#define sipNameNr_filterAcceptsRow 26766
#define sipName_filterAcceptsRow &sipStrings_QtCore[26766]
#define sipNameNr_hasPendingEvents 26783
#define sipName_hasPendingEvents &sipStrings_QtCore[26783]
#define sipNameNr_idealThreadCount 26800
#define sipName_idealThreadCount &sipStrings_QtCore[26800]
#define sipNameNr_indexOfAnimation 26817
#define sipName_indexOfAnimation &sipStrings_QtCore[26817]
#define sipNameNr_indexOfClassInfo 26834
#define sipName_indexOfClassInfo &sipStrings_QtCore[26834]
#define sipNameNr_inputChannelMode 26851
#define sipName_inputChannelMode &sipStrings_QtCore[26851]
#define sipNameNr_invalidateFilter 26868
#define sipName_invalidateFilter &sipStrings_QtCore[26868]
#define sipNameNr_isColumnSelected 26885
#define sipName_isColumnSelected &sipStrings_QtCore[26885]
#define sipNameNr_isWarningEnabled 26902
#define sipName_isWarningEnabled &sipStrings_QtCore[26902]
#define sipNameNr_languageToString 26919
#define sipName_languageToString &sipStrings_QtCore[26919]
#define sipNameNr_licensedProducts 26936
#define sipName_licensedProducts &sipStrings_QtCore[26936]
#define sipNameNr_organizationName 26953
#define sipName_organizationName &sipStrings_QtCore[26953]
#define sipNameNr_postDelayedEvent 26970
#define sipName_postDelayedEvent &sipStrings_QtCore[26970]
#define sipNameNr_readChannelCount 26987
#define sipName_readChannelCount &sipStrings_QtCore[26987]
#define sipNameNr_readQVariantHash 27004
#define sipName_readQVariantHash &sipStrings_QtCore[27004]
#define sipNameNr_readQVariantList 27021
#define sipName_readQVariantList &sipStrings_QtCore[27021]
#define sipNameNr_registerResource 20925
#define sipName_registerResource &sipStrings_QtCore[20925]
#define sipNameNr_registeredTimers 27038
#define sipName_registeredTimers &sipStrings_QtCore[27038]
#define sipNameNr_relativeFilePath 27055
#define sipName_relativeFilePath &sipStrings_QtCore[27055]
#define sipNameNr_removeTransition 27072
#define sipName_removeTransition &sipStrings_QtCore[27072]
#define sipNameNr_removeTranslator 27089
#define sipName_removeTranslator &sipStrings_QtCore[27089]
#define sipNameNr_searchDelimiters 27106
#define sipName_searchDelimiters &sipStrings_QtCore[27106]
#define sipNameNr_selectionChanged 27123
#define sipName_selectionChanged &sipStrings_QtCore[27123]
#define sipNameNr_sendPostedEvents 27140
#define sipName_sendPostedEvents &sipStrings_QtCore[27140]
#define sipNameNr_setDefaultFormat 27157
#define sipName_setDefaultFormat &sipStrings_QtCore[27157]
#define sipNameNr_setDefaultValues 27174
#define sipName_setDefaultValues &sipStrings_QtCore[27174]
#define sipNameNr_setExpiryTimeout 27191
#define sipName_setExpiryTimeout &sipStrings_QtCore[27191]
#define sipNameNr_setNumberOptions 27208
#define sipName_setNumberOptions &sipStrings_QtCore[27208]
#define sipNameNr_setOffsetFromUtc 27225
#define sipName_setOffsetFromUtc &sipStrings_QtCore[27225]
#define sipNameNr_setPatternSyntax 27242
#define sipName_setPatternSyntax &sipStrings_QtCore[27242]
#define sipNameNr_setRemainingTime 27259
#define sipName_setRemainingTime &sipStrings_QtCore[27259]
#define sipNameNr_setSetuidAllowed 27276
#define sipName_setSetuidAllowed &sipStrings_QtCore[27276]
#define sipNameNr_setStaleLockTime 27293
#define sipName_setStaleLockTime &sipStrings_QtCore[27293]
#define sipNameNr_startTransaction 27310
#define sipName_startTransaction &sipStrings_QtCore[27310]
#define sipNameNr_staticMetaObject 27327
#define sipName_staticMetaObject &sipStrings_QtCore[27327]
#define sipNameNr_systemTimeZoneId 27344
#define sipName_systemTimeZoneId &sipStrings_QtCore[27344]
#define sipNameNr_toCurrencyString 27361
#define sipName_toCurrencyString &sipStrings_QtCore[27361]
#define sipNameNr_toSecsSinceEpoch 27378
#define sipName_toSecsSinceEpoch &sipStrings_QtCore[27378]
#define sipNameNr_uncompressedData 27395
#define sipName_uncompressedData &sipStrings_QtCore[27395]
#define sipNameNr_uncompressedSize 27412
#define sipName_uncompressedSize &sipStrings_QtCore[27412]
#define sipNameNr_unregisterTimers 27429
#define sipName_unregisterTimers &sipStrings_QtCore[27429]
#define sipNameNr_valueForProgress 27446
#define sipName_valueForProgress &sipStrings_QtCore[27446]
#define sipNameNr_waitForReadyRead 27463
#define sipName_waitForReadyRead &sipStrings_QtCore[27463]
#define sipNameNr_workingDirectory 27480
#define sipName_workingDirectory &sipStrings_QtCore[27480]
#define sipNameNr_writableLocation 27497
#define sipName_writableLocation &sipStrings_QtCore[27497]
#define sipNameNr_writeEndDocument 27514
#define sipName_writeEndDocument &sipStrings_QtCore[27514]
#define sipNameNr_writeQStringList 27531
#define sipName_writeQStringList &sipStrings_QtCore[27531]
#define sipNameNr_writeQVariantMap 27548
#define sipName_writeQVariantMap &sipStrings_QtCore[27548]
#define sipNameNr_writeTextElement 27565
#define sipName_writeTextElement &sipStrings_QtCore[27565]
#define sipNameNr_AllToolBarAreas 27582
#define sipName_AllToolBarAreas &sipStrings_QtCore[27582]
#define sipNameNr_AncientEgyptian 27598
#define sipName_AncientEgyptian &sipStrings_QtCore[27598]
#define sipNameNr_AndroidLollipop 27614
#define sipName_AndroidLollipop &sipStrings_QtCore[27614]
#define sipNameNr_AppDataLocation 27630
#define sipName_AppDataLocation &sipStrings_QtCore[27630]
#define sipNameNr_AscensionIsland 27646
#define sipName_AscensionIsland &sipStrings_QtCore[27646]
#define sipNameNr_AspectRatioMode 16623
#define sipName_AspectRatioMode &sipStrings_QtCore[16623]
#define sipNameNr_AssumeLocalFile 27662
#define sipName_AssumeLocalFile &sipStrings_QtCore[27662]
#define sipNameNr_AutoCloseHandle 27678
#define sipName_AutoCloseHandle &sipStrings_QtCore[27678]
#define sipNameNr_BhaiksukiScript 27694
#define sipName_BhaiksukiScript &sipStrings_QtCore[27694]
#define sipNameNr_BoundaryReasons 803
#define sipName_BoundaryReasons &sipStrings_QtCore[803]
#define sipNameNr_CaseInsensitive 27710
#define sipName_CaseInsensitive &sipStrings_QtCore[27710]
#define sipNameNr_CaseSensitivity 7916
#define sipName_CaseSensitivity &sipStrings_QtCore[7916]
#define sipNameNr_CeutaAndMelilla 27726
#define sipName_CeutaAndMelilla &sipStrings_QtCore[27726]
#define sipNameNr_ChecksumIso3309 27742
#define sipName_ChecksumIso3309 &sipStrings_QtCore[27742]
#define sipNameNr_ChristmasIsland 27758
#define sipName_ChristmasIsland &sipStrings_QtCore[27758]
#define sipNameNr_ControlModifier 27774
#define sipName_ControlModifier &sipStrings_QtCore[27774]
#define sipNameNr_ConversionFlags 4389
#define sipName_ConversionFlags &sipStrings_QtCore[4389]
#define sipNameNr_CuneiformScript 27790
#define sipName_CuneiformScript &sipStrings_QtCore[27790]
#define sipNameNr_CurrencyIsoCode 27806
#define sipName_CurrencyIsoCode &sipStrings_QtCore[27806]
#define sipNameNr_CursorMoveStyle 16663
#define sipName_CursorMoveStyle &sipStrings_QtCore[16663]
#define sipNameNr_DataSizeFormats 7316
#define sipName_DataSizeFormats &sipStrings_QtCore[7316]
#define sipNameNr_DescendingOrder 27822
#define sipName_DescendingOrder &sipStrings_QtCore[27822]
#define sipNameNr_DesktopLocation 27838
#define sipName_DesktopLocation &sipStrings_QtCore[27838]
#define sipNameNr_DockWidgetAreas 16683
#define sipName_DockWidgetAreas &sipStrings_QtCore[16683]
#define sipNameNr_DontCloseHandle 27854
#define sipName_DontCloseHandle &sipStrings_QtCore[27854]
#define sipNameNr_DoublePrecision 27870
#define sipName_DoublePrecision &sipStrings_QtCore[27870]
#define sipNameNr_EnterKeyDefault 27886
#define sipName_EnterKeyDefault &sipStrings_QtCore[27886]
#define sipNameNr_EntityReference 15403
#define sipName_EntityReference &sipStrings_QtCore[15403]
#define sipNameNr_ExclusiveStates 27902
#define sipName_ExclusiveStates &sipStrings_QtCore[27902]
#define sipNameNr_FalklandIslands 27918
#define sipName_FalklandIslands &sipStrings_QtCore[27918]
#define sipNameNr_FileHandleFlags 3392
#define sipName_FileHandleFlags &sipStrings_QtCore[3392]
#define sipNameNr_FindChildOption 16703
#define sipName_FindChildOption &sipStrings_QtCore[16703]
#define sipNameNr_ForbiddenCursor 27934
#define sipName_ForbiddenCursor &sipStrings_QtCore[27934]
#define sipNameNr_ForeverConstant 2270
#define sipName_ForeverConstant &sipStrings_QtCore[2270]
#define sipNameNr_FrenchPolynesia 27950
#define sipName_FrenchPolynesia &sipStrings_QtCore[27950]
#define sipNameNr_GestureCanceled 27966
#define sipName_GestureCanceled &sipStrings_QtCore[27966]
#define sipNameNr_GestureFinished 27982
#define sipName_GestureFinished &sipStrings_QtCore[27982]
#define sipNameNr_GestureOverride 27998
#define sipName_GestureOverride &sipStrings_QtCore[27998]
#define sipNameNr_HighestPriority 28014
#define sipName_HighestPriority &sipStrings_QtCore[28014]
#define sipNameNr_HitTestAccuracy 16723
#define sipName_HitTestAccuracy &sipStrings_QtCore[16723]
#define sipNameNr_InheritPriority 28030
#define sipName_InheritPriority &sipStrings_QtCore[28030]
#define sipNameNr_InputMethodHint 16743
#define sipName_InputMethodHint &sipStrings_QtCore[16743]
#define sipNameNr_KeepAspectRatio 28046
#define sipName_KeepAspectRatio &sipStrings_QtCore[28046]
#define sipNameNr_KeepWhenStopped 28062
#define sipName_KeepWhenStopped &sipStrings_QtCore[28062]
#define sipNameNr_Key_Acircumflex 28078
#define sipName_Key_Acircumflex &sipStrings_QtCore[28078]
#define sipNameNr_Key_AddFavorite 28094
#define sipName_Key_AddFavorite &sipStrings_QtCore[28094]
#define sipNameNr_Key_AsciiCircum 28110
#define sipName_Key_AsciiCircum &sipStrings_QtCore[28110]
#define sipNameNr_Key_AudioRepeat 28126
#define sipName_Key_AudioRepeat &sipStrings_QtCore[28126]
#define sipNameNr_Key_AudioRewind 28142
#define sipName_Key_AudioRewind &sipStrings_QtCore[28142]
#define sipNameNr_Key_BackForward 28158
#define sipName_Key_BackForward &sipStrings_QtCore[28158]
#define sipNameNr_Key_BracketLeft 28174
#define sipName_Key_BracketLeft &sipStrings_QtCore[28174]
#define sipNameNr_Key_CameraFocus 28190
#define sipName_Key_CameraFocus &sipStrings_QtCore[28190]
#define sipNameNr_Key_ChannelDown 28206
#define sipName_Key_ChannelDown &sipStrings_QtCore[28206]
#define sipNameNr_Key_Dead_Macron 28222
#define sipName_Key_Dead_Macron &sipStrings_QtCore[28222]
#define sipNameNr_Key_Dead_Ogonek 28238
#define sipName_Key_Dead_Ogonek &sipStrings_QtCore[28238]
#define sipNameNr_Key_Dead_Stroke 28254
#define sipName_Key_Dead_Stroke &sipStrings_QtCore[28254]
#define sipNameNr_Key_Direction_L 28270
#define sipName_Key_Direction_L &sipStrings_QtCore[28270]
#define sipNameNr_Key_Direction_R 28286
#define sipName_Key_Direction_R &sipStrings_QtCore[28286]
#define sipNameNr_Key_Ecircumflex 28302
#define sipName_Key_Ecircumflex &sipStrings_QtCore[28302]
#define sipNameNr_Key_Eisu_toggle 28318
#define sipName_Key_Eisu_toggle &sipStrings_QtCore[28318]
#define sipNameNr_Key_Hangul_Jamo 28334
#define sipName_Key_Hangul_Jamo &sipStrings_QtCore[28334]
#define sipNameNr_Key_Icircumflex 28350
#define sipName_Key_Icircumflex &sipStrings_QtCore[28350]
#define sipNameNr_Key_LaunchMedia 28366
#define sipName_Key_LaunchMedia &sipStrings_QtCore[28366]
#define sipNameNr_Key_MailForward 28382
#define sipName_Key_MailForward &sipStrings_QtCore[28382]
#define sipNameNr_Key_MediaRecord 28398
#define sipName_Key_MediaRecord &sipStrings_QtCore[28398]
#define sipNameNr_Key_MicVolumeUp 28414
#define sipName_Key_MicVolumeUp &sipStrings_QtCore[28414]
#define sipNameNr_Key_Mode_switch 28430
#define sipName_Key_Mode_switch &sipStrings_QtCore[28430]
#define sipNameNr_Key_Ocircumflex 28446
#define sipName_Key_Ocircumflex &sipStrings_QtCore[28446]
#define sipNameNr_Key_ScreenSaver 28462
#define sipName_Key_ScreenSaver &sipStrings_QtCore[28462]
#define sipNameNr_Key_SplitScreen 28478
#define sipName_Key_SplitScreen &sipStrings_QtCore[28478]
#define sipNameNr_Key_TouchpadOff 28494
#define sipName_Key_TouchpadOff &sipStrings_QtCore[28494]
#define sipNameNr_Key_Ucircumflex 28510
#define sipName_Key_Ucircumflex &sipStrings_QtCore[28510]
#define sipNameNr_Key_onesuperior 28526
#define sipName_Key_onesuperior &sipStrings_QtCore[28526]
#define sipNameNr_Key_ordfeminine 28542
#define sipName_Key_ordfeminine &sipStrings_QtCore[28542]
#define sipNameNr_Key_twosuperior 28558
#define sipName_Key_twosuperior &sipStrings_QtCore[28558]
#define sipNameNr_KhudawadiScript 28574
#define sipName_KhudawadiScript &sipStrings_QtCore[28574]
#define sipNameNr_LayoutDirection 12497
#define sipName_LayoutDirection &sipStrings_QtCore[12497]
#define sipNameNr_LeftToolBarArea 28590
#define sipName_LeftToolBarArea &sipStrings_QtCore[28590]
#define sipNameNr_LibraryLocation 2950
#define sipName_LibraryLocation &sipStrings_QtCore[2950]
#define sipNameNr_LiteraryChinese 28606
#define sipName_LiteraryChinese &sipStrings_QtCore[28606]
#define sipNameNr_LocateDirectory 28622
#define sipName_LocateDirectory &sipStrings_QtCore[28622]
#define sipNameNr_LockFailedError 28638
#define sipName_LockFailedError &sipStrings_QtCore[28638]
#define sipNameNr_MacOSHighSierra 28654
#define sipName_MacOSHighSierra &sipStrings_QtCore[28654]
#define sipNameNr_MalayalamScript 28670
#define sipName_MalayalamScript &sipStrings_QtCore[28670]
#define sipNameNr_MarshallIslands 28686
#define sipName_MarshallIslands &sipStrings_QtCore[28686]
#define sipNameNr_MatchStartsWith 28702
#define sipName_MatchStartsWith &sipStrings_QtCore[28702]
#define sipNameNr_MongolianScript 28718
#define sipName_MongolianScript &sipStrings_QtCore[28718]
#define sipNameNr_MouseEventFlags 16783
#define sipName_MouseEventFlags &sipStrings_QtCore[16783]
#define sipNameNr_MultilineOption 28734
#define sipName_MultilineOption &sipStrings_QtCore[28734]
#define sipNameNr_NabataeanScript 28750
#define sipName_NabataeanScript &sipStrings_QtCore[28750]
#define sipNameNr_NegativeInteger 23216
#define sipName_NegativeInteger &sipStrings_QtCore[23216]
#define sipNameNr_NewTaiLueScript 28766
#define sipName_NewTaiLueScript &sipStrings_QtCore[28766]
#define sipNameNr_NoIteratorFlags 28782
#define sipName_NoIteratorFlags &sipStrings_QtCore[28782]
#define sipNameNr_NoPatternOption 28798
#define sipName_NoPatternOption &sipStrings_QtCore[28798]
#define sipNameNr_NorwegianBokmal 28814
#define sipName_NorwegianBokmal &sipStrings_QtCore[28814]
#define sipNameNr_OldItalicScript 28830
#define sipName_OldItalicScript &sipStrings_QtCore[28830]
#define sipNameNr_OldPermicScript 28846
#define sipName_OldPermicScript &sipStrings_QtCore[28846]
#define sipNameNr_OutlyingOceania 28862
#define sipName_OutlyingOceania &sipStrings_QtCore[28862]
#define sipNameNr_PalmyreneScript 28878
#define sipName_PalmyreneScript &sipStrings_QtCore[28878]
#define sipNameNr_ParentIsInvalid 28894
#define sipName_ParentIsInvalid &sipStrings_QtCore[28894]
#define sipNameNr_PauCinHauScript 28910
#define sipName_PauCinHauScript &sipStrings_QtCore[28910]
#define sipNameNr_PermissionError 28926
#define sipName_PermissionError &sipStrings_QtCore[28926]
#define sipNameNr_PlatformSurface 28942
#define sipName_PlatformSurface &sipStrings_QtCore[28942]
#define sipNameNr_PrakritLanguage 28958
#define sipName_PrakritLanguage &sipStrings_QtCore[28958]
#define sipNameNr_PreferLocalFile 28974
#define sipName_PreferLocalFile &sipStrings_QtCore[28974]
#define sipNameNr_QAnimationGroup 28990
#define sipName_QAnimationGroup &sipStrings_QtCore[28990]
#define sipNameNr_QCborSimpleType 29006
#define sipName_QCborSimpleType &sipStrings_QtCore[29006]
#define sipNameNr_QDir__SortFlags 29022
#define sipName_QDir__SortFlags &sipStrings_QtCore[29022]
#define sipNameNr_QJsonParseError 29038
#define sipName_QJsonParseError &sipStrings_QtCore[29038]
#define sipNameNr_29054 29054
#define sipName_29054 &sipStrings_QtCore[29054]
#define sipNameNr_29070 29070
#define sipName_29070 &sipStrings_QtCore[29070]
#define sipNameNr_QLocale__Script 29086
#define sipName_QLocale__Script &sipStrings_QtCore[29086]
#define sipNameNr_QMetaType__Type 29102
#define sipName_QMetaType__Type &sipStrings_QtCore[29102]
#define sipNameNr_QPauseAnimation 29118
#define sipName_QPauseAnimation &sipStrings_QtCore[29118]
#define sipNameNr_QRecursiveMutex 29134
#define sipName_QRecursiveMutex &sipStrings_QtCore[29134]
#define sipNameNr_QSocketNotifier 29150
#define sipName_QSocketNotifier &sipStrings_QtCore[29150]
#define sipNameNr_QSysInfo__Sizes 29166
#define sipName_QSysInfo__Sizes &sipStrings_QtCore[29166]
#define sipNameNr_QT_TR_NOOP_UTF8 29182
#define sipName_QT_TR_NOOP_UTF8 &sipStrings_QtCore[29182]
#define sipNameNr_Qml2ImportsPath 29198
#define sipName_Qml2ImportsPath &sipStrings_QtCore[29198]
#define sipNameNr_Qt__AnchorPoint 29214
#define sipName_Qt__AnchorPoint &sipStrings_QtCore[29214]
#define sipNameNr_Qt__CursorShape 29230
#define sipName_Qt__CursorShape &sipStrings_QtCore[29230]
#define sipNameNr_Qt__DropActions 29246
#define sipName_Qt__DropActions &sipStrings_QtCore[29246]
#define sipNameNr_Qt__FocusPolicy 29262
#define sipName_Qt__FocusPolicy &sipStrings_QtCore[29262]
#define sipNameNr_Qt__FocusReason 29278
#define sipName_Qt__FocusReason &sipStrings_QtCore[29278]
#define sipNameNr_Qt__GestureFlag 29294
#define sipName_Qt__GestureFlag &sipStrings_QtCore[29294]
#define sipNameNr_Qt__GestureType 29310
#define sipName_Qt__GestureType &sipStrings_QtCore[29310]
#define sipNameNr_Qt__GlobalColor 29326
#define sipName_Qt__GlobalColor &sipStrings_QtCore[29326]
#define sipNameNr_Qt__MouseButton 29342
#define sipName_Qt__MouseButton &sipStrings_QtCore[29342]
#define sipNameNr_Qt__Orientation 29358
#define sipName_Qt__Orientation &sipStrings_QtCore[29358]
#define sipNameNr_Qt__PenCapStyle 29374
#define sipName_Qt__PenCapStyle &sipStrings_QtCore[29374]
#define sipNameNr_Qt__ScrollPhase 29390
#define sipName_Qt__ScrollPhase &sipStrings_QtCore[29390]
#define sipNameNr_Qt__ToolBarArea 29406
#define sipName_Qt__ToolBarArea &sipStrings_QtCore[29406]
#define sipNameNr_Qt__WindowFlags 29422
#define sipName_Qt__WindowFlags &sipStrings_QtCore[29422]
#define sipNameNr_Qt__WindowState 29438
#define sipName_Qt__WindowState &sipStrings_QtCore[29438]
#define sipNameNr_ReadCorruptData 29454
#define sipName_ReadCorruptData &sipStrings_QtCore[29454]
#define sipNameNr_RemoveAuthority 29470
#define sipName_RemoveAuthority &sipStrings_QtCore[29470]
#define sipNameNr_RepublicOfKorea 5959
#define sipName_RepublicOfKorea &sipStrings_QtCore[5959]
#define sipNameNr_RuntimeLocation 29486
#define sipName_RuntimeLocation &sipStrings_QtCore[29486]
#define sipNameNr_SaintBarthelemy 29502
#define sipName_SaintBarthelemy &sipStrings_QtCore[29502]
#define sipNameNr_SamaritanScript 29518
#define sipName_SamaritanScript &sipStrings_QtCore[29518]
#define sipNameNr_ScrollBarPolicy 16803
#define sipName_ScrollBarPolicy &sipStrings_QtCore[16803]
#define sipNameNr_ShortcutContext 16823
#define sipName_ShortcutContext &sipStrings_QtCore[16823]
#define sipNameNr_SinglePrecision 29534
#define sipName_SinglePrecision &sipStrings_QtCore[29534]
#define sipNameNr_SizeBDiagCursor 29550
#define sipName_SizeBDiagCursor &sipStrings_QtCore[29550]
#define sipNameNr_SizeFDiagCursor 29566
#define sipName_SizeFDiagCursor &sipStrings_QtCore[29566]
#define sipNameNr_SouthernKurdish 29582
#define sipName_SouthernKurdish &sipStrings_QtCore[29582]
#define sipNameNr_SundaneseScript 29598
#define sipName_SundaneseScript &sipStrings_QtCore[29598]
#define sipNameNr_ThresholdDither 29614
#define sipName_ThresholdDither &sipStrings_QtCore[29614]
#define sipNameNr_TokelauLanguage 29630
#define sipName_TokelauLanguage &sipStrings_QtCore[29630]
#define sipNameNr_ToolButtonStyle 16843
#define sipName_ToolButtonStyle &sipStrings_QtCore[16843]
#define sipNameNr_TopRightSection 29646
#define sipName_TopRightSection &sipStrings_QtCore[29646]
#define sipNameNr_TouchPointMoved 29662
#define sipName_TouchPointMoved &sipStrings_QtCore[29662]
#define sipNameNr_TouchPointState 16863
#define sipName_TouchPointState &sipStrings_QtCore[16863]
#define sipNameNr_TransparentMode 29678
#define sipName_TransparentMode &sipStrings_QtCore[29678]
#define sipNameNr_UI_AnimateCombo 29694
#define sipName_UI_AnimateCombo &sipStrings_QtCore[29694]
#define sipNameNr_UnexpectedBreak 29710
#define sipName_UnexpectedBreak &sipStrings_QtCore[29710]
#define sipNameNr_UnsignedInteger 23306
#define sipName_UnsignedInteger &sipStrings_QtCore[23306]
#define sipNameNr_UnsupportedType 29726
#define sipName_UnsupportedType &sipStrings_QtCore[29726]
#define sipNameNr_UppercaseDigits 29742
#define sipName_UppercaseDigits &sipStrings_QtCore[29742]
#define sipNameNr_VeryCoarseTimer 29758
#define sipName_VeryCoarseTimer &sipStrings_QtCore[29758]
#define sipNameNr_VisualMoveStyle 29774
#define sipName_VisualMoveStyle &sipStrings_QtCore[29774]
#define sipNameNr_WA_MacSmallSize 29790
#define sipName_WA_MacSmallSize &sipStrings_QtCore[29790]
#define sipNameNr_WA_NativeWindow 29806
#define sipName_WA_NativeWindow &sipStrings_QtCore[29806]
#define sipNameNr_WhatsThisCursor 29822
#define sipName_WhatsThisCursor &sipStrings_QtCore[29822]
#define sipNameNr_WidgetAttribute 16883
#define sipName_WidgetAttribute &sipStrings_QtCore[16883]
#define sipNameNr_WindowMaximized 29838
#define sipName_WindowMaximized &sipStrings_QtCore[29838]
#define sipNameNr_WindowMinimized 29854
#define sipName_WindowMinimized &sipStrings_QtCore[29854]
#define sipNameNr_WindowTitleHint 29870
#define sipName_WindowTitleHint &sipStrings_QtCore[29870]
#define sipNameNr_WindowType_Mask 29886
#define sipName_WindowType_Mask &sipStrings_QtCore[29886]
#define sipNameNr_WindowUnblocked 29902
#define sipName_WindowUnblocked &sipStrings_QtCore[29902]
#define sipNameNr_ZlibCompression 29918
#define sipName_ZlibCompression &sipStrings_QtCore[29918]
#define sipNameNr_ZstdCompression 29934
#define sipName_ZstdCompression &sipStrings_QtCore[29934]
#define sipNameNr_anchoredPattern 29950
#define sipName_anchoredPattern &sipStrings_QtCore[29950]
#define sipNameNr_appendUndefined 29966
#define sipName_appendUndefined &sipStrings_QtCore[29966]
#define sipNameNr_applicationName 29982
#define sipName_applicationName &sipStrings_QtCore[29982]
#define sipNameNr_availableCodecs 29998
#define sipName_availableCodecs &sipStrings_QtCore[29998]
#define sipNameNr_beginInsertRows 30014
#define sipName_beginInsertRows &sipStrings_QtCore[30014]
#define sipNameNr_beginRemoveRows 30030
#define sipName_beginRemoveRows &sipStrings_QtCore[30030]
#define sipNameNr_beginResetModel 30046
#define sipName_beginResetModel &sipStrings_QtCore[30046]
#define sipNameNr_beginWriteArray 30062
#define sipName_beginWriteArray &sipStrings_QtCore[30062]
#define sipNameNr_boundaryReasons 30078
#define sipName_boundaryReasons &sipStrings_QtCore[30078]
#define sipNameNr_canDropMimeData 30094
#define sipName_canDropMimeData &sipStrings_QtCore[30094]
#define sipNameNr_caseSensitivity 30110
#define sipName_caseSensitivity &sipStrings_QtCore[30110]
#define sipNameNr_characterOffset 30126
#define sipName_characterOffset &sipStrings_QtCore[30126]
#define sipNameNr_classInfoOffset 30142
#define sipName_classInfoOffset &sipStrings_QtCore[30142]
#define sipNameNr_codecForUtfText 30158
#define sipName_codecForUtfText &sipStrings_QtCore[30158]
#define sipNameNr_columnsInserted 30174
#define sipName_columnsInserted &sipStrings_QtCore[30174]
#define sipNameNr_countryToString 30190
#define sipName_countryToString &sipStrings_QtCore[30190]
#define sipNameNr_currentDateTime 30206
#define sipName_currentDateTime &sipStrings_QtCore[30206]
#define sipNameNr_currentLoopTime 30222
#define sipName_currentLoopTime &sipStrings_QtCore[30222]
#define sipNameNr_currentThreadId 30238
#define sipName_currentThreadId &sipStrings_QtCore[30238]
#define sipNameNr_defaultCategory 30254
#define sipName_defaultCategory &sipStrings_QtCore[30254]
#define sipNameNr_documentVersion 30270
#define sipName_documentVersion &sipStrings_QtCore[30270]
#define sipNameNr_enumeratorCount 30286
#define sipName_enumeratorCount &sipStrings_QtCore[30286]
#define sipNameNr_eventDispatcher 30302
#define sipName_eventDispatcher &sipStrings_QtCore[30302]
#define sipNameNr_filterKeyColumn 30318
#define sipName_filterKeyColumn &sipStrings_QtCore[30318]
#define sipNameNr_genericIconName 30334
#define sipName_genericIconName &sipStrings_QtCore[30334]
#define sipNameNr_hasDaylightTime 30350
#define sipName_hasDaylightTime &sipStrings_QtCore[30350]
#define sipNameNr_hasNotifySignal 30366
#define sipName_hasNotifySignal &sipStrings_QtCore[30366]
#define sipNameNr_hasPartialMatch 30382
#define sipName_hasPartialMatch &sipStrings_QtCore[30382]
#define sipNameNr_indexOfProperty 30398
#define sipName_indexOfProperty &sipStrings_QtCore[30398]
#define sipNameNr_insertAnimation 30414
#define sipName_insertAnimation &sipStrings_QtCore[30414]
#define sipNameNr_internalPointer 30430
#define sipName_internalPointer &sipStrings_QtCore[30430]
#define sipNameNr_isSetuidAllowed 30446
#define sipName_isSetuidAllowed &sipStrings_QtCore[30446]
#define sipNameNr_isStartDocument 30462
#define sipName_isStartDocument &sipStrings_QtCore[30462]
#define sipNameNr_lowercasedigits 30478
#define sipName_lowercasedigits &sipStrings_QtCore[30478]
#define sipNameNr_machineHostName 30494
#define sipName_machineHostName &sipStrings_QtCore[30494]
#define sipNameNr_manhattanLength 30510
#define sipName_manhattanLength &sipStrings_QtCore[30510]
#define sipNameNr_matchingLocales 30526
#define sipName_matchingLocales &sipStrings_QtCore[30526]
#define sipNameNr_methodSignature 30542
#define sipName_methodSignature &sipStrings_QtCore[30542]
#define sipNameNr_mimeTypeForData 30558
#define sipName_mimeTypeForData &sipStrings_QtCore[30558]
#define sipNameNr_mimeTypeForFile 30574
#define sipName_mimeTypeForFile &sipStrings_QtCore[30574]
#define sipNameNr_mimeTypeForName 30590
#define sipName_mimeTypeForName &sipStrings_QtCore[30590]
#define sipNameNr_moveBottomRight 30606
#define sipName_moveBottomRight &sipStrings_QtCore[30606]
#define sipNameNr_parentMimeTypes 30622
#define sipName_parentMimeTypes &sipStrings_QtCore[30622]
#define sipNameNr_preferredSuffix 30638
#define sipName_preferredSuffix &sipStrings_QtCore[30638]
#define sipNameNr_qAddPostRoutine 30654
#define sipName_qAddPostRoutine &sipStrings_QtCore[30654]
#define sipNameNr_readElementText 30670
#define sipName_readElementText &sipStrings_QtCore[30670]
#define sipNameNr_readQStringList 30686
#define sipName_readQStringList &sipStrings_QtCore[30686]
#define sipNameNr_readQVariantMap 30702
#define sipName_readQVariantMap &sipStrings_QtCore[30702]
#define sipNameNr_removeAnimation 30718
#define sipName_removeAnimation &sipStrings_QtCore[30718]
#define sipNameNr_removeQueryItem 30734
#define sipName_removeQueryItem &sipStrings_QtCore[30734]
#define sipNameNr_selectedColumns 30750
#define sipName_selectedColumns &sipStrings_QtCore[30750]
#define sipNameNr_selectedIndexes 30766
#define sipName_selectedIndexes &sipStrings_QtCore[30766]
#define sipNameNr_setCurrentIndex 30782
#define sipName_setCurrentIndex &sipStrings_QtCore[30782]
#define sipNameNr_setDefaultState 30798
#define sipName_setDefaultState &sipStrings_QtCore[30798]
#define sipNameNr_setDefaultValue 30814
#define sipName_setDefaultValue &sipStrings_QtCore[30814]
#define sipNameNr_setFileTemplate 30830
#define sipName_setFileTemplate &sipStrings_QtCore[30830]
#define sipNameNr_setFilterRegExp 30846
#define sipName_setFilterRegExp &sipStrings_QtCore[30846]
#define sipNameNr_setIdnWhitelist 30862
#define sipName_setIdnWhitelist &sipStrings_QtCore[30862]
#define sipNameNr_setInitialState 30878
#define sipName_setInitialState &sipStrings_QtCore[30878]
#define sipNameNr_setLibraryPaths 30894
#define sipName_setLibraryPaths &sipStrings_QtCore[30894]
#define sipNameNr_setProcessState 30910
#define sipName_setProcessState &sipStrings_QtCore[30910]
#define sipNameNr_setPropertyName 30926
#define sipName_setPropertyName &sipStrings_QtCore[30926]
#define sipNameNr_setSenderObject 30942
#define sipName_setSenderObject &sipStrings_QtCore[30942]
#define sipNameNr_setTargetObject 30958
#define sipName_setTargetObject &sipStrings_QtCore[30958]
#define sipNameNr_setTargetStates 30974
#define sipName_setTargetStates &sipStrings_QtCore[30974]
#define sipNameNr_siblingAtColumn 30990
#define sipName_siblingAtColumn &sipStrings_QtCore[30990]
#define sipNameNr_sortRoleChanged 31006
#define sipName_sortRoleChanged &sipStrings_QtCore[31006]
#define sipNameNr_staticInstances 31022
#define sipName_staticInstances &sipStrings_QtCore[31022]
#define sipNameNr_toDisplayString 31038
#define sipName_toDisplayString &sipStrings_QtCore[31038]
#define sipNameNr_toOffsetFromUtc 31054
#define sipName_toOffsetFromUtc &sipStrings_QtCore[31054]
#define sipNameNr_toggleDirection 31070
#define sipName_toggleDirection &sipStrings_QtCore[31070]
#define sipNameNr_tryLockForWrite 31086
#define sipName_tryLockForWrite &sipStrings_QtCore[31086]
#define sipNameNr_unregisterTimer 31102
#define sipName_unregisterTimer &sipStrings_QtCore[31102]
#define sipNameNr_updateDirection 31118
#define sipName_updateDirection &sipStrings_QtCore[31118]
#define sipNameNr_uppercasedigits 31134
#define sipName_uppercasedigits &sipStrings_QtCore[31134]
#define sipNameNr_waitForFinished 31150
#define sipName_waitForFinished &sipStrings_QtCore[31150]
#define sipNameNr_writeAttributes 31166
#define sipName_writeAttributes &sipStrings_QtCore[31166]
#define sipNameNr_writeCharacters 31182
#define sipName_writeCharacters &sipStrings_QtCore[31182]
#define sipNameNr_writeEndElement 31198
#define sipName_writeEndElement &sipStrings_QtCore[31198]
#define sipNameNr_AA_UseOpenGLES 31214
#define sipName_AA_UseOpenGLES &sipStrings_QtCore[31214]
#define sipNameNr_AddToSelection 31229
#define sipName_AddToSelection &sipStrings_QtCore[31229]
#define sipNameNr_AdvancePastEnd 31244
#define sipName_AdvancePastEnd &sipStrings_QtCore[31244]
#define sipNameNr_ArmenianScript 31259
#define sipName_ArmenianScript &sipStrings_QtCore[31259]
#define sipNameNr_AscendingOrder 31274
#define sipName_AscendingOrder &sipStrings_QtCore[31274]
#define sipNameNr_AutoConnection 31289
#define sipName_AutoConnection &sipStrings_QtCore[31289]
#define sipNameNr_BackgroundRole 31304
#define sipName_BackgroundRole &sipStrings_QtCore[31304]
#define sipNameNr_BalineseScript 31319
#define sipName_BalineseScript &sipStrings_QtCore[31319]
#define sipNameNr_Base64Encoding 20129
#define sipName_Base64Encoding &sipStrings_QtCore[20129]
#define sipNameNr_BassaVahScript 31334
#define sipName_BassaVahScript &sipStrings_QtCore[31334]
#define sipNameNr_BopomofoScript 11376
#define sipName_BopomofoScript &sipStrings_QtCore[11376]
#define sipNameNr_BoundaryReason 1130
#define sipName_BoundaryReason &sipStrings_QtCore[1130]
#define sipNameNr_BugineseScript 31349
#define sipName_BugineseScript &sipStrings_QtCore[31349]
#define sipNameNr_CaretWontMatch 31364
#define sipName_CaretWontMatch &sipStrings_QtCore[31364]
#define sipNameNr_CentralKurdish 31379
#define sipName_CentralKurdish &sipStrings_QtCore[31379]
#define sipNameNr_CheckStateRole 31394
#define sipName_CheckStateRole &sipStrings_QtCore[31394]
#define sipNameNr_ChecksumItuV41 31409
#define sipName_ChecksumItuV41 &sipStrings_QtCore[31409]
#define sipNameNr_CherokeeScript 31424
#define sipName_CherokeeScript &sipStrings_QtCore[31424]
#define sipNameNr_ClearAndSelect 31439
#define sipName_ClearAndSelect &sipStrings_QtCore[31439]
#define sipNameNr_ConfigLocation 11332
#define sipName_ConfigLocation &sipStrings_QtCore[11332]
#define sipNameNr_ConnectionType 19350
#define sipName_ConnectionType &sipStrings_QtCore[19350]
#define sipNameNr_ConversionFlag 5373
#define sipName_ConversionFlag &sipStrings_QtCore[5373]
#define sipNameNr_ConverterState 5400
#define sipName_ConverterState &sipStrings_QtCore[5400]
#define sipNameNr_CurrencySymbol 31454
#define sipName_CurrencySymbol &sipStrings_QtCore[31454]
#define sipNameNr_CustomDashLine 31469
#define sipName_CustomDashLine &sipStrings_QtCore[31469]
#define sipNameNr_CyrillicScript 31484
#define sipName_CyrillicScript &sipStrings_QtCore[31484]
#define sipNameNr_DashDotDotLine 31499
#define sipName_DashDotDotLine &sipStrings_QtCore[31499]
#define sipNameNr_DataSizeFormat 8617
#define sipName_DataSizeFormat &sipStrings_QtCore[8617]
#define sipNameNr_DataValidation 2921
#define sipName_DataValidation &sipStrings_QtCore[2921]
#define sipNameNr_DateTimeString 31514
#define sipName_DateTimeString &sipStrings_QtCore[31514]
#define sipNameNr_DecodeReserved 31529
#define sipName_DecodeReserved &sipStrings_QtCore[31529]
#define sipNameNr_DecorationRole 31544
#define sipName_DecorationRole &sipStrings_QtCore[31544]
#define sipNameNr_DeferredDelete 31559
#define sipName_DeferredDelete &sipStrings_QtCore[31559]
#define sipNameNr_DeletionPolicy 1270
#define sipName_DeletionPolicy &sipStrings_QtCore[1270]
#define sipNameNr_DoNotUseParent 31574
#define sipName_DoNotUseParent &sipStrings_QtCore[31574]
#define sipNameNr_DockWidgetArea 13451
#define sipName_DockWidgetArea &sipStrings_QtCore[13451]
#define sipNameNr_DragCopyCursor 31589
#define sipName_DragCopyCursor &sipStrings_QtCore[31589]
#define sipNameNr_DragLinkCursor 31604
#define sipName_DragLinkCursor &sipStrings_QtCore[31604]
#define sipNameNr_DragMoveCursor 31619
#define sipName_DragMoveCursor &sipStrings_QtCore[31619]
#define sipNameNr_DuployanScript 31634
#define sipName_DuployanScript &sipStrings_QtCore[31634]
#define sipNameNr_EaseInOutCurve 31649
#define sipName_EaseInOutCurve &sipStrings_QtCore[31649]
#define sipNameNr_EncodeReserved 31664
#define sipName_EncodeReserved &sipStrings_QtCore[31664]
#define sipNameNr_EnterEditFocus 31679
#define sipName_EnterEditFocus &sipStrings_QtCore[31679]
#define sipNameNr_EnterKeyReturn 31694
#define sipName_EnterKeyReturn &sipStrings_QtCore[31694]
#define sipNameNr_EnterKeySearch 31709
#define sipName_EnterKeySearch &sipStrings_QtCore[31709]
#define sipNameNr_EthiopicScript 31724
#define sipName_EthiopicScript &sipStrings_QtCore[31724]
#define sipNameNr_ExpectedBase16 31739
#define sipName_ExpectedBase16 &sipStrings_QtCore[31739]
#define sipNameNr_ExpectedBase64 31754
#define sipName_ExpectedBase64 &sipStrings_QtCore[31754]
#define sipNameNr_FieldAlignment 4418
#define sipName_FieldAlignment &sipStrings_QtCore[4418]
#define sipNameNr_FileAccessTime 31769
#define sipName_FileAccessTime &sipStrings_QtCore[31769]
#define sipNameNr_FileHandleFlag 4250
#define sipName_FileHandleFlag &sipStrings_QtCore[4250]
#define sipNameNr_FollowSymlinks 31784
#define sipName_FollowSymlinks &sipStrings_QtCore[31784]
#define sipNameNr_ForegroundRole 31799
#define sipName_ForegroundRole &sipStrings_QtCore[31799]
#define sipNameNr_GeorgianScript 31814
#define sipName_GeorgianScript &sipStrings_QtCore[31814]
#define sipNameNr_GestureStarted 31829
#define sipName_GestureStarted &sipStrings_QtCore[31829]
#define sipNameNr_GestureUpdated 31844
#define sipName_GestureUpdated &sipStrings_QtCore[31844]
#define sipNameNr_GujaratiScript 31859
#define sipName_GujaratiScript &sipStrings_QtCore[31859]
#define sipNameNr_GurmukhiScript 31874
#define sipName_GurmukhiScript &sipStrings_QtCore[31874]
#define sipNameNr_HiddenFromHelp 31889
#define sipName_HiddenFromHelp &sipStrings_QtCore[31889]
#define sipNameNr_HiraganaScript 31904
#define sipName_HiraganaScript &sipStrings_QtCore[31904]
#define sipNameNr_IconTextChange 31919
#define sipName_IconTextChange &sipStrings_QtCore[31919]
#define sipNameNr_IllegalPadding 31934
#define sipName_IllegalPadding &sipStrings_QtCore[31934]
#define sipNameNr_ImEnterKeyType 31949
#define sipName_ImEnterKeyType &sipStrings_QtCore[31949]
#define sipNameNr_ImPlatformData 31964
#define sipName_ImPlatformData &sipStrings_QtCore[31964]
#define sipNameNr_ImhPreferLatin 31979
#define sipName_ImhPreferLatin &sipStrings_QtCore[31979]
#define sipNameNr_ImperialSystem 31994
#define sipName_ImperialSystem &sipStrings_QtCore[31994]
#define sipNameNr_ItemIsEditable 32009
#define sipName_ItemIsEditable &sipStrings_QtCore[32009]
#define sipNameNr_ItemIsTristate 32024
#define sipName_ItemIsTristate &sipStrings_QtCore[32024]
#define sipNameNr_JapaneseScript 32039
#define sipName_JapaneseScript &sipStrings_QtCore[32039]
#define sipNameNr_JavaneseScript 32054
#define sipName_JavaneseScript &sipStrings_QtCore[32054]
#define sipNameNr_KatakanaScript 32069
#define sipName_KatakanaScript &sipStrings_QtCore[32069]
#define sipNameNr_Key_Adiaeresis 32084
#define sipName_Key_Adiaeresis &sipStrings_QtCore[32084]
#define sipNameNr_Key_Apostrophe 32099
#define sipName_Key_Apostrophe &sipStrings_QtCore[32099]
#define sipNameNr_Key_AsciiTilde 32114
#define sipName_Key_AsciiTilde &sipStrings_QtCore[32114]
#define sipNameNr_Key_BraceRight 32129
#define sipName_Key_BraceRight &sipStrings_QtCore[32129]
#define sipNameNr_Key_Calculator 32144
#define sipName_Key_Calculator &sipStrings_QtCore[32144]
#define sipNameNr_Key_Dead_Acute 32159
#define sipName_Key_Dead_Acute &sipStrings_QtCore[32159]
#define sipNameNr_Key_Dead_Breve 32174
#define sipName_Key_Dead_Breve &sipStrings_QtCore[32174]
#define sipNameNr_Key_Dead_Caron 32189
#define sipName_Key_Dead_Caron &sipStrings_QtCore[32189]
#define sipNameNr_Key_Dead_Grave 32204
#define sipName_Key_Dead_Grave &sipStrings_QtCore[32204]
#define sipNameNr_Key_Dead_Greek 32219
#define sipName_Key_Dead_Greek &sipStrings_QtCore[32219]
#define sipNameNr_Key_Dead_Tilde 32234
#define sipName_Key_Dead_Tilde &sipStrings_QtCore[32234]
#define sipNameNr_Key_Ediaeresis 32249
#define sipName_Key_Ediaeresis &sipStrings_QtCore[32249]
#define sipNameNr_Key_Eisu_Shift 32264
#define sipName_Key_Eisu_Shift &sipStrings_QtCore[32264]
#define sipNameNr_Key_Hangul_End 32279
#define sipName_Key_Hangul_End &sipStrings_QtCore[32279]
#define sipNameNr_Key_Idiaeresis 32294
#define sipName_Key_Idiaeresis &sipStrings_QtCore[32294]
#define sipNameNr_Key_Kana_Shift 32309
#define sipName_Key_Kana_Shift &sipStrings_QtCore[32309]
#define sipNameNr_Key_LaunchMail 32324
#define sipName_Key_LaunchMail &sipStrings_QtCore[32324]
#define sipNameNr_Key_MediaPause 32339
#define sipName_Key_MediaPause &sipStrings_QtCore[32339]
#define sipNameNr_Key_NumberSign 32354
#define sipName_Key_NumberSign &sipStrings_QtCore[32354]
#define sipNameNr_Key_Odiaeresis 32369
#define sipName_Key_Odiaeresis &sipStrings_QtCore[32369]
#define sipNameNr_Key_OfficeHome 32384
#define sipName_Key_OfficeHome &sipStrings_QtCore[32384]
#define sipNameNr_Key_ParenRight 32399
#define sipName_Key_ParenRight &sipStrings_QtCore[32399]
#define sipNameNr_Key_RotationKB 32414
#define sipName_Key_RotationKB &sipStrings_QtCore[32414]
#define sipNameNr_Key_RotationPB 32429
#define sipName_Key_RotationPB &sipStrings_QtCore[32429]
#define sipNameNr_Key_ScrollLock 32444
#define sipName_Key_ScrollLock &sipStrings_QtCore[32444]
#define sipNameNr_Key_TouchpadOn 32459
#define sipName_Key_TouchpadOn &sipStrings_QtCore[32459]
#define sipNameNr_Key_TrebleDown 32474
#define sipName_Key_TrebleDown &sipStrings_QtCore[32474]
#define sipNameNr_Key_Udiaeresis 32489
#define sipName_Key_Udiaeresis &sipStrings_QtCore[32489]
#define sipNameNr_Key_Underscore 32504
#define sipName_Key_Underscore &sipStrings_QtCore[32504]
#define sipNameNr_Key_VolumeDown 32519
#define sipName_Key_VolumeDown &sipStrings_QtCore[32519]
#define sipNameNr_Key_VolumeMute 32534
#define sipName_Key_VolumeMute &sipStrings_QtCore[32534]
#define sipNameNr_Key_exclamdown 32549
#define sipName_Key_exclamdown &sipStrings_QtCore[32549]
#define sipNameNr_Key_onequarter 32564
#define sipName_Key_onequarter &sipStrings_QtCore[32564]
#define sipNameNr_Key_registered 32579
#define sipName_Key_registered &sipStrings_QtCore[32579]
#define sipNameNr_Key_ydiaeresis 32594
#define sipName_Key_ydiaeresis &sipStrings_QtCore[32594]
#define sipNameNr_KeypadModifier 32609
#define sipName_KeypadModifier &sipStrings_QtCore[32609]
#define sipNameNr_KoyraboroSenni 32624
#define sipName_KoyraboroSenni &sipStrings_QtCore[32624]
#define sipNameNr_LanguageChange 32639
#define sipName_LanguageChange &sipStrings_QtCore[32639]
#define sipNameNr_LeaveEditFocus 32654
#define sipName_LeaveEditFocus &sipStrings_QtCore[32654]
#define sipNameNr_LowestPriority 32669
#define sipName_LowestPriority &sipStrings_QtCore[32669]
#define sipNameNr_MSWindowsOwnDC 32684
#define sipName_MSWindowsOwnDC &sipStrings_QtCore[32684]
#define sipNameNr_MahajaniScript 32699
#define sipName_MahajaniScript &sipStrings_QtCore[32699]
#define sipNameNr_MandaeanScript 32714
#define sipName_MandaeanScript &sipStrings_QtCore[32714]
#define sipNameNr_MandatoryBreak 32729
#define sipName_MandatoryBreak &sipStrings_QtCore[32729]
#define sipNameNr_MatchExtension 32744
#define sipName_MatchExtension &sipStrings_QtCore[32744]
#define sipNameNr_MatchRecursive 32759
#define sipName_MatchRecursive &sipStrings_QtCore[32759]
#define sipNameNr_MemoryMapFlags 4278
#define sipName_MemoryMapFlags &sipStrings_QtCore[4278]
#define sipNameNr_MergedChannels 32774
#define sipName_MergedChannels &sipStrings_QtCore[32774]
#define sipNameNr_MeroiticScript 32789
#define sipName_MeroiticScript &sipStrings_QtCore[32789]
#define sipNameNr_MinimumDescent 32804
#define sipName_MinimumDescent &sipStrings_QtCore[32804]
#define sipNameNr_ModifiedChange 32819
#define sipName_ModifiedChange &sipStrings_QtCore[32819]
#define sipNameNr_MonotonicClock 32834
#define sipName_MonotonicClock &sipStrings_QtCore[32834]
#define sipNameNr_MouseEventFlag 19388
#define sipName_MouseEventFlag &sipStrings_QtCore[19388]
#define sipNameNr_MoviesLocation 32849
#define sipName_MoviesLocation &sipStrings_QtCore[32849]
#define sipNameNr_NavigationMode 19407
#define sipName_NavigationMode &sipStrings_QtCore[19407]
#define sipNameNr_NegativeBignum 32864
#define sipName_NegativeBignum &sipStrings_QtCore[32864]
#define sipNameNr_NestingTooDeep 32879
#define sipName_NestingTooDeep &sipStrings_QtCore[32879]
#define sipNameNr_NigerianPidgin 32894
#define sipName_NigerianPidgin &sipStrings_QtCore[32894]
#define sipNameNr_NoDotAndDotDot 32909
#define sipName_NoDotAndDotDot &sipStrings_QtCore[32909]
#define sipNameNr_NoIntersection 32924
#define sipName_NoIntersection &sipStrings_QtCore[32924]
#define sipNameNr_NormalPriority 32939
#define sipName_NormalPriority &sipStrings_QtCore[32939]
#define sipNameNr_OpenHandCursor 32954
#define sipName_OpenHandCursor &sipStrings_QtCore[32954]
#define sipNameNr_OutOfResources 32969
#define sipName_OutOfResources &sipStrings_QtCore[32969]
#define sipNameNr_PapuaNewGuinea 32984
#define sipName_PapuaNewGuinea &sipStrings_QtCore[32984]
#define sipNameNr_ParallelStates 32999
#define sipName_ParallelStates &sipStrings_QtCore[32999]
#define sipNameNr_ParseAsOptions 33014
#define sipName_ParseAsOptions &sipStrings_QtCore[33014]
#define sipNameNr_PatternOptions 1340
#define sipName_PatternOptions &sipStrings_QtCore[1340]
#define sipNameNr_PermissionMask 33029
#define sipName_PermissionMask &sipStrings_QtCore[33029]
#define sipNameNr_PositiveBignum 33044
#define sipName_PositiveBignum &sipStrings_QtCore[33044]
#define sipNameNr_ProcessChannel 7367
#define sipName_ProcessChannel &sipStrings_QtCore[7367]
#define sipNameNr_QAbstractState 33059
#define sipName_QAbstractState &sipStrings_QtCore[33059]
#define sipNameNr_QByteArrayList 33074
#define sipName_QByteArrayList &sipStrings_QtCore[33074]
#define sipNameNr_QCborKnownTags 33089
#define sipName_QCborKnownTags &sipStrings_QtCore[33089]
#define sipNameNr_QDeadlineTimer 33104
#define sipName_QDeadlineTimer &sipStrings_QtCore[33104]
#define sipNameNr_QDir__SortFlag 33119
#define sipName_QDir__SortFlag &sipStrings_QtCore[33119]
#define sipNameNr_QItemSelection 33134
#define sipName_QItemSelection &sipStrings_QtCore[33134]
#define sipNameNr_33149 33149
#define sipName_33149 &sipStrings_QtCore[33149]
#define sipNameNr_QMessageLogger 33164
#define sipName_QMessageLogger &sipStrings_QtCore[33164]
#define sipNameNr_QMetaClassInfo 33179
#define sipName_QMetaClassInfo &sipStrings_QtCore[33179]
#define sipNameNr_33194 33194
#define sipName_33194 &sipStrings_QtCore[33194]
#define sipNameNr_QReadWriteLock 33209
#define sipName_QReadWriteLock &sipStrings_QtCore[33209]
#define sipNameNr_QSignalBlocker 33224
#define sipName_QSignalBlocker &sipStrings_QtCore[33224]
#define sipNameNr_QStandardPaths 33239
#define sipName_QStandardPaths &sipStrings_QtCore[33239]
#define sipNameNr_QT_VERSION_STR 25085
#define sipName_QT_VERSION_STR &sipStrings_QtCore[25085]
#define sipNameNr_QTemporaryFile 33254
#define sipName_QTemporaryFile &sipStrings_QtCore[33254]
#define sipNameNr_QUuid__Variant 33269
#define sipName_QUuid__Variant &sipStrings_QtCore[33269]
#define sipNameNr_QUuid__Version 33284
#define sipName_QUuid__Version &sipStrings_QtCore[33284]
#define sipNameNr_QVariant__Type 33299
#define sipName_QVariant__Type &sipStrings_QtCore[33299]
#define sipNameNr_QVersionNumber 33314
#define sipName_QVersionNumber &sipStrings_QtCore[33314]
#define sipNameNr_QWaitCondition 33329
#define sipName_QWaitCondition &sipStrings_QtCore[33329]
#define sipNameNr_Qt__BrushStyle 33344
#define sipName_Qt__BrushStyle &sipStrings_QtCore[33344]
#define sipNameNr_Qt__CheckState 33359
#define sipName_Qt__CheckState &sipStrings_QtCore[33359]
#define sipNameNr_Qt__DateFormat 33374
#define sipName_Qt__DateFormat &sipStrings_QtCore[33374]
#define sipNameNr_Qt__DropAction 33389
#define sipName_Qt__DropAction &sipStrings_QtCore[33389]
#define sipNameNr_Qt__MatchFlags 33404
#define sipName_Qt__MatchFlags &sipStrings_QtCore[33404]
#define sipNameNr_Qt__TextFormat 33419
#define sipName_Qt__TextFormat &sipStrings_QtCore[33419]
#define sipNameNr_Qt__WindowType 33434
#define sipName_Qt__WindowType &sipStrings_QtCore[33434]
#define sipNameNr_QueryWhatsThis 33449
#define sipName_QueryWhatsThis &sipStrings_QtCore[33449]
#define sipNameNr_QuotationStyle 8641
#define sipName_QuotationStyle &sipStrings_QtCore[8641]
#define sipNameNr_ReadOnlyChange 33464
#define sipName_ReadOnlyChange &sipStrings_QtCore[33464]
#define sipNameNr_RemoveFilename 33479
#define sipName_RemoveFilename &sipStrings_QtCore[33479]
#define sipNameNr_RemoveFragment 33494
#define sipName_RemoveFragment &sipStrings_QtCore[33494]
#define sipNameNr_RemovePassword 33509
#define sipName_RemovePassword &sipStrings_QtCore[33509]
#define sipNameNr_RemoveUserInfo 33524
#define sipName_RemoveUserInfo &sipStrings_QtCore[33524]
#define sipNameNr_ScrollMomentum 33539
#define sipName_ScrollMomentum &sipStrings_QtCore[33539]
#define sipNameNr_SelectionFlags 1094
#define sipName_SelectionFlags &sipStrings_QtCore[1094]
#define sipNameNr_ShallowHistory 33554
#define sipName_ShallowHistory &sipStrings_QtCore[33554]
#define sipNameNr_SolomonIslands 33569
#define sipName_SolomonIslands &sipStrings_QtCore[33569]
#define sipNameNr_StandardOutput 9337
#define sipName_StandardOutput &sipStrings_QtCore[9337]
#define sipNameNr_Subdirectories 33584
#define sipName_Subdirectories &sipStrings_QtCore[33584]
#define sipNameNr_TabFocusReason 33599
#define sipName_TabFocusReason &sipStrings_QtCore[33599]
#define sipNameNr_TagbanwaScript 33614
#define sipName_TagbanwaScript &sipStrings_QtCore[33614]
#define sipNameNr_TextExpandTabs 33629
#define sipName_TextExpandTabs &sipStrings_QtCore[33629]
#define sipNameNr_TextSingleLine 33644
#define sipName_TextSingleLine &sipStrings_QtCore[33644]
#define sipNameNr_TexturePattern 33659
#define sipName_TexturePattern &sipStrings_QtCore[33659]
#define sipNameNr_TifinaghScript 33674
#define sipName_TifinaghScript &sipStrings_QtCore[33674]
#define sipNameNr_TokelauCountry 33689
#define sipName_TokelauCountry &sipStrings_QtCore[33689]
#define sipNameNr_TopLeftSection 33704
#define sipName_TopLeftSection &sipStrings_QtCore[33704]
#define sipNameNr_TopRightCorner 33719
#define sipName_TopRightCorner &sipStrings_QtCore[33719]
#define sipNameNr_TopToolBarArea 33734
#define sipName_TopToolBarArea &sipStrings_QtCore[33734]
#define sipNameNr_TransitionType 986
#define sipName_TransitionType &sipStrings_QtCore[986]
#define sipNameNr_TristanDaCunha 33749
#define sipName_TristanDaCunha &sipStrings_QtCore[33749]
#define sipNameNr_TuvaluLanguage 33764
#define sipName_TuvaluLanguage &sipStrings_QtCore[33764]
#define sipNameNr_UI_AnimateMenu 33779
#define sipName_UI_AnimateMenu &sipStrings_QtCore[33779]
#define sipNameNr_UI_FadeTooltip 33794
#define sipName_UI_FadeTooltip &sipStrings_QtCore[33794]
#define sipNameNr_UgariticScript 33809
#define sipName_UgariticScript &sipStrings_QtCore[33809]
#define sipNameNr_UngrabKeyboard 33824
#define sipName_UngrabKeyboard &sipStrings_QtCore[33824]
#define sipNameNr_W3CXmlSchema11 33839
#define sipName_W3CXmlSchema11 &sipStrings_QtCore[33839]
#define sipNameNr_WA_AcceptDrops 33854
#define sipName_WA_AcceptDrops &sipStrings_QtCore[33854]
#define sipNameNr_WA_GroupLeader 33869
#define sipName_WA_GroupLeader &sipStrings_QtCore[33869]
#define sipNameNr_WA_InvalidSize 33884
#define sipName_WA_InvalidSize &sipStrings_QtCore[33884]
#define sipNameNr_WA_MacMiniSize 33899
#define sipName_WA_MacMiniSize &sipStrings_QtCore[33899]
#define sipNameNr_WA_MacNoShadow 33914
#define sipName_WA_MacNoShadow &sipStrings_QtCore[33914]
#define sipNameNr_WA_MouseNoMask 33929
#define sipName_WA_MouseNoMask &sipStrings_QtCore[33929]
#define sipNameNr_WA_QuitOnClose 33944
#define sipName_WA_QuitOnClose &sipStrings_QtCore[33944]
#define sipNameNr_WA_RightToLeft 33959
#define sipName_WA_RightToLeft &sipStrings_QtCore[33959]
#define sipNameNr_WesternBalochi 33974
#define sipName_WesternBalochi &sipStrings_QtCore[33974]
#define sipNameNr_WesternFrisian 33989
#define sipName_WesternFrisian &sipStrings_QtCore[33989]
#define sipNameNr_WhiteSpaceMode 19426
#define sipName_WhiteSpaceMode &sipStrings_QtCore[19426]
#define sipNameNr_WidgetShortcut 34004
#define sipName_WidgetShortcut &sipStrings_QtCore[34004]
#define sipNameNr_WindowActivate 34019
#define sipName_WindowActivate &sipStrings_QtCore[34019]
#define sipNameNr_WindowModality 19445
#define sipName_WindowModality &sipStrings_QtCore[19445]
#define sipNameNr_WindowShortcut 34034
#define sipName_WindowShortcut &sipStrings_QtCore[34034]
#define sipNameNr_addLibraryPath 34049
#define sipName_addLibraryPath &sipStrings_QtCore[34049]
#define sipNameNr_addSourceModel 34064
#define sipName_addSourceModel &sipStrings_QtCore[34064]
#define sipNameNr_animationCount 34079
#define sipName_animationCount &sipStrings_QtCore[34079]
#define sipNameNr_applicationPid 34094
#define sipName_applicationPid &sipStrings_QtCore[34094]
#define sipNameNr_assignProperty 34109
#define sipName_assignProperty &sipStrings_QtCore[34109]
#define sipNameNr_autoFormatting 34124
#define sipName_autoFormatting &sipStrings_QtCore[34124]
#define sipNameNr_beginReadArray 34139
#define sipName_beginReadArray &sipStrings_QtCore[34139]
#define sipNameNr_bytesAvailable 34154
#define sipName_bytesAvailable &sipStrings_QtCore[34154]
#define sipNameNr_capturedLength 34169
#define sipName_capturedLength &sipStrings_QtCore[34169]
#define sipNameNr_classInfoCount 34184
#define sipName_classInfoCount &sipStrings_QtCore[34184]
#define sipNameNr_clearSelection 34199
#define sipName_clearSelection &sipStrings_QtCore[34199]
#define sipNameNr_codecForLocale 34214
#define sipName_codecForLocale &sipStrings_QtCore[34214]
#define sipNameNr_columnsRemoved 34229
#define sipName_columnsRemoved &sipStrings_QtCore[34229]
#define sipNameNr_completeSuffix 34244
#define sipName_completeSuffix &sipStrings_QtCore[34244]
#define sipNameNr_containerDepth 34259
#define sipName_containerDepth &sipStrings_QtCore[34259]
#define sipNameNr_currencySymbol 34274
#define sipName_currencySymbol &sipStrings_QtCore[34274]
#define sipNameNr_currentChanged 34289
#define sipName_currentChanged &sipStrings_QtCore[34289]
#define sipNameNr_dateTimeFormat 34304
#define sipName_dateTimeFormat &sipStrings_QtCore[34304]
#define sipNameNr_decodingStatus 34319
#define sipName_decodingStatus &sipStrings_QtCore[34319]
#define sipNameNr_disambiguation 34334
#define sipName_disambiguation &sipStrings_QtCore[34334]
#define sipNameNr_dumpObjectInfo 34349
#define sipName_dumpObjectInfo &sipStrings_QtCore[34349]
#define sipNameNr_dumpObjectTree 34364
#define sipName_dumpObjectTree &sipStrings_QtCore[34364]
#define sipNameNr_enableTestMode 34379
#define sipName_enableTestMode &sipStrings_QtCore[34379]
#define sipNameNr_endMoveColumns 34394
#define sipName_endMoveColumns &sipStrings_QtCore[34394]
#define sipNameNr_enterContainer 34409
#define sipName_enterContainer &sipStrings_QtCore[34409]
#define sipNameNr_entityResolver 34424
#define sipName_entityResolver &sipStrings_QtCore[34424]
#define sipNameNr_extraSelectors 34439
#define sipName_extraSelectors &sipStrings_QtCore[34439]
#define sipNameNr_fieldAlignment 34454
#define sipName_fieldAlignment &sipStrings_QtCore[34454]
#define sipNameNr_fileSystemType 34469
#define sipName_fileSystemType &sipStrings_QtCore[34469]
#define sipNameNr_findExecutable 34484
#define sipName_findExecutable &sipStrings_QtCore[34484]
#define sipNameNr_firstDayOfWeek 34499
#define sipName_firstDayOfWeek &sipStrings_QtCore[34499]
#define sipNameNr_fromBinaryData 34514
#define sipName_fromBinaryData &sipStrings_QtCore[34514]
#define sipNameNr_fromStringList 34529
#define sipName_fromStringList &sipStrings_QtCore[34529]
#define sipNameNr_generateDouble 34544
#define sipName_generateDouble &sipStrings_QtCore[34544]
#define sipNameNr_globalInstance 34559
#define sipName_globalInstance &sipStrings_QtCore[34559]
#define sipNameNr_groupSeparator 34574
#define sipName_groupSeparator &sipStrings_QtCore[34574]
#define sipNameNr_hasTransitions 34589
#define sipName_hasTransitions &sipStrings_QtCore[34589]
#define sipNameNr_isAbsolutePath 34604
#define sipName_isAbsolutePath &sipStrings_QtCore[34604]
#define sipNameNr_isDaylightTime 34619
#define sipName_isDaylightTime &sipStrings_QtCore[34619]
#define sipNameNr_isDebugEnabled 34634
#define sipName_isDebugEnabled &sipStrings_QtCore[34634]
#define sipNameNr_isRelativePath 34649
#define sipName_isRelativePath &sipStrings_QtCore[34649]
#define sipNameNr_isStartElement 34664
#define sipName_isStartElement &sipStrings_QtCore[34664]
#define sipNameNr_isSymbolicLink 34679
#define sipName_isSymbolicLink &sipStrings_QtCore[34679]
#define sipNameNr_leaveContainer 34694
#define sipName_leaveContainer &sipStrings_QtCore[34694]
#define sipNameNr_marginsRemoved 34709
#define sipName_marginsRemoved &sipStrings_QtCore[34709]
#define sipNameNr_maxThreadCount 34724
#define sipName_maxThreadCount &sipStrings_QtCore[34724]
#define sipNameNr_mimeTypeForUrl 34739
#define sipName_mimeTypeForUrl &sipStrings_QtCore[34739]
#define sipNameNr_mountedVolumes 34754
#define sipName_mountedVolumes &sipStrings_QtCore[34754]
#define sipNameNr_moveBottomLeft 34769
#define sipName_moveBottomLeft &sipStrings_QtCore[34769]
#define sipNameNr_nextTransition 34784
#define sipName_nextTransition &sipStrings_QtCore[34784]
#define sipNameNr_normalizedType 34799
#define sipName_normalizedType &sipStrings_QtCore[34799]
#define sipNameNr_parameterCount 34814
#define sipName_parameterCount &sipStrings_QtCore[34814]
#define sipNameNr_parameterNames 34829
#define sipName_parameterNames &sipStrings_QtCore[34829]
#define sipNameNr_parameterTypes 34844
#define sipName_parameterTypes &sipStrings_QtCore[34844]
#define sipNameNr_patternOptions 34859
#define sipName_patternOptions &sipStrings_QtCore[34859]
#define sipNameNr_productVersion 34874
#define sipName_productVersion &sipStrings_QtCore[34874]
#define sipNameNr_propertyOffset 34889
#define sipName_propertyOffset &sipStrings_QtCore[34889]
#define sipNameNr_qAddPreRoutine 34904
#define sipName_qAddPreRoutine &sipStrings_QtCore[34904]
#define sipNameNr_qFloatDistance 34919
#define sipName_qFloatDistance &sipStrings_QtCore[34919]
#define sipNameNr_qSetFieldWidth 34934
#define sipName_qSetFieldWidth &sipStrings_QtCore[34934]
#define sipNameNr_queryItemValue 34949
#define sipName_queryItemValue &sipStrings_QtCore[34949]
#define sipNameNr_removeMappings 34964
#define sipName_removeMappings &sipStrings_QtCore[34964]
#define sipNameNr_rightJustified 34979
#define sipName_rightJustified &sipStrings_QtCore[34979]
#define sipNameNr_runningChanged 34994
#define sipName_runningChanged &sipStrings_QtCore[34994]
#define sipNameNr_scriptToString 35009
#define sipName_scriptToString &sipStrings_QtCore[35009]
#define sipNameNr_securelySeeded 35024
#define sipName_securelySeeded &sipStrings_QtCore[35024]
#define sipNameNr_setBottomRight 35039
#define sipName_setBottomRight &sipStrings_QtCore[35039]
#define sipNameNr_setCurrentTime 35054
#define sipName_setCurrentTime &sipStrings_QtCore[35054]
#define sipNameNr_setDescription 35069
#define sipName_setDescription &sipStrings_QtCore[35069]
#define sipNameNr_setEasingCurve 35084
#define sipName_setEasingCurve &sipStrings_QtCore[35084]
#define sipNameNr_setErrorString 35099
#define sipName_setErrorString &sipStrings_QtCore[35099]
#define sipNameNr_setEventSource 35114
#define sipName_setEventSource &sipStrings_QtCore[35114]
#define sipNameNr_setFilterRules 35129
#define sipName_setFilterRules &sipStrings_QtCore[35129]
#define sipNameNr_setHistoryType 35144
#define sipName_setHistoryType &sipStrings_QtCore[35144]
#define sipNameNr_setIntegerBase 35159
#define sipName_setIntegerBase &sipStrings_QtCore[35159]
#define sipNameNr_setNameFilters 35174
#define sipName_setNameFilters &sipStrings_QtCore[35174]
#define sipNameNr_setNumberFlags 35189
#define sipName_setNumberFlags &sipStrings_QtCore[35189]
#define sipNameNr_setNumericMode 35204
#define sipName_setNumericMode &sipStrings_QtCore[35204]
#define sipNameNr_setPermissions 35219
#define sipName_setPermissions &sipStrings_QtCore[35219]
#define sipNameNr_setReadChannel 35234
#define sipName_setReadChannel &sipStrings_QtCore[35234]
#define sipNameNr_setSearchPaths 35249
#define sipName_setSearchPaths &sipStrings_QtCore[35249]
#define sipNameNr_setSourceModel 35264
#define sipName_setSourceModel &sipStrings_QtCore[35264]
#define sipNameNr_setTargetState 35279
#define sipName_setTargetState &sipStrings_QtCore[35279]
#define sipNameNr_shortMonthName 35294
#define sipName_shortMonthName &sipStrings_QtCore[35294]
#define sipNameNr_signalsBlocked 35309
#define sipName_signalsBlocked &sipStrings_QtCore[35309]
#define sipNameNr_skipWhiteSpace 35324
#define sipName_skipWhiteSpace &sipStrings_QtCore[35324]
#define sipNameNr_systemTimeZone 35339
#define sipName_systemTimeZone &sipStrings_QtCore[35339]
#define sipNameNr_toNextBoundary 35354
#define sipName_toNextBoundary &sipStrings_QtCore[35354]
#define sipNameNr_topLevelDomain 35369
#define sipName_topLevelDomain &sipStrings_QtCore[35369]
#define sipNameNr_transitionType 35384
#define sipName_transitionType &sipStrings_QtCore[35384]
#define sipNameNr_tryLockForRead 35399
#define sipName_tryLockForRead &sipStrings_QtCore[35399]
#define sipNameNr_updateInterval 35414
#define sipName_updateInterval &sipStrings_QtCore[35414]
#define sipNameNr_waitForStarted 35429
#define sipName_waitForStarted &sipStrings_QtCore[35429]
#define sipNameNr_writeAttribute 35444
#define sipName_writeAttribute &sipStrings_QtCore[35444]
#define sipNameNr_writeNamespace 35459
#define sipName_writeNamespace &sipStrings_QtCore[35459]
#define sipNameNr_AA_SetPalette 35474
#define sipName_AA_SetPalette &sipStrings_QtCore[35474]
#define sipNameNr_ActionChanged 35488
#define sipName_ActionChanged &sipStrings_QtCore[35488]
#define sipNameNr_ActionRemoved 35502
#define sipName_ActionRemoved &sipStrings_QtCore[35502]
#define sipNameNr_AlignAbsolute 35516
#define sipName_AlignAbsolute &sipStrings_QtCore[35516]
#define sipNameNr_AlignBaseline 35530
#define sipName_AlignBaseline &sipStrings_QtCore[35530]
#define sipNameNr_AlignTrailing 35544
#define sipName_AlignTrailing &sipStrings_QtCore[35544]
#define sipNameNr_AlignmentFlag 22264
#define sipName_AlignmentFlag &sipStrings_QtCore[22264]
#define sipNameNr_AlreadyExists 35558
#define sipName_AlreadyExists &sipStrings_QtCore[35558]
#define sipNameNr_AmericanSamoa 35572
#define sipName_AmericanSamoa &sipStrings_QtCore[35572]
#define sipNameNr_AndroidKitKat 35586
#define sipName_AndroidKitKat &sipStrings_QtCore[35586]
#define sipNameNr_AndroidNougat 35600
#define sipName_AndroidNougat &sipStrings_QtCore[35600]
#define sipNameNr_AvestanScript 35614
#define sipName_AvestanScript &sipStrings_QtCore[35614]
#define sipNameNr_Base64Options 6247
#define sipName_Base64Options &sipStrings_QtCore[6247]
#define sipNameNr_BengaliScript 35628
#define sipName_BengaliScript &sipStrings_QtCore[35628]
#define sipNameNr_BottomSection 35642
#define sipName_BottomSection &sipStrings_QtCore[35642]
#define sipNameNr_BrailleScript 35656
#define sipName_BrailleScript &sipStrings_QtCore[35656]
#define sipNameNr_COSE_Encrypt0 35670
#define sipName_COSE_Encrypt0 &sipStrings_QtCore[35670]
#define sipNameNr_CacheLocation 13557
#define sipName_CacheLocation &sipStrings_QtCore[13557]
#define sipNameNr_CanaryIslands 35684
#define sipName_CanaryIslands &sipStrings_QtCore[35684]
#define sipNameNr_CaretAtOffset 35698
#define sipName_CaretAtOffset &sipStrings_QtCore[35698]
#define sipNameNr_CaseSensitive 18743
#define sipName_CaseSensitive &sipStrings_QtCore[18743]
#define sipNameNr_CaymanIslands 35712
#define sipName_CaymanIslands &sipStrings_QtCore[35712]
#define sipNameNr_ChildPolished 35726
#define sipName_ChildPolished &sipStrings_QtCore[35726]
#define sipNameNr_ClipOperation 22282
#define sipName_ClipOperation &sipStrings_QtCore[22282]
#define sipNameNr_CongoKinshasa 35740
#define sipName_CongoKinshasa &sipStrings_QtCore[35740]
#define sipNameNr_CustomGesture 35754
#define sipName_CustomGesture &sipStrings_QtCore[35754]
#define sipNameNr_CypriotScript 35768
#define sipName_CypriotScript &sipStrings_QtCore[35768]
#define sipNameNr_CzechRepublic 35782
#define sipName_CzechRepublic &sipStrings_QtCore[35782]
#define sipNameNr_Dense1Pattern 35796
#define sipName_Dense1Pattern &sipStrings_QtCore[35796]
#define sipNameNr_Dense2Pattern 35810
#define sipName_Dense2Pattern &sipStrings_QtCore[35810]
#define sipNameNr_Dense3Pattern 35824
#define sipName_Dense3Pattern &sipStrings_QtCore[35824]
#define sipNameNr_Dense4Pattern 35838
#define sipName_Dense4Pattern &sipStrings_QtCore[35838]
#define sipNameNr_Dense5Pattern 35852
#define sipName_Dense5Pattern &sipStrings_QtCore[35852]
#define sipNameNr_Dense6Pattern 35866
#define sipName_Dense6Pattern &sipStrings_QtCore[35866]
#define sipNameNr_Dense7Pattern 35880
#define sipName_Dense7Pattern &sipStrings_QtCore[35880]
#define sipNameNr_DeseretScript 35894
#define sipName_DeseretScript &sipStrings_QtCore[35894]
#define sipNameNr_DiffuseDither 35908
#define sipName_DiffuseDither &sipStrings_QtCore[35908]
#define sipNameNr_ElbasanScript 35922
#define sipName_ElbasanScript &sipStrings_QtCore[35922]
#define sipNameNr_EmbeddedPOSIX 35936
#define sipName_EmbeddedPOSIX &sipStrings_QtCore[35936]
#define sipNameNr_EnabledChange 35950
#define sipName_EnabledChange &sipStrings_QtCore[35950]
#define sipNameNr_EncodeUnicode 35964
#define sipName_EncodeUnicode &sipStrings_QtCore[35964]
#define sipNameNr_EuropeanUnion 35978
#define sipName_EuropeanUnion &sipStrings_QtCore[35978]
#define sipNameNr_EventPriority 3510
#define sipName_EventPriority &sipStrings_QtCore[3510]
#define sipNameNr_ExtraButton10 35992
#define sipName_ExtraButton10 &sipStrings_QtCore[35992]
#define sipNameNr_ExtraButton11 36006
#define sipName_ExtraButton11 &sipStrings_QtCore[36006]
#define sipNameNr_ExtraButton12 36020
#define sipName_ExtraButton12 &sipStrings_QtCore[36020]
#define sipNameNr_ExtraButton13 36034
#define sipName_ExtraButton13 &sipStrings_QtCore[36034]
#define sipNameNr_ExtraButton14 36048
#define sipName_ExtraButton14 &sipStrings_QtCore[36048]
#define sipNameNr_ExtraButton15 36062
#define sipName_ExtraButton15 &sipStrings_QtCore[36062]
#define sipNameNr_ExtraButton16 36076
#define sipName_ExtraButton16 &sipStrings_QtCore[36076]
#define sipNameNr_ExtraButton17 36090
#define sipName_ExtraButton17 &sipStrings_QtCore[36090]
#define sipNameNr_ExtraButton18 36104
#define sipName_ExtraButton18 &sipStrings_QtCore[36104]
#define sipNameNr_ExtraButton19 36118
#define sipName_ExtraButton19 &sipStrings_QtCore[36118]
#define sipNameNr_ExtraButton20 36132
#define sipName_ExtraButton20 &sipStrings_QtCore[36132]
#define sipNameNr_ExtraButton21 36146
#define sipName_ExtraButton21 &sipStrings_QtCore[36146]
#define sipNameNr_ExtraButton22 36160
#define sipName_ExtraButton22 &sipStrings_QtCore[36160]
#define sipNameNr_ExtraButton23 36174
#define sipName_ExtraButton23 &sipStrings_QtCore[36174]
#define sipNameNr_ExtraButton24 36188
#define sipName_ExtraButton24 &sipStrings_QtCore[36188]
#define sipNameNr_FailedToStart 36202
#define sipName_FailedToStart &sipStrings_QtCore[36202]
#define sipNameNr_FileBirthTime 36216
#define sipName_FileBirthTime &sipStrings_QtCore[36216]
#define sipNameNr_FixedNotation 36230
#define sipName_FixedNotation &sipStrings_QtCore[36230]
#define sipNameNr_FontsLocation 36244
#define sipName_FontsLocation &sipStrings_QtCore[36244]
#define sipNameNr_ForeignWindow 36258
#define sipName_ForeignWindow &sipStrings_QtCore[36258]
#define sipNameNr_ForwardButton 36272
#define sipName_ForwardButton &sipStrings_QtCore[36272]
#define sipNameNr_GranthaScript 36286
#define sipName_GranthaScript &sipStrings_QtCore[36286]
#define sipNameNr_HanunooScript 36300
#define sipName_HanunooScript &sipStrings_QtCore[36300]
#define sipNameNr_ISODateWithMs 36314
#define sipName_ISODateWithMs &sipStrings_QtCore[36314]
#define sipNameNr_IllegalNumber 36328
#define sipName_IllegalNumber &sipStrings_QtCore[36328]
#define sipNameNr_ImhDigitsOnly 36342
#define sipName_ImhDigitsOnly &sipStrings_QtCore[36342]
#define sipNameNr_ImhHiddenText 36356
#define sipName_ImhHiddenText &sipStrings_QtCore[36356]
#define sipNameNr_ImhNoEditMenu 36370
#define sipName_ImhNoEditMenu &sipStrings_QtCore[36370]
#define sipNameNr_IntersectClip 36384
#define sipName_IntersectClip &sipStrings_QtCore[36384]
#define sipNameNr_IntersectType 11795
#define sipName_IntersectType &sipStrings_QtCore[11795]
#define sipNameNr_InvalidFormat 36398
#define sipName_InvalidFormat &sipStrings_QtCore[36398]
#define sipNameNr_IsEnumeration 36412
#define sipName_IsEnumeration &sipStrings_QtCore[36412]
#define sipNameNr_ItemIsEnabled 36426
#define sipName_ItemIsEnabled &sipStrings_QtCore[36426]
#define sipNameNr_IteratorFlags 4195
#define sipName_IteratorFlags &sipStrings_QtCore[4195]
#define sipNameNr_KannadaScript 36440
#define sipName_KannadaScript &sipStrings_QtCore[36440]
#define sipNameNr_KayahLiScript 36454
#define sipName_KayahLiScript &sipStrings_QtCore[36454]
#define sipNameNr_Key_Ampersand 36468
#define sipName_Key_Ampersand &sipStrings_QtCore[36468]
#define sipNameNr_Key_Backslash 36482
#define sipName_Key_Backslash &sipStrings_QtCore[36482]
#define sipNameNr_Key_Backspace 36496
#define sipName_Key_Backspace &sipStrings_QtCore[36496]
#define sipNameNr_Key_BassBoost 36510
#define sipName_Key_BassBoost &sipStrings_QtCore[36510]
#define sipNameNr_Key_Bluetooth 36524
#define sipName_Key_Bluetooth &sipStrings_QtCore[36524]
#define sipNameNr_Key_BraceLeft 36538
#define sipName_Key_BraceLeft &sipStrings_QtCore[36538]
#define sipNameNr_Key_ChannelUp 36552
#define sipName_Key_ChannelUp &sipStrings_QtCore[36552]
#define sipNameNr_Key_ClearGrab 36566
#define sipName_Key_ClearGrab &sipStrings_QtCore[36566]
#define sipNameNr_Key_Codeinput 36580
#define sipName_Key_Codeinput &sipStrings_QtCore[36580]
#define sipNameNr_Key_Community 36594
#define sipName_Key_Community &sipStrings_QtCore[36594]
#define sipNameNr_Key_Dead_Hook 36608
#define sipName_Key_Dead_Hook &sipStrings_QtCore[36608]
#define sipNameNr_Key_Dead_Horn 36622
#define sipName_Key_Dead_Horn &sipStrings_QtCore[36622]
#define sipNameNr_Key_Dead_Iota 36636
#define sipName_Key_Dead_Iota &sipStrings_QtCore[36636]
#define sipNameNr_Key_Documents 36650
#define sipName_Key_Documents &sipStrings_QtCore[36650]
#define sipNameNr_Key_Favorites 36664
#define sipName_Key_Favorites &sipStrings_QtCore[36664]
#define sipNameNr_Key_Hibernate 36678
#define sipName_Key_Hibernate &sipStrings_QtCore[36678]
#define sipNameNr_Key_Kana_Lock 36692
#define sipName_Key_Kana_Lock &sipStrings_QtCore[36692]
#define sipNameNr_Key_LightBulb 36706
#define sipName_Key_LightBulb &sipStrings_QtCore[36706]
#define sipNameNr_Key_MediaLast 36720
#define sipName_Key_MediaLast &sipStrings_QtCore[36720]
#define sipNameNr_Key_MediaNext 36734
#define sipName_Key_MediaNext &sipStrings_QtCore[36734]
#define sipNameNr_Key_MediaPlay 36748
#define sipName_Key_MediaPlay &sipStrings_QtCore[36748]
#define sipNameNr_Key_MediaStop 36762
#define sipName_Key_MediaStop &sipStrings_QtCore[36762]
#define sipNameNr_Key_Messenger 36776
#define sipName_Key_Messenger &sipStrings_QtCore[36776]
#define sipNameNr_Key_Multi_key 36790
#define sipName_Key_Multi_key &sipStrings_QtCore[36790]
#define sipNameNr_Key_ParenLeft 36804
#define sipName_Key_ParenLeft &sipStrings_QtCore[36804]
#define sipNameNr_Key_PowerDown 36818
#define sipName_Key_PowerDown &sipStrings_QtCore[36818]
#define sipNameNr_Key_QuoteLeft 36832
#define sipName_Key_QuoteLeft &sipStrings_QtCore[36832]
#define sipNameNr_Key_Semicolon 36846
#define sipName_Key_Semicolon &sipStrings_QtCore[36846]
#define sipNameNr_Key_VoiceDial 36860
#define sipName_Key_VoiceDial &sipStrings_QtCore[36860]
#define sipNameNr_Key_brokenbar 36874
#define sipName_Key_brokenbar &sipStrings_QtCore[36874]
#define sipNameNr_Key_copyright 36888
#define sipName_Key_copyright &sipStrings_QtCore[36888]
#define sipNameNr_Key_diaeresis 36902
#define sipName_Key_diaeresis &sipStrings_QtCore[36902]
#define sipNameNr_Key_masculine 36916
#define sipName_Key_masculine &sipStrings_QtCore[36916]
#define sipNameNr_Key_paragraph 36930
#define sipName_Key_paragraph &sipStrings_QtCore[36930]
#define sipNameNr_Key_plusminus 36944
#define sipName_Key_plusminus &sipStrings_QtCore[36944]
#define sipNameNr_LayoutRequest 36958
#define sipName_LayoutRequest &sipStrings_QtCore[36958]
#define sipNameNr_LibrariesPath 36972
#define sipName_LibrariesPath &sipStrings_QtCore[36972]
#define sipNameNr_Liechtenstein 36986
#define sipName_Liechtenstein &sipStrings_QtCore[36986]
#define sipNameNr_LinearAScript 37000
#define sipName_LinearAScript &sipStrings_QtCore[37000]
#define sipNameNr_LinearBScript 37014
#define sipName_LinearBScript &sipStrings_QtCore[37014]
#define sipNameNr_LocateOptions 3072
#define sipName_LocateOptions &sipStrings_QtCore[3072]
#define sipNameNr_Luxembourgish 37028
#define sipName_Luxembourgish &sipStrings_QtCore[37028]
#define sipNameNr_MODIFIER_MASK 37042
#define sipName_MODIFIER_MASK &sipStrings_QtCore[37042]
#define sipNameNr_MPenJoinStyle 37056
#define sipName_MPenJoinStyle &sipStrings_QtCore[37056]
#define sipNameNr_MacOSCatalina 37070
#define sipName_MacOSCatalina &sipStrings_QtCore[37070]
#define sipNameNr_MacSizeChange 37084
#define sipName_MacSizeChange &sipStrings_QtCore[37084]
#define sipNameNr_MakhuwaMeetto 37098
#define sipName_MakhuwaMeetto &sipStrings_QtCore[37098]
#define sipNameNr_MarchenScript 37112
#define sipName_MarchenScript &sipStrings_QtCore[37112]
#define sipNameNr_MatchContains 37126
#define sipName_MatchContains &sipStrings_QtCore[37126]
#define sipNameNr_MatchEndsWith 37140
#define sipName_MatchEndsWith &sipStrings_QtCore[37140]
#define sipNameNr_MatchWildcard 37154
#define sipName_MatchWildcard &sipStrings_QtCore[37154]
#define sipNameNr_MissingObject 37168
#define sipName_MissingObject &sipStrings_QtCore[37168]
#define sipNameNr_MonthNameType 13956
#define sipName_MonthNameType &sipStrings_QtCore[13956]
#define sipNameNr_MultaniScript 37182
#define sipName_MultaniScript &sipStrings_QtCore[37182]
#define sipNameNr_MusicLocation 37196
#define sipName_MusicLocation &sipStrings_QtCore[37196]
#define sipNameNr_MyanmarScript 37210
#define sipName_MyanmarScript &sipStrings_QtCore[37210]
#define sipNameNr_NativeGesture 10516
#define sipName_NativeGesture &sipStrings_QtCore[10516]
#define sipNameNr_NauruLanguage 37224
#define sipName_NauruLanguage &sipStrings_QtCore[37224]
#define sipNameNr_NoCompression 37238
#define sipName_NoCompression &sipStrings_QtCore[37238]
#define sipNameNr_NoContextMenu 37252
#define sipName_NoContextMenu &sipStrings_QtCore[37252]
#define sipNameNr_NoFocusReason 37266
#define sipName_NoFocusReason &sipStrings_QtCore[37266]
#define sipNameNr_NoMatchOption 37280
#define sipName_NoMatchOption &sipStrings_QtCore[37280]
#define sipNameNr_NoScrollPhase 37294
#define sipName_NoScrollPhase &sipStrings_QtCore[37294]
#define sipNameNr_NoToolBarArea 37308
#define sipName_NoToolBarArea &sipStrings_QtCore[37308]
#define sipNameNr_NorfolkIsland 37322
#define sipName_NorfolkIsland &sipStrings_QtCore[37322]
#define sipNameNr_NorthernSotho 37336
#define sipName_NorthernSotho &sipStrings_QtCore[37336]
#define sipNameNr_NotAtBoundary 37350
#define sipName_NotAtBoundary &sipStrings_QtCore[37350]
#define sipNameNr_NumberOptions 10240
#define sipName_NumberOptions &sipStrings_QtCore[10240]
#define sipNameNr_OffsetFromUTC 37364
#define sipName_OffsetFromUTC &sipStrings_QtCore[37364]
#define sipNameNr_OlChikiScript 37378
#define sipName_OlChikiScript &sipStrings_QtCore[37378]
#define sipNameNr_OrderedDither 37392
#define sipName_OrderedDither &sipStrings_QtCore[37392]
#define sipNameNr_OsmanyaScript 37406
#define sipName_OsmanyaScript &sipStrings_QtCore[37406]
#define sipNameNr_PaletteChange 6868
#define sipName_PaletteChange &sipStrings_QtCore[6868]
#define sipNameNr_PatternOption 1581
#define sipName_PatternOption &sipStrings_QtCore[1581]
#define sipNameNr_PatternSyntax 10309
#define sipName_PatternSyntax &sipStrings_QtCore[10309]
#define sipNameNr_PhagsPaScript 37420
#define sipName_PhagsPaScript &sipStrings_QtCore[37420]
#define sipNameNr_PlatformPanel 37434
#define sipName_PlatformPanel &sipStrings_QtCore[37434]
#define sipNameNr_PolishRequest 37448
#define sipName_PolishRequest &sipStrings_QtCore[37448]
#define sipNameNr_PositionError 37462
#define sipName_PositionError &sipStrings_QtCore[37462]
#define sipNameNr_PreferredSize 37476
#define sipName_PreferredSize &sipStrings_QtCore[37476]
#define sipNameNr_PrettyDecoded 37490
#define sipName_PrettyDecoded &sipStrings_QtCore[37490]
#define sipNameNr_QDir__Filters 37504
#define sipName_QDir__Filters &sipStrings_QtCore[37504]
#define sipNameNr_QElapsedTimer 37518
#define sipName_QElapsedTimer &sipStrings_QtCore[37518]
#define sipNameNr_QFileSelector 37532
#define sipName_QFileSelector &sipStrings_QtCore[37532]
#define sipNameNr_QHistoryState 37546
#define sipName_QHistoryState &sipStrings_QtCore[37546]
#define sipNameNr_QJsonDocument 37560
#define sipName_QJsonDocument &sipStrings_QtCore[37560]
#define sipNameNr_QMetaProperty 37574
#define sipName_QMetaProperty &sipStrings_QtCore[37574]
#define sipNameNr_QMimeDatabase 37588
#define sipName_QMimeDatabase &sipStrings_QtCore[37588]
#define sipNameNr_QPluginLoader 37602
#define sipName_QPluginLoader &sipStrings_QtCore[37602]
#define sipNameNr_QSharedMemory 37616
#define sipName_QSharedMemory &sipStrings_QtCore[37616]
#define sipNameNr_QSignalMapper 37630
#define sipName_QSignalMapper &sipStrings_QtCore[37630]
#define sipNameNr_QStateMachine 37644
#define sipName_QStateMachine &sipStrings_QtCore[37644]
#define sipNameNr_QTemporaryDir 37658
#define sipName_QTemporaryDir &sipStrings_QtCore[37658]
#define sipNameNr_Qt__Alignment 37672
#define sipName_Qt__Alignment &sipStrings_QtCore[37672]
#define sipNameNr_Qt__ArrowType 37686
#define sipName_Qt__ArrowType &sipStrings_QtCore[37686]
#define sipNameNr_Qt__DayOfWeek 37700
#define sipName_Qt__DayOfWeek &sipStrings_QtCore[37700]
#define sipNameNr_Qt__ItemFlags 37714
#define sipName_Qt__ItemFlags &sipStrings_QtCore[37714]
#define sipNameNr_Qt__MatchFlag 37728
#define sipName_Qt__MatchFlag &sipStrings_QtCore[37728]
#define sipNameNr_Qt__SortOrder 37742
#define sipName_Qt__SortOrder &sipStrings_QtCore[37742]
#define sipNameNr_Qt__TimerType 37756
#define sipName_Qt__TimerType &sipStrings_QtCore[37756]
#define sipNameNr_QtCriticalMsg 37770
#define sipName_QtCriticalMsg &sipStrings_QtCore[37770]
#define sipNameNr_RecursionMode 3012
#define sipName_RecursionMode &sipStrings_QtCore[3012]
#define sipNameNr_ResourceError 37784
#define sipName_ResourceError &sipStrings_QtCore[37784]
#define sipNameNr_RestorePolicy 10976
#define sipName_RestorePolicy &sipStrings_QtCore[10976]
#define sipNameNr_RhaetoRomance 37798
#define sipName_RhaetoRomance &sipStrings_QtCore[37798]
#define sipNameNr_ScrollPrepare 37812
#define sipName_ScrollPrepare &sipStrings_QtCore[37812]
#define sipNameNr_SelectCurrent 37826
#define sipName_SelectCurrent &sipStrings_QtCore[37826]
#define sipNameNr_SelectionFlag 1306
#define sipName_SelectionFlag &sipStrings_QtCore[1306]
#define sipNameNr_SerboCroatian 37840
#define sipName_SerboCroatian &sipStrings_QtCore[37840]
#define sipNameNr_SharadaScript 37854
#define sipName_SharadaScript &sipStrings_QtCore[37854]
#define sipNameNr_ShavianScript 37868
#define sipName_ShavianScript &sipStrings_QtCore[37868]
#define sipNameNr_ShiftModifier 37882
#define sipName_ShiftModifier &sipStrings_QtCore[37882]
#define sipNameNr_SiddhamScript 37896
#define sipName_SiddhamScript &sipStrings_QtCore[37896]
#define sipNameNr_SinhalaScript 37910
#define sipName_SinhalaScript &sipStrings_QtCore[37910]
#define sipNameNr_SizeAllCursor 37924
#define sipName_SizeAllCursor &sipStrings_QtCore[37924]
#define sipNameNr_SizeHorCursor 37938
#define sipName_SizeHorCursor &sipStrings_QtCore[37938]
#define sipNameNr_SizeVerCursor 37952
#define sipName_SizeVerCursor &sipStrings_QtCore[37952]
#define sipNameNr_SmartNotation 37966
#define sipName_SmartNotation &sipStrings_QtCore[37966]
#define sipNameNr_SouthernSotho 37980
#define sipName_SouthernSotho &sipStrings_QtCore[37980]
#define sipNameNr_StandardError 10861
#define sipName_StandardError &sipStrings_QtCore[10861]
#define sipNameNr_StartDocument 20985
#define sipName_StartDocument &sipStrings_QtCore[20985]
#define sipNameNr_StatusTipRole 37994
#define sipName_StatusTipRole &sipStrings_QtCore[37994]
#define sipNameNr_TabletRelease 38008
#define sipName_TabletRelease &sipStrings_QtCore[38008]
#define sipNameNr_TagalogScript 38022
#define sipName_TagalogScript &sipStrings_QtCore[38022]
#define sipNameNr_TaiVietScript 38036
#define sipName_TaiVietScript &sipStrings_QtCore[38036]
#define sipNameNr_TextColorRole 38050
#define sipName_TextColorRole &sipStrings_QtCore[38050]
#define sipNameNr_TextDontPrint 38064
#define sipName_TextDontPrint &sipStrings_QtCore[38064]
#define sipNameNr_TextElideMode 22318
#define sipName_TextElideMode &sipStrings_QtCore[22318]
#define sipNameNr_TibetanScript 38078
#define sipName_TibetanScript &sipStrings_QtCore[38078]
#define sipNameNr_TirhutaScript 38092
#define sipName_TirhutaScript &sipStrings_QtCore[38092]
#define sipNameNr_ToggleCurrent 38106
#define sipName_ToggleCurrent &sipStrings_QtCore[38106]
#define sipNameNr_ToolBarChange 38120
#define sipName_ToolBarChange &sipStrings_QtCore[38120]
#define sipNameNr_ToolTipChange 38134
#define sipName_ToolTipChange &sipStrings_QtCore[38134]
#define sipNameNr_TopLeftCorner 38148
#define sipName_TopLeftCorner &sipStrings_QtCore[38148]
#define sipNameNr_TuvaluCountry 38162
#define sipName_TuvaluCountry &sipStrings_QtCore[38162]
#define sipNameNr_UNICODE_ACCEL 38176
#define sipName_UNICODE_ACCEL &sipStrings_QtCore[38176]
#define sipNameNr_UnitedKingdom 38190
#define sipName_UnitedKingdom &sipStrings_QtCore[38190]
#define sipNameNr_UpArrowCursor 38204
#define sipName_UpArrowCursor &sipStrings_QtCore[38204]
#define sipNameNr_UpdateRequest 38218
#define sipName_UpdateRequest &sipStrings_QtCore[38218]
#define sipNameNr_UppercaseBase 38232
#define sipName_UppercaseBase &sipStrings_QtCore[38232]
#define sipNameNr_WA_SetPalette 38246
#define sipName_WA_SetPalette &sipStrings_QtCore[38246]
#define sipNameNr_WA_StyleSheet 38260
#define sipName_WA_StyleSheet &sipStrings_QtCore[38260]
#define sipNameNr_WA_UnderMouse 38274
#define sipName_WA_UnderMouse &sipStrings_QtCore[38274]
#define sipNameNr_WesternSahara 38288
#define sipName_WesternSahara &sipStrings_QtCore[38288]
#define sipNameNr_WhatsThisRole 38302
#define sipName_WhatsThisRole &sipStrings_QtCore[38302]
#define sipNameNr_WhiteSpacePre 38316
#define sipName_WhiteSpacePre &sipStrings_QtCore[38316]
#define sipNameNr_WindowBlocked 38330
#define sipName_WindowBlocked &sipStrings_QtCore[38330]
#define sipNameNr_WindowNoState 38344
#define sipName_WindowNoState &sipStrings_QtCore[38344]
#define sipNameNr_WithoutBraces 38358
#define sipName_WithoutBraces &sipStrings_QtCore[38358]
#define sipNameNr_activeChanged 38372
#define sipName_activeChanged &sipStrings_QtCore[38372]
#define sipNameNr_addHelpOption 38386
#define sipName_addHelpOption &sipStrings_QtCore[38386]
#define sipNameNr_addSearchPath 38400
#define sipName_addSearchPath &sipStrings_QtCore[38400]
#define sipNameNr_addTCBSegment 38414
#define sipName_addTCBSegment &sipStrings_QtCore[38414]
#define sipNameNr_addTransition 38428
#define sipName_addTransition &sipStrings_QtCore[38428]
#define sipNameNr_availableMibs 38442
#define sipName_availableMibs &sipStrings_QtCore[38442]
#define sipNameNr_beginMoveRows 38456
#define sipName_beginMoveRows &sipStrings_QtCore[38456]
#define sipNameNr_cancelWriting 38470
#define sipName_cancelWriting &sipStrings_QtCore[38470]
#define sipNameNr_canonicalPath 38484
#define sipName_canonicalPath &sipStrings_QtCore[38484]
#define sipNameNr_capturedStart 38498
#define sipName_capturedStart &sipStrings_QtCore[38498]
#define sipNameNr_capturedTexts 38512
#define sipName_capturedTexts &sipStrings_QtCore[38512]
#define sipNameNr_configuration 38526
#define sipName_configuration &sipStrings_QtCore[38526]
#define sipNameNr_connectNotify 26667
#define sipName_connectNotify &sipStrings_QtCore[26667]
#define sipNameNr_currentOffset 38540
#define sipName_currentOffset &sipStrings_QtCore[38540]
#define sipNameNr_currentThread 38554
#define sipName_currentThread &sipStrings_QtCore[38554]
#define sipNameNr_dateFromParts 38568
#define sipName_dateFromParts &sipStrings_QtCore[38568]
#define sipNameNr_deadlineNSecs 38582
#define sipName_deadlineNSecs &sipStrings_QtCore[38582]
#define sipNameNr_defaultFormat 38596
#define sipName_defaultFormat &sipStrings_QtCore[38596]
#define sipNameNr_defaultValues 38610
#define sipName_defaultValues &sipStrings_QtCore[38610]
#define sipNameNr_endInsertRows 38624
#define sipName_endInsertRows &sipStrings_QtCore[38624]
#define sipNameNr_endRemoveRows 38638
#define sipName_endRemoveRows &sipStrings_QtCore[38638]
#define sipNameNr_endResetModel 38652
#define sipName_endResetModel &sipStrings_QtCore[38652]
#define sipNameNr_entryInfoList 38666
#define sipName_entryInfoList &sipStrings_QtCore[38666]
#define sipNameNr_errorOccurred 38680
#define sipName_errorOccurred &sipStrings_QtCore[38680]
#define sipNameNr_expiryTimeout 38694
#define sipName_expiryTimeout &sipStrings_QtCore[38694]
#define sipNameNr_fromJulianDay 38708
#define sipName_fromJulianDay &sipStrings_QtCore[38708]
#define sipNameNr_fromLocalFile 38722
#define sipName_fromLocalFile &sipStrings_QtCore[38722]
#define sipNameNr_fromUserInput 38736
#define sipName_fromUserInput &sipStrings_QtCore[38736]
#define sipNameNr_indexOfMethod 38750
#define sipName_indexOfMethod &sipStrings_QtCore[38750]
#define sipNameNr_indexOfSignal 38764
#define sipName_indexOfSignal &sipStrings_QtCore[38764]
#define sipNameNr_insertColumns 38778
#define sipName_insertColumns &sipStrings_QtCore[38778]
#define sipNameNr_isEndDocument 38792
#define sipName_isEndDocument &sipStrings_QtCore[38792]
#define sipNameNr_isInfoEnabled 38806
#define sipName_isInfoEnabled &sipStrings_QtCore[38806]
#define sipNameNr_isLengthKnown 38820
#define sipName_isLengthKnown &sipStrings_QtCore[38820]
#define sipNameNr_isRowSelected 38834
#define sipName_isRowSelected &sipStrings_QtCore[38834]
#define sipNameNr_kernelVersion 38848
#define sipName_kernelVersion &sipStrings_QtCore[38848]
#define sipNameNr_layoutChanged 38862
#define sipName_layoutChanged &sipStrings_QtCore[38862]
#define sipNameNr_leftJustified 38876
#define sipName_leftJustified &sipStrings_QtCore[38876]
#define sipNameNr_listSeparator 38890
#define sipName_listSeparator &sipStrings_QtCore[38890]
#define sipNameNr_longMonthName 38904
#define sipName_longMonthName &sipStrings_QtCore[38904]
#define sipNameNr_lowercasebase 38918
#define sipName_lowercasebase &sipStrings_QtCore[38918]
#define sipNameNr_mapFromSource 38932
#define sipName_mapFromSource &sipStrings_QtCore[38932]
#define sipNameNr_matchedLength 38946
#define sipName_matchedLength &sipStrings_QtCore[38946]
#define sipNameNr_numberOptions 38960
#define sipName_numberOptions &sipStrings_QtCore[38960]
#define sipNameNr_offsetFromUtc 38974
#define sipName_offsetFromUtc &sipStrings_QtCore[38974]
#define sipNameNr_offsetSeconds 38988
#define sipName_offsetSeconds &sipStrings_QtCore[38988]
#define sipNameNr_parameterType 39002
#define sipName_parameterType &sipStrings_QtCore[39002]
#define sipNameNr_partsFromDate 39016
#define sipName_partsFromDate &sipStrings_QtCore[39016]
#define sipNameNr_patternSyntax 39030
#define sipName_patternSyntax &sipStrings_QtCore[39030]
#define sipNameNr_processEvents 39044
#define sipName_processEvents &sipStrings_QtCore[39044]
#define sipNameNr_propertyCount 39058
#define sipName_propertyCount &sipStrings_QtCore[39058]
#define sipNameNr_propertyIndex 39072
#define sipName_propertyIndex &sipStrings_QtCore[39072]
#define sipNameNr_pyqtConfigure 39086
#define sipName_pyqtConfigure &sipStrings_QtCore[39086]
#define sipNameNr_qErrnoWarning 39100
#define sipName_qErrnoWarning &sipStrings_QtCore[39100]
#define sipNameNr_qFuzzyCompare 39114
#define sipName_qFuzzyCompare &sipStrings_QtCore[39114]
#define sipNameNr_qualifiedName 39128
#define sipName_qualifiedName &sipStrings_QtCore[39128]
#define sipNameNr_readByteArray 39142
#define sipName_readByteArray &sipStrings_QtCore[39142]
#define sipNameNr_readWriteLock 39156
#define sipName_readWriteLock &sipStrings_QtCore[39156]
#define sipNameNr_recursionMode 39170
#define sipName_recursionMode &sipStrings_QtCore[39170]
#define sipNameNr_registerTimer 31104
#define sipName_registerTimer &sipStrings_QtCore[31104]
#define sipNameNr_releaseThread 39184
#define sipName_releaseThread &sipStrings_QtCore[39184]
#define sipNameNr_remainingTime 39198
#define sipName_remainingTime &sipStrings_QtCore[39198]
#define sipNameNr_removeColumns 39212
#define sipName_removeColumns &sipStrings_QtCore[39212]
#define sipNameNr_reserveThread 39226
#define sipName_reserveThread &sipStrings_QtCore[39226]
#define sipNameNr_setArrayIndex 39240
#define sipName_setArrayIndex &sipStrings_QtCore[39240]
#define sipNameNr_setAutoDelete 39254
#define sipName_setAutoDelete &sipStrings_QtCore[39254]
#define sipNameNr_setAutoRemove 39268
#define sipName_setAutoRemove &sipStrings_QtCore[39268]
#define sipNameNr_setBottomLeft 39282
#define sipName_setBottomLeft &sipStrings_QtCore[39282]
#define sipNameNr_setCurveShape 39296
#define sipName_setCurveShape &sipStrings_QtCore[39296]
#define sipNameNr_setCustomType 39310
#define sipName_setCustomType &sipStrings_QtCore[39310]
#define sipNameNr_setErrorState 39324
#define sipName_setErrorState &sipStrings_QtCore[39324]
#define sipNameNr_setFieldWidth 39338
#define sipName_setFieldWidth &sipStrings_QtCore[39338]
#define sipNameNr_setFilterRole 39352
#define sipName_setFilterRole &sipStrings_QtCore[39352]
#define sipNameNr_setFrameRange 39366
#define sipName_setFrameRange &sipStrings_QtCore[39366]
#define sipNameNr_setHeaderData 39380
#define sipName_setHeaderData &sipStrings_QtCore[39380]
#define sipNameNr_setKeyValueAt 39394
#define sipName_setKeyValueAt &sipStrings_QtCore[39394]
#define sipNameNr_setObjectName 39408
#define sipName_setObjectName &sipStrings_QtCore[39408]
#define sipNameNr_setQueryItems 39422
#define sipName_setQueryItems &sipStrings_QtCore[39422]
#define sipNameNr_setSingleShot 39436
#define sipName_setSingleShot &sipStrings_QtCore[39436]
#define sipNameNr_setStartFrame 39450
#define sipName_setStartFrame &sipStrings_QtCore[39450]
#define sipNameNr_setStartValue 39464
#define sipName_setStartValue &sipStrings_QtCore[39464]
#define sipNameNr_setStringList 39478
#define sipName_setStringList &sipStrings_QtCore[39478]
#define sipNameNr_signalChanged 39492
#define sipName_signalChanged &sipStrings_QtCore[39492]
#define sipNameNr_staleLockTime 39506
#define sipName_staleLockTime &sipStrings_QtCore[39506]
#define sipNameNr_startDetached 39520
#define sipName_startDetached &sipStrings_QtCore[39520]
#define sipNameNr_symLinkTarget 39534
#define sipName_symLinkTarget &sipStrings_QtCore[39534]
#define sipNameNr_takeAnimation 39548
#define sipName_takeAnimation &sipStrings_QtCore[39548]
#define sipNameNr_testAttribute 39562
#define sipName_testAttribute &sipStrings_QtCore[39562]
#define sipNameNr_textDirection 39576
#define sipName_textDirection &sipStrings_QtCore[39576]
#define sipNameNr_toAlignedRect 39590
#define sipName_toAlignedRect &sipStrings_QtCore[39590]
#define sipNameNr_toCubicSpline 39604
#define sipName_toCubicSpline &sipStrings_QtCore[39604]
#define sipNameNr_totalDuration 39618
#define sipName_totalDuration &sipStrings_QtCore[39618]
#define sipNameNr_uppercasebase 39632
#define sipName_uppercasebase &sipStrings_QtCore[39632]
#define sipNameNr_writeQVariant 39646
#define sipName_writeQVariant &sipStrings_QtCore[39646]
#define sipNameNr_AbsoluteSize 39660
#define sipName_AbsoluteSize &sipStrings_QtCore[39660]
#define sipNameNr_AlandIslands 39673
#define sipName_AlandIslands &sipStrings_QtCore[39673]
#define sipNameNr_AlignHCenter 39686
#define sipName_AlignHCenter &sipStrings_QtCore[39686]
#define sipNameNr_AlignJustify 39699
#define sipName_AlignJustify &sipStrings_QtCore[39699]
#define sipNameNr_AlignLeading 39712
#define sipName_AlignLeading &sipStrings_QtCore[39712]
#define sipNameNr_AlignVCenter 39725
#define sipName_AlignVCenter &sipStrings_QtCore[39725]
#define sipNameNr_AnchorBottom 39738
#define sipName_AnchorBottom &sipStrings_QtCore[39738]
#define sipNameNr_AncientGreek 39751
#define sipName_AncientGreek &sipStrings_QtCore[39751]
#define sipNameNr_ArabicScript 39764
#define sipName_ArabicScript &sipStrings_QtCore[39764]
#define sipNameNr_ArchDataPath 39777
#define sipName_ArchDataPath &sipStrings_QtCore[39777]
#define sipNameNr_BDiagPattern 39790
#define sipName_BDiagPattern &sipStrings_QtCore[39790]
#define sipNameNr_Base64Option 7219
#define sipName_Base64Option &sipStrings_QtCore[7219]
#define sipNameNr_BezierSpline 39803
#define sipName_BezierSpline &sipStrings_QtCore[39803]
#define sipNameNr_BinariesPath 39816
#define sipName_BinariesPath &sipStrings_QtCore[39816]
#define sipNameNr_BitmapCursor 39829
#define sipName_BitmapCursor &sipStrings_QtCore[39829]
#define sipNameNr_BoundaryType 1616
#define sipName_BoundaryType &sipStrings_QtCore[1616]
#define sipNameNr_BouvetIsland 39842
#define sipName_BouvetIsland &sipStrings_QtCore[39842]
#define sipNameNr_BrahmiScript 39855
#define sipName_BrahmiScript &sipStrings_QtCore[39855]
#define sipNameNr_Byelorussian 39868
#define sipName_Byelorussian &sipStrings_QtCore[39868]
#define sipNameNr_COSE_Encrypt 39881
#define sipName_COSE_Encrypt &sipStrings_QtCore[39881]
#define sipNameNr_CarianScript 39894
#define sipName_CarianScript &sipStrings_QtCore[39894]
#define sipNameNr_ChakmaScript 39907
#define sipName_ChakmaScript &sipStrings_QtCore[39907]
#define sipNameNr_ChecksumType 25597
#define sipName_ChecksumType &sipStrings_QtCore[25597]
#define sipNameNr_ChildRemoved 39920
#define sipName_ChildRemoved &sipStrings_QtCore[39920]
#define sipNameNr_CocosIslands 39933
#define sipName_CocosIslands &sipStrings_QtCore[39933]
#define sipNameNr_CongoSwahili 39946
#define sipName_CongoSwahili &sipStrings_QtCore[39946]
#define sipNameNr_CopticScript 39959
#define sipName_CopticScript &sipStrings_QtCore[39959]
#define sipNameNr_CrossPattern 24339
#define sipName_CrossPattern &sipStrings_QtCore[24339]
#define sipNameNr_CursorChange 39972
#define sipName_CursorChange &sipStrings_QtCore[39972]
#define sipNameNr_CustomCursor 39985
#define sipName_CustomCursor &sipStrings_QtCore[39985]
#define sipNameNr_DataLocation 13348
#define sipName_DataLocation &sipStrings_QtCore[13348]
#define sipNameNr_DataTooLarge 39998
#define sipName_DataTooLarge &sipStrings_QtCore[39998]
#define sipNameNr_DaylightTime 30353
#define sipName_DaylightTime &sipStrings_QtCore[30353]
#define sipNameNr_DeepBindHint 40011
#define sipName_DeepBindHint &sipStrings_QtCore[40011]
#define sipNameNr_EaseOutCurve 40024
#define sipName_EaseOutCurve &sipStrings_QtCore[40024]
#define sipNameNr_EasternKayah 40037
#define sipName_EasternKayah &sipStrings_QtCore[40037]
#define sipNameNr_EncodeSpaces 40050
#define sipName_EncodeSpaces &sipStrings_QtCore[40050]
#define sipNameNr_EnterKeyDone 40063
#define sipName_EnterKeyDone &sipStrings_QtCore[40063]
#define sipNameNr_EnterKeyNext 40076
#define sipName_EnterKeyNext &sipStrings_QtCore[40076]
#define sipNameNr_EnterKeySend 40089
#define sipName_EnterKeySend &sipStrings_QtCore[40089]
#define sipNameNr_EnterKeyType 25614
#define sipName_EnterKeyType &sipStrings_QtCore[25614]
#define sipNameNr_ExamplesPath 40102
#define sipName_ExamplesPath &sipStrings_QtCore[40102]
#define sipNameNr_ExistingOnly 40115
#define sipName_ExistingOnly &sipStrings_QtCore[40115]
#define sipNameNr_ExtraButton1 40128
#define sipName_ExtraButton1 &sipStrings_QtCore[40128]
#define sipNameNr_ExtraButton2 40141
#define sipName_ExtraButton2 &sipStrings_QtCore[40141]
#define sipNameNr_ExtraButton3 40154
#define sipName_ExtraButton3 &sipStrings_QtCore[40154]
#define sipNameNr_ExtraButton4 40167
#define sipName_ExtraButton4 &sipStrings_QtCore[40167]
#define sipNameNr_ExtraButton5 40180
#define sipName_ExtraButton5 &sipStrings_QtCore[40180]
#define sipNameNr_ExtraButton6 40193
#define sipName_ExtraButton6 &sipStrings_QtCore[40193]
#define sipNameNr_ExtraButton7 40206
#define sipName_ExtraButton7 &sipStrings_QtCore[40206]
#define sipNameNr_ExtraButton8 40219
#define sipName_ExtraButton8 &sipStrings_QtCore[40219]
#define sipNameNr_ExtraButton9 40232
#define sipName_ExtraButton9 &sipStrings_QtCore[40232]
#define sipNameNr_FDiagPattern 40245
#define sipName_FDiagPattern &sipStrings_QtCore[40245]
#define sipNameNr_FaroeIslands 40258
#define sipName_FaroeIslands &sipStrings_QtCore[40258]
#define sipNameNr_FirstGuiType 40271
#define sipName_FirstGuiType &sipStrings_QtCore[40271]
#define sipNameNr_FraserScript 40284
#define sipName_FraserScript &sipStrings_QtCore[40284]
#define sipNameNr_FrenchGuiana 40297
#define sipName_FrenchGuiana &sipStrings_QtCore[40297]
#define sipNameNr_FullyDecoded 40310
#define sipName_FullyDecoded &sipStrings_QtCore[40310]
#define sipNameNr_FullyEncoded 40323
#define sipName_FullyEncoded &sipStrings_QtCore[40323]
#define sipNameNr_GarbageAtEnd 40336
#define sipName_GarbageAtEnd &sipStrings_QtCore[40336]
#define sipNameNr_GestureFlags 25631
#define sipName_GestureFlags &sipStrings_QtCore[25631]
#define sipNameNr_GestureState 25648
#define sipName_GestureState &sipStrings_QtCore[25648]
#define sipNameNr_GothicScript 40349
#define sipName_GothicScript &sipStrings_QtCore[40349]
#define sipNameNr_GrabKeyboard 40362
#define sipName_GrabKeyboard &sipStrings_QtCore[40362]
#define sipNameNr_GuineaBissau 40375
#define sipName_GuineaBissau &sipStrings_QtCore[40375]
#define sipNameNr_HangulScript 40388
#define sipName_HangulScript &sipStrings_QtCore[40388]
#define sipNameNr_HatranScript 40401
#define sipName_HatranScript &sipStrings_QtCore[40401]
#define sipNameNr_HebrewScript 40414
#define sipName_HebrewScript &sipStrings_QtCore[40414]
#define sipNameNr_HideToParent 40427
#define sipName_HideToParent &sipStrings_QtCore[40427]
#define sipNameNr_HighPriority 40440
#define sipName_HighPriority &sipStrings_QtCore[40440]
#define sipNameNr_HomeLocation 40453
#define sipName_HomeLocation &sipStrings_QtCore[40453]
#define sipNameNr_IdlePriority 40466
#define sipName_IdlePriority &sipStrings_QtCore[40466]
#define sipNameNr_IgnoreAction 40479
#define sipName_IgnoreAction &sipStrings_QtCore[40479]
#define sipNameNr_IgnoreHeader 40492
#define sipName_IgnoreHeader &sipStrings_QtCore[40492]
#define sipNameNr_IllegalValue 40505
#define sipName_IllegalValue &sipStrings_QtCore[40505]
#define sipNameNr_ImMicroFocus 40518
#define sipName_ImMicroFocus &sipStrings_QtCore[40518]
#define sipNameNr_ImQueryInput 40531
#define sipName_ImQueryInput &sipStrings_QtCore[40531]
#define sipNameNr_ImhLatinOnly 40544
#define sipName_ImhLatinOnly &sipStrings_QtCore[40544]
#define sipNameNr_ImhMultiLine 40557
#define sipName_ImhMultiLine &sipStrings_QtCore[40557]
#define sipNameNr_InOutElastic 40570
#define sipName_InOutElastic &sipStrings_QtCore[40570]
#define sipNameNr_IndexIsValid 40583
#define sipName_IndexIsValid &sipStrings_QtCore[40583]
#define sipNameNr_IslamicCivil 40596
#define sipName_IslamicCivil &sipStrings_QtCore[40596]
#define sipNameNr_ItemDataRole 25665
#define sipName_ItemDataRole &sipStrings_QtCore[25665]
#define sipNameNr_IteratorFlag 5159
#define sipName_IteratorFlag &sipStrings_QtCore[5159]
#define sipNameNr_Kabuverdianu 40609
#define sipName_Kabuverdianu &sipStrings_QtCore[40609]
#define sipNameNr_KaithiScript 40622
#define sipName_KaithiScript &sipStrings_QtCore[40622]
#define sipNameNr_Key_Asterisk 40635
#define sipName_Key_Asterisk &sipStrings_QtCore[40635]
#define sipNameNr_Key_BassDown 40648
#define sipName_Key_BassDown &sipStrings_QtCore[40648]
#define sipNameNr_Key_Calendar 40661
#define sipName_Key_Calendar &sipStrings_QtCore[40661]
#define sipNameNr_Key_CapsLock 40674
#define sipName_Key_CapsLock &sipStrings_QtCore[40674]
#define sipNameNr_Key_Ccedilla 40687
#define sipName_Key_Ccedilla &sipStrings_QtCore[40687]
#define sipNameNr_Key_Context1 40700
#define sipName_Key_Context1 &sipStrings_QtCore[40700]
#define sipNameNr_Key_Context2 40713
#define sipName_Key_Context2 &sipStrings_QtCore[40713]
#define sipNameNr_Key_Context3 40726
#define sipName_Key_Context3 &sipStrings_QtCore[40726]
#define sipNameNr_Key_Context4 40739
#define sipName_Key_Context4 &sipStrings_QtCore[40739]
#define sipNameNr_Key_Explorer 40752
#define sipName_Key_Explorer &sipStrings_QtCore[40752]
#define sipNameNr_Key_Hiragana 40765
#define sipName_Key_Hiragana &sipStrings_QtCore[40765]
#define sipNameNr_Key_HomePage 40778
#define sipName_Key_HomePage &sipStrings_QtCore[40778]
#define sipNameNr_Key_HotLinks 40791
#define sipName_Key_HotLinks &sipStrings_QtCore[40791]
#define sipNameNr_Key_Katakana 40804
#define sipName_Key_Katakana &sipStrings_QtCore[40804]
#define sipNameNr_Key_Muhenkan 40817
#define sipName_Key_Muhenkan &sipStrings_QtCore[40817]
#define sipNameNr_Key_Ooblique 40830
#define sipName_Key_Ooblique &sipStrings_QtCore[40830]
#define sipNameNr_Key_PageDown 40843
#define sipName_Key_PageDown &sipStrings_QtCore[40843]
#define sipNameNr_Key_Pictures 40856
#define sipName_Key_Pictures &sipStrings_QtCore[40856]
#define sipNameNr_Key_PowerOff 40869
#define sipName_Key_PowerOff &sipStrings_QtCore[40869]
#define sipNameNr_Key_Question 40882
#define sipName_Key_Question &sipStrings_QtCore[40882]
#define sipNameNr_Key_QuoteDbl 40895
#define sipName_Key_QuoteDbl &sipStrings_QtCore[40895]
#define sipNameNr_Key_Settings 40908
#define sipName_Key_Settings &sipStrings_QtCore[40908]
#define sipNameNr_Key_Subtitle 40921
#define sipName_Key_Subtitle &sipStrings_QtCore[40921]
#define sipNameNr_Key_TaskPane 40934
#define sipName_Key_TaskPane &sipStrings_QtCore[40934]
#define sipNameNr_Key_Terminal 40947
#define sipName_Key_Terminal &sipStrings_QtCore[40947]
#define sipNameNr_Key_ToDoList 40960
#define sipName_Key_ToDoList &sipStrings_QtCore[40960]
#define sipNameNr_Key_TrebleUp 40973
#define sipName_Key_TrebleUp &sipStrings_QtCore[40973]
#define sipNameNr_Key_VolumeUp 40986
#define sipName_Key_VolumeUp &sipStrings_QtCore[40986]
#define sipNameNr_Key_currency 40999
#define sipName_Key_currency &sipStrings_QtCore[40999]
#define sipNameNr_Key_division 41012
#define sipName_Key_division &sipStrings_QtCore[41012]
#define sipNameNr_Key_multiply 41025
#define sipName_Key_multiply &sipStrings_QtCore[41025]
#define sipNameNr_Key_sterling 41038
#define sipName_Key_sterling &sipStrings_QtCore[41038]
#define sipNameNr_KhojkiScript 41051
#define sipName_KhojkiScript &sipStrings_QtCore[41051]
#define sipNameNr_KoreanScript 41064
#define sipName_KoreanScript &sipStrings_QtCore[41064]
#define sipNameNr_LastCoreType 41077
#define sipName_LastCoreType &sipStrings_QtCore[41077]
#define sipNameNr_LastLanguage 41090
#define sipName_LastLanguage &sipStrings_QtCore[41090]
#define sipNameNr_LatinAmerica 41103
#define sipName_LatinAmerica &sipStrings_QtCore[41103]
#define sipNameNr_LepchaScript 41116
#define sipName_LepchaScript &sipStrings_QtCore[41116]
#define sipNameNr_LittleEndian 41129
#define sipName_LittleEndian &sipStrings_QtCore[41129]
#define sipNameNr_LocaleChange 41142
#define sipName_LocaleChange &sipStrings_QtCore[41142]
#define sipNameNr_LocateOption 3482
#define sipName_LocateOption &sipStrings_QtCore[3482]
#define sipNameNr_LowerSorbian 41155
#define sipName_LowerSorbian &sipStrings_QtCore[41155]
#define sipNameNr_LycianScript 41168
#define sipName_LycianScript &sipStrings_QtCore[41168]
#define sipNameNr_LydianScript 41181
#define sipName_LydianScript &sipStrings_QtCore[41181]
#define sipNameNr_MPenCapStyle 41194
#define sipName_MPenCapStyle &sipStrings_QtCore[41194]
#define sipNameNr_MarkdownText 41207
#define sipName_MarkdownText &sipStrings_QtCore[41207]
#define sipNameNr_MaskOutColor 41220
#define sipName_MaskOutColor &sipStrings_QtCore[41220]
#define sipNameNr_MatchContent 41233
#define sipName_MatchContent &sipStrings_QtCore[41233]
#define sipNameNr_MatchDefault 41246
#define sipName_MatchDefault &sipStrings_QtCore[41246]
#define sipNameNr_MatchExactly 41259
#define sipName_MatchExactly &sipStrings_QtCore[41259]
#define sipNameNr_MatchOptions 1915
#define sipName_MatchOptions &sipStrings_QtCore[1915]
#define sipNameNr_MetaModifier 41272
#define sipName_MetaModifier &sipStrings_QtCore[41272]
#define sipNameNr_MetricSystem 41285
#define sipName_MetricSystem &sipStrings_QtCore[41285]
#define sipNameNr_MiddleButton 41298
#define sipName_MiddleButton &sipStrings_QtCore[41298]
#define sipNameNr_MouseButtons 25682
#define sipName_MouseButtons &sipStrings_QtCore[25682]
#define sipNameNr_NarrowFormat 41311
#define sipName_NarrowFormat &sipStrings_QtCore[41311]
#define sipNameNr_NativeFormat 41324
#define sipName_NativeFormat &sipStrings_QtCore[41324]
#define sipNameNr_NauruCountry 41337
#define sipName_NauruCountry &sipStrings_QtCore[41337]
#define sipNameNr_NewCaledonia 41350
#define sipName_NewCaledonia &sipStrings_QtCore[41350]
#define sipNameNr_NonRecursive 41363
#define sipName_NonRecursive &sipStrings_QtCore[41363]
#define sipNameNr_NorthNdebele 41376
#define sipName_NorthNdebele &sipStrings_QtCore[41376]
#define sipNameNr_NorthernLuri 41389
#define sipName_NorthernLuri &sipStrings_QtCore[41389]
#define sipNameNr_NorthernSami 41402
#define sipName_NorthernSami &sipStrings_QtCore[41402]
#define sipNameNr_NorthernThai 41415
#define sipName_NorthernThai &sipStrings_QtCore[41415]
#define sipNameNr_NumberOption 11818
#define sipName_NumberOption &sipStrings_QtCore[11818]
#define sipNameNr_OSXElCapitan 41428
#define sipName_OSXElCapitan &sipStrings_QtCore[41428]
#define sipNameNr_OSXMavericks 41441
#define sipName_OSXMavericks &sipStrings_QtCore[41441]
#define sipNameNr_OpenModeFlag 8595
#define sipName_OpenModeFlag &sipStrings_QtCore[8595]
#define sipNameNr_Orientations 10402
#define sipName_Orientations &sipStrings_QtCore[10402]
#define sipNameNr_OrkhonScript 41454
#define sipName_OrkhonScript &sipStrings_QtCore[41454]
#define sipNameNr_OutInElastic 41467
#define sipName_OutInElastic &sipStrings_QtCore[41467]
#define sipNameNr_PYQT_VERSION 41480
#define sipName_PYQT_VERSION &sipStrings_QtCore[41480]
#define sipNameNr_ParentChange 41493
#define sipName_ParentChange &sipStrings_QtCore[41493]
#define sipNameNr_PenJoinStyle 25716
#define sipName_PenJoinStyle &sipStrings_QtCore[25716]
#define sipNameNr_PinchGesture 41506
#define sipName_PinchGesture &sipStrings_QtCore[41506]
#define sipNameNr_PreciseTimer 41519
#define sipName_PreciseTimer &sipStrings_QtCore[41519]
#define sipNameNr_PreferDither 41532
#define sipName_PreferDither &sipStrings_QtCore[41532]
#define sipNameNr_ProcessError 10264
#define sipName_ProcessError &sipStrings_QtCore[10264]
#define sipNameNr_ProcessState 10287
#define sipName_ProcessState &sipStrings_QtCore[10287]
#define sipNameNr_PyQt5_QtCore 41545
#define sipName_PyQt5_QtCore &sipStrings_QtCore[41545]
#define sipNameNr_QDir__Filter 41558
#define sipName_QDir__Filter &sipStrings_QtCore[41558]
#define sipNameNr_QDirIterator 41571
#define sipName_QDirIterator &sipStrings_QtCore[41571]
#define sipNameNr_QEasingCurve 41584
#define sipName_QEasingCurve &sipStrings_QtCore[41584]
#define sipNameNr_QEvent__Type 41597
#define sipName_QEvent__Type &sipStrings_QtCore[41597]
#define sipNameNr_QKeySequence 41610
#define sipName_QKeySequence &sipStrings_QtCore[41610]
#define sipNameNr_QLibraryInfo 41623
#define sipName_QLibraryInfo &sipStrings_QtCore[41623]
#define sipNameNr_41636 41636
#define sipName_41636 &sipStrings_QtCore[41636]
#define sipNameNr_QMutexLocker 41649
#define sipName_QMutexLocker &sipStrings_QtCore[41649]
#define sipNameNr_QStorageInfo 41662
#define sipName_QStorageInfo &sipStrings_QtCore[41662]
#define sipNameNr_QTextDecoder 41675
#define sipName_QTextDecoder &sipStrings_QtCore[41675]
#define sipNameNr_QTextEncoder 41688
#define sipName_QTextEncoder &sipStrings_QtCore[41688]
#define sipNameNr_QUrlTwoFlags 41701
#define sipName_QUrlTwoFlags &sipStrings_QtCore[41701]
#define sipNameNr_QVariantHash 24065
#define sipName_QVariantHash &sipStrings_QtCore[24065]
#define sipNameNr_QVariantList 24083
#define sipName_QVariantList &sipStrings_QtCore[24083]
#define sipNameNr_41714 41714
#define sipName_41714 &sipStrings_QtCore[41714]
#define sipNameNr_QWriteLocker 41727
#define sipName_QWriteLocker &sipStrings_QtCore[41727]
#define sipNameNr_Q_RETURN_ARG 41740
#define sipName_Q_RETURN_ARG &sipStrings_QtCore[41740]
#define sipNameNr_Qt__FillRule 41753
#define sipName_Qt__FillRule &sipStrings_QtCore[41753]
#define sipNameNr_Qt__ItemFlag 41766
#define sipName_Qt__ItemFlag &sipStrings_QtCore[41766]
#define sipNameNr_Qt__MaskMode 41779
#define sipName_Qt__MaskMode &sipStrings_QtCore[41779]
#define sipNameNr_Qt__Modifier 41792
#define sipName_Qt__Modifier &sipStrings_QtCore[41792]
#define sipNameNr_Qt__PenStyle 41805
#define sipName_Qt__PenStyle &sipStrings_QtCore[41805]
#define sipNameNr_Qt__SizeHint 41818
#define sipName_Qt__SizeHint &sipStrings_QtCore[41818]
#define sipNameNr_Qt__SizeMode 41831
#define sipName_Qt__SizeMode &sipStrings_QtCore[41831]
#define sipNameNr_Qt__TextFlag 41844
#define sipName_Qt__TextFlag &sipStrings_QtCore[41844]
#define sipNameNr_Qt__TileRule 41857
#define sipName_Qt__TileRule &sipStrings_QtCore[41857]
#define sipNameNr_Qt__TimeSpec 41870
#define sipName_Qt__TimeSpec &sipStrings_QtCore[41870]
#define sipNameNr_Qt__UIEffect 41883
#define sipName_Qt__UIEffect &sipStrings_QtCore[41883]
#define sipNameNr_QtWarningMsg 41896
#define sipName_QtWarningMsg &sipStrings_QtCore[41896]
#define sipNameNr_RejangScript 41909
#define sipName_RejangScript &sipStrings_QtCore[41909]
#define sipNameNr_RelativeSize 41922
#define sipName_RelativeSize &sipStrings_QtCore[41922]
#define sipNameNr_RemoveScheme 41935
#define sipName_RemoveScheme &sipStrings_QtCore[41935]
#define sipNameNr_RightSection 18117
#define sipName_RightSection &sipStrings_QtCore[18117]
#define sipNameNr_ScrollUpdate 41948
#define sipName_ScrollUpdate &sipStrings_QtCore[41948]
#define sipNameNr_SettingsPath 41961
#define sipName_SettingsPath &sipStrings_QtCore[41961]
#define sipNameNr_ShowToParent 41974
#define sipName_ShowToParent &sipStrings_QtCore[41974]
#define sipNameNr_SizeHintRole 41987
#define sipName_SizeHintRole &sipStrings_QtCore[41987]
#define sipNameNr_SolidPattern 42000
#define sipName_SolidPattern &sipStrings_QtCore[42000]
#define sipNameNr_SouthNdebele 42013
#define sipName_SouthNdebele &sipStrings_QtCore[42013]
#define sipNameNr_SouthernSami 42026
#define sipName_SouthernSami &sipStrings_QtCore[42026]
#define sipNameNr_SplashScreen 42039
#define sipName_SplashScreen &sipStrings_QtCore[42039]
#define sipNameNr_SplitHCursor 42052
#define sipName_SplitHCursor &sipStrings_QtCore[42052]
#define sipNameNr_SplitVCursor 42065
#define sipName_SplitVCursor &sipStrings_QtCore[42065]
#define sipNameNr_StandardTime 42078
#define sipName_StandardTime &sipStrings_QtCore[42078]
#define sipNameNr_StartElement 15154
#define sipName_StartElement &sipStrings_QtCore[15154]
#define sipNameNr_StringFormat 16586
#define sipName_StringFormat &sipStrings_QtCore[16586]
#define sipNameNr_SvgMiterJoin 42091
#define sipName_SvgMiterJoin &sipStrings_QtCore[42091]
#define sipNameNr_SwipeGesture 42104
#define sipName_SwipeGesture &sipStrings_QtCore[42104]
#define sipNameNr_SyriacScript 42117
#define sipName_SyriacScript &sipStrings_QtCore[42117]
#define sipNameNr_TangutScript 42130
#define sipName_TangutScript &sipStrings_QtCore[42130]
#define sipNameNr_TeluguScript 42143
#define sipName_TeluguScript &sipStrings_QtCore[42143]
#define sipNameNr_TempLocation 42156
#define sipName_TempLocation &sipStrings_QtCore[42156]
#define sipNameNr_TextDontClip 42169
#define sipName_TextDontClip &sipStrings_QtCore[42169]
#define sipNameNr_TextEditable 42182
#define sipName_TextEditable &sipStrings_QtCore[42182]
#define sipNameNr_TextWordWrap 42195
#define sipName_TextWordWrap &sipStrings_QtCore[42195]
#define sipNameNr_ThaanaScript 42208
#define sipName_ThaanaScript &sipStrings_QtCore[42208]
#define sipNameNr_ThreadChange 42221
#define sipName_ThreadChange &sipStrings_QtCore[42221]
#define sipNameNr_TimeOutError 42234
#define sipName_TimeOutError &sipStrings_QtCore[42234]
#define sipNameNr_TitleBarArea 42247
#define sipName_TitleBarArea &sipStrings_QtCore[42247]
#define sipNameNr_TolerantMode 42260
#define sipName_TolerantMode &sipStrings_QtCore[42260]
#define sipNameNr_ToolBarAreas 25733
#define sipName_ToolBarAreas &sipStrings_QtCore[25733]
#define sipNameNr_Turkmenistan 42273
#define sipName_Turkmenistan &sipStrings_QtCore[42273]
#define sipNameNr_UnitedStates 42286
#define sipName_UnitedStates &sipStrings_QtCore[42286]
#define sipNameNr_UnknownError 42299
#define sipName_UnknownError &sipStrings_QtCore[42299]
#define sipNameNr_UpperSorbian 42312
#define sipName_UpperSorbian &sipStrings_QtCore[42312]
#define sipNameNr_WA_SetCursor 42325
#define sipName_WA_SetCursor &sipStrings_QtCore[42325]
#define sipNameNr_WA_SetLocale 42338
#define sipName_WA_SetLocale &sipStrings_QtCore[42338]
#define sipNameNr_WildcardUnix 42351
#define sipName_WildcardUnix &sipStrings_QtCore[42351]
#define sipNameNr_WindowActive 42364
#define sipName_WindowActive &sipStrings_QtCore[42364]
#define sipNameNr_WindowStates 25750
#define sipName_WindowStates &sipStrings_QtCore[25750]
#define sipNameNr_WrappedEvent 4364
#define sipName_WrappedEvent &sipStrings_QtCore[4364]
#define sipNameNr_YearMonthDay 8499
#define sipName_YearMonthDay &sipStrings_QtCore[8499]
#define sipNameNr_ZOrderChange 42377
#define sipName_ZOrderChange &sipStrings_QtCore[42377]
#define sipNameNr___contains__ 42390
#define sipName___contains__ &sipStrings_QtCore[42390]
#define sipNameNr___itruediv__ 42403
#define sipName___itruediv__ &sipStrings_QtCore[42403]
#define sipNameNr_abbreviation 42416
#define sipName_abbreviation &sipStrings_QtCore[42416]
#define sipNameNr_aboutToBlock 42429
#define sipName_aboutToBlock &sipStrings_QtCore[42429]
#define sipNameNr_aboutToClose 42442
#define sipName_aboutToClose &sipStrings_QtCore[42442]
#define sipNameNr_absolutePath 42455
#define sipName_absolutePath &sipStrings_QtCore[42455]
#define sipNameNr_addAnimation 42468
#define sipName_addAnimation &sipStrings_QtCore[42468]
#define sipNameNr_addQueryItem 42481
#define sipName_addQueryItem &sipStrings_QtCore[42481]
#define sipNameNr_allAncestors 42494
#define sipName_allAncestors &sipStrings_QtCore[42494]
#define sipNameNr_allMimeTypes 42507
#define sipName_allMimeTypes &sipStrings_QtCore[42507]
#define sipNameNr_allSelectors 42520
#define sipName_allSelectors &sipStrings_QtCore[42520]
#define sipNameNr_blockSignals 42533
#define sipName_blockSignals &sipStrings_QtCore[42533]
#define sipNameNr_bytesToWrite 42546
#define sipName_bytesToWrite &sipStrings_QtCore[42546]
#define sipNameNr_bytesWritten 42559
#define sipName_bytesWritten &sipStrings_QtCore[42559]
#define sipNameNr_canFetchMore 42572
#define sipName_canFetchMore &sipStrings_QtCore[42572]
#define sipNameNr_captureCount 42585
#define sipName_captureCount &sipStrings_QtCore[42585]
#define sipNameNr_categoryName 42598
#define sipName_categoryName &sipStrings_QtCore[42598]
#define sipNameNr_codecForHtml 42611
#define sipName_codecForHtml &sipStrings_QtCore[42611]
#define sipNameNr_codecForName 42624
#define sipName_codecForName &sipStrings_QtCore[42624]
#define sipNameNr_columnNumber 42637
#define sipName_columnNumber &sipStrings_QtCore[42637]
#define sipNameNr_columnsMoved 42650
#define sipName_columnsMoved &sipStrings_QtCore[42650]
#define sipNameNr_commonPrefix 42663
#define sipName_commonPrefix &sipStrings_QtCore[42663]
#define sipNameNr_createUuidV3 42676
#define sipName_createUuidV3 &sipStrings_QtCore[42676]
#define sipNameNr_createUuidV5 42689
#define sipName_createUuidV5 &sipStrings_QtCore[42689]
#define sipNameNr_currentFrame 42702
#define sipName_currentFrame &sipStrings_QtCore[42702]
#define sipNameNr_currentIndex 42715
#define sipName_currentIndex &sipStrings_QtCore[42715]
#define sipNameNr_currentValue 42728
#define sipName_currentValue &sipStrings_QtCore[42728]
#define sipNameNr_decimalPoint 42741
#define sipName_decimalPoint &sipStrings_QtCore[42741]
#define sipNameNr_defaultState 42754
#define sipName_defaultState &sipStrings_QtCore[42754]
#define sipNameNr_defaultValue 42767
#define sipName_defaultValue &sipStrings_QtCore[42767]
#define sipNameNr_dropMimeData 42780
#define sipName_dropMimeData &sipStrings_QtCore[42780]
#define sipNameNr_fileTemplate 42793
#define sipName_fileTemplate &sipStrings_QtCore[42793]
#define sipNameNr_filterRegExp 42806
#define sipName_filterRegExp &sipStrings_QtCore[42806]
#define sipNameNr_filterString 42819
#define sipName_filterString &sipStrings_QtCore[42819]
#define sipNameNr_findChildren 42832
#define sipName_findChildren &sipStrings_QtCore[42832]
#define sipNameNr_frameChanged 42845
#define sipName_frameChanged &sipStrings_QtCore[42845]
#define sipNameNr_frameForTime 42858
#define sipName_frameForTime &sipStrings_QtCore[42858]
#define sipNameNr_globPatterns 42871
#define sipName_globPatterns &sipStrings_QtCore[42871]
#define sipNameNr_hasAttribute 42884
#define sipName_hasAttribute &sipStrings_QtCore[42884]
#define sipNameNr_hasQueryItem 42897
#define sipName_hasQueryItem &sipStrings_QtCore[42897]
#define sipNameNr_hasSelection 42910
#define sipName_hasSelection &sipStrings_QtCore[42910]
#define sipNameNr_hasStdCppSet 42923
#define sipName_hasStdCppSet &sipStrings_QtCore[42923]
#define sipNameNr_idnWhitelist 42936
#define sipName_idnWhitelist &sipStrings_QtCore[42936]
#define sipNameNr_initialState 42949
#define sipName_initialState &sipStrings_QtCore[42949]
#define sipNameNr_initialValue 42962
#define sipName_initialValue &sipStrings_QtCore[42962]
#define sipNameNr_insertColumn 42975
#define sipName_insertColumn &sipStrings_QtCore[42975]
#define sipNameNr_interpolated 42988
#define sipName_interpolated &sipStrings_QtCore[42988]
#define sipNameNr_invokeMethod 43001
#define sipName_invokeMethod &sipStrings_QtCore[43001]
#define sipNameNr_isAtBoundary 43014
#define sipName_isAtBoundary &sipStrings_QtCore[43014]
#define sipNameNr_isCharacters 43027
#define sipName_isCharacters &sipStrings_QtCore[43027]
#define sipNameNr_isCompressed 43040
#define sipName_isCompressed &sipStrings_QtCore[43040]
#define sipNameNr_isDebugBuild 43053
#define sipName_isDebugBuild &sipStrings_QtCore[43053]
#define sipNameNr_isDesignable 43066
#define sipName_isDesignable &sipStrings_QtCore[43066]
#define sipNameNr_isEndElement 43079
#define sipName_isEndElement &sipStrings_QtCore[43079]
#define sipNameNr_isExecutable 43092
#define sipName_isExecutable &sipStrings_QtCore[43092]
#define sipNameNr_isNativePath 43105
#define sipName_isNativePath &sipStrings_QtCore[43105]
#define sipNameNr_isNormalized 43118
#define sipName_isNormalized &sipStrings_QtCore[43118]
#define sipNameNr_isRegistered 43131
#define sipName_isRegistered &sipStrings_QtCore[43131]
#define sipNameNr_isResettable 43144
#define sipName_isResettable &sipStrings_QtCore[43144]
#define sipNameNr_isScriptable 43157
#define sipName_isScriptable &sipStrings_QtCore[43157]
#define sipNameNr_isSequential 43170
#define sipName_isSequential &sipStrings_QtCore[43170]
#define sipNameNr_isSimpleType 43183
#define sipName_isSimpleType &sipStrings_QtCore[43183]
#define sipNameNr_isSingleShot 43196
#define sipName_isSingleShot &sipStrings_QtCore[43196]
#define sipNameNr_isWhitespace 43209
#define sipName_isWhitespace &sipStrings_QtCore[43209]
#define sipNameNr_isWidgetType 43222
#define sipName_isWidgetType &sipStrings_QtCore[43222]
#define sipNameNr_isWindowType 43235
#define sipName_isWindowType &sipStrings_QtCore[43235]
#define sipNameNr_lastModified 43248
#define sipName_lastModified &sipStrings_QtCore[43248]
#define sipNameNr_libraryPaths 43261
#define sipName_libraryPaths &sipStrings_QtCore[43261]
#define sipNameNr_loadFromData 43274
#define sipName_loadFromData &sipStrings_QtCore[43274]
#define sipNameNr_lockForWrite 43287
#define sipName_lockForWrite &sipStrings_QtCore[43287]
#define sipNameNr_majorVersion 43300
#define sipName_majorVersion &sipStrings_QtCore[43300]
#define sipNameNr_makeAbsolute 43313
#define sipName_makeAbsolute &sipStrings_QtCore[43313]
#define sipNameNr_mappedObject 43326
#define sipName_mappedObject &sipStrings_QtCore[43326]
#define sipNameNr_mappedString 43339
#define sipName_mappedString &sipStrings_QtCore[43339]
#define sipNameNr_mappedWidget 43352
#define sipName_mappedWidget &sipStrings_QtCore[43352]
#define sipNameNr_marginsAdded 43365
#define sipName_marginsAdded &sipStrings_QtCore[43365]
#define sipNameNr_matchOptions 43378
#define sipName_matchOptions &sipStrings_QtCore[43378]
#define sipNameNr_maxRecursion 43391
#define sipName_maxRecursion &sipStrings_QtCore[43391]
#define sipNameNr_methodOffset 43404
#define sipName_methodOffset &sipStrings_QtCore[43404]
#define sipNameNr_microVersion 43417
#define sipName_microVersion &sipStrings_QtCore[43417]
#define sipNameNr_minorVersion 43430
#define sipName_minorVersion &sipStrings_QtCore[43430]
#define sipNameNr_modelChanged 43443
#define sipName_modelChanged &sipStrings_QtCore[43443]
#define sipNameNr_monthsInYear 43456
#define sipName_monthsInYear &sipStrings_QtCore[43456]
#define sipNameNr_moveToThread 43469
#define sipName_moveToThread &sipStrings_QtCore[43469]
#define sipNameNr_moveTopRight 43482
#define sipName_moveTopRight &sipStrings_QtCore[43482]
#define sipNameNr_namespaceUri 43495
#define sipName_namespaceUri &sipStrings_QtCore[43495]
#define sipNameNr_negativeSign 43508
#define sipName_negativeSign &sipStrings_QtCore[43508]
#define sipNameNr_noforcepoint 43521
#define sipName_noforcepoint &sipStrings_QtCore[43521]
#define sipNameNr_normalVector 43534
#define sipName_normalVector &sipStrings_QtCore[43534]
#define sipNameNr_notationName 43547
#define sipName_notationName &sipStrings_QtCore[43547]
#define sipNameNr_notifySignal 43560
#define sipName_notifySignal &sipStrings_QtCore[43560]
#define sipNameNr_nsecsElapsed 43573
#define sipName_nsecsElapsed &sipStrings_QtCore[43573]
#define sipNameNr_onTransition 43586
#define sipName_onTransition &sipStrings_QtCore[43586]
#define sipNameNr_positiveSign 43599
#define sipName_positiveSign &sipStrings_QtCore[43599]
#define sipNameNr_propertyName 43612
#define sipName_propertyName &sipStrings_QtCore[43612]
#define sipNameNr_qSharedBuild 43625
#define sipName_qSharedBuild &sipStrings_QtCore[43625]
#define sipNameNr_readLineData 43638
#define sipName_readLineData &sipStrings_QtCore[43638]
#define sipNameNr_readQVariant 43651
#define sipName_readQVariant &sipStrings_QtCore[43651]
#define sipNameNr_removeColumn 43664
#define sipName_removeColumn &sipStrings_QtCore[43664]
#define sipNameNr_removeFormat 43677
#define sipName_removeFormat &sipStrings_QtCore[43677]
#define sipNameNr_retrieveData 43690
#define sipName_retrieveData &sipStrings_QtCore[43690]
#define sipNameNr_rowsInserted 43703
#define sipName_rowsInserted &sipStrings_QtCore[43703]
#define sipNameNr_segmentCount 43716
#define sipName_segmentCount &sipStrings_QtCore[43716]
#define sipNameNr_selectedRows 43729
#define sipName_selectedRows &sipStrings_QtCore[43729]
#define sipNameNr_senderObject 43742
#define sipName_senderObject &sipStrings_QtCore[43742]
#define sipNameNr_setAmplitude 43755
#define sipName_setAmplitude &sipStrings_QtCore[43755]
#define sipNameNr_setArguments 43768
#define sipName_setArguments &sipStrings_QtCore[43768]
#define sipNameNr_setAttribute 43781
#define sipName_setAttribute &sipStrings_QtCore[43781]
#define sipNameNr_setAuthority 43794
#define sipName_setAuthority &sipStrings_QtCore[43794]
#define sipNameNr_setByteOrder 43807
#define sipName_setByteOrder &sipStrings_QtCore[43807]
#define sipNameNr_setChildMode 43820
#define sipName_setChildMode &sipStrings_QtCore[43820]
#define sipNameNr_setColorData 43833
#define sipName_setColorData &sipStrings_QtCore[43833]
#define sipNameNr_setDirection 43846
#define sipName_setDirection &sipStrings_QtCore[43846]
#define sipNameNr_setEventType 43859
#define sipName_setEventType &sipStrings_QtCore[43859]
#define sipNameNr_setImageData 43872
#define sipName_setImageData &sipStrings_QtCore[43872]
#define sipNameNr_setKeyValues 43885
#define sipName_setKeyValues &sipStrings_QtCore[43885]
#define sipNameNr_setLoadHints 43898
#define sipName_setLoadHints &sipStrings_QtCore[43898]
#define sipNameNr_setLoopCount 43911
#define sipName_setLoopCount &sipStrings_QtCore[43911]
#define sipNameNr_setNativeKey 43924
#define sipName_setNativeKey &sipStrings_QtCore[43924]
#define sipNameNr_setOvershoot 43937
#define sipName_setOvershoot &sipStrings_QtCore[43937]
#define sipNameNr_setStackSize 43950
#define sipName_setStackSize &sipStrings_QtCore[43950]
#define sipNameNr_setTimerType 43963
#define sipName_setTimerType &sipStrings_QtCore[43963]
#define sipNameNr_setValueName 43976
#define sipName_setValueName &sipStrings_QtCore[43976]
#define sipNameNr_shortDayName 43989
#define sipName_shortDayName &sipStrings_QtCore[43989]
#define sipNameNr_siblingAtRow 44002
#define sipName_siblingAtRow &sipStrings_QtCore[44002]
#define sipNameNr_sourceModels 44015
#define sipName_sourceModels &sipStrings_QtCore[44015]
#define sipNameNr_stateChanged 44028
#define sipName_stateChanged &sipStrings_QtCore[44028]
#define sipNameNr_targetObject 44041
#define sipName_targetObject &sipStrings_QtCore[44041]
#define sipNameNr_targetStates 44054
#define sipName_targetStates &sipStrings_QtCore[44054]
#define sipNameNr_toBinaryData 44067
#define sipName_toBinaryData &sipStrings_QtCore[44067]
#define sipNameNr_toPyDateTime 44080
#define sipName_toPyDateTime &sipStrings_QtCore[44080]
#define sipNameNr_toSimpleType 44093
#define sipName_toSimpleType &sipStrings_QtCore[44093]
#define sipNameNr_toStringList 44106
#define sipName_toStringList &sipStrings_QtCore[44106]
#define sipNameNr_userProperty 44119
#define sipName_userProperty &sipStrings_QtCore[44119]
#define sipNameNr_valueChanged 44132
#define sipName_valueChanged &sipStrings_QtCore[44132]
#define sipNameNr_valueForTime 44145
#define sipName_valueForTime &sipStrings_QtCore[44145]
#define sipNameNr_writeComment 44158
#define sipName_writeComment &sipStrings_QtCore[44158]
#define sipNameNr_writeQString 44171
#define sipName_writeQString &sipStrings_QtCore[44171]
#define sipNameNr_writeRawData 44184
#define sipName_writeRawData &sipStrings_QtCore[44184]
#define sipNameNr_AA_Use96Dpi 44197
#define sipName_AA_Use96Dpi &sipStrings_QtCore[44197]
#define sipNameNr_AccessError 44209
#define sipName_AccessError &sipStrings_QtCore[44209]
#define sipNameNr_ActionAdded 44221
#define sipName_ActionAdded &sipStrings_QtCore[44221]
#define sipNameNr_AdlamScript 44233
#define sipName_AdlamScript &sipStrings_QtCore[44233]
#define sipNameNr_Afghanistan 44245
#define sipName_Afghanistan &sipStrings_QtCore[44245]
#define sipNameNr_AlignBottom 44257
#define sipName_AlignBottom &sipStrings_QtCore[44257]
#define sipNameNr_AlignCenter 44269
#define sipName_AlignCenter &sipStrings_QtCore[44269]
#define sipNameNr_AltModifier 44281
#define sipName_AltModifier &sipStrings_QtCore[44281]
#define sipNameNr_AnchorPoint 29218
#define sipName_AnchorPoint &sipStrings_QtCore[29218]
#define sipNameNr_AnchorRight 44293
#define sipName_AnchorRight &sipStrings_QtCore[44293]
#define sipNameNr_AndroidOreo 44305
#define sipName_AndroidOreo &sipStrings_QtCore[44305]
#define sipNameNr_AnyLanguage 44317
#define sipName_AnyLanguage &sipStrings_QtCore[44317]
#define sipNameNr_ArrowCursor 38206
#define sipName_ArrowCursor &sipStrings_QtCore[38206]
#define sipNameNr_AvoidDither 44329
#define sipName_AvoidDither &sipStrings_QtCore[44329]
#define sipNameNr_Azerbaijani 44341
#define sipName_Azerbaijani &sipStrings_QtCore[44341]
#define sipNameNr_BamumScript 44353
#define sipName_BamumScript &sipStrings_QtCore[44353]
#define sipNameNr_BatakScript 44365
#define sipName_BatakScript &sipStrings_QtCore[44365]
#define sipNameNr_BlankCursor 44377
#define sipName_BlankCursor &sipStrings_QtCore[44377]
#define sipNameNr_BuhidScript 44389
#define sipName_BuhidScript &sipStrings_QtCore[44389]
#define sipNameNr_BurkinaFaso 44401
#define sipName_BurkinaFaso &sipStrings_QtCore[44401]
#define sipNameNr_CaretAtZero 44413
#define sipName_CaretAtZero &sipStrings_QtCore[44413]
#define sipNameNr_CoarseTimer 29762
#define sipName_CoarseTimer &sipStrings_QtCore[29762]
#define sipNameNr_Compression 7595
#define sipName_Compression &sipStrings_QtCore[7595]
#define sipNameNr_Constructor 20189
#define sipName_Constructor &sipStrings_QtCore[20189]
#define sipNameNr_ContextMenu 6995
#define sipName_ContextMenu &sipStrings_QtCore[6995]
#define sipNameNr_CookIslands 44425
#define sipName_CookIslands &sipStrings_QtCore[44425]
#define sipNameNr_CosineCurve 44437
#define sipName_CosineCurve &sipStrings_QtCore[44437]
#define sipNameNr_CoverWindow 44449
#define sipName_CoverWindow &sipStrings_QtCore[44449]
#define sipNameNr_CrossCursor 44461
#define sipName_CrossCursor &sipStrings_QtCore[44461]
#define sipNameNr_CursorShape 29234
#define sipName_CursorShape &sipStrings_QtCore[29234]
#define sipNameNr_CustomError 44473
#define sipName_CustomError &sipStrings_QtCore[44473]
#define sipNameNr_DashDotLine 44485
#define sipName_DashDotLine &sipStrings_QtCore[44485]
#define sipNameNr_DecodedMode 44497
#define sipName_DecodedMode &sipStrings_QtCore[44497]
#define sipNameNr_DeepHistory 44509
#define sipName_DeepHistory &sipStrings_QtCore[44509]
#define sipNameNr_DeepNesting 44521
#define sipName_DeepNesting &sipStrings_QtCore[44521]
#define sipNameNr_DefaultName 44533
#define sipName_DefaultName &sipStrings_QtCore[44533]
#define sipNameNr_DiegoGarcia 44545
#define sipName_DiegoGarcia &sipStrings_QtCore[44545]
#define sipNameNr_DisplayRole 44557
#define sipName_DisplayRole &sipStrings_QtCore[44557]
#define sipNameNr_DropActions 15365
#define sipName_DropActions &sipStrings_QtCore[15365]
#define sipNameNr_EaseInCurve 44569
#define sipName_EaseInCurve &sipStrings_QtCore[44569]
#define sipNameNr_EasingCurve 35087
#define sipName_EasingCurve &sipStrings_QtCore[35087]
#define sipNameNr_EasternCham 44581
#define sipName_EasternCham &sipStrings_QtCore[44581]
#define sipNameNr_ElideMiddle 44593
#define sipName_ElideMiddle &sipStrings_QtCore[44593]
#define sipNameNr_EncodedCbor 44605
#define sipName_EncodedCbor &sipStrings_QtCore[44605]
#define sipNameNr_EndDocument 27519
#define sipName_EndDocument &sipStrings_QtCore[27519]
#define sipNameNr_EndOfString 44617
#define sipName_EndOfString &sipStrings_QtCore[44617]
#define sipNameNr_FixedString 15260
#define sipName_FixedString &sipStrings_QtCore[15260]
#define sipNameNr_FocusPolicy 29266
#define sipName_FocusPolicy &sipStrings_QtCore[29266]
#define sipNameNr_FocusReason 8188
#define sipName_FocusReason &sipStrings_QtCore[8188]
#define sipNameNr_FormatError 44629
#define sipName_FormatError &sipStrings_QtCore[44629]
#define sipNameNr_GenericTime 44641
#define sipName_GenericTime &sipStrings_QtCore[44641]
#define sipNameNr_GestureFlag 29298
#define sipName_GestureFlag &sipStrings_QtCore[29298]
#define sipNameNr_GestureType 12127
#define sipName_GestureType &sipStrings_QtCore[12127]
#define sipNameNr_GlobalColor 29330
#define sipName_GlobalColor &sipStrings_QtCore[29330]
#define sipNameNr_GreekScript 44653
#define sipName_GreekScript &sipStrings_QtCore[44653]
#define sipNameNr_Greenlandic 44665
#define sipName_Greenlandic &sipStrings_QtCore[44665]
#define sipNameNr_HeadersPath 44677
#define sipName_HeadersPath &sipStrings_QtCore[44677]
#define sipNameNr_HistoryType 5187
#define sipName_HistoryType &sipStrings_QtCore[5187]
#define sipNameNr_IBeamCursor 44689
#define sipName_IBeamCursor &sipStrings_QtCore[44689]
#define sipNameNr_IllegalType 44701
#define sipName_IllegalType &sipStrings_QtCore[44701]
#define sipNameNr_ImportsPath 29202
#define sipName_ImportsPath &sipStrings_QtCore[29202]
#define sipNameNr_InOutBounce 44713
#define sipName_InOutBounce &sipStrings_QtCore[44713]
#define sipNameNr_InputMethod 44725
#define sipName_InputMethod &sipStrings_QtCore[44725]
#define sipNameNr_Interlingua 44737
#define sipName_Interlingua &sipStrings_QtCore[44737]
#define sipNameNr_Interlingue 44749
#define sipName_Interlingue &sipStrings_QtCore[44749]
#define sipNameNr_InvalidSize 33887
#define sipName_InvalidSize &sipStrings_QtCore[33887]
#define sipNameNr_KeySequence 41611
#define sipName_KeySequence &sipStrings_QtCore[41611]
#define sipNameNr_Key_Backtab 44761
#define sipName_Key_Backtab &sipStrings_QtCore[44761]
#define sipNameNr_Key_Battery 44773
#define sipName_Key_Battery &sipStrings_QtCore[44773]
#define sipNameNr_Key_Control 44785
#define sipName_Key_Control &sipStrings_QtCore[44785]
#define sipNameNr_Key_Display 44797
#define sipName_Key_Display &sipStrings_QtCore[44797]
#define sipNameNr_Key_Execute 44809
#define sipName_Key_Execute &sipStrings_QtCore[44809]
#define sipNameNr_Key_Finance 44821
#define sipName_Key_Finance &sipStrings_QtCore[44821]
#define sipNameNr_Key_Forward 44833
#define sipName_Key_Forward &sipStrings_QtCore[44833]
#define sipNameNr_Key_Greater 44845
#define sipName_Key_Greater &sipStrings_QtCore[44845]
#define sipNameNr_Key_Hankaku 44857
#define sipName_Key_Hankaku &sipStrings_QtCore[44857]
#define sipNameNr_Key_History 44869
#define sipName_Key_History &sipStrings_QtCore[44869]
#define sipNameNr_Key_Hyper_L 44881
#define sipName_Key_Hyper_L &sipStrings_QtCore[44881]
#define sipNameNr_Key_Hyper_R 44893
#define sipName_Key_Hyper_R &sipStrings_QtCore[44893]
#define sipNameNr_Key_Launch0 44905
#define sipName_Key_Launch0 &sipStrings_QtCore[44905]
#define sipNameNr_Key_Launch1 44917
#define sipName_Key_Launch1 &sipStrings_QtCore[44917]
#define sipNameNr_Key_Launch2 44929
#define sipName_Key_Launch2 &sipStrings_QtCore[44929]
#define sipNameNr_Key_Launch3 44941
#define sipName_Key_Launch3 &sipStrings_QtCore[44941]
#define sipNameNr_Key_Launch4 44953
#define sipName_Key_Launch4 &sipStrings_QtCore[44953]
#define sipNameNr_Key_Launch5 44965
#define sipName_Key_Launch5 &sipStrings_QtCore[44965]
#define sipNameNr_Key_Launch6 44977
#define sipName_Key_Launch6 &sipStrings_QtCore[44977]
#define sipNameNr_Key_Launch7 44989
#define sipName_Key_Launch7 &sipStrings_QtCore[44989]
#define sipNameNr_Key_Launch8 45001
#define sipName_Key_Launch8 &sipStrings_QtCore[45001]
#define sipNameNr_Key_Launch9 45013
#define sipName_Key_Launch9 &sipStrings_QtCore[45013]
#define sipNameNr_Key_LaunchA 45025
#define sipName_Key_LaunchA &sipStrings_QtCore[45025]
#define sipNameNr_Key_LaunchB 45037
#define sipName_Key_LaunchB &sipStrings_QtCore[45037]
#define sipNameNr_Key_LaunchC 45049
#define sipName_Key_LaunchC &sipStrings_QtCore[45049]
#define sipNameNr_Key_LaunchD 45061
#define sipName_Key_LaunchD &sipStrings_QtCore[45061]
#define sipNameNr_Key_LaunchE 45073
#define sipName_Key_LaunchE &sipStrings_QtCore[45073]
#define sipNameNr_Key_LaunchF 45085
#define sipName_Key_LaunchF &sipStrings_QtCore[45085]
#define sipNameNr_Key_LaunchG 45097
#define sipName_Key_LaunchG &sipStrings_QtCore[45097]
#define sipNameNr_Key_LaunchH 45109
#define sipName_Key_LaunchH &sipStrings_QtCore[45109]
#define sipNameNr_Key_Meeting 45121
#define sipName_Key_Meeting &sipStrings_QtCore[45121]
#define sipNameNr_Key_MicMute 45133
#define sipName_Key_MicMute &sipStrings_QtCore[45133]
#define sipNameNr_Key_MySites 45145
#define sipName_Key_MySites &sipStrings_QtCore[45145]
#define sipNameNr_Key_NumLock 45157
#define sipName_Key_NumLock &sipStrings_QtCore[45157]
#define sipNameNr_Key_OpenUrl 45169
#define sipName_Key_OpenUrl &sipStrings_QtCore[45169]
#define sipNameNr_Key_Percent 45181
#define sipName_Key_Percent &sipStrings_QtCore[45181]
#define sipNameNr_Key_Printer 45193
#define sipName_Key_Printer &sipStrings_QtCore[45193]
#define sipNameNr_Key_Refresh 45205
#define sipName_Key_Refresh &sipStrings_QtCore[45205]
#define sipNameNr_Key_Standby 45217
#define sipName_Key_Standby &sipStrings_QtCore[45217]
#define sipNameNr_Key_Super_L 45229
#define sipName_Key_Super_L &sipStrings_QtCore[45229]
#define sipNameNr_Key_Super_R 45241
#define sipName_Key_Super_R &sipStrings_QtCore[45241]
#define sipNameNr_Key_Support 45253
#define sipName_Key_Support &sipStrings_QtCore[45253]
#define sipNameNr_Key_Suspend 45265
#define sipName_Key_Suspend &sipStrings_QtCore[45265]
#define sipNameNr_Key_TopMenu 45277
#define sipName_Key_TopMenu &sipStrings_QtCore[45277]
#define sipNameNr_Key_Touroku 45289
#define sipName_Key_Touroku &sipStrings_QtCore[45289]
#define sipNameNr_Key_Zenkaku 45301
#define sipName_Key_Zenkaku &sipStrings_QtCore[45301]
#define sipNameNr_Key_ZoomOut 45313
#define sipName_Key_ZoomOut &sipStrings_QtCore[45313]
#define sipNameNr_Key_cedilla 45325
#define sipName_Key_cedilla &sipStrings_QtCore[45325]
#define sipNameNr_Key_notsign 45337
#define sipName_Key_notsign &sipStrings_QtCore[45337]
#define sipNameNr_Key_onehalf 45349
#define sipName_Key_onehalf &sipStrings_QtCore[45349]
#define sipNameNr_Key_section 45361
#define sipName_Key_section &sipStrings_QtCore[45361]
#define sipNameNr_Key_unknown 45373
#define sipName_Key_unknown &sipStrings_QtCore[45373]
#define sipNameNr_KhmerScript 45385
#define sipName_KhmerScript &sipStrings_QtCore[45385]
#define sipNameNr_Kinyarwanda 45397
#define sipName_Kinyarwanda &sipStrings_QtCore[45397]
#define sipNameNr_KoyraChiini 45409
#define sipName_KoyraChiini &sipStrings_QtCore[45409]
#define sipNameNr_LannaScript 45421
#define sipName_LannaScript &sipStrings_QtCore[45421]
#define sipNameNr_LastCountry 45433
#define sipName_LastCountry &sipStrings_QtCore[45433]
#define sipNameNr_LatinScript 45445
#define sipName_LatinScript &sipStrings_QtCore[45445]
#define sipNameNr_LeftSection 21150
#define sipName_LeftSection &sipStrings_QtCore[21150]
#define sipNameNr_LeftToRight 45457
#define sipName_LeftToRight &sipStrings_QtCore[45457]
#define sipNameNr_LimbuScript 45469
#define sipName_LimbuScript &sipStrings_QtCore[45469]
#define sipNameNr_LinearCurve 45481
#define sipName_LinearCurve &sipStrings_QtCore[45481]
#define sipNameNr_LocaleAware 20740
#define sipName_LocaleAware &sipStrings_QtCore[20740]
#define sipNameNr_LowPriority 45493
#define sipName_LowPriority &sipStrings_QtCore[45493]
#define sipNameNr_LubaKatanga 45505
#define sipName_LubaKatanga &sipStrings_QtCore[45505]
#define sipNameNr_MacOSBigSur 45517
#define sipName_MacOSBigSur &sipStrings_QtCore[45517]
#define sipNameNr_MacOSMojave 45529
#define sipName_MacOSMojave &sipStrings_QtCore[45529]
#define sipNameNr_MacOSSierra 45541
#define sipName_MacOSSierra &sipStrings_QtCore[45541]
#define sipNameNr_Marshallese 45553
#define sipName_Marshallese &sipStrings_QtCore[45553]
#define sipNameNr_MaskInColor 45565
#define sipName_MaskInColor &sipStrings_QtCore[45565]
#define sipNameNr_MatchOption 1515
#define sipName_MatchOption &sipStrings_QtCore[1515]
#define sipNameNr_MatchRegExp 45577
#define sipName_MatchRegExp &sipStrings_QtCore[45577]
#define sipNameNr_MaximumSize 45589
#define sipName_MaximumSize &sipStrings_QtCore[45589]
#define sipNameNr_Mazanderani 45601
#define sipName_Mazanderani &sipStrings_QtCore[45601]
#define sipNameNr_MimeMessage 45613
#define sipName_MimeMessage &sipStrings_QtCore[45613]
#define sipNameNr_MinimumSize 45625
#define sipName_MinimumSize &sipStrings_QtCore[45625]
#define sipNameNr_MouseButton 29346
#define sipName_MouseButton &sipStrings_QtCore[29346]
#define sipNameNr_MovableType 45637
#define sipName_MovableType &sipStrings_QtCore[45637]
#define sipNameNr_Netherlands 45649
#define sipName_Netherlands &sipStrings_QtCore[45649]
#define sipNameNr_NoItemFlags 45661
#define sipName_NoItemFlags &sipStrings_QtCore[45661]
#define sipNameNr_NormalMatch 45673
#define sipName_NormalMatch &sipStrings_QtCore[45673]
#define sipNameNr_NumberFlags 7395
#define sipName_NumberFlags &sipStrings_QtCore[7395]
#define sipNameNr_OSXYosemite 45685
#define sipName_OSXYosemite &sipStrings_QtCore[45685]
#define sipNameNr_OddEvenFill 45697
#define sipName_OddEvenFill &sipStrings_QtCore[45697]
#define sipNameNr_OghamScript 45709
#define sipName_OghamScript &sipStrings_QtCore[45709]
#define sipNameNr_Orientation 3193
#define sipName_Orientation &sipStrings_QtCore[3193]
#define sipNameNr_OriyaScript 45721
#define sipName_OriyaScript &sipStrings_QtCore[45721]
#define sipNameNr_OsageScript 45733
#define sipName_OsageScript &sipStrings_QtCore[45733]
#define sipNameNr_OutInBounce 45745
#define sipName_OutInBounce &sipStrings_QtCore[45745]
#define sipNameNr_ParsingMode 22230
#define sipName_ParsingMode &sipStrings_QtCore[22230]
#define sipNameNr_PassThrough 45757
#define sipName_PassThrough &sipStrings_QtCore[45757]
#define sipNameNr_PenCapStyle 29378
#define sipName_PenCapStyle &sipStrings_QtCore[29378]
#define sipNameNr_Permissions 7295
#define sipName_Permissions &sipStrings_QtCore[7295]
#define sipNameNr_Philippines 45769
#define sipName_Philippines &sipStrings_QtCore[45769]
#define sipNameNr_PluginsPath 45781
#define sipName_PluginsPath &sipStrings_QtCore[45781]
#define sipNameNr_QBasicTimer 45793
#define sipName_QBasicTimer &sipStrings_QtCore[45793]
#define sipNameNr_QChildEvent 45805
#define sipName_QChildEvent &sipStrings_QtCore[45805]
#define sipNameNr_QColorSpace 45817
#define sipName_QColorSpace &sipStrings_QtCore[45817]
#define sipNameNr_QDataStream 45829
#define sipName_QDataStream &sipStrings_QtCore[45829]
#define sipNameNr_QFileDevice 45841
#define sipName_QFileDevice &sipStrings_QtCore[45841]
#define sipNameNr_QFinalState 45853
#define sipName_QFinalState &sipStrings_QtCore[45853]
#define sipNameNr_QJsonObject 45865
#define sipName_QJsonObject &sipStrings_QtCore[45865]
#define sipNameNr_45877 45877
#define sipName_45877 &sipStrings_QtCore[45877]
#define sipNameNr_QMetaMethod 45889
#define sipName_QMetaMethod &sipStrings_QtCore[45889]
#define sipNameNr_QMetaObject 45901
#define sipName_QMetaObject &sipStrings_QtCore[45901]
#define sipNameNr_QModelIndex 45913
#define sipName_QModelIndex &sipStrings_QtCore[45913]
#define sipNameNr_QObjectStar 45925
#define sipName_QObjectStar &sipStrings_QtCore[45925]
#define sipNameNr_QQuaternion 45937
#define sipName_QQuaternion &sipStrings_QtCore[45937]
#define sipNameNr_QReadLocker 45949
#define sipName_QReadLocker &sipStrings_QtCore[45949]
#define sipNameNr_QSizePolicy 45961
#define sipName_QSizePolicy &sipStrings_QtCore[45961]
#define sipNameNr_QStringList 27536
#define sipName_QStringList &sipStrings_QtCore[27536]
#define sipNameNr_QTextFormat 45973
#define sipName_QTextFormat &sipStrings_QtCore[45973]
#define sipNameNr_QTextLength 45985
#define sipName_QTextLength &sipStrings_QtCore[45985]
#define sipNameNr_QTextStream 45997
#define sipName_QTextStream &sipStrings_QtCore[45997]
#define sipNameNr_QThreadPool 46009
#define sipName_QThreadPool &sipStrings_QtCore[46009]
#define sipNameNr_QTimerEvent 46021
#define sipName_QTimerEvent &sipStrings_QtCore[46021]
#define sipNameNr_QTranslator 46033
#define sipName_QTranslator &sipStrings_QtCore[46033]
#define sipNameNr_QVariantMap 27553
#define sipName_QVariantMap &sipStrings_QtCore[27553]
#define sipNameNr_Q_CLASSINFO 46045
#define sipName_Q_CLASSINFO &sipStrings_QtCore[46045]
#define sipNameNr_QtSystemMsg 46057
#define sipName_QtSystemMsg &sipStrings_QtCore[46057]
#define sipNameNr_RFC2822Date 46069
#define sipName_RFC2822Date &sipStrings_QtCore[46069]
#define sipNameNr_ReadPastEnd 46081
#define sipName_ReadPastEnd &sipStrings_QtCore[46081]
#define sipNameNr_RemoveError 46093
#define sipName_RemoveError &sipStrings_QtCore[46093]
#define sipNameNr_RemoveQuery 46105
#define sipName_RemoveQuery &sipStrings_QtCore[46105]
#define sipNameNr_RenameError 46117
#define sipName_RenameError &sipStrings_QtCore[46117]
#define sipNameNr_ReplaceClip 46129
#define sipName_ReplaceClip &sipStrings_QtCore[46129]
#define sipNameNr_ResizeError 46141
#define sipName_ResizeError &sipStrings_QtCore[46141]
#define sipNameNr_RightButton 46153
#define sipName_RightButton &sipStrings_QtCore[46153]
#define sipNameNr_RightToLeft 33962
#define sipName_RightToLeft &sipStrings_QtCore[33962]
#define sipNameNr_RunicScript 46165
#define sipName_RunicScript &sipStrings_QtCore[46165]
#define sipNameNr_SaintHelena 46177
#define sipName_SaintHelena &sipStrings_QtCore[46177]
#define sipNameNr_SaintMartin 46189
#define sipName_SaintMartin &sipStrings_QtCore[46189]
#define sipNameNr_SaudiArabia 46201
#define sipName_SaudiArabia &sipStrings_QtCore[46201]
#define sipNameNr_ScrollBegin 46213
#define sipName_ScrollBegin &sipStrings_QtCore[46213]
#define sipNameNr_ScrollPhase 29394
#define sipName_ScrollPhase &sipStrings_QtCore[29394]
#define sipNameNr_ShortFormat 46225
#define sipName_ShortFormat &sipStrings_QtCore[46225]
#define sipNameNr_SierraLeone 46237
#define sipName_SierraLeone &sipStrings_QtCore[46237]
#define sipNameNr_SignalEvent 5349
#define sipName_SignalEvent &sipStrings_QtCore[5349]
#define sipNameNr_SintMaarten 46249
#define sipName_SintMaarten &sipStrings_QtCore[46249]
#define sipNameNr_SouthAfrica 46261
#define sipName_SouthAfrica &sipStrings_QtCore[46261]
#define sipNameNr_StartOfItem 46273
#define sipName_StartOfItem &sipStrings_QtCore[46273]
#define sipNameNr_StretchTile 46285
#define sipName_StretchTile &sipStrings_QtCore[46285]
#define sipNameNr_StrongFocus 46297
#define sipName_StrongFocus &sipStrings_QtCore[46297]
#define sipNameNr_StyleChange 46309
#define sipName_StyleChange &sipStrings_QtCore[46309]
#define sipNameNr_SwissGerman 46321
#define sipName_SwissGerman &sipStrings_QtCore[46321]
#define sipNameNr_Switzerland 46333
#define sipName_Switzerland &sipStrings_QtCore[46333]
#define sipNameNr_SystemScope 46345
#define sipName_SystemScope &sipStrings_QtCore[46345]
#define sipNameNr_TabletPress 46357
#define sipName_TabletPress &sipStrings_QtCore[46357]
#define sipNameNr_TaiLeScript 46369
#define sipName_TaiLeScript &sipStrings_QtCore[46369]
#define sipNameNr_TakriScript 46381
#define sipName_TakriScript &sipStrings_QtCore[46381]
#define sipNameNr_TamilScript 46393
#define sipName_TamilScript &sipStrings_QtCore[46393]
#define sipNameNr_TickCounter 46405
#define sipName_TickCounter &sipStrings_QtCore[46405]
#define sipNameNr_ToolBarArea 21186
#define sipName_ToolBarArea &sipStrings_QtCore[21186]
#define sipNameNr_ToolTipRole 46417
#define sipName_ToolTipRole &sipStrings_QtCore[46417]
#define sipNameNr_TouchCancel 46429
#define sipName_TouchCancel &sipStrings_QtCore[46429]
#define sipNameNr_TouchUpdate 46441
#define sipName_TouchUpdate &sipStrings_QtCore[46441]
#define sipNameNr_UI_FadeMenu 46453
#define sipName_UI_FadeMenu &sipStrings_QtCore[46453]
#define sipNameNr_UngrabMouse 46465
#define sipName_UngrabMouse &sipStrings_QtCore[46465]
#define sipNameNr_UnknownType 46477
#define sipName_UnknownType &sipStrings_QtCore[46477]
#define sipNameNr_Unspecified 46489
#define sipName_Unspecified &sipStrings_QtCore[46489]
#define sipNameNr_UpdateLater 46501
#define sipName_UpdateLater &sipStrings_QtCore[46501]
#define sipNameNr_WA_Disabled 46513
#define sipName_WA_Disabled &sipStrings_QtCore[46513]
#define sipNameNr_WA_SetStyle 46525
#define sipName_WA_SetStyle &sipStrings_QtCore[46525]
#define sipNameNr_WinEventAct 46537
#define sipName_WinEventAct &sipStrings_QtCore[46537]
#define sipNameNr_WinIdChange 46549
#define sipName_WinIdChange &sipStrings_QtCore[46549]
#define sipNameNr_WindingFill 46561
#define sipName_WindingFill &sipStrings_QtCore[46561]
#define sipNameNr_WindowFlags 29426
#define sipName_WindowFlags &sipStrings_QtCore[29426]
#define sipNameNr_WindowModal 46573
#define sipName_WindowModal &sipStrings_QtCore[46573]
#define sipNameNr_WindowState 29442
#define sipName_WindowState &sipStrings_QtCore[29442]
#define sipNameNr_WriteFailed 46585
#define sipName_WriteFailed &sipStrings_QtCore[46585]
#define sipNameNr___delitem__ 46597
#define sipName___delitem__ &sipStrings_QtCore[46597]
#define sipNameNr___getattr__ 46609
#define sipName___getattr__ &sipStrings_QtCore[46609]
#define sipNameNr___getitem__ 46621
#define sipName___getitem__ &sipStrings_QtCore[46621]
#define sipNameNr___setitem__ 46633
#define sipName___setitem__ &sipStrings_QtCore[46633]
#define sipNameNr___truediv__ 46645
#define sipName___truediv__ &sipStrings_QtCore[46645]
#define sipNameNr_aboutToQuit 46657
#define sipName_aboutToQuit &sipStrings_QtCore[46657]
#define sipNameNr_absoluteDir 46669
#define sipName_absoluteDir &sipStrings_QtCore[46669]
#define sipNameNr_animationAt 46681
#define sipName_animationAt &sipStrings_QtCore[46681]
#define sipNameNr_application 46693
#define sipName_application &sipStrings_QtCore[46693]
#define sipNameNr_bottomRight 46705
#define sipName_bottomRight &sipStrings_QtCore[46705]
#define sipNameNr_canReadLine 46717
#define sipName_canReadLine &sipStrings_QtCore[46717]
#define sipNameNr_capturedEnd 46729
#define sipName_capturedEnd &sipStrings_QtCore[46729]
#define sipNameNr_childGroups 46741
#define sipName_childGroups &sipStrings_QtCore[46741]
#define sipNameNr_closingDown 46753
#define sipName_closingDown &sipStrings_QtCore[46753]
#define sipNameNr_codecForMib 46765
#define sipName_codecForMib &sipStrings_QtCore[46765]
#define sipNameNr_columnCount 46777
#define sipName_columnCount &sipStrings_QtCore[46777]
#define sipNameNr_constructor 46789
#define sipName_constructor &sipStrings_QtCore[46789]
#define sipNameNr_createIndex 46801
#define sipName_createIndex &sipStrings_QtCore[46801]
#define sipNameNr_currentDate 46813
#define sipName_currentDate &sipStrings_QtCore[46813]
#define sipNameNr_currentLoop 46825
#define sipName_currentLoop &sipStrings_QtCore[46825]
#define sipNameNr_currentPath 46837
#define sipName_currentPath &sipStrings_QtCore[46837]
#define sipNameNr_currentTime 46849
#define sipName_currentTime &sipStrings_QtCore[46849]
#define sipNameNr_currentType 46861
#define sipName_currentType &sipStrings_QtCore[46861]
#define sipNameNr_customEvent 46873
#define sipName_customEvent &sipStrings_QtCore[46873]
#define sipNameNr_darkMagenta 46885
#define sipName_darkMagenta &sipStrings_QtCore[46885]
#define sipNameNr_dataChanged 46897
#define sipName_dataChanged &sipStrings_QtCore[46897]
#define sipNameNr_daysInMonth 46909
#define sipName_daysInMonth &sipStrings_QtCore[46909]
#define sipNameNr_defaultPort 46921
#define sipName_defaultPort &sipStrings_QtCore[46921]
#define sipNameNr_deleteLater 46933
#define sipName_deleteLater &sipStrings_QtCore[46933]
#define sipNameNr_description 46945
#define sipName_description &sipStrings_QtCore[46945]
#define sipNameNr_directories 33587
#define sipName_directories &sipStrings_QtCore[33587]
#define sipNameNr_displayName 46957
#define sipName_displayName &sipStrings_QtCore[46957]
#define sipNameNr_dtdPublicId 46969
#define sipName_dtdPublicId &sipStrings_QtCore[46969]
#define sipNameNr_dtdSystemId 46981
#define sipName_dtdSystemId &sipStrings_QtCore[46981]
#define sipNameNr_easingCurve 46993
#define sipName_easingCurve &sipStrings_QtCore[46993]
#define sipNameNr_endMoveRows 47005
#define sipName_endMoveRows &sipStrings_QtCore[47005]
#define sipNameNr_errorString 47017
#define sipName_errorString &sipStrings_QtCore[47017]
#define sipNameNr_eventFilter 47029
#define sipName_eventFilter &sipStrings_QtCore[47029]
#define sipNameNr_eventSource 47041
#define sipName_eventSource &sipStrings_QtCore[47041]
#define sipNameNr_exponential 47053
#define sipName_exponential &sipStrings_QtCore[47053]
#define sipNameNr_fileChanged 47065
#define sipName_fileChanged &sipStrings_QtCore[47065]
#define sipNameNr_fromEncoded 47077
#define sipName_fromEncoded &sipStrings_QtCore[47077]
#define sipNameNr_fromRawData 47089
#define sipName_fromRawData &sipStrings_QtCore[47089]
#define sipNameNr_fromRfc4122 47101
#define sipName_fromRfc4122 &sipStrings_QtCore[47101]
#define sipNameNr_fromUnicode 47113
#define sipName_fromUnicode &sipStrings_QtCore[47113]
#define sipNameNr_fromVariant 47125
#define sipName_fromVariant &sipStrings_QtCore[47125]
#define sipNameNr_getLockInfo 47137
#define sipName_getLockInfo &sipStrings_QtCore[47137]
#define sipNameNr_globalMatch 47149
#define sipName_globalMatch &sipStrings_QtCore[47149]
#define sipNameNr_handleFlags 47161
#define sipName_handleFlags &sipStrings_QtCore[47161]
#define sipNameNr_hasChildren 47173
#define sipName_hasChildren &sipStrings_QtCore[47173]
#define sipNameNr_hasFragment 47185
#define sipName_hasFragment &sipStrings_QtCore[47185]
#define sipNameNr_hasYearZero 47197
#define sipName_hasYearZero &sipStrings_QtCore[47197]
#define sipNameNr_historyType 47209
#define sipName_historyType &sipStrings_QtCore[47209]
#define sipNameNr_indexOfSlot 47221
#define sipName_indexOfSlot &sipStrings_QtCore[47221]
#define sipNameNr_insertPause 47233
#define sipName_insertPause &sipStrings_QtCore[47233]
#define sipNameNr_integerBase 47245
#define sipName_integerBase &sipStrings_QtCore[47245]
#define sipNameNr_intersected 47257
#define sipName_intersected &sipStrings_QtCore[47257]
#define sipNameNr_isByteArray 47269
#define sipName_isByteArray &sipStrings_QtCore[47269]
#define sipNameNr_isContainer 47281
#define sipName_isContainer &sipStrings_QtCore[47281]
#define sipNameNr_isDateValid 47293
#define sipName_isDateValid &sipStrings_QtCore[47293]
#define sipNameNr_isGregorian 47305
#define sipName_isGregorian &sipStrings_QtCore[47305]
#define sipNameNr_isLocalFile 47317
#define sipName_isLocalFile &sipStrings_QtCore[47317]
#define sipNameNr_isLuniSolar 47329
#define sipName_isLuniSolar &sipStrings_QtCore[47329]
#define sipNameNr_isMonotonic 47341
#define sipName_isMonotonic &sipStrings_QtCore[47341]
#define sipNameNr_isProleptic 47353
#define sipName_isProleptic &sipStrings_QtCore[47353]
#define sipNameNr_isRecursive 47365
#define sipName_isRecursive &sipStrings_QtCore[47365]
#define sipNameNr_isUndefined 47377
#define sipName_isUndefined &sipStrings_QtCore[47377]
#define sipNameNr_keysToValue 47389
#define sipName_keysToValue &sipStrings_QtCore[47389]
#define sipNameNr_lastIndexIn 47401
#define sipName_lastIndexIn &sipStrings_QtCore[47401]
#define sipNameNr_lastIndexOf 47413
#define sipName_lastIndexOf &sipStrings_QtCore[47413]
#define sipNameNr_lockForRead 47425
#define sipName_lockForRead &sipStrings_QtCore[47425]
#define sipNameNr_longDayName 47437
#define sipName_longDayName &sipStrings_QtCore[47437]
#define sipNameNr_makeDecoder 47449
#define sipName_makeDecoder &sipStrings_QtCore[47449]
#define sipNameNr_makeEncoder 47461
#define sipName_makeEncoder &sipStrings_QtCore[47461]
#define sipNameNr_mapToSource 47473
#define sipName_mapToSource &sipStrings_QtCore[47473]
#define sipNameNr_methodCount 47485
#define sipName_methodCount &sipStrings_QtCore[47485]
#define sipNameNr_methodIndex 47497
#define sipName_methodIndex &sipStrings_QtCore[47497]
#define sipNameNr_moveColumns 19961
#define sipName_moveColumns &sipStrings_QtCore[19961]
#define sipNameNr_moveToTrash 47509
#define sipName_moveToTrash &sipStrings_QtCore[47509]
#define sipNameNr_moveTopLeft 47521
#define sipName_moveTopLeft &sipStrings_QtCore[47521]
#define sipNameNr_nameFilters 47533
#define sipName_nameFilters &sipStrings_QtCore[47533]
#define sipNameNr_noforcesign 47545
#define sipName_noforcesign &sipStrings_QtCore[47545]
#define sipNameNr_numberFlags 47557
#define sipName_numberFlags &sipStrings_QtCore[47557]
#define sipNameNr_numericMode 47569
#define sipName_numericMode &sipStrings_QtCore[47569]
#define sipNameNr_optionNames 47581
#define sipName_optionNames &sipStrings_QtCore[47581]
#define sipNameNr_parentState 47593
#define sipName_parentState &sipStrings_QtCore[47593]
#define sipNameNr_pathInTrash 47605
#define sipName_pathInTrash &sipStrings_QtCore[47605]
#define sipNameNr_permissions 47617
#define sipName_permissions &sipStrings_QtCore[47617]
#define sipNameNr_productType 47629
#define sipName_productType &sipStrings_QtCore[47629]
#define sipNameNr_qSetPadChar 47641
#define sipName_qSetPadChar &sipStrings_QtCore[47641]
#define sipNameNr_qUncompress 47653
#define sipName_qUncompress &sipStrings_QtCore[47653]
#define sipNameNr_quoteString 47665
#define sipName_quoteString &sipStrings_QtCore[47665]
#define sipNameNr_readChannel 47677
#define sipName_readChannel &sipStrings_QtCore[47677]
#define sipNameNr_readQString 47689
#define sipName_readQString &sipStrings_QtCore[47689]
#define sipNameNr_readRawData 47701
#define sipName_readRawData &sipStrings_QtCore[47701]
#define sipNameNr_removePaths 47713
#define sipName_removePaths &sipStrings_QtCore[47713]
#define sipNameNr_removeState 47725
#define sipName_removeState &sipStrings_QtCore[47725]
#define sipNameNr_resetStatus 47737
#define sipName_resetStatus &sipStrings_QtCore[47737]
#define sipNameNr_rowsRemoved 47749
#define sipName_rowsRemoved &sipStrings_QtCore[47749]
#define sipNameNr_searchPaths 47761
#define sipName_searchPaths &sipStrings_QtCore[47761]
#define sipNameNr_setAccepted 47773
#define sipName_setAccepted &sipStrings_QtCore[47773]
#define sipNameNr_setAnimated 47785
#define sipName_setAnimated &sipStrings_QtCore[47785]
#define sipNameNr_setDeadline 47797
#define sipName_setDeadline &sipStrings_QtCore[47797]
#define sipNameNr_setDuration 47809
#define sipName_setDuration &sipStrings_QtCore[47809]
#define sipNameNr_setEndFrame 47821
#define sipName_setEndFrame &sipStrings_QtCore[47821]
#define sipNameNr_setEndValue 47833
#define sipName_setEndValue &sipStrings_QtCore[47833]
#define sipNameNr_setFileName 47845
#define sipName_setFileName &sipStrings_QtCore[47845]
#define sipNameNr_setFileTime 47857
#define sipName_setFileTime &sipStrings_QtCore[47857]
#define sipNameNr_setFragment 47869
#define sipName_setFragment &sipStrings_QtCore[47869]
#define sipNameNr_setIniCodec 47881
#define sipName_setIniCodec &sipStrings_QtCore[47881]
#define sipNameNr_setInterval 47893
#define sipName_setInterval &sipStrings_QtCore[47893]
#define sipNameNr_setItemData 47905
#define sipName_setItemData &sipStrings_QtCore[47905]
#define sipNameNr_setOpenMode 47917
#define sipName_setOpenMode &sipStrings_QtCore[47917]
#define sipNameNr_setPassword 47929
#define sipName_setPassword &sipStrings_QtCore[47929]
#define sipNameNr_setPosition 47941
#define sipName_setPosition &sipStrings_QtCore[47941]
#define sipNameNr_setPriority 47953
#define sipName_setPriority &sipStrings_QtCore[47953]
#define sipNameNr_setProperty 47965
#define sipName_setProperty &sipStrings_QtCore[47965]
#define sipNameNr_setSortRole 47977
#define sipName_setSortRole &sipStrings_QtCore[47977]
#define sipNameNr_setTimeSpec 47989
#define sipName_setTimeSpec &sipStrings_QtCore[47989]
#define sipNameNr_setTimeZone 48001
#define sipName_setTimeZone &sipStrings_QtCore[48001]
#define sipNameNr_setTopRight 48013
#define sipName_setTopRight &sipStrings_QtCore[48013]
#define sipNameNr_setUserInfo 48025
#define sipName_setUserInfo &sipStrings_QtCore[48025]
#define sipNameNr_setUserName 48037
#define sipName_setUserName &sipStrings_QtCore[48037]
#define sipNameNr_showVersion 48049
#define sipName_showVersion &sipStrings_QtCore[48049]
#define sipNameNr_signalIndex 48061
#define sipName_signalIndex &sipStrings_QtCore[48061]
#define sipNameNr_skipRawData 48073
#define sipName_skipRawData &sipStrings_QtCore[48073]
#define sipNameNr_sourceModel 48085
#define sipName_sourceModel &sipStrings_QtCore[48085]
#define sipNameNr_sourceState 48097
#define sipName_sourceState &sipStrings_QtCore[48097]
#define sipNameNr_spontaneous 48109
#define sipName_spontaneous &sipStrings_QtCore[48109]
#define sipNameNr_suffixIndex 48121
#define sipName_suffixIndex &sipStrings_QtCore[48121]
#define sipNameNr_targetState 48133
#define sipName_targetState &sipStrings_QtCore[48133]
#define sipNameNr_toByteArray 48145
#define sipName_toByteArray &sipStrings_QtCore[48145]
#define sipNameNr_toJulianDay 48157
#define sipName_toJulianDay &sipStrings_QtCore[48157]
#define sipNameNr_toLocalFile 48169
#define sipName_toLocalFile &sipStrings_QtCore[48169]
#define sipNameNr_toLocalTime 48181
#define sipName_toLocalTime &sipStrings_QtCore[48181]
#define sipNameNr_toULongLong 48193
#define sipName_toULongLong &sipStrings_QtCore[48193]
#define sipNameNr_tokenString 48205
#define sipName_tokenString &sipStrings_QtCore[48205]
#define sipNameNr_transitions 48217
#define sipName_transitions &sipStrings_QtCore[48217]
#define sipNameNr_transparent 48229
#define sipName_transparent &sipStrings_QtCore[48229]
#define sipNameNr_uiLanguages 48241
#define sipName_uiLanguages &sipStrings_QtCore[48241]
#define sipNameNr_updateState 48253
#define sipName_updateState &sipStrings_QtCore[48253]
#define sipNameNr_valueToKeys 48265
#define sipName_valueToKeys &sipStrings_QtCore[48265]
#define sipNameNr_waitForDone 48277
#define sipName_waitForDone &sipStrings_QtCore[48277]
#define sipNameNr_weekDayName 48289
#define sipName_weekDayName &sipStrings_QtCore[48289]
#define sipNameNr_writeDouble 48301
#define sipName_writeDouble &sipStrings_QtCore[48301]
#define sipNameNr_writeString 48313
#define sipName_writeString &sipStrings_QtCore[48313]
#define sipNameNr_writeUInt16 48325
#define sipName_writeUInt16 &sipStrings_QtCore[48325]
#define sipNameNr_writeUInt32 48337
#define sipName_writeUInt32 &sipStrings_QtCore[48337]
#define sipNameNr_writeUInt64 48349
#define sipName_writeUInt64 &sipStrings_QtCore[48349]
#define sipNameNr_AbortError 48361
#define sipName_AbortError &sipStrings_QtCore[48361]
#define sipNameNr_AccessMask 48372
#define sipName_AccessMask &sipStrings_QtCore[48372]
#define sipNameNr_AccessMode 3542
#define sipName_AccessMode &sipStrings_QtCore[3542]
#define sipNameNr_ActionMask 48383
#define sipName_ActionMask &sipStrings_QtCore[48383]
#define sipNameNr_AhomScript 48394
#define sipName_AhomScript &sipStrings_QtCore[48394]
#define sipNameNr_AlignRight 48405
#define sipName_AlignRight &sipStrings_QtCore[48405]
#define sipNameNr_AllButtons 48416
#define sipName_AllButtons &sipStrings_QtCore[48416]
#define sipNameNr_AllEntries 48427
#define sipName_AllEntries &sipStrings_QtCore[48427]
#define sipNameNr_AnchorLeft 48438
#define sipName_AnchorLeft &sipStrings_QtCore[48438]
#define sipNameNr_Antarctica 48449
#define sipName_Antarctica &sipStrings_QtCore[48449]
#define sipNameNr_AnyCountry 48460
#define sipName_AnyCountry &sipStrings_QtCore[48460]
#define sipNameNr_AutoDither 48471
#define sipName_AutoDither &sipStrings_QtCore[48471]
#define sipNameNr_Azerbaijan 48482
#define sipName_Azerbaijan &sipStrings_QtCore[48482]
#define sipNameNr_BackButton 48493
#define sipName_BackButton &sipStrings_QtCore[48493]
#define sipNameNr_Bangladesh 48504
#define sipName_Bangladesh &sipStrings_QtCore[48504]
#define sipNameNr_Belarusian 48515
#define sipName_Belarusian &sipStrings_QtCore[48515]
#define sipNameNr_BottomEdge 48526
#define sipName_BottomEdge &sipStrings_QtCore[48526]
#define sipNameNr_BrushStyle 33348
#define sipName_BrushStyle &sipStrings_QtCore[33348]
#define sipNameNr_BusyCursor 48537
#define sipName_BusyCursor &sipStrings_QtCore[48537]
#define sipNameNr_ByteString 48548
#define sipName_ByteString &sipStrings_QtCore[48548]
#define sipNameNr_COSE_Sign1 48559
#define sipName_COSE_Sign1 &sipStrings_QtCore[48559]
#define sipNameNr_ChamScript 48570
#define sipName_ChamScript &sipStrings_QtCore[48570]
#define sipNameNr_Characters 31187
#define sipName_Characters &sipStrings_QtCore[31187]
#define sipNameNr_CheckState 33363
#define sipName_CheckState &sipStrings_QtCore[33363]
#define sipNameNr_ChildAdded 48581
#define sipName_ChildAdded &sipStrings_QtCore[48581]
#define sipNameNr_ClickFocus 48592
#define sipName_ClickFocus &sipStrings_QtCore[48592]
#define sipNameNr_Connection 6896
#define sipName_Connection &sipStrings_QtCore[6896]
#define sipNameNr_CopyAction 48603
#define sipName_CopyAction &sipStrings_QtCore[48603]
#define sipNameNr_CurveShape 11996
#define sipName_CurveShape &sipStrings_QtCore[11996]
#define sipNameNr_DateFormat 33378
#define sipName_DateFormat &sipStrings_QtCore[33378]
#define sipNameNr_DropAction 33393
#define sipName_DropAction &sipStrings_QtCore[33393]
#define sipNameNr_ElSalvador 48614
#define sipName_ElSalvador &sipStrings_QtCore[48614]
#define sipNameNr_ElideRight 48625
#define sipName_ElideRight &sipStrings_QtCore[48625]
#define sipNameNr_EndElement 31203
#define sipName_EndElement &sipStrings_QtCore[31203]
#define sipNameNr_EnterKeyGo 48636
#define sipName_EnterKeyGo &sipStrings_QtCore[48636]
#define sipNameNr_Executable 34488
#define sipName_Executable &sipStrings_QtCore[34488]
#define sipNameNr_ExitStatus 14064
#define sipName_ExitStatus &sipStrings_QtCore[14064]
#define sipNameNr_FatalError 48647
#define sipName_FatalError &sipStrings_QtCore[48647]
#define sipNameNr_FontChange 11160
#define sipName_FontChange &sipStrings_QtCore[11160]
#define sipNameNr_ForcePoint 48658
#define sipName_ForcePoint &sipStrings_QtCore[48658]
#define sipNameNr_FormatType 16428
#define sipName_FormatType &sipStrings_QtCore[16428]
#define sipNameNr_Guadeloupe 48669
#define sipName_Guadeloupe &sipStrings_QtCore[48669]
#define sipNameNr_HorPattern 48680
#define sipName_HorPattern &sipStrings_QtCore[48680]
#define sipNameNr_Horizontal 48691
#define sipName_Horizontal &sipStrings_QtCore[48691]
#define sipNameNr_HoverEnter 8309
#define sipName_HoverEnter &sipStrings_QtCore[8309]
#define sipNameNr_HoverLeave 8333
#define sipName_HoverLeave &sipStrings_QtCore[8333]
#define sipNameNr_IgnoreCase 48702
#define sipName_IgnoreCase &sipStrings_QtCore[48702]
#define sipNameNr_ImQueryAll 48713
#define sipName_ImQueryAll &sipStrings_QtCore[48713]
#define sipNameNr_InOutCubic 48724
#define sipName_InOutCubic &sipStrings_QtCore[48724]
#define sipNameNr_InOutQuart 48735
#define sipName_InOutQuart &sipStrings_QtCore[48735]
#define sipNameNr_InOutQuint 48746
#define sipName_InOutQuint &sipStrings_QtCore[48746]
#define sipNameNr_Indonesian 48757
#define sipName_Indonesian &sipStrings_QtCore[48757]
#define sipNameNr_IvoryCoast 48768
#define sipName_IvoryCoast &sipStrings_QtCore[48768]
#define sipNameNr_JamoScript 48779
#define sipName_JamoScript &sipStrings_QtCore[48779]
#define sipNameNr_JsonFormat 6302
#define sipName_JsonFormat &sipStrings_QtCore[6302]
#define sipNameNr_Kazakhstan 48790
#define sipName_Kazakhstan &sipStrings_QtCore[48790]
#define sipNameNr_Keccak_224 48801
#define sipName_Keccak_224 &sipStrings_QtCore[48801]
#define sipNameNr_Keccak_256 48812
#define sipName_Keccak_256 &sipStrings_QtCore[48812]
#define sipNameNr_Keccak_384 48823
#define sipName_Keccak_384 &sipStrings_QtCore[48823]
#define sipNameNr_Keccak_512 48834
#define sipName_Keccak_512 &sipStrings_QtCore[48834]
#define sipNameNr_KeyRelease 48845
#define sipName_KeyRelease &sipStrings_QtCore[48845]
#define sipNameNr_Key_Aacute 48856
#define sipName_Key_Aacute &sipStrings_QtCore[48856]
#define sipNameNr_Key_Agrave 48867
#define sipName_Key_Agrave &sipStrings_QtCore[48867]
#define sipNameNr_Key_Atilde 48878
#define sipName_Key_Atilde &sipStrings_QtCore[48878]
#define sipNameNr_Key_BassUp 48889
#define sipName_Key_BassUp &sipStrings_QtCore[48889]
#define sipNameNr_Key_Camera 48900
#define sipName_Key_Camera &sipStrings_QtCore[48900]
#define sipNameNr_Key_Cancel 48911
#define sipName_Key_Cancel &sipStrings_QtCore[48911]
#define sipNameNr_Key_Dead_A 48922
#define sipName_Key_Dead_A &sipStrings_QtCore[48922]
#define sipNameNr_Key_Dead_E 48933
#define sipName_Key_Dead_E &sipStrings_QtCore[48933]
#define sipNameNr_Key_Dead_I 48944
#define sipName_Key_Dead_I &sipStrings_QtCore[48944]
#define sipNameNr_Key_Dead_O 48955
#define sipName_Key_Dead_O &sipStrings_QtCore[48955]
#define sipNameNr_Key_Dead_U 48966
#define sipName_Key_Dead_U &sipStrings_QtCore[48966]
#define sipNameNr_Key_Dead_a 48977
#define sipName_Key_Dead_a &sipStrings_QtCore[48977]
#define sipNameNr_Key_Dead_e 48988
#define sipName_Key_Dead_e &sipStrings_QtCore[48988]
#define sipNameNr_Key_Dead_i 48999
#define sipName_Key_Dead_i &sipStrings_QtCore[48999]
#define sipNameNr_Key_Dead_o 49010
#define sipName_Key_Dead_o &sipStrings_QtCore[49010]
#define sipNameNr_Key_Dead_u 49021
#define sipName_Key_Dead_u &sipStrings_QtCore[49021]
#define sipNameNr_Key_Delete 49032
#define sipName_Key_Delete &sipStrings_QtCore[49032]
#define sipNameNr_Key_Dollar 49043
#define sipName_Key_Dollar &sipStrings_QtCore[49043]
#define sipNameNr_Key_Eacute 49054
#define sipName_Key_Eacute &sipStrings_QtCore[49054]
#define sipNameNr_Key_Egrave 49065
#define sipName_Key_Egrave &sipStrings_QtCore[49065]
#define sipNameNr_Key_Escape 49076
#define sipName_Key_Escape &sipStrings_QtCore[49076]
#define sipNameNr_Key_Exclam 49087
#define sipName_Key_Exclam &sipStrings_QtCore[49087]
#define sipNameNr_Key_Hangul 49098
#define sipName_Key_Hangul &sipStrings_QtCore[49098]
#define sipNameNr_Key_Hangup 49109
#define sipName_Key_Hangup &sipStrings_QtCore[49109]
#define sipNameNr_Key_Henkan 49120
#define sipName_Key_Henkan &sipStrings_QtCore[49120]
#define sipNameNr_Key_Iacute 49131
#define sipName_Key_Iacute &sipStrings_QtCore[49131]
#define sipNameNr_Key_Igrave 49142
#define sipName_Key_Igrave &sipStrings_QtCore[49142]
#define sipNameNr_Key_Insert 49153
#define sipName_Key_Insert &sipStrings_QtCore[49153]
#define sipNameNr_Key_LogOff 49164
#define sipName_Key_LogOff &sipStrings_QtCore[49164]
#define sipNameNr_Key_Market 49175
#define sipName_Key_Market &sipStrings_QtCore[49175]
#define sipNameNr_Key_Massyo 49186
#define sipName_Key_Massyo &sipStrings_QtCore[49186]
#define sipNameNr_Key_MenuKB 49197
#define sipName_Key_MenuKB &sipStrings_QtCore[49197]
#define sipNameNr_Key_MenuPB 49208
#define sipName_Key_MenuPB &sipStrings_QtCore[49208]
#define sipNameNr_Key_Ntilde 49219
#define sipName_Key_Ntilde &sipStrings_QtCore[49219]
#define sipNameNr_Key_Oacute 49230
#define sipName_Key_Oacute &sipStrings_QtCore[49230]
#define sipNameNr_Key_Ograve 49241
#define sipName_Key_Ograve &sipStrings_QtCore[49241]
#define sipNameNr_Key_Option 49252
#define sipName_Key_Option &sipStrings_QtCore[49252]
#define sipNameNr_Key_Otilde 49263
#define sipName_Key_Otilde &sipStrings_QtCore[49263]
#define sipNameNr_Key_PageUp 49274
#define sipName_Key_PageUp &sipStrings_QtCore[49274]
#define sipNameNr_Key_Period 49285
#define sipName_Key_Period &sipStrings_QtCore[49285]
#define sipNameNr_Key_Reload 49296
#define sipName_Key_Reload &sipStrings_QtCore[49296]
#define sipNameNr_Key_Return 49307
#define sipName_Key_Return &sipStrings_QtCore[49307]
#define sipNameNr_Key_Romaji 49318
#define sipName_Key_Romaji &sipStrings_QtCore[49318]
#define sipNameNr_Key_Search 49329
#define sipName_Key_Search &sipStrings_QtCore[49329]
#define sipNameNr_Key_Select 49340
#define sipName_Key_Select &sipStrings_QtCore[49340]
#define sipNameNr_Key_SysReq 49351
#define sipName_Key_SysReq &sipStrings_QtCore[49351]
#define sipNameNr_Key_Travel 49362
#define sipName_Key_Travel &sipStrings_QtCore[49362]
#define sipNameNr_Key_Uacute 49373
#define sipName_Key_Uacute &sipStrings_QtCore[49373]
#define sipNameNr_Key_Ugrave 49384
#define sipName_Key_Ugrave &sipStrings_QtCore[49384]
#define sipNameNr_Key_WakeUp 49395
#define sipName_Key_WakeUp &sipStrings_QtCore[49395]
#define sipNameNr_Key_WebCam 49406
#define sipName_Key_WebCam &sipStrings_QtCore[49406]
#define sipNameNr_Key_Yacute 49417
#define sipName_Key_Yacute &sipStrings_QtCore[49417]
#define sipNameNr_Key_Yellow 49428
#define sipName_Key_Yellow &sipStrings_QtCore[49428]
#define sipNameNr_Key_ZoomIn 49439
#define sipName_Key_ZoomIn &sipStrings_QtCore[49439]
#define sipNameNr_Key_degree 49450
#define sipName_Key_degree &sipStrings_QtCore[49450]
#define sipNameNr_Key_hyphen 49461
#define sipName_Key_hyphen &sipStrings_QtCore[49461]
#define sipNameNr_Key_iTouch 49472
#define sipName_Key_iTouch &sipStrings_QtCore[49472]
#define sipNameNr_Key_macron 49483
#define sipName_Key_macron &sipStrings_QtCore[49483]
#define sipNameNr_Key_ssharp 49494
#define sipName_Key_ssharp &sipStrings_QtCore[49494]
#define sipNameNr_Kyrgyzstan 49505
#define sipName_Kyrgyzstan &sipStrings_QtCore[49505]
#define sipNameNr_LastCursor 49516
#define sipName_LastCursor &sipStrings_QtCore[49516]
#define sipNameNr_LeftButton 49527
#define sipName_LeftButton &sipStrings_QtCore[49527]
#define sipNameNr_Limburgish 49538
#define sipName_Limburgish &sipStrings_QtCore[49538]
#define sipNameNr_LinkAction 49549
#define sipName_LinkAction &sipStrings_QtCore[49549]
#define sipNameNr_Lithuanian 49560
#define sipName_Lithuanian &sipStrings_QtCore[49560]
#define sipNameNr_LocaleDate 25905
#define sipName_LocaleDate &sipStrings_QtCore[25905]
#define sipNameNr_LocateFile 49571
#define sipName_LocateFile &sipStrings_QtCore[49571]
#define sipNameNr_LongFormat 49582
#define sipName_LongFormat &sipStrings_QtCore[49582]
#define sipNameNr_Luxembourg 49593
#define sipName_Luxembourg &sipStrings_QtCore[49593]
#define sipNameNr_Macedonian 49604
#define sipName_Macedonian &sipStrings_QtCore[49604]
#define sipNameNr_Madagascar 49615
#define sipName_Madagascar &sipStrings_QtCore[49615]
#define sipNameNr_Martinique 49626
#define sipName_Martinique &sipStrings_QtCore[49626]
#define sipNameNr_MatchFlags 33408
#define sipName_MatchFlags &sipStrings_QtCore[33408]
#define sipNameNr_Mauritania 49637
#define sipName_Mauritania &sipStrings_QtCore[49637]
#define sipNameNr_MethodType 8669
#define sipName_MethodType &sipStrings_QtCore[8669]
#define sipNameNr_Micronesia 49648
#define sipName_Micronesia &sipStrings_QtCore[49648]
#define sipNameNr_Milankovic 49659
#define sipName_Milankovic &sipStrings_QtCore[49659]
#define sipNameNr_ModelIndex 11886
#define sipName_ModelIndex &sipStrings_QtCore[11886]
#define sipNameNr_ModiScript 49670
#define sipName_ModiScript &sipStrings_QtCore[49670]
#define sipNameNr_Montenegro 49681
#define sipName_Montenegro &sipStrings_QtCore[49681]
#define sipNameNr_Montserrat 49692
#define sipName_Montserrat &sipStrings_QtCore[49692]
#define sipNameNr_MoveAction 25922
#define sipName_MoveAction &sipStrings_QtCore[25922]
#define sipNameNr_Mozambique 49703
#define sipName_Mozambique &sipStrings_QtCore[49703]
#define sipNameNr_NewZealand 49714
#define sipName_NewZealand &sipStrings_QtCore[49714]
#define sipNameNr_NewaScript 49725
#define sipName_NewaScript &sipStrings_QtCore[49725]
#define sipNameNr_NoModifier 49736
#define sipName_NoModifier &sipStrings_QtCore[49736]
#define sipNameNr_NoSymLinks 49747
#define sipName_NoSymLinks &sipStrings_QtCore[49747]
#define sipNameNr_NoTabFocus 49758
#define sipName_NoTabFocus &sipStrings_QtCore[49758]
#define sipNameNr_NormalExit 49769
#define sipName_NormalExit &sipStrings_QtCore[49769]
#define sipNameNr_NorthKorea 49780
#define sipName_NorthKorea &sipStrings_QtCore[49780]
#define sipNameNr_NotRunning 49791
#define sipName_NotRunning &sipStrings_QtCore[49791]
#define sipNameNr_NumberFlag 8789
#define sipName_NumberFlag &sipStrings_QtCore[8789]
#define sipNameNr_OffsetData 12018
#define sipName_OffsetData &sipStrings_QtCore[12018]
#define sipNameNr_OffsetName 49802
#define sipName_OffsetName &sipStrings_QtCore[49802]
#define sipNameNr_OldPersian 49813
#define sipName_OldPersian &sipStrings_QtCore[49813]
#define sipNameNr_OldTurkish 49824
#define sipName_OldTurkish &sipStrings_QtCore[49824]
#define sipNameNr_OpaqueMode 49835
#define sipName_OpaqueMode &sipStrings_QtCore[49835]
#define sipNameNr_OutElastic 40572
#define sipName_OutElastic &sipStrings_QtCore[40572]
#define sipNameNr_OutInCubic 49846
#define sipName_OutInCubic &sipStrings_QtCore[49846]
#define sipNameNr_OutInQuart 49857
#define sipName_OutInQuart &sipStrings_QtCore[49857]
#define sipNameNr_OutInQuint 49868
#define sipName_OutInQuint &sipStrings_QtCore[49868]
#define sipNameNr_PanGesture 49879
#define sipName_PanGesture &sipStrings_QtCore[49879]
#define sipNameNr_Papiamento 49890
#define sipName_Papiamento &sipStrings_QtCore[49890]
#define sipNameNr_ParseError 4310
#define sipName_ParseError &sipStrings_QtCore[4310]
#define sipNameNr_Permission 8549
#define sipName_Permission &sipStrings_QtCore[8549]
#define sipNameNr_Phoenician 49901
#define sipName_Phoenician &sipStrings_QtCore[49901]
#define sipNameNr_Portuguese 49912
#define sipName_Portuguese &sipStrings_QtCore[49912]
#define sipNameNr_PrefixPath 49923
#define sipName_PrefixPath &sipStrings_QtCore[49923]
#define sipNameNr_PuertoRico 49934
#define sipName_PuertoRico &sipStrings_QtCore[49934]
#define sipNameNr_QByteArray 49945
#define sipName_QByteArray &sipStrings_QtCore[49945]
#define sipNameNr_QCborArray 49956
#define sipName_QCborArray &sipStrings_QtCore[49956]
#define sipNameNr_QCborError 49967
#define sipName_QCborError &sipStrings_QtCore[49967]
#define sipNameNr_QCborValue 49978
#define sipName_QCborValue &sipStrings_QtCore[49978]
#define sipNameNr_QEventLoop 49989
#define sipName_QEventLoop &sipStrings_QtCore[49989]
#define sipNameNr_QJsonArray 50000
#define sipName_QJsonArray &sipStrings_QtCore[50000]
#define sipNameNr_QJsonValue 50011
#define sipName_QJsonValue &sipStrings_QtCore[50011]
#define sipNameNr_50022 50022
#define sipName_50022 &sipStrings_QtCore[50022]
#define sipNameNr_QMatrix4x4 50033
#define sipName_QMatrix4x4 &sipStrings_QtCore[50033]
#define sipNameNr_QSemaphore 50044
#define sipName_QSemaphore &sipStrings_QtCore[50044]
#define sipNameNr_QStringRef 50055
#define sipName_QStringRef &sipStrings_QtCore[50055]
#define sipNameNr_QT_TR_NOOP 50066
#define sipName_QT_TR_NOOP &sipStrings_QtCore[50066]
#define sipNameNr_QT_VERSION 41482
#define sipName_QT_VERSION &sipStrings_QtCore[41482]
#define sipNameNr_QTextCodec 50077
#define sipName_QTextCodec &sipStrings_QtCore[50077]
#define sipNameNr_QTransform 50088
#define sipName_QTransform &sipStrings_QtCore[50088]
#define sipNameNr_Qt__BGMode 50099
#define sipName_Qt__BGMode &sipStrings_QtCore[50099]
#define sipNameNr_Qt__Corner 50110
#define sipName_Qt__Corner &sipStrings_QtCore[50110]
#define sipNameNr_QtDebugMsg 50121
#define sipName_QtDebugMsg &sipStrings_QtCore[50121]
#define sipNameNr_QtFatalMsg 50132
#define sipName_QtFatalMsg &sipStrings_QtCore[50132]
#define sipNameNr_Quaternion 45938
#define sipName_Quaternion &sipStrings_QtCore[45938]
#define sipNameNr_RemovePath 50143
#define sipName_RemovePath &sipStrings_QtCore[50143]
#define sipNameNr_RemovePort 50154
#define sipName_RemovePort &sipStrings_QtCore[50154]
#define sipNameNr_RepeatTile 50165
#define sipName_RepeatTile &sipStrings_QtCore[50165]
#define sipNameNr_RightArrow 50176
#define sipName_RightArrow &sipStrings_QtCore[50176]
#define sipNameNr_SaintLucia 50187
#define sipName_SaintLucia &sipStrings_QtCore[50187]
#define sipNameNr_Saurashtra 50198
#define sipName_Saurashtra &sipStrings_QtCore[50198]
#define sipNameNr_Seychelles 50209
#define sipName_Seychelles &sipStrings_QtCore[50209]
#define sipNameNr_SimpleType 21529
#define sipName_SimpleType &sipStrings_QtCore[21529]
#define sipNameNr_SizePolicy 9077
#define sipName_SizePolicy &sipStrings_QtCore[9077]
#define sipNameNr_SoftHyphen 50220
#define sipName_SoftHyphen &sipStrings_QtCore[50220]
#define sipNameNr_SortByMask 50231
#define sipName_SortByMask &sipStrings_QtCore[50231]
#define sipNameNr_SouthKorea 50242
#define sipName_SouthKorea &sipStrings_QtCore[50242]
#define sipNameNr_SouthSudan 50253
#define sipName_SouthSudan &sipStrings_QtCore[50253]
#define sipNameNr_StrictMode 50264
#define sipName_StrictMode &sipStrings_QtCore[50264]
#define sipNameNr_StringList 27537
#define sipName_StringList &sipStrings_QtCore[27537]
#define sipNameNr_SystemTime 50275
#define sipName_SystemTime &sipStrings_QtCore[50275]
#define sipNameNr_TabletMove 50286
#define sipName_TabletMove &sipStrings_QtCore[50286]
#define sipNameNr_Tajikistan 50297
#define sipName_Tajikistan &sipStrings_QtCore[50297]
#define sipNameNr_TapGesture 50308
#define sipName_TapGesture &sipStrings_QtCore[50308]
#define sipNameNr_TaskButton 50319
#define sipName_TaskButton &sipStrings_QtCore[50319]
#define sipNameNr_TextFormat 33423
#define sipName_TextFormat &sipStrings_QtCore[33423]
#define sipNameNr_TextLength 15768
#define sipName_TextLength &sipStrings_QtCore[15768]
#define sipNameNr_TextString 50330
#define sipName_TextString &sipStrings_QtCore[50330]
#define sipNameNr_ThaiScript 50341
#define sipName_ThaiScript &sipStrings_QtCore[50341]
#define sipNameNr_TopSection 50352
#define sipName_TopSection &sipStrings_QtCore[50352]
#define sipNameNr_TouchBegin 50363
#define sipName_TouchBegin &sipStrings_QtCore[50363]
#define sipNameNr_UI_General 50374
#define sipName_UI_General &sipStrings_QtCore[50374]
#define sipNameNr_Unbuffered 50385
#define sipName_Unbuffered &sipStrings_QtCore[50385]
#define sipNameNr_UnixTime_t 50396
#define sipName_UnixTime_t &sipStrings_QtCore[50396]
#define sipNameNr_Uzbekistan 50407
#define sipName_Uzbekistan &sipStrings_QtCore[50407]
#define sipNameNr_VarUnknown 50418
#define sipName_VarUnknown &sipStrings_QtCore[50418]
#define sipNameNr_VerPattern 50429
#define sipName_VerPattern &sipStrings_QtCore[50429]
#define sipNameNr_VerUnknown 50440
#define sipName_VerUnknown &sipStrings_QtCore[50440]
#define sipNameNr_Vietnamese 50451
#define sipName_Vietnamese &sipStrings_QtCore[50451]
#define sipNameNr_WA_LaidOut 50462
#define sipName_WA_LaidOut &sipStrings_QtCore[50462]
#define sipNameNr_WA_Resized 50473
#define sipName_WA_Resized &sipStrings_QtCore[50473]
#define sipNameNr_WA_SetFont 50484
#define sipName_WA_SetFont &sipStrings_QtCore[50484]
#define sipNameNr_WaitCursor 50495
#define sipName_WaitCursor &sipStrings_QtCore[50495]
#define sipNameNr_WheelFocus 50506
#define sipName_WheelFocus &sipStrings_QtCore[50506]
#define sipNameNr_WindowType 33438
#define sipName_WindowType &sipStrings_QtCore[33438]
#define sipNameNr_Windows8_1 50517
#define sipName_Windows8_1 &sipStrings_QtCore[50517]
#define sipNameNr_WithBraces 50528
#define sipName_WithBraces &sipStrings_QtCore[50528]
#define sipNameNr_WriteError 50539
#define sipName_WriteError &sipStrings_QtCore[50539]
#define sipNameNr_WriteGroup 50550
#define sipName_WriteGroup &sipStrings_QtCore[50550]
#define sipNameNr_WriteOther 50561
#define sipName_WriteOther &sipStrings_QtCore[50561]
#define sipNameNr_WriteOwner 50572
#define sipName_WriteOwner &sipStrings_QtCore[50572]
#define sipNameNr___fspath__ 50583
#define sipName___fspath__ &sipStrings_QtCore[50583]
#define sipNameNr___invert__ 50594
#define sipName___invert__ &sipStrings_QtCore[50594]
#define sipNameNr___lshift__ 50605
#define sipName___lshift__ &sipStrings_QtCore[50605]
#define sipNameNr___rshift__ 50616
#define sipName___rshift__ &sipStrings_QtCore[50616]
#define sipNameNr_addOptions 50627
#define sipName_addOptions &sipStrings_QtCore[50627]
#define sipNameNr_animations 50638
#define sipName_animations &sipStrings_QtCore[50638]
#define sipNameNr_appendNull 50649
#define sipName_appendNull &sipStrings_QtCore[50649]
#define sipNameNr_attributes 50660
#define sipName_attributes &sipStrings_QtCore[50660]
#define sipNameNr_autoDelete 50671
#define sipName_autoDelete &sipStrings_QtCore[50671]
#define sipNameNr_autoRemove 50682
#define sipName_autoRemove &sipStrings_QtCore[50682]
#define sipNameNr_beginGroup 50693
#define sipName_beginGroup &sipStrings_QtCore[50693]
#define sipNameNr_bottomLeft 50704
#define sipName_bottomLeft &sipStrings_QtCore[50704]
#define sipNameNr_bundleName 50715
#define sipName_bundleName &sipStrings_QtCore[50715]
#define sipNameNr_bytesTotal 50726
#define sipName_bytesTotal &sipStrings_QtCore[50726]
#define sipNameNr_canConvert 50737
#define sipName_canConvert &sipStrings_QtCore[50737]
#define sipNameNr_checkIndex 50748
#define sipName_checkIndex &sipStrings_QtCore[50748]
#define sipNameNr_childEvent 50759
#define sipName_childEvent &sipStrings_QtCore[50759]
#define sipNameNr_clearError 50770
#define sipName_clearError &sipStrings_QtCore[50770]
#define sipNameNr_createUuid 50781
#define sipName_createUuid &sipStrings_QtCore[50781]
#define sipNameNr_curveShape 50792
#define sipName_curveShape &sipStrings_QtCore[50792]
#define sipNameNr_customType 50803
#define sipName_customType &sipStrings_QtCore[50803]
#define sipNameNr_darkYellow 50814
#define sipName_darkYellow &sipStrings_QtCore[50814]
#define sipNameNr_dateFormat 50825
#define sipName_dateFormat &sipStrings_QtCore[50825]
#define sipNameNr_daysInYear 50836
#define sipName_daysInYear &sipStrings_QtCore[50836]
#define sipNameNr_decodeData 50847
#define sipName_decodeData &sipStrings_QtCore[50847]
#define sipNameNr_decodeName 50858
#define sipName_decodeName &sipStrings_QtCore[50858]
#define sipNameNr_disconnect 50869
#define sipName_disconnect &sipStrings_QtCore[50869]
#define sipNameNr_dotProduct 50880
#define sipName_dotProduct &sipStrings_QtCore[50880]
#define sipNameNr_encodeData 50891
#define sipName_encodeData &sipStrings_QtCore[50891]
#define sipNameNr_encodeName 50902
#define sipName_encodeName &sipStrings_QtCore[50902]
#define sipNameNr_enumerator 50913
#define sipName_enumerator &sipStrings_QtCore[50913]
#define sipNameNr_errorState 50924
#define sipName_errorState &sipStrings_QtCore[50924]
#define sipNameNr_exactMatch 50935
#define sipName_exactMatch &sipStrings_QtCore[50935]
#define sipNameNr_exitStatus 50946
#define sipName_exitStatus &sipStrings_QtCore[50946]
#define sipNameNr_expandedTo 50957
#define sipName_expandedTo &sipStrings_QtCore[50957]
#define sipNameNr_fieldWidth 50968
#define sipName_fieldWidth &sipStrings_QtCore[50968]
#define sipNameNr_filterRole 50979
#define sipName_filterRole &sipStrings_QtCore[50979]
#define sipNameNr_forcepoint 43523
#define sipName_forcepoint &sipStrings_QtCore[43523]
#define sipNameNr_fromBase64 50990
#define sipName_fromBase64 &sipStrings_QtCore[50990]
#define sipNameNr_fromString 51001
#define sipName_fromString &sipStrings_QtCore[51001]
#define sipNameNr_fromTime_t 51012
#define sipName_fromTime_t &sipStrings_QtCore[51012]
#define sipNameNr_generate64 51023
#define sipName_generate64 &sipStrings_QtCore[51023]
#define sipNameNr_hasExpired 51034
#define sipName_hasExpired &sipStrings_QtCore[51034]
#define sipNameNr_hashLength 51045
#define sipName_hashLength &sipStrings_QtCore[51045]
#define sipNameNr_headerData 51056
#define sipName_headerData &sipStrings_QtCore[51056]
#define sipNameNr_insertRows 51067
#define sipName_insertRows &sipStrings_QtCore[51067]
#define sipNameNr_internalId 51078
#define sipName_internalId &sipStrings_QtCore[51078]
#define sipNameNr_intersects 51089
#define sipName_intersects &sipStrings_QtCore[51089]
#define sipNameNr_invalidate 51100
#define sipName_invalidate &sipStrings_QtCore[51100]
#define sipNameNr_isAbsolute 51111
#define sipName_isAbsolute &sipStrings_QtCore[51111]
#define sipNameNr_isAccepted 51122
#define sipName_isAccepted &sipStrings_QtCore[51122]
#define sipNameNr_isAnimated 51133
#define sipName_isAnimated &sipStrings_QtCore[51133]
#define sipNameNr_isAttached 51144
#define sipName_isAttached &sipStrings_QtCore[51144]
#define sipNameNr_isConstant 51155
#define sipName_isConstant &sipStrings_QtCore[51155]
#define sipNameNr_isDetached 51166
#define sipName_isDetached &sipStrings_QtCore[51166]
#define sipNameNr_isEnumType 51177
#define sipName_isEnumType &sipStrings_QtCore[51177]
#define sipNameNr_isFinished 51188
#define sipName_isFinished &sipStrings_QtCore[51188]
#define sipNameNr_isFlagType 51199
#define sipName_isFlagType &sipStrings_QtCore[51199]
#define sipNameNr_isJunction 51210
#define sipName_isJunction &sipStrings_QtCore[51210]
#define sipNameNr_isLeapYear 51221
#define sipName_isLeapYear &sipStrings_QtCore[51221]
#define sipNameNr_isParentOf 51232
#define sipName_isParentOf &sipStrings_QtCore[51232]
#define sipNameNr_isPrefixOf 51243
#define sipName_isPrefixOf &sipStrings_QtCore[51243]
#define sipNameNr_isReadOnly 51254
#define sipName_isReadOnly &sipStrings_QtCore[51254]
#define sipNameNr_isReadable 51265
#define sipName_isReadable &sipStrings_QtCore[51265]
#define sipNameNr_isRelative 51276
#define sipName_isRelative &sipStrings_QtCore[51276]
#define sipNameNr_isRequired 51287
#define sipName_isRequired &sipStrings_QtCore[51287]
#define sipNameNr_isSelected 51298
#define sipName_isSelected &sipStrings_QtCore[51298]
#define sipNameNr_isShortcut 51309
#define sipName_isShortcut &sipStrings_QtCore[51309]
#define sipNameNr_isWritable 51320
#define sipName_isWritable &sipStrings_QtCore[51320]
#define sipNameNr_kernelType 51331
#define sipName_kernelType &sipStrings_QtCore[51331]
#define sipNameNr_keyToValue 51342
#define sipName_keyToValue &sipStrings_QtCore[51342]
#define sipNameNr_keyValueAt 51353
#define sipName_keyValueAt &sipStrings_QtCore[51353]
#define sipNameNr_lineNumber 51364
#define sipName_lineNumber &sipStrings_QtCore[51364]
#define sipNameNr_metaObject 51375
#define sipName_metaObject &sipStrings_QtCore[51375]
#define sipNameNr_methodType 51386
#define sipName_methodType &sipStrings_QtCore[51386]
#define sipNameNr_modelReset 51397
#define sipName_modelReset &sipStrings_QtCore[51397]
#define sipNameNr_moveBottom 51408
#define sipName_moveBottom &sipStrings_QtCore[51408]
#define sipNameNr_moveCenter 51419
#define sipName_moveCenter &sipStrings_QtCore[51419]
#define sipNameNr_moveColumn 43666
#define sipName_moveColumn &sipStrings_QtCore[43666]
#define sipNameNr_nameToType 51430
#define sipName_nameToType &sipStrings_QtCore[51430]
#define sipNameNr_normalized 51441
#define sipName_normalized &sipStrings_QtCore[51441]
#define sipNameNr_noshowbase 51452
#define sipName_noshowbase &sipStrings_QtCore[51452]
#define sipNameNr_nullDevice 51463
#define sipName_nullDevice &sipStrings_QtCore[51463]
#define sipNameNr_objectName 51474
#define sipName_objectName &sipStrings_QtCore[51474]
#define sipNameNr_offsetData 51485
#define sipName_offsetData &sipStrings_QtCore[51485]
#define sipNameNr_permission 51496
#define sipName_permission &sipStrings_QtCore[51496]
#define sipNameNr_push_front 51507
#define sipName_push_front &sipStrings_QtCore[51507]
#define sipNameNr_queryItems 51518
#define sipName_queryItems &sipStrings_QtCore[51518]
#define sipNameNr_raiseError 51529
#define sipName_raiseError &sipStrings_QtCore[51529]
#define sipNameNr_readDouble 51540
#define sipName_readDouble &sipStrings_QtCore[51540]
#define sipNameNr_readString 51551
#define sipName_readString &sipStrings_QtCore[51551]
#define sipNameNr_readUInt16 51562
#define sipName_readUInt16 &sipStrings_QtCore[51562]
#define sipNameNr_readUInt32 51573
#define sipName_readUInt32 &sipStrings_QtCore[51573]
#define sipNameNr_readUInt64 51584
#define sipName_readUInt64 &sipStrings_QtCore[51584]
#define sipNameNr_removePath 51595
#define sipName_removePath &sipStrings_QtCore[51595]
#define sipNameNr_removeRows 51606
#define sipName_removeRows &sipStrings_QtCore[51606]
#define sipNameNr_returnCode 51617
#define sipName_returnCode &sipStrings_QtCore[51617]
#define sipNameNr_returnType 51628
#define sipName_returnType &sipStrings_QtCore[51628]
#define sipNameNr_scientific 51639
#define sipName_scientific &sipStrings_QtCore[51639]
#define sipNameNr_setCaching 51650
#define sipName_setCaching &sipStrings_QtCore[51650]
#define sipNameNr_setCurrent 51661
#define sipName_setCurrent &sipStrings_QtCore[51661]
#define sipNameNr_setDefault 51672
#define sipName_setDefault &sipStrings_QtCore[51672]
#define sipNameNr_setEnabled 51683
#define sipName_setEnabled &sipStrings_QtCore[51683]
#define sipNameNr_setMapping 51694
#define sipName_setMapping &sipStrings_QtCore[51694]
#define sipNameNr_setMinimal 51705
#define sipName_setMinimal &sipStrings_QtCore[51705]
#define sipNameNr_setPadChar 51716
#define sipName_setPadChar &sipStrings_QtCore[51716]
#define sipNameNr_setPattern 51727
#define sipName_setPattern &sipStrings_QtCore[51727]
#define sipNameNr_setProgram 51738
#define sipName_setProgram &sipStrings_QtCore[51738]
#define sipNameNr_setRunning 51749
#define sipName_setRunning &sipStrings_QtCore[51749]
#define sipNameNr_setSorting 51760
#define sipName_setSorting &sipStrings_QtCore[51760]
#define sipNameNr_setTopLeft 51771
#define sipName_setTopLeft &sipStrings_QtCore[51771]
#define sipNameNr_setVersion 51782
#define sipName_setVersion &sipStrings_QtCore[51782]
#define sipNameNr_simplified 51793
#define sipName_simplified &sipStrings_QtCore[51793]
#define sipNameNr_singleShot 51804
#define sipName_singleShot &sipStrings_QtCore[51804]
#define sipNameNr_sortColumn 51815
#define sipName_sortColumn &sipStrings_QtCore[51815]
#define sipNameNr_startArray 51826
#define sipName_startArray &sipStrings_QtCore[51826]
#define sipNameNr_startFrame 51837
#define sipName_startFrame &sipStrings_QtCore[51837]
#define sipNameNr_startOfDay 51848
#define sipName_startOfDay &sipStrings_QtCore[51848]
#define sipNameNr_startTimer 51859
#define sipName_startTimer &sipStrings_QtCore[51859]
#define sipNameNr_startValue 51870
#define sipName_startValue &sipStrings_QtCore[51870]
#define sipNameNr_startingUp 51881
#define sipName_startingUp &sipStrings_QtCore[51881]
#define sipNameNr_startsWith 51892
#define sipName_startsWith &sipStrings_QtCore[51892]
#define sipNameNr_stringList 51903
#define sipName_stringList &sipStrings_QtCore[51903]
#define sipNameNr_superClass 51914
#define sipName_superClass &sipStrings_QtCore[51914]
#define sipNameNr_timeFormat 51925
#define sipName_timeFormat &sipStrings_QtCore[51925]
#define sipNameNr_timerEvent 51936
#define sipName_timerEvent &sipStrings_QtCore[51936]
#define sipNameNr_toDateTime 51947
#define sipName_toDateTime &sipStrings_QtCore[51947]
#define sipNameNr_toLongLong 51958
#define sipName_toLongLong &sipStrings_QtCore[51958]
#define sipNameNr_toTimeSpec 51969
#define sipName_toTimeSpec &sipStrings_QtCore[51969]
#define sipNameNr_toTimeZone 51980
#define sipName_toTimeZone &sipStrings_QtCore[51980]
#define sipNameNr_translated 51991
#define sipName_translated &sipStrings_QtCore[51991]
#define sipNameNr_transposed 52002
#define sipName_transposed &sipStrings_QtCore[52002]
#define sipNameNr_tryAcquire 52013
#define sipName_tryAcquire &sipStrings_QtCore[52013]
#define sipNameNr_typeToName 52024
#define sipName_typeToName &sipStrings_QtCore[52024]
#define sipNameNr_unitVector 52035
#define sipName_unitVector &sipStrings_QtCore[52035]
#define sipNameNr_unsetError 52046
#define sipName_unsetError &sipStrings_QtCore[52046]
#define sipNameNr_validation 52057
#define sipName_validation &sipStrings_QtCore[52057]
#define sipNameNr_valueToKey 52068
#define sipName_valueToKey &sipStrings_QtCore[52068]
#define sipNameNr_weekNumber 52079
#define sipName_weekNumber &sipStrings_QtCore[52079]
#define sipNameNr_writeBytes 52090
#define sipName_writeBytes &sipStrings_QtCore[52090]
#define sipNameNr_writeCDATA 52101
#define sipName_writeCDATA &sipStrings_QtCore[52101]
#define sipNameNr_writeFloat 52112
#define sipName_writeFloat &sipStrings_QtCore[52112]
#define sipNameNr_writeInt16 52123
#define sipName_writeInt16 &sipStrings_QtCore[52123]
#define sipNameNr_writeInt32 52134
#define sipName_writeInt32 &sipStrings_QtCore[52134]
#define sipNameNr_writeInt64 52145
#define sipName_writeInt64 &sipStrings_QtCore[52145]
#define sipNameNr_writeUInt8 52156
#define sipName_writeUInt8 &sipStrings_QtCore[52156]
#define sipNameNr_yearNumber 52167
#define sipName_yearNumber &sipStrings_QtCore[52167]
#define sipNameNr_Abkhazian 52178
#define sipName_Abkhazian &sipStrings_QtCore[52178]
#define sipNameNr_Afrikaans 52188
#define sipName_Afrikaans &sipStrings_QtCore[52188]
#define sipNameNr_Algorithm 2866
#define sipName_Algorithm &sipStrings_QtCore[2866]
#define sipNameNr_AlignLeft 52198
#define sipName_AlignLeft &sipStrings_QtCore[52198]
#define sipNameNr_Alignment 4423
#define sipName_Alignment &sipStrings_QtCore[4423]
#define sipNameNr_AllEvents 52208
#define sipName_AllEvents &sipStrings_QtCore[52208]
#define sipNameNr_AnchorTop 52218
#define sipName_AnchorTop &sipStrings_QtCore[52218]
#define sipNameNr_AnyScript 52228
#define sipName_AnyScript &sipStrings_QtCore[52228]
#define sipNameNr_Aragonese 52238
#define sipName_Aragonese &sipStrings_QtCore[52238]
#define sipNameNr_Argentina 52248
#define sipName_Argentina &sipStrings_QtCore[52248]
#define sipNameNr_ArrowType 37690
#define sipName_ArrowType &sipStrings_QtCore[37690]
#define sipNameNr_Australia 52258
#define sipName_Australia &sipStrings_QtCore[52258]
#define sipNameNr_AutoColor 52268
#define sipName_AutoColor &sipStrings_QtCore[52268]
#define sipNameNr_Base64url 21404
#define sipName_Base64url &sipStrings_QtCore[21404]
#define sipNameNr_BatakToba 52278
#define sipName_BatakToba &sipStrings_QtCore[52278]
#define sipNameNr_BevelJoin 52288
#define sipName_BevelJoin &sipStrings_QtCore[52288]
#define sipNameNr_BigEndian 52298
#define sipName_BigEndian &sipStrings_QtCore[52298]
#define sipNameNr_Bulgarian 52308
#define sipName_Bulgarian &sipStrings_QtCore[52308]
#define sipNameNr_ByteArray 39146
#define sipName_ByteArray &sipStrings_QtCore[39146]
#define sipNameNr_ByteOrder 10129
#define sipName_ByteOrder &sipStrings_QtCore[10129]
#define sipNameNr_COSE_Mac0 52318
#define sipName_COSE_Mac0 &sipStrings_QtCore[52318]
#define sipNameNr_COSE_Sign 52328
#define sipName_COSE_Sign &sipStrings_QtCore[52328]
#define sipNameNr_Cambodian 52338
#define sipName_Cambodian &sipStrings_QtCore[52338]
#define sipNameNr_Cantonese 52348
#define sipName_Cantonese &sipStrings_QtCore[52348]
#define sipNameNr_CapeVerde 52358
#define sipName_CapeVerde &sipStrings_QtCore[52358]
#define sipNameNr_CaretMode 19298
#define sipName_CaretMode &sipStrings_QtCore[19298]
#define sipNameNr_Chickasaw 52368
#define sipName_Chickasaw &sipStrings_QtCore[52368]
#define sipNameNr_ChildMode 22178
#define sipName_ChildMode &sipStrings_QtCore[22178]
#define sipNameNr_Clipboard 52378
#define sipName_Clipboard &sipStrings_QtCore[52378]
#define sipNameNr_ClockType 7272
#define sipName_ClockType &sipStrings_QtCore[7272]
#define sipNameNr_Colognian 52388
#define sipName_Colognian &sipStrings_QtCore[52388]
#define sipNameNr_ColorOnly 52398
#define sipName_ColorOnly &sipStrings_QtCore[52398]
#define sipNameNr_CopyError 52408
#define sipName_CopyError &sipStrings_QtCore[52408]
#define sipNameNr_CostaRica 52418
#define sipName_CostaRica &sipStrings_QtCore[52418]
#define sipNameNr_CrashExit 52428
#define sipName_CrashExit &sipStrings_QtCore[52428]
#define sipNameNr_DayOfWeek 34504
#define sipName_DayOfWeek &sipStrings_QtCore[34504]
#define sipNameNr_Direction 2836
#define sipName_Direction &sipStrings_QtCore[2836]
#define sipNameNr_DirsFirst 52438
#define sipName_DirsFirst &sipStrings_QtCore[52438]
#define sipNameNr_DownArrow 52448
#define sipName_DownArrow &sipStrings_QtCore[52448]
#define sipNameNr_DragEnter 9761
#define sipName_DragEnter &sipStrings_QtCore[9761]
#define sipNameNr_DragLeave 9784
#define sipName_DragLeave &sipStrings_QtCore[9784]
#define sipNameNr_EastTimor 52458
#define sipName_EastTimor &sipStrings_QtCore[52458]
#define sipNameNr_ElideLeft 52468
#define sipName_ElideLeft &sipStrings_QtCore[52468]
#define sipNameNr_ElideNone 52478
#define sipName_ElideNone &sipStrings_QtCore[52478]
#define sipNameNr_EndOfFile 52488
#define sipName_EndOfFile &sipStrings_QtCore[52488]
#define sipNameNr_EndOfItem 52498
#define sipName_EndOfItem &sipStrings_QtCore[52498]
#define sipNameNr_Esperanto 52508
#define sipName_Esperanto &sipStrings_QtCore[52508]
#define sipNameNr_Exception 52518
#define sipName_Exception &sipStrings_QtCore[52518]
#define sipNameNr_FileError 10152
#define sipName_FileError &sipStrings_QtCore[10152]
#define sipNameNr_ForceSign 52528
#define sipName_ForceSign &sipStrings_QtCore[52528]
#define sipNameNr_Gibraltar 52538
#define sipName_Gibraltar &sipStrings_QtCore[52538]
#define sipNameNr_GrabMouse 52548
#define sipName_GrabMouse &sipStrings_QtCore[52548]
#define sipNameNr_Greenland 52558
#define sipName_Greenland &sipStrings_QtCore[52558]
#define sipNameNr_Gregorian 47307
#define sipName_Gregorian &sipStrings_QtCore[47307]
#define sipNameNr_Guatemala 52568
#define sipName_Guatemala &sipStrings_QtCore[52568]
#define sipNameNr_HalfFloat 52578
#define sipName_HalfFloat &sipStrings_QtCore[52578]
#define sipNameNr_HanScript 14590
#define sipName_HanScript &sipStrings_QtCore[14590]
#define sipNameNr_HmongNjua 52588
#define sipName_HmongNjua &sipStrings_QtCore[52588]
#define sipNameNr_HoverMove 9807
#define sipName_HoverMove &sipStrings_QtCore[9807]
#define sipNameNr_Hungarian 52598
#define sipName_Hungarian &sipStrings_QtCore[52598]
#define sipNameNr_Icelandic 52608
#define sipName_Icelandic &sipStrings_QtCore[52608]
#define sipNameNr_ImEnabled 52618
#define sipName_ImEnabled &sipStrings_QtCore[52618]
#define sipNameNr_InElastic 41470
#define sipName_InElastic &sipStrings_QtCore[41470]
#define sipNameNr_InOutBack 52628
#define sipName_InOutBack &sipStrings_QtCore[52628]
#define sipNameNr_InOutCirc 52638
#define sipName_InOutCirc &sipStrings_QtCore[52638]
#define sipNameNr_InOutExpo 52648
#define sipName_InOutExpo &sipStrings_QtCore[52648]
#define sipNameNr_InOutQuad 52658
#define sipName_InOutQuad &sipStrings_QtCore[52658]
#define sipNameNr_InOutSine 52668
#define sipName_InOutSine &sipStrings_QtCore[52668]
#define sipNameNr_InariSami 52678
#define sipName_InariSami &sipStrings_QtCore[52678]
#define sipNameNr_Indonesia 52688
#define sipName_Indonesia &sipStrings_QtCore[52688]
#define sipNameNr_IniFormat 52698
#define sipName_IniFormat &sipStrings_QtCore[52698]
#define sipNameNr_Inuktitut 52708
#define sipName_Inuktitut &sipStrings_QtCore[52708]
#define sipNameNr_IsleOfMan 52718
#define sipName_IsleOfMan &sipStrings_QtCore[52718]
#define sipNameNr_ItemFlags 37718
#define sipName_ItemFlags &sipStrings_QtCore[37718]
#define sipNameNr_JolaFonyi 52728
#define sipName_JolaFonyi &sipStrings_QtCore[52728]
#define sipNameNr_Key_AltGr 52738
#define sipName_Key_AltGr &sipStrings_QtCore[52738]
#define sipNameNr_Key_Aring 52748
#define sipName_Key_Aring &sipStrings_QtCore[52748]
#define sipNameNr_Key_Clear 52758
#define sipName_Key_Clear &sipStrings_QtCore[52758]
#define sipNameNr_Key_Close 52768
#define sipName_Key_Close &sipStrings_QtCore[52768]
#define sipNameNr_Key_Colon 52778
#define sipName_Key_Colon &sipStrings_QtCore[52778]
#define sipNameNr_Key_Comma 52788
#define sipName_Key_Comma &sipStrings_QtCore[52788]
#define sipNameNr_Key_Eject 52798
#define sipName_Key_Eject &sipStrings_QtCore[52798]
#define sipNameNr_Key_Enter 52808
#define sipName_Key_Enter &sipStrings_QtCore[52808]
#define sipNameNr_Key_Equal 52818
#define sipName_Key_Equal &sipStrings_QtCore[52818]
#define sipNameNr_Key_Excel 52828
#define sipName_Key_Excel &sipStrings_QtCore[52828]
#define sipNameNr_Key_Green 52838
#define sipName_Key_Green &sipStrings_QtCore[52838]
#define sipNameNr_Key_Guide 52848
#define sipName_Key_Guide &sipStrings_QtCore[52848]
#define sipNameNr_Key_Kanji 52858
#define sipName_Key_Kanji &sipStrings_QtCore[52858]
#define sipNameNr_Key_Minus 52868
#define sipName_Key_Minus &sipStrings_QtCore[52868]
#define sipNameNr_Key_Music 52878
#define sipName_Key_Music &sipStrings_QtCore[52878]
#define sipNameNr_Key_Paste 52888
#define sipName_Key_Paste &sipStrings_QtCore[52888]
#define sipNameNr_Key_Pause 52898
#define sipName_Key_Pause &sipStrings_QtCore[52898]
#define sipNameNr_Key_Phone 52908
#define sipName_Key_Phone &sipStrings_QtCore[52908]
#define sipNameNr_Key_Print 52918
#define sipName_Key_Print &sipStrings_QtCore[52918]
#define sipNameNr_Key_Reply 52928
#define sipName_Key_Reply &sipStrings_QtCore[52928]
#define sipNameNr_Key_Right 52938
#define sipName_Key_Right &sipStrings_QtCore[52938]
#define sipNameNr_Key_Shift 52948
#define sipName_Key_Shift &sipStrings_QtCore[52948]
#define sipNameNr_Key_Slash 52958
#define sipName_Key_Slash &sipStrings_QtCore[52958]
#define sipNameNr_Key_Sleep 52968
#define sipName_Key_Sleep &sipStrings_QtCore[52968]
#define sipNameNr_Key_Space 52978
#define sipName_Key_Space &sipStrings_QtCore[52978]
#define sipNameNr_Key_Spell 52988
#define sipName_Key_Spell &sipStrings_QtCore[52988]
#define sipNameNr_Key_THORN 52998
#define sipName_Key_THORN &sipStrings_QtCore[52998]
#define sipNameNr_Key_Tools 53008
#define sipName_Key_Tools &sipStrings_QtCore[53008]
#define sipNameNr_Key_Video 53018
#define sipName_Key_Video &sipStrings_QtCore[53018]
#define sipNameNr_Key_acute 53028
#define sipName_Key_acute &sipStrings_QtCore[53028]
#define sipNameNr_LaoScript 53038
#define sipName_LaoScript &sipStrings_QtCore[53038]
#define sipNameNr_LeftArrow 53048
#define sipName_LeftArrow &sipStrings_QtCore[53048]
#define sipNameNr_Lithuania 53058
#define sipName_Lithuania &sipStrings_QtCore[53058]
#define sipNameNr_LoadHints 16389
#define sipName_LoadHints &sipStrings_QtCore[16389]
#define sipNameNr_LocalDate 53068
#define sipName_LocalDate &sipStrings_QtCore[53068]
#define sipNameNr_LocalTime 48183
#define sipName_LocalTime &sipStrings_QtCore[48183]
#define sipNameNr_LockError 14023
#define sipName_LockError &sipStrings_QtCore[14023]
#define sipNameNr_LowGerman 53078
#define sipName_LowGerman &sipStrings_QtCore[53078]
#define sipNameNr_MPenStyle 53088
#define sipName_MPenStyle &sipStrings_QtCore[53088]
#define sipNameNr_Macedonia 53098
#define sipName_Macedonia &sipStrings_QtCore[53098]
#define sipNameNr_Malayalam 53108
#define sipName_Malayalam &sipStrings_QtCore[53108]
#define sipNameNr_MatchFlag 37732
#define sipName_MatchFlag &sipStrings_QtCore[37732]
#define sipNameNr_MatchMode 7347
#define sipName_MatchMode &sipStrings_QtCore[7347]
#define sipNameNr_MatchType 3046
#define sipName_MatchType &sipStrings_QtCore[3046]
#define sipNameNr_MatchWrap 53118
#define sipName_MatchWrap &sipStrings_QtCore[53118]
#define sipNameNr_Matrix4x4 50034
#define sipName_Matrix4x4 &sipStrings_QtCore[50034]
#define sipNameNr_Mauritius 53128
#define sipName_Mauritius &sipStrings_QtCore[53128]
#define sipNameNr_Microsoft 53138
#define sipName_Microsoft &sipStrings_QtCore[53138]
#define sipNameNr_MidButton 53148
#define sipName_MidButton &sipStrings_QtCore[53148]
#define sipNameNr_MiterJoin 42094
#define sipName_MiterJoin &sipStrings_QtCore[42094]
#define sipNameNr_Moldavian 53158
#define sipName_Moldavian &sipStrings_QtCore[53158]
#define sipNameNr_Mongolian 53168
#define sipName_Mongolian &sipStrings_QtCore[53168]
#define sipNameNr_MouseMove 9830
#define sipName_MouseMove &sipStrings_QtCore[9830]
#define sipNameNr_MroScript 53178
#define sipName_MroScript &sipStrings_QtCore[53178]
#define sipNameNr_Ngiemboon 53188
#define sipName_Ngiemboon &sipStrings_QtCore[53188]
#define sipNameNr_Nicaragua 53198
#define sipName_Nicaragua &sipStrings_QtCore[53198]
#define sipNameNr_NkoScript 53208
#define sipName_NkoScript &sipStrings_QtCore[53208]
#define sipNameNr_NoOptions 53218
#define sipName_NoOptions &sipStrings_QtCore[53218]
#define sipNameNr_NoSection 53228
#define sipName_NoSection &sipStrings_QtCore[53228]
#define sipNameNr_Norwegian 53238
#define sipName_Norwegian &sipStrings_QtCore[53238]
#define sipNameNr_OkRequest 53248
#define sipName_OkRequest &sipStrings_QtCore[53248]
#define sipNameNr_OpenError 53258
#define sipName_OpenError &sipStrings_QtCore[53258]
#define sipNameNr_OutBounce 44715
#define sipName_OutBounce &sipStrings_QtCore[44715]
#define sipNameNr_OutInBack 53268
#define sipName_OutInBack &sipStrings_QtCore[53268]
#define sipNameNr_OutInCirc 53278
#define sipName_OutInCirc &sipStrings_QtCore[53278]
#define sipNameNr_OutInExpo 53288
#define sipName_OutInExpo &sipStrings_QtCore[53288]
#define sipNameNr_OutInQuad 53298
#define sipName_OutInQuad &sipStrings_QtCore[53298]
#define sipNameNr_OutInSine 53308
#define sipName_OutInSine &sipStrings_QtCore[53308]
#define sipNameNr_PlainText 53318
#define sipName_PlainText &sipStrings_QtCore[53318]
#define sipNameNr_Protected 53328
#define sipName_Protected &sipStrings_QtCore[53328]
#define sipNameNr_QBitArray 53338
#define sipName_QBitArray &sipStrings_QtCore[53338]
#define sipNameNr_QCalendar 53348
#define sipName_QCalendar &sipStrings_QtCore[53348]
#define sipNameNr_QCollator 53358
#define sipName_QCollator &sipStrings_QtCore[53358]
#define sipNameNr_QDateTime 53368
#define sipName_QDateTime &sipStrings_QtCore[53368]
#define sipNameNr_QFileInfo 53378
#define sipName_QFileInfo &sipStrings_QtCore[53378]
#define sipNameNr_QIODevice 53388
#define sipName_QIODevice &sipStrings_QtCore[53388]
#define sipNameNr_QLockFile 53398
#define sipName_QLockFile &sipStrings_QtCore[53398]
#define sipNameNr_QMarginsF 53408
#define sipName_QMarginsF &sipStrings_QtCore[53408]
#define sipNameNr_QMetaEnum 53418
#define sipName_QMetaEnum &sipStrings_QtCore[53418]
#define sipNameNr_QMetaType 53428
#define sipName_QMetaType &sipStrings_QtCore[53428]
#define sipNameNr_QMimeData 53438
#define sipName_QMimeData &sipStrings_QtCore[53438]
#define sipNameNr_QMimeType 53448
#define sipName_QMimeType &sipStrings_QtCore[53448]
#define sipNameNr_QPolygonF 53458
#define sipName_QPolygonF &sipStrings_QtCore[53458]
#define sipNameNr_QResource 53468
#define sipName_QResource &sipStrings_QtCore[53468]
#define sipNameNr_QRunnable 53478
#define sipName_QRunnable &sipStrings_QtCore[53478]
#define sipNameNr_QSaveFile 53488
#define sipName_QSaveFile &sipStrings_QtCore[53488]
#define sipNameNr_QSettings 53498
#define sipName_QSettings &sipStrings_QtCore[53498]
#define sipNameNr_QTimeLine 53508
#define sipName_QTimeLine &sipStrings_QtCore[53508]
#define sipNameNr_QTimeZone 53518
#define sipName_QTimeZone &sipStrings_QtCore[53518]
#define sipNameNr_QUrlQuery 53528
#define sipName_QUrlQuery &sipStrings_QtCore[53528]
#define sipNameNr_QVector2D 53538
#define sipName_QVector2D &sipStrings_QtCore[53538]
#define sipNameNr_QVector3D 53548
#define sipName_QVector3D &sipStrings_QtCore[53548]
#define sipNameNr_QVector4D 53558
#define sipName_QVector4D &sipStrings_QtCore[53558]
#define sipNameNr_Qt__Edges 53568
#define sipName_Qt__Edges &sipStrings_QtCore[53568]
#define sipNameNr_QtInfoMsg 53578
#define sipName_QtInfoMsg &sipStrings_QtCore[53578]
#define sipNameNr_QtMsgType 53588
#define sipName_QtMsgType &sipStrings_QtCore[53588]
#define sipNameNr_ReadError 53598
#define sipName_ReadError &sipStrings_QtCore[53598]
#define sipNameNr_ReadGroup 53608
#define sipName_ReadGroup &sipStrings_QtCore[53608]
#define sipNameNr_ReadOther 53618
#define sipName_ReadOther &sipStrings_QtCore[53618]
#define sipNameNr_ReadOwner 53628
#define sipName_ReadOwner &sipStrings_QtCore[53628]
#define sipNameNr_ReadWrite 53638
#define sipName_ReadWrite &sipStrings_QtCore[53638]
#define sipNameNr_Recursive 32764
#define sipName_Recursive &sipStrings_QtCore[32764]
#define sipNameNr_RightEdge 53648
#define sipName_RightEdge &sipStrings_QtCore[53648]
#define sipNameNr_RoundJoin 53658
#define sipName_RoundJoin &sipStrings_QtCore[53658]
#define sipNameNr_RoundTile 53668
#define sipName_RoundTile &sipStrings_QtCore[53668]
#define sipNameNr_Samaritan 53678
#define sipName_Samaritan &sipStrings_QtCore[53678]
#define sipNameNr_SanMarino 53688
#define sipName_SanMarino &sipStrings_QtCore[53688]
#define sipNameNr_Sardinian 53698
#define sipName_Sardinian &sipStrings_QtCore[53698]
#define sipNameNr_ScrollEnd 53708
#define sipName_ScrollEnd &sipStrings_QtCore[53708]
#define sipNameNr_ShortName 53718
#define sipName_ShortName &sipStrings_QtCore[53718]
#define sipNameNr_SichuanYi 53728
#define sipName_SichuanYi &sipStrings_QtCore[53728]
#define sipNameNr_Signature 17549
#define sipName_Signature &sipStrings_QtCore[17549]
#define sipNameNr_SineCurve 53738
#define sipName_SineCurve &sipStrings_QtCore[53738]
#define sipNameNr_Singapore 53748
#define sipName_Singapore &sipStrings_QtCore[53748]
#define sipNameNr_SkoltSami 53758
#define sipName_SkoltSami &sipStrings_QtCore[53758]
#define sipNameNr_Slovenian 53768
#define sipName_Slovenian &sipStrings_QtCore[53768]
#define sipNameNr_SolidLine 53778
#define sipName_SolidLine &sipStrings_QtCore[53778]
#define sipNameNr_SortFlags 29028
#define sipName_SortFlags &sipStrings_QtCore[29028]
#define sipNameNr_SortOrder 37746
#define sipName_SortOrder &sipStrings_QtCore[37746]
#define sipNameNr_SquareCap 53788
#define sipName_SquareCap &sipStrings_QtCore[53788]
#define sipNameNr_StatusTip 53798
#define sipName_StatusTip &sipStrings_QtCore[53798]
#define sipNameNr_SubWindow 53808
#define sipName_SubWindow &sipStrings_QtCore[53808]
#define sipNameNr_Sundanese 53818
#define sipName_Sundanese &sipStrings_QtCore[53818]
#define sipNameNr_Swaziland 53828
#define sipName_Swaziland &sipStrings_QtCore[53828]
#define sipNameNr_TCBSpline 53838
#define sipName_TCBSpline &sipStrings_QtCore[53838]
#define sipNameNr_Tachelhit 53848
#define sipName_Tachelhit &sipStrings_QtCore[53848]
#define sipNameNr_TedimChin 53858
#define sipName_TedimChin &sipStrings_QtCore[53858]
#define sipNameNr_TestsPath 53868
#define sipName_TestsPath &sipStrings_QtCore[53868]
#define sipNameNr_TimerInfo 955
#define sipName_TimerInfo &sipStrings_QtCore[955]
#define sipNameNr_TimerType 37760
#define sipName_TimerType &sipStrings_QtCore[37760]
#define sipNameNr_TokenType 4479
#define sipName_TokenType &sipStrings_QtCore[4479]
#define sipNameNr_Transform 50089
#define sipName_Transform &sipStrings_QtCore[50089]
#define sipNameNr_TypeFlags 14044
#define sipName_TypeFlags &sipStrings_QtCore[14044]
#define sipNameNr_ULongLong 48195
#define sipName_ULongLong &sipStrings_QtCore[48195]
#define sipNameNr_Ukrainian 53878
#define sipName_Ukrainian &sipStrings_QtCore[53878]
#define sipNameNr_Unchecked 53888
#define sipName_Unchecked &sipStrings_QtCore[53888]
#define sipNameNr_Undefined 9102
#define sipName_Undefined &sipStrings_QtCore[9102]
#define sipNameNr_UserScope 53898
#define sipName_UserScope &sipStrings_QtCore[53898]
#define sipNameNr_VaiScript 53908
#define sipName_VaiScript &sipStrings_QtCore[53908]
#define sipNameNr_Venezuela 53918
#define sipName_Venezuela &sipStrings_QtCore[53918]
#define sipNameNr_WA_Mapped 53928
#define sipName_WA_Mapped &sipStrings_QtCore[53928]
#define sipNameNr_Wednesday 53938
#define sipName_Wednesday &sipStrings_QtCore[53938]
#define sipNameNr_WhatsThis 19754
#define sipName_WhatsThis &sipStrings_QtCore[19754]
#define sipNameNr_Windows10 53948
#define sipName_Windows10 &sipStrings_QtCore[53948]
#define sipNameNr_WriteOnly 53958
#define sipName_WriteOnly &sipStrings_QtCore[53958]
#define sipNameNr_WriteUser 53968
#define sipName_WriteUser &sipStrings_QtCore[53968]
#define sipNameNr_YearRange 13981
#define sipName_YearRange &sipStrings_QtCore[13981]
#define sipNameNr___enter__ 53978
#define sipName___enter__ &sipStrings_QtCore[53978]
#define sipNameNr___index__ 53988
#define sipName___index__ &sipStrings_QtCore[53988]
#define sipNameNr_activated 9531
#define sipName_activated &sipStrings_QtCore[9531]
#define sipNameNr_addMonths 53998
#define sipName_addMonths &sipStrings_QtCore[53998]
#define sipNameNr_addOption 54008
#define sipName_addOption &sipStrings_QtCore[54008]
#define sipNameNr_amplitude 54018
#define sipName_amplitude &sipStrings_QtCore[54018]
#define sipNameNr_arguments 54028
#define sipName_arguments &sipStrings_QtCore[54028]
#define sipNameNr_authority 54038
#define sipName_authority &sipStrings_QtCore[54038]
#define sipNameNr_available 54048
#define sipName_available &sipStrings_QtCore[54048]
#define sipNameNr_bcp47Name 54058
#define sipName_bcp47Name &sipStrings_QtCore[54058]
#define sipNameNr_behaviour 54068
#define sipName_behaviour &sipStrings_QtCore[54068]
#define sipNameNr_birthTime 54078
#define sipName_birthTime &sipStrings_QtCore[54078]
#define sipNameNr_blockSize 54088
#define sipName_blockSize &sipStrings_QtCore[54088]
#define sipNameNr_boundedTo 54098
#define sipName_boundedTo &sipStrings_QtCore[54098]
#define sipNameNr_buildDate 54108
#define sipName_buildDate &sipStrings_QtCore[54108]
#define sipNameNr_byteOrder 54118
#define sipName_byteOrder &sipStrings_QtCore[54118]
#define sipNameNr_bytesFree 54128
#define sipName_bytesFree &sipStrings_QtCore[54128]
#define sipNameNr_canEncode 54138
#define sipName_canEncode &sipStrings_QtCore[54138]
#define sipNameNr_caretMode 54148
#define sipName_caretMode &sipStrings_QtCore[54148]
#define sipNameNr_childKeys 54158
#define sipName_childKeys &sipStrings_QtCore[54158]
#define sipNameNr_childMode 54168
#define sipName_childMode &sipStrings_QtCore[54168]
#define sipNameNr_classInfo 54178
#define sipName_classInfo &sipStrings_QtCore[54178]
#define sipNameNr_className 54188
#define sipName_className &sipStrings_QtCore[54188]
#define sipNameNr_cleanPath 54198
#define sipName_cleanPath &sipStrings_QtCore[54198]
#define sipNameNr_clockType 54208
#define sipName_clockType &sipStrings_QtCore[54208]
#define sipNameNr_collation 54218
#define sipName_collation &sipStrings_QtCore[54218]
#define sipNameNr_colorData 54228
#define sipName_colorData &sipStrings_QtCore[54228]
#define sipNameNr_constData 54238
#define sipName_constData &sipStrings_QtCore[54238]
#define sipNameNr_darkGreen 54248
#define sipName_darkGreen &sipStrings_QtCore[54248]
#define sipNameNr_dayOfWeek 54258
#define sipName_dayOfWeek &sipStrings_QtCore[54258]
#define sipNameNr_dayOfYear 54268
#define sipName_dayOfYear &sipStrings_QtCore[54268]
#define sipNameNr_destroyed 54278
#define sipName_destroyed &sipStrings_QtCore[54278]
#define sipNameNr_direction 54288
#define sipName_direction &sipStrings_QtCore[54288]
#define sipNameNr_directory 54298
#define sipName_directory &sipStrings_QtCore[54298]
#define sipNameNr_entryList 54308
#define sipName_entryList &sipStrings_QtCore[54308]
#define sipNameNr_errorText 54318
#define sipName_errorText &sipStrings_QtCore[54318]
#define sipNameNr_eventTest 54328
#define sipName_eventTest &sipStrings_QtCore[54328]
#define sipNameNr_eventType 54338
#define sipName_eventType &sipStrings_QtCore[54338]
#define sipNameNr_fetchMore 54348
#define sipName_fetchMore &sipStrings_QtCore[54348]
#define sipNameNr_findChild 54358
#define sipName_findChild &sipStrings_QtCore[54358]
#define sipNameNr_forcesign 47547
#define sipName_forcesign &sipStrings_QtCore[47547]
#define sipNameNr_fromPolar 54368
#define sipName_fromPolar &sipStrings_QtCore[54368]
#define sipNameNr_getCoords 54378
#define sipName_getCoords &sipStrings_QtCore[54378]
#define sipNameNr_hasFormat 54388
#define sipName_hasFormat &sipStrings_QtCore[54388]
#define sipNameNr_imageData 54398
#define sipName_imageData &sipStrings_QtCore[54398]
#define sipNameNr_insertRow 54408
#define sipName_insertRow &sipStrings_QtCore[54408]
#define sipNameNr_interrupt 54418
#define sipName_interrupt &sipStrings_QtCore[54418]
#define sipNameNr_intersect 54428
#define sipName_intersect &sipStrings_QtCore[54428]
#define sipNameNr_isComment 54438
#define sipName_isComment &sipStrings_QtCore[54438]
#define sipNameNr_isDefault 54448
#define sipName_isDefault &sipStrings_QtCore[54448]
#define sipNameNr_isEnabled 54458
#define sipName_isEnabled &sipStrings_QtCore[54458]
#define sipNameNr_isFloat16 54468
#define sipName_isFloat16 &sipStrings_QtCore[54468]
#define sipNameNr_isForever 54478
#define sipName_isForever &sipStrings_QtCore[54478]
#define sipNameNr_isInteger 54488
#define sipName_isInteger &sipStrings_QtCore[54488]
#define sipNameNr_isInvalid 54498
#define sipName_isInvalid &sipStrings_QtCore[54498]
#define sipNameNr_isLibrary 54508
#define sipName_isLibrary &sipStrings_QtCore[54508]
#define sipNameNr_isMinimal 54518
#define sipName_isMinimal &sipStrings_QtCore[54518]
#define sipNameNr_isRunning 54528
#define sipName_isRunning &sipStrings_QtCore[54528]
#define sipNameNr_isSymLink 54538
#define sipName_isSymLink &sipStrings_QtCore[54538]
#define sipNameNr_keyValues 54548
#define sipName_keyValues &sipStrings_QtCore[54548]
#define sipNameNr_killTimer 54558
#define sipName_killTimer &sipStrings_QtCore[54558]
#define sipNameNr_lastError 54568
#define sipName_lastError &sipStrings_QtCore[54568]
#define sipNameNr_lightGray 54578
#define sipName_lightGray &sipStrings_QtCore[54578]
#define sipNameNr_loadHints 54588
#define sipName_loadHints &sipStrings_QtCore[54588]
#define sipNameNr_locateAll 54598
#define sipName_locateAll &sipStrings_QtCore[54598]
#define sipNameNr_loopCount 54608
#define sipName_loopCount &sipStrings_QtCore[54608]
#define sipNameNr_loopLevel 54618
#define sipName_loopLevel &sipStrings_QtCore[54618]
#define sipNameNr_mappedInt 54628
#define sipName_mappedInt &sipStrings_QtCore[54628]
#define sipNameNr_matchType 54638
#define sipName_matchType &sipStrings_QtCore[54638]
#define sipNameNr_maxLength 54648
#define sipName_maxLength &sipStrings_QtCore[54648]
#define sipNameNr_mimeTypes 54658
#define sipName_mimeTypes &sipStrings_QtCore[54658]
#define sipNameNr_monthName 54668
#define sipName_monthName &sipStrings_QtCore[54668]
#define sipNameNr_moveRight 54678
#define sipName_moveRight &sipStrings_QtCore[54678]
#define sipNameNr_nativeKey 54688
#define sipName_nativeKey &sipStrings_QtCore[54688]
#define sipNameNr_overshoot 54698
#define sipName_overshoot &sipStrings_QtCore[54698]
#define sipNameNr_postEvent 54708
#define sipName_postEvent &sipStrings_QtCore[54708]
#define sipNameNr_precision 54718
#define sipName_precision &sipStrings_QtCore[54718]
#define sipNameNr_processId 54728
#define sipName_processId &sipStrings_QtCore[54728]
#define sipNameNr_push_back 54738
#define sipName_push_back &sipStrings_QtCore[54738]
#define sipNameNr_qChecksum 54748
#define sipName_qChecksum &sipStrings_QtCore[54748]
#define sipNameNr_qCompress 54758
#define sipName_qCompress &sipStrings_QtCore[54758]
#define sipNameNr_qCritical 54768
#define sipName_qCritical &sipStrings_QtCore[54768]
#define sipNameNr_qIsFinite 54778
#define sipName_qIsFinite &sipStrings_QtCore[54778]
#define sipNameNr_readBytes 54788
#define sipName_readBytes &sipStrings_QtCore[54788]
#define sipNameNr_readFloat 54798
#define sipName_readFloat &sipStrings_QtCore[54798]
#define sipNameNr_readInt16 54808
#define sipName_readInt16 &sipStrings_QtCore[54808]
#define sipNameNr_readInt32 54818
#define sipName_readInt32 &sipStrings_QtCore[54818]
#define sipNameNr_readInt64 54828
#define sipName_readInt64 &sipStrings_QtCore[54828]
#define sipNameNr_readUInt8 54838
#define sipName_readUInt8 &sipStrings_QtCore[54838]
#define sipNameNr_readyRead 54848
#define sipName_readyRead &sipStrings_QtCore[54848]
#define sipNameNr_receivers 54858
#define sipName_receivers &sipStrings_QtCore[54858]
#define sipNameNr_removeAll 54868
#define sipName_removeAll &sipStrings_QtCore[54868]
#define sipNameNr_removeRow 54878
#define sipName_removeRow &sipStrings_QtCore[54878]
#define sipNameNr_roleNames 54888
#define sipName_roleNames &sipStrings_QtCore[54888]
#define sipNameNr_rowsMoved 54898
#define sipName_rowsMoved &sipStrings_QtCore[54898]
#define sipNameNr_segmentAt 54908
#define sipName_segmentAt &sipStrings_QtCore[54908]
#define sipNameNr_selection 54918
#define sipName_selection &sipStrings_QtCore[54918]
#define sipNameNr_semaphore 54928
#define sipName_semaphore &sipStrings_QtCore[54928]
#define sipNameNr_sendEvent 54938
#define sipName_sendEvent &sipStrings_QtCore[54938]
#define sipNameNr_separator 54948
#define sipName_separator &sipStrings_QtCore[54948]
#define sipNameNr_setBottom 54958
#define sipName_setBottom &sipStrings_QtCore[54958]
#define sipNameNr_setBuffer 54968
#define sipName_setBuffer &sipStrings_QtCore[54968]
#define sipNameNr_setCoords 54978
#define sipName_setCoords &sipStrings_QtCore[54978]
#define sipNameNr_setDevice 54988
#define sipName_setDevice &sipStrings_QtCore[54988]
#define sipNameNr_setFilter 54998
#define sipName_setFilter &sipStrings_QtCore[54998]
#define sipNameNr_setHeight 55008
#define sipName_setHeight &sipStrings_QtCore[55008]
#define sipNameNr_setHidden 55018
#define sipName_setHidden &sipStrings_QtCore[55018]
#define sipNameNr_setLength 55028
#define sipName_setLength &sipStrings_QtCore[55028]
#define sipNameNr_setLocale 55038
#define sipName_setLocale &sipStrings_QtCore[55038]
#define sipNameNr_setObject 55048
#define sipName_setObject &sipStrings_QtCore[55048]
#define sipNameNr_setParent 55058
#define sipName_setParent &sipStrings_QtCore[55058]
#define sipNameNr_setPaused 55068
#define sipName_setPaused &sipStrings_QtCore[55068]
#define sipNameNr_setPeriod 55078
#define sipName_setPeriod &sipStrings_QtCore[55078]
#define sipNameNr_setPoints 55088
#define sipName_setPoints &sipStrings_QtCore[55088]
#define sipNameNr_setScheme 55098
#define sipName_setScheme &sipStrings_QtCore[55098]
#define sipNameNr_setSignal 55108
#define sipName_setSignal &sipStrings_QtCore[55108]
#define sipNameNr_setStatus 47739
#define sipName_setStatus &sipStrings_QtCore[47739]
#define sipNameNr_setTime_t 55118
#define sipName_setTime_t &sipStrings_QtCore[55118]
#define sipNameNr_sortOrder 55128
#define sipName_sortOrder &sipStrings_QtCore[55128]
#define sipNameNr_stackSize 55138
#define sipName_stackSize &sipStrings_QtCore[55138]
#define sipNameNr_subvolume 55148
#define sipName_subvolume &sipStrings_QtCore[55148]
#define sipNameNr_takeFirst 55158
#define sipName_takeFirst &sipStrings_QtCore[55158]
#define sipNameNr_terminate 55168
#define sipName_terminate &sipStrings_QtCore[55168]
#define sipNameNr_timerType 55178
#define sipName_timerType &sipStrings_QtCore[55178]
#define sipNameNr_toEncoded 55188
#define sipName_toEncoded &sipStrings_QtCore[55188]
#define sipNameNr_toInteger 55198
#define sipName_toInteger &sipStrings_QtCore[55198]
#define sipNameNr_toMargins 55208
#define sipName_toMargins &sipStrings_QtCore[55208]
#define sipNameNr_toRfc4122 55218
#define sipName_toRfc4122 &sipStrings_QtCore[55218]
#define sipNameNr_toUnicode 55228
#define sipName_toUnicode &sipStrings_QtCore[55228]
#define sipNameNr_toVariant 55238
#define sipName_toVariant &sipStrings_QtCore[55238]
#define sipNameNr_toggleBit 55248
#define sipName_toggleBit &sipStrings_QtCore[55248]
#define sipNameNr_tokenType 55258
#define sipName_tokenType &sipStrings_QtCore[55258]
#define sipNameNr_translate 55268
#define sipName_translate &sipStrings_QtCore[55268]
#define sipNameNr_transpose 55278
#define sipName_transpose &sipStrings_QtCore[55278]
#define sipNameNr_triggered 55288
#define sipName_triggered &sipStrings_QtCore[55288]
#define sipNameNr_typeFlags 55298
#define sipName_typeFlags &sipStrings_QtCore[55298]
#define sipNameNr_ungetChar 55308
#define sipName_ungetChar &sipStrings_QtCore[55308]
#define sipNameNr_valueName 55318
#define sipName_valueName &sipStrings_QtCore[55318]
#define sipNameNr_writeBool 55328
#define sipName_writeBool &sipStrings_QtCore[55328]
#define sipNameNr_writeData 55338
#define sipName_writeData &sipStrings_QtCore[55338]
#define sipNameNr_writeInt8 55348
#define sipName_writeInt8 &sipStrings_QtCore[55348]
#define sipNameNr_zeroDigit 55358
#define sipName_zeroDigit &sipStrings_QtCore[55358]
#define sipNameNr_Akkadian 55368
#define sipName_Akkadian &sipStrings_QtCore[55368]
#define sipNameNr_Albanian 55377
#define sipName_Albanian &sipStrings_QtCore[55377]
#define sipNameNr_AlignTop 55386
#define sipName_AlignTop &sipStrings_QtCore[55386]
#define sipNameNr_Anguilla 55395
#define sipName_Anguilla &sipStrings_QtCore[55395]
#define sipNameNr_Armenian 55404
#define sipName_Armenian &sipStrings_QtCore[55404]
#define sipNameNr_Assamese 55413
#define sipName_Assamese &sipStrings_QtCore[55413]
#define sipNameNr_Asturian 55422
#define sipName_Asturian &sipStrings_QtCore[55422]
#define sipNameNr_AutoText 55431
#define sipName_AutoText &sipStrings_QtCore[55431]
#define sipNameNr_Backward 55440
#define sipName_Backward &sipStrings_QtCore[55440]
#define sipNameNr_Balinese 55449
#define sipName_Balinese &sipStrings_QtCore[55449]
#define sipNameNr_Barbados 55458
#define sipName_Barbados &sipStrings_QtCore[55458]
#define sipNameNr_Bhojpuri 55467
#define sipName_Bhojpuri &sipStrings_QtCore[55467]
#define sipNameNr_Bigfloat 55476
#define sipName_Bigfloat &sipStrings_QtCore[55476]
#define sipNameNr_BitArray 53339
#define sipName_BitArray &sipStrings_QtCore[53339]
#define sipNameNr_Botswana 55485
#define sipName_Botswana &sipStrings_QtCore[55485]
#define sipNameNr_Buginese 55494
#define sipName_Buginese &sipStrings_QtCore[55494]
#define sipNameNr_Bulgaria 55503
#define sipName_Bulgaria &sipStrings_QtCore[55503]
#define sipNameNr_COSE_Mac 55512
#define sipName_COSE_Mac &sipStrings_QtCore[55512]
#define sipNameNr_Cambodia 55521
#define sipName_Cambodia &sipStrings_QtCore[55521]
#define sipNameNr_Cameroon 55530
#define sipName_Cameroon &sipStrings_QtCore[55530]
#define sipNameNr_Chamorro 55539
#define sipName_Chamorro &sipStrings_QtCore[55539]
#define sipNameNr_Cherokee 55548
#define sipName_Cherokee &sipStrings_QtCore[55548]
#define sipNameNr_Colombia 55557
#define sipName_Colombia &sipStrings_QtCore[55557]
#define sipNameNr_Corsican 55566
#define sipName_Corsican &sipStrings_QtCore[55566]
#define sipNameNr_Croatian 37845
#define sipName_Croatian &sipStrings_QtCore[37845]
#define sipNameNr_DashLine 31475
#define sipName_DashLine &sipStrings_QtCore[31475]
#define sipNameNr_DataPath 39781
#define sipName_DataPath &sipStrings_QtCore[39781]
#define sipNameNr_DateTime 30213
#define sipName_DateTime &sipStrings_QtCore[30213]
#define sipNameNr_Deselect 55575
#define sipName_Deselect &sipStrings_QtCore[55575]
#define sipNameNr_DirsLast 55584
#define sipName_DirsLast &sipStrings_QtCore[55584]
#define sipNameNr_Djibouti 55593
#define sipName_Djibouti &sipStrings_QtCore[55593]
#define sipNameNr_Dominica 55602
#define sipName_Dominica &sipStrings_QtCore[55602]
#define sipNameNr_DragMove 11360
#define sipName_DragMove &sipStrings_QtCore[11360]
#define sipNameNr_Dzongkha 55611
#define sipName_Dzongkha &sipStrings_QtCore[55611]
#define sipNameNr_EditRole 55620
#define sipName_EditRole &sipStrings_QtCore[55620]
#define sipNameNr_Estonian 55629
#define sipName_Estonian &sipStrings_QtCore[55629]
#define sipNameNr_Ethiopia 55638
#define sipName_Ethiopia &sipStrings_QtCore[55638]
#define sipNameNr_Etruscan 55647
#define sipName_Etruscan &sipStrings_QtCore[55647]
#define sipNameNr_ExactHit 55656
#define sipName_ExactHit &sipStrings_QtCore[55656]
#define sipNameNr_ExeGroup 55665
#define sipName_ExeGroup &sipStrings_QtCore[55665]
#define sipNameNr_ExeOther 55674
#define sipName_ExeOther &sipStrings_QtCore[55674]
#define sipNameNr_ExeOwner 55683
#define sipName_ExeOwner &sipStrings_QtCore[55683]
#define sipNameNr_FileOpen 55692
#define sipName_FileOpen &sipStrings_QtCore[55692]
#define sipNameNr_FileTime 11756
#define sipName_FileTime &sipStrings_QtCore[11756]
#define sipNameNr_Filipino 55701
#define sipName_Filipino &sipStrings_QtCore[55701]
#define sipNameNr_FillRule 41757
#define sipName_FillRule &sipStrings_QtCore[41757]
#define sipNameNr_FocusOut 55710
#define sipName_FocusOut &sipStrings_QtCore[55710]
#define sipNameNr_FontRole 55719
#define sipName_FontRole &sipStrings_QtCore[55719]
#define sipNameNr_Friulian 55728
#define sipName_Friulian &sipStrings_QtCore[55728]
#define sipNameNr_FuzzyHit 55737
#define sipName_FuzzyHit &sipStrings_QtCore[55737]
#define sipNameNr_Galician 55746
#define sipName_Galician &sipStrings_QtCore[55746]
#define sipNameNr_Georgian 55755
#define sipName_Georgian &sipStrings_QtCore[55755]
#define sipNameNr_Grapheme 55764
#define sipName_Grapheme &sipStrings_QtCore[55764]
#define sipNameNr_Guernsey 55773
#define sipName_Guernsey &sipStrings_QtCore[55773]
#define sipNameNr_Gujarati 55782
#define sipName_Gujarati &sipStrings_QtCore[55782]
#define sipNameNr_Hawaiian 55791
#define sipName_Hawaiian &sipStrings_QtCore[55791]
#define sipNameNr_HiriMotu 55800
#define sipName_HiriMotu &sipStrings_QtCore[55800]
#define sipNameNr_Honduras 55809
#define sipName_Honduras &sipStrings_QtCore[55809]
#define sipNameNr_HongKong 55818
#define sipName_HongKong &sipStrings_QtCore[55818]
#define sipNameNr_IconDrag 55827
#define sipName_IconDrag &sipStrings_QtCore[55827]
#define sipNameNr_InBounce 45748
#define sipName_InBounce &sipStrings_QtCore[45748]
#define sipNameNr_Indented 55836
#define sipName_Indented &sipStrings_QtCore[55836]
#define sipNameNr_ItemFlag 41770
#define sipName_ItemFlag &sipStrings_QtCore[41770]
#define sipNameNr_Japanese 55845
#define sipName_Japanese &sipStrings_QtCore[55845]
#define sipNameNr_Javanese 55854
#define sipName_Javanese &sipStrings_QtCore[55854]
#define sipNameNr_Kalenjin 55863
#define sipName_Kalenjin &sipStrings_QtCore[55863]
#define sipNameNr_Kashmiri 55872
#define sipName_Kashmiri &sipStrings_QtCore[55872]
#define sipNameNr_KeyError 55881
#define sipName_KeyError &sipStrings_QtCore[55881]
#define sipNameNr_KeyPress 55890
#define sipName_KeyPress &sipStrings_QtCore[55890]
#define sipNameNr_Key_Away 55899
#define sipName_Key_Away &sipStrings_QtCore[55899]
#define sipNameNr_Key_Back 55908
#define sipName_Key_Back &sipStrings_QtCore[55908]
#define sipNameNr_Key_Blue 55917
#define sipName_Key_Blue &sipStrings_QtCore[55917]
#define sipNameNr_Key_Book 55926
#define sipName_Key_Book &sipStrings_QtCore[55926]
#define sipNameNr_Key_Call 55935
#define sipName_Key_Call &sipStrings_QtCore[55935]
#define sipNameNr_Key_Copy 55944
#define sipName_Key_Copy &sipStrings_QtCore[55944]
#define sipNameNr_Key_Down 55953
#define sipName_Key_Down &sipStrings_QtCore[55953]
#define sipNameNr_Key_Exit 55962
#define sipName_Key_Exit &sipStrings_QtCore[55962]
#define sipNameNr_Key_Find 55971
#define sipName_Key_Find &sipStrings_QtCore[55971]
#define sipNameNr_Key_Flip 55980
#define sipName_Key_Flip &sipStrings_QtCore[55980]
#define sipNameNr_Key_Game 55989
#define sipName_Key_Game &sipStrings_QtCore[55989]
#define sipNameNr_Key_Help 55998
#define sipName_Key_Help &sipStrings_QtCore[55998]
#define sipNameNr_Key_Home 56007
#define sipName_Key_Home &sipStrings_QtCore[56007]
#define sipNameNr_Key_Info 56016
#define sipName_Key_Info &sipStrings_QtCore[56016]
#define sipNameNr_Key_Left 56025
#define sipName_Key_Left &sipStrings_QtCore[56025]
#define sipNameNr_Key_Less 56034
#define sipName_Key_Less &sipStrings_QtCore[56034]
#define sipNameNr_Key_Memo 56043
#define sipName_Key_Memo &sipStrings_QtCore[56043]
#define sipNameNr_Key_Menu 56052
#define sipName_Key_Menu &sipStrings_QtCore[56052]
#define sipNameNr_Key_Meta 56061
#define sipName_Key_Meta &sipStrings_QtCore[56061]
#define sipNameNr_Key_News 56070
#define sipName_Key_News &sipStrings_QtCore[56070]
#define sipNameNr_Key_Open 56079
#define sipName_Key_Open &sipStrings_QtCore[56079]
#define sipNameNr_Key_Play 56088
#define sipName_Key_Play &sipStrings_QtCore[56088]
#define sipNameNr_Key_Plus 56097
#define sipName_Key_Plus &sipStrings_QtCore[56097]
#define sipNameNr_Key_Redo 56106
#define sipName_Key_Redo &sipStrings_QtCore[56106]
#define sipNameNr_Key_Save 56115
#define sipName_Key_Save &sipStrings_QtCore[56115]
#define sipNameNr_Key_Send 56124
#define sipName_Key_Send &sipStrings_QtCore[56124]
#define sipNameNr_Key_Shop 56133
#define sipName_Key_Shop &sipStrings_QtCore[56133]
#define sipNameNr_Key_Stop 56142
#define sipName_Key_Stop &sipStrings_QtCore[56142]
#define sipNameNr_Key_Time 56151
#define sipName_Key_Time &sipStrings_QtCore[56151]
#define sipNameNr_Key_Undo 56160
#define sipName_Key_Undo &sipStrings_QtCore[56160]
#define sipNameNr_Key_View 56169
#define sipName_Key_View &sipStrings_QtCore[56169]
#define sipNameNr_Key_WLAN 56178
#define sipName_Key_WLAN &sipStrings_QtCore[56178]
#define sipNameNr_Key_Word 56187
#define sipName_Key_Word &sipStrings_QtCore[56187]
#define sipNameNr_Key_Xfer 56196
#define sipName_Key_Xfer &sipStrings_QtCore[56196]
#define sipNameNr_Key_Zoom 56205
#define sipName_Key_Zoom &sipStrings_QtCore[56205]
#define sipNameNr_Key_cent 56214
#define sipName_Key_cent &sipStrings_QtCore[56214]
#define sipNameNr_Kiribati 56223
#define sipName_Kiribati &sipStrings_QtCore[56223]
#define sipNameNr_Kwanyama 56232
#define sipName_Kwanyama &sipStrings_QtCore[56232]
#define sipNameNr_Language 13268
#define sipName_Language &sipStrings_QtCore[13268]
#define sipNameNr_LeftEdge 56241
#define sipName_LeftEdge &sipStrings_QtCore[56241]
#define sipNameNr_Lezghian 56250
#define sipName_Lezghian &sipStrings_QtCore[56250]
#define sipNameNr_LoadHint 19204
#define sipName_LoadHint &sipStrings_QtCore[19204]
#define sipNameNr_LongLong 48196
#define sipName_LongLong &sipStrings_QtCore[48196]
#define sipNameNr_LongName 56259
#define sipName_LongName &sipStrings_QtCore[56259]
#define sipNameNr_LuleSami 56268
#define sipName_LuleSami &sipStrings_QtCore[56268]
#define sipNameNr_Maithili 56277
#define sipName_Maithili &sipStrings_QtCore[56277]
#define sipNameNr_Malagasy 56286
#define sipName_Malagasy &sipStrings_QtCore[56286]
#define sipNameNr_Malaysia 56295
#define sipName_Malaysia &sipStrings_QtCore[56295]
#define sipNameNr_Maldives 56304
#define sipName_Maldives &sipStrings_QtCore[56304]
#define sipNameNr_Mandingo 56313
#define sipName_Mandingo &sipStrings_QtCore[56313]
#define sipNameNr_Manipuri 56322
#define sipName_Manipuri &sipStrings_QtCore[56322]
#define sipNameNr_MaskMode 41783
#define sipName_MaskMode &sipStrings_QtCore[41783]
#define sipNameNr_Meroitic 56331
#define sipName_Meroitic &sipStrings_QtCore[56331]
#define sipNameNr_MetaCall 56340
#define sipName_MetaCall &sipStrings_QtCore[56340]
#define sipNameNr_Modified 22773
#define sipName_Modified &sipStrings_QtCore[22773]
#define sipNameNr_Modifier 14276
#define sipName_Modifier &sipStrings_QtCore[14276]
#define sipNameNr_Mongolia 56349
#define sipName_Mongolia &sipStrings_QtCore[56349]
#define sipNameNr_MonoOnly 56358
#define sipName_MonoOnly &sipStrings_QtCore[56358]
#define sipNameNr_Morisyen 56367
#define sipName_Morisyen &sipStrings_QtCore[56367]
#define sipNameNr_Muscogee 56376
#define sipName_Muscogee &sipStrings_QtCore[56376]
#define sipNameNr_NameType 13961
#define sipName_NameType &sipStrings_QtCore[13961]
#define sipNameNr_NoButton 56385
#define sipName_NoButton &sipStrings_QtCore[56385]
#define sipNameNr_NoDotDot 56394
#define sipName_NoDotDot &sipStrings_QtCore[56394]
#define sipNameNr_NoFilter 56403
#define sipName_NoFilter &sipStrings_QtCore[56403]
#define sipNameNr_NoOption 56412
#define sipName_NoOption &sipStrings_QtCore[56412]
#define sipNameNr_NoUpdate 56421
#define sipName_NoUpdate &sipStrings_QtCore[56421]
#define sipNameNr_NonModal 56430
#define sipName_NonModal &sipStrings_QtCore[56430]
#define sipNameNr_NotFound 56439
#define sipName_NotFound &sipStrings_QtCore[56439]
#define sipNameNr_Nyankole 56448
#define sipName_Nyankole &sipStrings_QtCore[56448]
#define sipNameNr_OldIrish 56457
#define sipName_OldIrish &sipStrings_QtCore[56457]
#define sipNameNr_OldNorse 56466
#define sipName_OldNorse &sipStrings_QtCore[56466]
#define sipNameNr_OpenMode 16310
#define sipName_OpenMode &sipStrings_QtCore[16310]
#define sipNameNr_OutCubic 48726
#define sipName_OutCubic &sipStrings_QtCore[48726]
#define sipNameNr_OutCurve 31655
#define sipName_OutCurve &sipStrings_QtCore[31655]
#define sipNameNr_OutQuart 48737
#define sipName_OutQuart &sipStrings_QtCore[48737]
#define sipNameNr_OutQuint 48748
#define sipName_OutQuint &sipStrings_QtCore[48748]
#define sipNameNr_Pakistan 56475
#define sipName_Pakistan &sipStrings_QtCore[56475]
#define sipNameNr_Paraguay 56484
#define sipName_Paraguay &sipStrings_QtCore[56484]
#define sipNameNr_Parthian 56493
#define sipName_Parthian &sipStrings_QtCore[56493]
#define sipNameNr_PenStyle 41809
#define sipName_PenStyle &sipStrings_QtCore[41809]
#define sipNameNr_Pitcairn 56502
#define sipName_Pitcairn &sipStrings_QtCore[56502]
#define sipNameNr_PolygonF 53459
#define sipName_PolygonF &sipStrings_QtCore[53459]
#define sipNameNr_Portugal 56511
#define sipName_Portugal &sipStrings_QtCore[56511]
#define sipNameNr_Priority 3515
#define sipName_Priority &sipStrings_QtCore[3515]
#define sipNameNr_Prussian 56520
#define sipName_Prussian &sipStrings_QtCore[56520]
#define sipNameNr_QCborMap 56529
#define sipName_QCborMap &sipStrings_QtCore[56529]
#define sipNameNr_QLibrary 56538
#define sipName_QLibrary &sipStrings_QtCore[56538]
#define sipNameNr_QMargins 56547
#define sipName_QMargins &sipStrings_QtCore[56547]
#define sipNameNr_QPalette 56556
#define sipName_QPalette &sipStrings_QtCore[56556]
#define sipNameNr_QPolygon 56565
#define sipName_QPolygon &sipStrings_QtCore[56565]
#define sipNameNr_QProcess 56574
#define sipName_QProcess &sipStrings_QtCore[56574]
#define sipNameNr_QSysInfo 56583
#define sipName_QSysInfo &sipStrings_QtCore[56583]
#define sipNameNr_QVariant 39651
#define sipName_QVariant &sipStrings_QtCore[39651]
#define sipNameNr_Qt__Axis 56592
#define sipName_Qt__Axis &sipStrings_QtCore[56592]
#define sipNameNr_Qt__Edge 56601
#define sipName_Qt__Edge &sipStrings_QtCore[56601]
#define sipNameNr_ReadOnly 51256
#define sipName_ReadOnly &sipStrings_QtCore[51256]
#define sipNameNr_ReadUser 56610
#define sipName_ReadUser &sipStrings_QtCore[56610]
#define sipNameNr_Readable 51267
#define sipName_Readable &sipStrings_QtCore[51267]
#define sipNameNr_Reserved 31535
#define sipName_Reserved &sipStrings_QtCore[31535]
#define sipNameNr_Reversed 56619
#define sipName_Reversed &sipStrings_QtCore[56619]
#define sipNameNr_RichText 56628
#define sipName_RichText &sipStrings_QtCore[56628]
#define sipNameNr_Romanian 56637
#define sipName_Romanian &sipStrings_QtCore[56637]
#define sipNameNr_RoundCap 56646
#define sipName_RoundCap &sipStrings_QtCore[56646]
#define sipNameNr_Sanskrit 56655
#define sipName_Sanskrit &sipStrings_QtCore[56655]
#define sipNameNr_Saturday 56664
#define sipName_Saturday &sipStrings_QtCore[56664]
#define sipNameNr_Sentence 56673
#define sipName_Sentence &sipStrings_QtCore[56673]
#define sipNameNr_Sha3_224 56682
#define sipName_Sha3_224 &sipStrings_QtCore[56682]
#define sipNameNr_Sha3_256 56691
#define sipName_Sha3_256 &sipStrings_QtCore[56691]
#define sipNameNr_Sha3_384 56700
#define sipName_Sha3_384 &sipStrings_QtCore[56700]
#define sipNameNr_Sha3_512 56709
#define sipName_Sha3_512 &sipStrings_QtCore[56709]
#define sipNameNr_Shambala 56718
#define sipName_Shambala &sipStrings_QtCore[56718]
#define sipNameNr_Shortcut 5595
#define sipName_Shortcut &sipStrings_QtCore[5595]
#define sipNameNr_ShowBase 56727
#define sipName_ShowBase &sipStrings_QtCore[56727]
#define sipNameNr_Sicilian 56736
#define sipName_Sicilian &sipStrings_QtCore[56736]
#define sipNameNr_Silesian 56745
#define sipName_Silesian &sipStrings_QtCore[56745]
#define sipNameNr_SizeHint 41822
#define sipName_SizeHint &sipStrings_QtCore[41822]
#define sipNameNr_SizeMode 41835
#define sipName_SizeMode &sipStrings_QtCore[41835]
#define sipNameNr_Slovakia 56754
#define sipName_Slovakia &sipStrings_QtCore[56754]
#define sipNameNr_Slovenia 56763
#define sipName_Slovenia &sipStrings_QtCore[56763]
#define sipNameNr_SortFlag 33125
#define sipName_SortFlag &sipStrings_QtCore[33125]
#define sipNameNr_SriLanka 56772
#define sipName_SriLanka &sipStrings_QtCore[56772]
#define sipNameNr_Starting 56781
#define sipName_Starting &sipStrings_QtCore[56781]
#define sipNameNr_Suriname 56790
#define sipName_Suriname &sipStrings_QtCore[56790]
#define sipNameNr_TabFocus 49760
#define sipName_TabFocus &sipStrings_QtCore[49760]
#define sipNameNr_Tagbanwa 56799
#define sipName_Tagbanwa &sipStrings_QtCore[56799]
#define sipNameNr_Tahitian 56808
#define sipName_Tahitian &sipStrings_QtCore[56808]
#define sipNameNr_Tanzania 56817
#define sipName_Tanzania &sipStrings_QtCore[56817]
#define sipNameNr_TextDate 56826
#define sipName_TextDate &sipStrings_QtCore[56826]
#define sipNameNr_TextFlag 41848
#define sipName_TextFlag &sipStrings_QtCore[41848]
#define sipNameNr_Thailand 56835
#define sipName_Thailand &sipStrings_QtCore[56835]
#define sipNameNr_Thursday 56844
#define sipName_Thursday &sipStrings_QtCore[56844]
#define sipNameNr_Tigrinya 56853
#define sipName_Tigrinya &sipStrings_QtCore[56853]
#define sipNameNr_TileRule 41861
#define sipName_TileRule &sipStrings_QtCore[41861]
#define sipNameNr_TimeSpec 41874
#define sipName_TimeSpec &sipStrings_QtCore[41874]
#define sipNameNr_TimeType 16570
#define sipName_TimeType &sipStrings_QtCore[16570]
#define sipNameNr_TimeZone 35345
#define sipName_TimeZone &sipStrings_QtCore[35345]
#define sipNameNr_Timedout 56862
#define sipName_Timedout &sipStrings_QtCore[56862]
#define sipNameNr_TokPisin 56871
#define sipName_TokPisin &sipStrings_QtCore[56871]
#define sipNameNr_TouchEnd 56880
#define sipName_TouchEnd &sipStrings_QtCore[56880]
#define sipNameNr_Truncate 56889
#define sipName_Truncate &sipStrings_QtCore[56889]
#define sipNameNr_TypeFlag 16470
#define sipName_TypeFlag &sipStrings_QtCore[16470]
#define sipNameNr_TypeMask 56898
#define sipName_TypeMask &sipStrings_QtCore[56898]
#define sipNameNr_UIEffect 41887
#define sipName_UIEffect &sipStrings_QtCore[41887]
#define sipNameNr_Ugaritic 56907
#define sipName_Ugaritic &sipStrings_QtCore[56907]
#define sipNameNr_Unsorted 56916
#define sipName_Unsorted &sipStrings_QtCore[56916]
#define sipNameNr_UserRole 56925
#define sipName_UserRole &sipStrings_QtCore[56925]
#define sipNameNr_UserType 56934
#define sipName_UserType &sipStrings_QtCore[56934]
#define sipNameNr_Validate 56943
#define sipName_Validate &sipStrings_QtCore[56943]
#define sipNameNr_Vector2D 53539
#define sipName_Vector2D &sipStrings_QtCore[53539]
#define sipNameNr_Vector3D 53549
#define sipName_Vector3D &sipStrings_QtCore[53549]
#define sipNameNr_Vector4D 53559
#define sipName_Vector4D &sipStrings_QtCore[53559]
#define sipNameNr_Vertical 56952
#define sipName_Vertical &sipStrings_QtCore[56952]
#define sipNameNr_VoidStar 56961
#define sipName_VoidStar &sipStrings_QtCore[56961]
#define sipNameNr_WA_Hover 56970
#define sipName_WA_Hover &sipStrings_QtCore[56970]
#define sipNameNr_WA_Moved 56979
#define sipName_WA_Moved &sipStrings_QtCore[56979]
#define sipNameNr_Warlpiri 56988
#define sipName_Warlpiri &sipStrings_QtCore[56988]
#define sipNameNr_Wildcard 23727
#define sipName_Wildcard &sipStrings_QtCore[23727]
#define sipNameNr_Windows7 56997
#define sipName_Windows7 &sipStrings_QtCore[56997]
#define sipNameNr_Windows8 57006
#define sipName_Windows8 &sipStrings_QtCore[57006]
#define sipNameNr_WordSize 57015
#define sipName_WordSize &sipStrings_QtCore[57015]
#define sipNameNr_Writable 51322
#define sipName_Writable &sipStrings_QtCore[51322]
#define sipNameNr_XButton1 57024
#define sipName_XButton1 &sipStrings_QtCore[57024]
#define sipNameNr_XButton2 57033
#define sipName_XButton2 &sipStrings_QtCore[57033]
#define sipNameNr_YiScript 57042
#define sipName_YiScript &sipStrings_QtCore[57042]
#define sipNameNr_Zimbabwe 57051
#define sipName_Zimbabwe &sipStrings_QtCore[57051]
#define sipNameNr___bool__ 57060
#define sipName___bool__ &sipStrings_QtCore[57060]
#define sipNameNr___call__ 57069
#define sipName___call__ &sipStrings_QtCore[57069]
#define sipNameNr___exit__ 57078
#define sipName___exit__ &sipStrings_QtCore[57078]
#define sipNameNr___hash__ 57087
#define sipName___hash__ &sipStrings_QtCore[57087]
#define sipNameNr___iadd__ 57096
#define sipName___iadd__ &sipStrings_QtCore[57096]
#define sipNameNr___iand__ 57105
#define sipName___iand__ &sipStrings_QtCore[57105]
#define sipNameNr___imul__ 57114
#define sipName___imul__ &sipStrings_QtCore[57114]
#define sipNameNr___isub__ 57123
#define sipName___isub__ &sipStrings_QtCore[57123]
#define sipNameNr___ixor__ 57132
#define sipName___ixor__ &sipStrings_QtCore[57132]
#define sipNameNr___repr__ 57141
#define sipName___repr__ &sipStrings_QtCore[57141]
#define sipNameNr_addMSecs 57150
#define sipName_addMSecs &sipStrings_QtCore[57150]
#define sipNameNr_addNSecs 57159
#define sipName_addNSecs &sipStrings_QtCore[57159]
#define sipNameNr_addPaths 57168
#define sipName_addPaths &sipStrings_QtCore[57168]
#define sipNameNr_addPause 57177
#define sipName_addPause &sipStrings_QtCore[57177]
#define sipNameNr_addState 57186
#define sipName_addState &sipStrings_QtCore[57186]
#define sipNameNr_addYears 57195
#define sipName_addYears &sipStrings_QtCore[57195]
#define sipNameNr_adjusted 57204
#define sipName_adjusted &sipStrings_QtCore[57204]
#define sipNameNr_baseName 57213
#define sipName_baseName &sipStrings_QtCore[57213]
#define sipNameNr_buildAbi 57222
#define sipName_buildAbi &sipStrings_QtCore[57222]
#define sipNameNr_capacity 57231
#define sipName_capacity &sipStrings_QtCore[57231]
#define sipNameNr_captured 57240
#define sipName_captured &sipStrings_QtCore[57240]
#define sipNameNr_category 57249
#define sipName_category &sipStrings_QtCore[57249]
#define sipNameNr_children 57258
#define sipName_children &sipStrings_QtCore[57258]
#define sipNameNr_clearBit 57267
#define sipName_clearBit &sipStrings_QtCore[57267]
#define sipNameNr_contains 57276
#define sipName_contains &sipStrings_QtCore[57276]
#define sipNameNr_critical 57285
#define sipName_critical &sipStrings_QtCore[57285]
#define sipNameNr_darkBlue 57294
#define sipName_darkBlue &sipStrings_QtCore[57294]
#define sipNameNr_darkCyan 57303
#define sipName_darkCyan &sipStrings_QtCore[57303]
#define sipNameNr_darkGray 57312
#define sipName_darkGray &sipStrings_QtCore[57312]
#define sipNameNr_deadline 57321
#define sipName_deadline &sipStrings_QtCore[57321]
#define sipNameNr_duration 57330
#define sipName_duration &sipStrings_QtCore[57330]
#define sipNameNr_endArray 57339
#define sipName_endArray &sipStrings_QtCore[57339]
#define sipNameNr_endFrame 57348
#define sipName_endFrame &sipStrings_QtCore[57348]
#define sipNameNr_endGroup 57357
#define sipName_endGroup &sipStrings_QtCore[57357]
#define sipNameNr_endOfDay 57366
#define sipName_endOfDay &sipStrings_QtCore[57366]
#define sipNameNr_endValue 57375
#define sipName_endValue &sipStrings_QtCore[57375]
#define sipNameNr_endsWith 57384
#define sipName_endsWith &sipStrings_QtCore[57384]
#define sipNameNr_enumName 57393
#define sipName_enumName &sipStrings_QtCore[57393]
#define sipNameNr_exitCode 57402
#define sipName_exitCode &sipStrings_QtCore[57402]
#define sipNameNr_fileInfo 57411
#define sipName_fileInfo &sipStrings_QtCore[57411]
#define sipNameNr_fileName 57420
#define sipName_fileName &sipStrings_QtCore[57420]
#define sipNameNr_filePath 57429
#define sipName_filePath &sipStrings_QtCore[57429]
#define sipNameNr_fileTime 57438
#define sipName_fileTime &sipStrings_QtCore[57438]
#define sipNameNr_finished 57447
#define sipName_finished &sipStrings_QtCore[57447]
#define sipNameNr_fragment 57456
#define sipName_fragment &sipStrings_QtCore[57456]
#define sipNameNr_fromBits 57465
#define sipName_fromBits &sipStrings_QtCore[57465]
#define sipNameNr_fromJson 57474
#define sipName_fromJson &sipStrings_QtCore[57474]
#define sipNameNr_function 57483
#define sipName_function &sipStrings_QtCore[57483]
#define sipNameNr_generate 57492
#define sipName_generate &sipStrings_QtCore[57492]
#define sipNameNr_hasColor 57501
#define sipName_hasColor &sipStrings_QtCore[57501]
#define sipNameNr_hasError 57510
#define sipName_hasError &sipStrings_QtCore[57510]
#define sipNameNr_hasImage 57519
#define sipName_hasImage &sipStrings_QtCore[57519]
#define sipNameNr_hasIndex 57528
#define sipName_hasIndex &sipStrings_QtCore[57528]
#define sipNameNr_hasMatch 57537
#define sipName_hasMatch &sipStrings_QtCore[57537]
#define sipNameNr_hasQuery 57546
#define sipName_hasQuery &sipStrings_QtCore[57546]
#define sipNameNr_helpText 57555
#define sipName_helpText &sipStrings_QtCore[57555]
#define sipNameNr_homePath 57564
#define sipName_homePath &sipStrings_QtCore[57564]
#define sipNameNr_iconName 57573
#define sipName_iconName &sipStrings_QtCore[57573]
#define sipNameNr_inherits 57582
#define sipName_inherits &sipStrings_QtCore[57582]
#define sipNameNr_iniCodec 57591
#define sipName_iniCodec &sipStrings_QtCore[57591]
#define sipNameNr_instance 57600
#define sipName_instance &sipStrings_QtCore[57600]
#define sipNameNr_interval 57609
#define sipName_interval &sipStrings_QtCore[57609]
#define sipNameNr_isActive 57618
#define sipName_isActive &sipStrings_QtCore[57618]
#define sipNameNr_isBundle 57627
#define sipName_isBundle &sipStrings_QtCore[57627]
#define sipNameNr_isDouble 57636
#define sipName_isDouble &sipStrings_QtCore[57636]
#define sipNameNr_isHidden 57645
#define sipName_isHidden &sipStrings_QtCore[57645]
#define sipNameNr_isLoaded 57654
#define sipName_isLoaded &sipStrings_QtCore[57654]
#define sipNameNr_isLocked 57663
#define sipName_isLocked &sipStrings_QtCore[57663]
#define sipNameNr_isObject 57672
#define sipName_isObject &sipStrings_QtCore[57672]
#define sipNameNr_isScoped 57681
#define sipName_isScoped &sipStrings_QtCore[57681]
#define sipNameNr_isStored 57690
#define sipName_isStored &sipStrings_QtCore[57690]
#define sipNameNr_isString 57699
#define sipName_isString &sipStrings_QtCore[57699]
#define sipNameNr_itemData 57708
#define sipName_itemData &sipStrings_QtCore[57708]
#define sipNameNr_keyCount 57717
#define sipName_keyCount &sipStrings_QtCore[57717]
#define sipNameNr_language 57726
#define sipName_language &sipStrings_QtCore[57726]
#define sipNameNr_lastRead 57735
#define sipName_lastRead &sipStrings_QtCore[57735]
#define sipNameNr_lessThan 57744
#define sipName_lessThan &sipStrings_QtCore[57744]
#define sipNameNr_licensee 57753
#define sipName_licensee &sipStrings_QtCore[57753]
#define sipNameNr_location 57762
#define sipName_location &sipStrings_QtCore[57762]
#define sipNameNr_mimeData 57771
#define sipName_mimeData &sipStrings_QtCore[57771]
#define sipNameNr_moveLeft 57780
#define sipName_moveLeft &sipStrings_QtCore[57780]
#define sipNameNr_moveRows 30037
#define sipName_moveRows &sipStrings_QtCore[30037]
#define sipNameNr_nameType 57789
#define sipName_nameType &sipStrings_QtCore[57789]
#define sipNameNr_openMode 57798
#define sipName_openMode &sipStrings_QtCore[57798]
#define sipNameNr_optimize 57807
#define sipName_optimize &sipStrings_QtCore[57807]
#define sipNameNr_password 57816
#define sipName_password &sipStrings_QtCore[57816]
#define sipNameNr_peekNext 57825
#define sipName_peekNext &sipStrings_QtCore[57825]
#define sipNameNr_polished 57834
#define sipName_polished &sipStrings_QtCore[57834]
#define sipNameNr_position 57843
#define sipName_position &sipStrings_QtCore[57843]
#define sipNameNr_priority 57852
#define sipName_priority &sipStrings_QtCore[57852]
#define sipNameNr_property 57861
#define sipName_property &sipStrings_QtCore[57861]
#define sipNameNr_publicId 57870
#define sipName_publicId &sipStrings_QtCore[57870]
#define sipNameNr_pyqtSlot 57879
#define sipName_pyqtSlot &sipStrings_QtCore[57879]
#define sipNameNr_qRound64 57888
#define sipName_qRound64 &sipStrings_QtCore[57888]
#define sipNameNr_qVersion 57897
#define sipName_qVersion &sipStrings_QtCore[57897]
#define sipNameNr_qWarning 57906
#define sipName_qWarning &sipStrings_QtCore[57906]
#define sipNameNr_quintptr 57915
#define sipName_quintptr &sipStrings_QtCore[57915]
#define sipNameNr_readBool 57924
#define sipName_readBool &sipStrings_QtCore[57924]
#define sipNameNr_readData 57933
#define sipName_readData &sipStrings_QtCore[57933]
#define sipNameNr_readInt8 57942
#define sipName_readInt8 &sipStrings_QtCore[57942]
#define sipNameNr_readLine 57951
#define sipName_readLine &sipStrings_QtCore[57951]
#define sipNameNr_readNext 57960
#define sipName_readNext &sipStrings_QtCore[57960]
#define sipNameNr_receiver 57969
#define sipName_receiver &sipStrings_QtCore[57969]
#define sipNameNr_removeAt 57978
#define sipName_removeAt &sipStrings_QtCore[57978]
#define sipNameNr_repeated 57987
#define sipName_repeated &sipStrings_QtCore[57987]
#define sipNameNr_resolved 57996
#define sipName_resolved &sipStrings_QtCore[57996]
#define sipNameNr_rootPath 58005
#define sipName_rootPath &sipStrings_QtCore[58005]
#define sipNameNr_rowCount 58014
#define sipName_rowCount &sipStrings_QtCore[58014]
#define sipNameNr_segments 58023
#define sipName_segments &sipStrings_QtCore[58023]
#define sipNameNr_setAngle 58032
#define sipName_setAngle &sipStrings_QtCore[58032]
#define sipNameNr_setArray 58041
#define sipName_setArray &sipStrings_QtCore[58041]
#define sipNameNr_setCodec 58050
#define sipName_setCodec &sipStrings_QtCore[58050]
#define sipNameNr_setFlags 58059
#define sipName_setFlags &sipStrings_QtCore[58059]
#define sipNameNr_setModel 30053
#define sipName_setModel &sipStrings_QtCore[30053]
#define sipNameNr_setQuery 58068
#define sipName_setQuery &sipStrings_QtCore[58068]
#define sipNameNr_setRight 58077
#define sipName_setRight &sipStrings_QtCore[58077]
#define sipNameNr_setValue 58086
#define sipName_setValue &sipStrings_QtCore[58086]
#define sipNameNr_setWidth 58095
#define sipName_setWidth &sipStrings_QtCore[58095]
#define sipNameNr_showHelp 58104
#define sipName_showHelp &sipStrings_QtCore[58104]
#define sipNameNr_showbase 51454
#define sipName_showbase &sipStrings_QtCore[51454]
#define sipNameNr_shrunkBy 58113
#define sipName_shrunkBy &sipStrings_QtCore[58113]
#define sipNameNr_sortRole 58122
#define sipName_sortRole &sipStrings_QtCore[58122]
#define sipNameNr_startMap 58131
#define sipName_startMap &sipStrings_QtCore[58131]
#define sipNameNr_suffixes 58140
#define sipName_suffixes &sipStrings_QtCore[58140]
#define sipNameNr_systemId 58149
#define sipName_systemId &sipStrings_QtCore[58149]
#define sipNameNr_takeLast 58158
#define sipName_takeLast &sipStrings_QtCore[58158]
#define sipNameNr_tempPath 58167
#define sipName_tempPath &sipStrings_QtCore[58167]
#define sipNameNr_timeSpec 58176
#define sipName_timeSpec &sipStrings_QtCore[58176]
#define sipNameNr_timeZone 58185
#define sipName_timeZone &sipStrings_QtCore[58185]
#define sipNameNr_toBase64 58194
#define sipName_toBase64 &sipStrings_QtCore[58194]
#define sipNameNr_toDouble 58203
#define sipName_toDouble &sipStrings_QtCore[58203]
#define sipNameNr_toObject 58212
#define sipName_toObject &sipStrings_QtCore[58212]
#define sipNameNr_toPyDate 58221
#define sipName_toPyDate &sipStrings_QtCore[58221]
#define sipNameNr_toPyTime 58230
#define sipName_toPyTime &sipStrings_QtCore[58230]
#define sipNameNr_toString 58239
#define sipName_toString &sipStrings_QtCore[58239]
#define sipNameNr_toTime_t 58248
#define sipName_toTime_t &sipStrings_QtCore[58248]
#define sipNameNr_toUShort 58257
#define sipName_toUShort &sipStrings_QtCore[58257]
#define sipNameNr_topRight 58266
#define sipName_topRight &sipStrings_QtCore[58266]
#define sipNameNr_truncate 58275
#define sipName_truncate &sipStrings_QtCore[58275]
#define sipNameNr_tryStart 58284
#define sipName_tryStart &sipStrings_QtCore[58284]
#define sipNameNr_typeName 58293
#define sipName_typeName &sipStrings_QtCore[58293]
#define sipNameNr_userInfo 58302
#define sipName_userInfo &sipStrings_QtCore[58302]
#define sipNameNr_userName 58311
#define sipName_userName &sipStrings_QtCore[58311]
#define sipNameNr_userType 58320
#define sipName_userType &sipStrings_QtCore[58320]
#define sipNameNr_weekdays 58329
#define sipName_weekdays &sipStrings_QtCore[58329]
#define sipNameNr_writeDTD 58338
#define sipName_writeDTD &sipStrings_QtCore[58338]
#define sipNameNr_writeInt 58347
#define sipName_writeInt &sipStrings_QtCore[58347]
#define sipNameNr_Albania 58356
#define sipName_Albania &sipStrings_QtCore[58356]
#define sipNameNr_Algeria 58364
#define sipName_Algeria &sipStrings_QtCore[58364]
#define sipNameNr_AllDirs 58372
#define sipName_AllDirs &sipStrings_QtCore[58372]
#define sipNameNr_Amharic 58380
#define sipName_Amharic &sipStrings_QtCore[58380]
#define sipNameNr_Andorra 58388
#define sipName_Andorra &sipStrings_QtCore[58388]
#define sipNameNr_Android 58396
#define sipName_Android &sipStrings_QtCore[58396]
#define sipNameNr_Aramaic 58404
#define sipName_Aramaic &sipStrings_QtCore[58404]
#define sipNameNr_Armenia 58412
#define sipName_Armenia &sipStrings_QtCore[58412]
#define sipNameNr_Austria 58420
#define sipName_Austria &sipStrings_QtCore[58420]
#define sipNameNr_Avestan 58428
#define sipName_Avestan &sipStrings_QtCore[58428]
#define sipNameNr_Bahamas 58436
#define sipName_Bahamas &sipStrings_QtCore[58436]
#define sipNameNr_Bahrain 58444
#define sipName_Bahrain &sipStrings_QtCore[58444]
#define sipNameNr_Bambara 58452
#define sipName_Bambara &sipStrings_QtCore[58452]
#define sipNameNr_Bashkir 58460
#define sipName_Bashkir &sipStrings_QtCore[58460]
#define sipNameNr_Belarus 58468
#define sipName_Belarus &sipStrings_QtCore[58468]
#define sipNameNr_Belgium 58476
#define sipName_Belgium &sipStrings_QtCore[58476]
#define sipNameNr_Bengali 58484
#define sipName_Bengali &sipStrings_QtCore[58484]
#define sipNameNr_Bermuda 58492
#define sipName_Bermuda &sipStrings_QtCore[58492]
#define sipNameNr_Bhutani 58500
#define sipName_Bhutani &sipStrings_QtCore[58500]
#define sipNameNr_Bislama 58508
#define sipName_Bislama &sipStrings_QtCore[58508]
#define sipNameNr_Bolivia 58516
#define sipName_Bolivia &sipStrings_QtCore[58516]
#define sipNameNr_Bonaire 58524
#define sipName_Bonaire &sipStrings_QtCore[58524]
#define sipNameNr_Bosnian 58532
#define sipName_Bosnian &sipStrings_QtCore[58532]
#define sipNameNr_Burmese 58540
#define sipName_Burmese &sipStrings_QtCore[58540]
#define sipNameNr_Burundi 58548
#define sipName_Burundi &sipStrings_QtCore[58548]
#define sipNameNr_Catalan 58556
#define sipName_Catalan &sipStrings_QtCore[58556]
#define sipNameNr_Cebuano 58564
#define sipName_Cebuano &sipStrings_QtCore[58564]
#define sipNameNr_Chechen 58572
#define sipName_Chechen &sipStrings_QtCore[58572]
#define sipNameNr_Checked 25126
#define sipName_Checked &sipStrings_QtCore[25126]
#define sipNameNr_Chinese 28614
#define sipName_Chinese &sipStrings_QtCore[28614]
#define sipNameNr_Chuvash 58580
#define sipName_Chuvash &sipStrings_QtCore[58580]
#define sipNameNr_Columns 19946
#define sipName_Columns &sipStrings_QtCore[19946]
#define sipNameNr_Comment 44163
#define sipName_Comment &sipStrings_QtCore[44163]
#define sipNameNr_Comoros 58588
#define sipName_Comoros &sipStrings_QtCore[58588]
#define sipNameNr_Compact 58596
#define sipName_Compact &sipStrings_QtCore[58596]
#define sipNameNr_Cornish 58604
#define sipName_Cornish &sipStrings_QtCore[58604]
#define sipNameNr_Country 25398
#define sipName_Country &sipStrings_QtCore[25398]
#define sipNameNr_Crashed 58612
#define sipName_Crashed &sipStrings_QtCore[58612]
#define sipNameNr_Croatia 58620
#define sipName_Croatia &sipStrings_QtCore[58620]
#define sipNameNr_CuraSao 58628
#define sipName_CuraSao &sipStrings_QtCore[58628]
#define sipNameNr_Current 37832
#define sipName_Current &sipStrings_QtCore[37832]
#define sipNameNr_Decimal 58636
#define sipName_Decimal &sipStrings_QtCore[58636]
#define sipNameNr_Denmark 58644
#define sipName_Denmark &sipStrings_QtCore[58644]
#define sipNameNr_Desktop 3719
#define sipName_Desktop &sipStrings_QtCore[3719]
#define sipNameNr_DotLine 31506
#define sipName_DotLine &sipStrings_QtCore[31506]
#define sipNameNr_Ecuador 58652
#define sipName_Ecuador &sipStrings_QtCore[58652]
#define sipNameNr_English 58660
#define sipName_English &sipStrings_QtCore[58660]
#define sipNameNr_Eritrea 58668
#define sipName_Eritrea &sipStrings_QtCore[58668]
#define sipNameNr_Estonia 58676
#define sipName_Estonia &sipStrings_QtCore[58676]
#define sipNameNr_ExeUser 58684
#define sipName_ExeUser &sipStrings_QtCore[58684]
#define sipNameNr_Faroese 58692
#define sipName_Faroese &sipStrings_QtCore[58692]
#define sipNameNr_Filters 35181
#define sipName_Filters &sipStrings_QtCore[35181]
#define sipNameNr_Finland 58700
#define sipName_Finland &sipStrings_QtCore[58700]
#define sipNameNr_Finnish 58708
#define sipName_Finnish &sipStrings_QtCore[58708]
#define sipNameNr_FlatCap 58716
#define sipName_FlatCap &sipStrings_QtCore[58716]
#define sipNameNr_Float16 54470
#define sipName_Float16 &sipStrings_QtCore[54470]
#define sipNameNr_FocusIn 58724
#define sipName_FocusIn &sipStrings_QtCore[58724]
#define sipNameNr_Forever 54480
#define sipName_Forever &sipStrings_QtCore[54480]
#define sipNameNr_Forward 24701
#define sipName_Forward &sipStrings_QtCore[24701]
#define sipNameNr_Frisian 33996
#define sipName_Frisian &sipStrings_QtCore[33996]
#define sipNameNr_Georgia 58732
#define sipName_Georgia &sipStrings_QtCore[58732]
#define sipNameNr_Germany 58740
#define sipName_Germany &sipStrings_QtCore[58740]
#define sipNameNr_Gesture 10522
#define sipName_Gesture &sipStrings_QtCore[10522]
#define sipNameNr_Grenada 58748
#define sipName_Grenada &sipStrings_QtCore[58748]
#define sipNameNr_Guarani 58756
#define sipName_Guarani &sipStrings_QtCore[58756]
#define sipNameNr_Haitian 58764
#define sipName_Haitian &sipStrings_QtCore[58764]
#define sipNameNr_Hanunoo 58772
#define sipName_Hanunoo &sipStrings_QtCore[58772]
#define sipNameNr_Hungary 58780
#define sipName_Hungary &sipStrings_QtCore[58780]
#define sipNameNr_ISODate 58788
#define sipName_ISODate &sipStrings_QtCore[58788]
#define sipNameNr_Iceland 58796
#define sipName_Iceland &sipStrings_QtCore[58796]
#define sipNameNr_ImHints 58804
#define sipName_ImHints &sipStrings_QtCore[58804]
#define sipNameNr_ImhDate 58812
#define sipName_ImhDate &sipStrings_QtCore[58812]
#define sipNameNr_ImhNone 58820
#define sipName_ImhNone &sipStrings_QtCore[58820]
#define sipNameNr_ImhTime 58828
#define sipName_ImhTime &sipStrings_QtCore[58828]
#define sipNameNr_InCubic 49849
#define sipName_InCubic &sipStrings_QtCore[49849]
#define sipNameNr_InCurve 44573
#define sipName_InCurve &sipStrings_QtCore[44573]
#define sipNameNr_InQuart 49860
#define sipName_InQuart &sipStrings_QtCore[49860]
#define sipNameNr_InQuint 49871
#define sipName_InQuint &sipStrings_QtCore[49871]
#define sipNameNr_Inupiak 58836
#define sipName_Inupiak &sipStrings_QtCore[58836]
#define sipNameNr_Invalid 28902
#define sipName_Invalid &sipStrings_QtCore[28902]
#define sipNameNr_Ireland 58844
#define sipName_Ireland &sipStrings_QtCore[58844]
#define sipNameNr_Italian 58852
#define sipName_Italian &sipStrings_QtCore[58852]
#define sipNameNr_Jamaica 58860
#define sipName_Jamaica &sipStrings_QtCore[58860]
#define sipNameNr_Kannada 58868
#define sipName_Kannada &sipStrings_QtCore[58868]
#define sipNameNr_Kenyang 58876
#define sipName_Kenyang &sipStrings_QtCore[58876]
#define sipNameNr_Key_Alt 58884
#define sipName_Key_Alt &sipStrings_QtCore[58884]
#define sipNameNr_Key_Any 58892
#define sipName_Key_Any &sipStrings_QtCore[58892]
#define sipNameNr_Key_Bar 58900
#define sipName_Key_Bar &sipStrings_QtCore[58900]
#define sipNameNr_Key_Cut 58908
#define sipName_Key_Cut &sipStrings_QtCore[58908]
#define sipNameNr_Key_DOS 58916
#define sipName_Key_DOS &sipStrings_QtCore[58916]
#define sipNameNr_Key_ETH 58924
#define sipName_Key_ETH &sipStrings_QtCore[58924]
#define sipNameNr_Key_End 58932
#define sipName_Key_End &sipStrings_QtCore[58932]
#define sipNameNr_Key_F10 58940
#define sipName_Key_F10 &sipStrings_QtCore[58940]
#define sipNameNr_Key_F11 58948
#define sipName_Key_F11 &sipStrings_QtCore[58948]
#define sipNameNr_Key_F12 58956
#define sipName_Key_F12 &sipStrings_QtCore[58956]
#define sipNameNr_Key_F13 58964
#define sipName_Key_F13 &sipStrings_QtCore[58964]
#define sipNameNr_Key_F14 58972
#define sipName_Key_F14 &sipStrings_QtCore[58972]
#define sipNameNr_Key_F15 58980
#define sipName_Key_F15 &sipStrings_QtCore[58980]
#define sipNameNr_Key_F16 58988
#define sipName_Key_F16 &sipStrings_QtCore[58988]
#define sipNameNr_Key_F17 58996
#define sipName_Key_F17 &sipStrings_QtCore[58996]
#define sipNameNr_Key_F18 59004
#define sipName_Key_F18 &sipStrings_QtCore[59004]
#define sipNameNr_Key_F19 59012
#define sipName_Key_F19 &sipStrings_QtCore[59012]
#define sipNameNr_Key_F20 59020
#define sipName_Key_F20 &sipStrings_QtCore[59020]
#define sipNameNr_Key_F21 59028
#define sipName_Key_F21 &sipStrings_QtCore[59028]
#define sipNameNr_Key_F22 59036
#define sipName_Key_F22 &sipStrings_QtCore[59036]
#define sipNameNr_Key_F23 59044
#define sipName_Key_F23 &sipStrings_QtCore[59044]
#define sipNameNr_Key_F24 59052
#define sipName_Key_F24 &sipStrings_QtCore[59052]
#define sipNameNr_Key_F25 59060
#define sipName_Key_F25 &sipStrings_QtCore[59060]
#define sipNameNr_Key_F26 59068
#define sipName_Key_F26 &sipStrings_QtCore[59068]
#define sipNameNr_Key_F27 59076
#define sipName_Key_F27 &sipStrings_QtCore[59076]
#define sipNameNr_Key_F28 59084
#define sipName_Key_F28 &sipStrings_QtCore[59084]
#define sipNameNr_Key_F29 59092
#define sipName_Key_F29 &sipStrings_QtCore[59092]
#define sipNameNr_Key_F30 59100
#define sipName_Key_F30 &sipStrings_QtCore[59100]
#define sipNameNr_Key_F31 59108
#define sipName_Key_F31 &sipStrings_QtCore[59108]
#define sipNameNr_Key_F32 59116
#define sipName_Key_F32 &sipStrings_QtCore[59116]
#define sipNameNr_Key_F33 59124
#define sipName_Key_F33 &sipStrings_QtCore[59124]
#define sipNameNr_Key_F34 59132
#define sipName_Key_F34 &sipStrings_QtCore[59132]
#define sipNameNr_Key_F35 59140
#define sipName_Key_F35 &sipStrings_QtCore[59140]
#define sipNameNr_Key_New 59148
#define sipName_Key_New &sipStrings_QtCore[59148]
#define sipNameNr_Key_Red 59156
#define sipName_Key_Red &sipStrings_QtCore[59156]
#define sipNameNr_Key_Tab 59164
#define sipName_Key_Tab &sipStrings_QtCore[59164]
#define sipNameNr_Key_UWB 59172
#define sipName_Key_UWB &sipStrings_QtCore[59172]
#define sipNameNr_Key_WWW 59180
#define sipName_Key_WWW &sipStrings_QtCore[59180]
#define sipNameNr_Key_Yes 59188
#define sipName_Key_Yes &sipStrings_QtCore[59188]
#define sipNameNr_Key_yen 59196
#define sipName_Key_yen &sipStrings_QtCore[59196]
#define sipNameNr_Kirghiz 59204
#define sipName_Kirghiz &sipStrings_QtCore[59204]
#define sipNameNr_Konkani 59212
#define sipName_Konkani &sipStrings_QtCore[59212]
#define sipNameNr_Kurdish 29590
#define sipName_Kurdish &sipStrings_QtCore[29590]
#define sipNameNr_Kurundi 59220
#define sipName_Kurundi &sipStrings_QtCore[59220]
#define sipNameNr_Latvian 59228
#define sipName_Latvian &sipStrings_QtCore[59228]
#define sipNameNr_Lebanon 59236
#define sipName_Lebanon &sipStrings_QtCore[59236]
#define sipNameNr_Lesotho 59244
#define sipName_Lesotho &sipStrings_QtCore[59244]
#define sipNameNr_Liberia 59252
#define sipName_Liberia &sipStrings_QtCore[59252]
#define sipNameNr_LinearA 59260
#define sipName_LinearA &sipStrings_QtCore[59260]
#define sipNameNr_Lingala 59268
#define sipName_Lingala &sipStrings_QtCore[59268]
#define sipNameNr_Machame 59276
#define sipName_Machame &sipStrings_QtCore[59276]
#define sipNameNr_Makonde 59284
#define sipName_Makonde &sipStrings_QtCore[59284]
#define sipNameNr_Maltese 59292
#define sipName_Maltese &sipStrings_QtCore[59292]
#define sipNameNr_Mapuche 59300
#define sipName_Mapuche &sipStrings_QtCore[59300]
#define sipNameNr_Marathi 59308
#define sipName_Marathi &sipStrings_QtCore[59308]
#define sipNameNr_MaxUser 59316
#define sipName_MaxUser &sipStrings_QtCore[59316]
#define sipNameNr_Mayotte 59324
#define sipName_Mayotte &sipStrings_QtCore[59324]
#define sipNameNr_Moldova 59332
#define sipName_Moldova &sipStrings_QtCore[59332]
#define sipNameNr_Morocco 59340
#define sipName_Morocco &sipStrings_QtCore[59340]
#define sipNameNr_Mundang 59348
#define sipName_Mundang &sipStrings_QtCore[59348]
#define sipNameNr_Myanmar 59356
#define sipName_Myanmar &sipStrings_QtCore[59356]
#define sipNameNr_Namibia 59364
#define sipName_Namibia &sipStrings_QtCore[59364]
#define sipNameNr_NewOnly 59372
#define sipName_NewOnly &sipStrings_QtCore[59372]
#define sipNameNr_Nigeria 59380
#define sipName_Nigeria &sipStrings_QtCore[59380]
#define sipNameNr_NoArrow 59388
#define sipName_NoArrow &sipStrings_QtCore[59388]
#define sipNameNr_NoBrush 59396
#define sipName_NoBrush &sipStrings_QtCore[59396]
#define sipNameNr_NoError 59404
#define sipName_NoError &sipStrings_QtCore[59404]
#define sipNameNr_NoFocus 59412
#define sipName_NoFocus &sipStrings_QtCore[59412]
#define sipNameNr_NoMatch 59420
#define sipName_NoMatch &sipStrings_QtCore[59420]
#define sipNameNr_NoToken 59428
#define sipName_NoToken &sipStrings_QtCore[59428]
#define sipNameNr_NotOpen 59436
#define sipName_NotOpen &sipStrings_QtCore[59436]
#define sipNameNr_Occitan 59444
#define sipName_Occitan &sipStrings_QtCore[59444]
#define sipNameNr_Ossetic 59452
#define sipName_Ossetic &sipStrings_QtCore[59452]
#define sipNameNr_OutBack 52630
#define sipName_OutBack &sipStrings_QtCore[52630]
#define sipNameNr_OutCirc 52640
#define sipName_OutCirc &sipStrings_QtCore[52640]
#define sipNameNr_OutExpo 52650
#define sipName_OutExpo &sipStrings_QtCore[52650]
#define sipNameNr_OutQuad 52660
#define sipName_OutQuad &sipStrings_QtCore[52660]
#define sipNameNr_OutSine 52670
#define sipName_OutSine &sipStrings_QtCore[52670]
#define sipNameNr_Pahlavi 59460
#define sipName_Pahlavi &sipStrings_QtCore[59460]
#define sipNameNr_Palauan 59468
#define sipName_Palauan &sipStrings_QtCore[59468]
#define sipNameNr_Palette 35480
#define sipName_Palette &sipStrings_QtCore[35480]
#define sipNameNr_Persian 8456
#define sipName_Persian &sipStrings_QtCore[8456]
#define sipNameNr_Polygon 56566
#define sipName_Polygon &sipStrings_QtCore[56566]
#define sipNameNr_Private 59476
#define sipName_Private &sipStrings_QtCore[59476]
#define sipNameNr_Punjabi 59484
#define sipName_Punjabi &sipStrings_QtCore[59484]
#define sipNameNr_QBitmap 59492
#define sipName_QBitmap &sipStrings_QtCore[59492]
#define sipNameNr_QBuffer 59500
#define sipName_QBuffer &sipStrings_QtCore[59500]
#define sipNameNr_QCursor 59508
#define sipName_QCursor &sipStrings_QtCore[59508]
#define sipNameNr_QLocale 59516
#define sipName_QLocale &sipStrings_QtCore[59516]
#define sipNameNr_QMatrix 59524
#define sipName_QMatrix &sipStrings_QtCore[59524]
#define sipNameNr_QObject 25211
#define sipName_QObject &sipStrings_QtCore[25211]
#define sipNameNr_QPixmap 59532
#define sipName_QPixmap &sipStrings_QtCore[59532]
#define sipNameNr_QPointF 59540
#define sipName_QPointF &sipStrings_QtCore[59540]
#define sipNameNr_QRegExp 59548
#define sipName_QRegExp &sipStrings_QtCore[59548]
#define sipNameNr_QRegion 59556
#define sipName_QRegion &sipStrings_QtCore[59556]
#define sipNameNr_QString 44176
#define sipName_QString &sipStrings_QtCore[44176]
#define sipNameNr_QThread 59564
#define sipName_QThread &sipStrings_QtCore[59564]
#define sipNameNr_QWidget 59572
#define sipName_QWidget &sipStrings_QtCore[59572]
#define sipNameNr_Q_ENUMS 59580
#define sipName_Q_ENUMS &sipStrings_QtCore[59580]
#define sipNameNr_Q_FLAGS 59588
#define sipName_Q_FLAGS &sipStrings_QtCore[59588]
#define sipNameNr_Qt__Key 59596
#define sipName_Qt__Key &sipStrings_QtCore[59596]
#define sipNameNr_Qt_5_10 59604
#define sipName_Qt_5_10 &sipStrings_QtCore[59604]
#define sipNameNr_Qt_5_11 59612
#define sipName_Qt_5_11 &sipStrings_QtCore[59612]
#define sipNameNr_Qt_5_12 59620
#define sipName_Qt_5_12 &sipStrings_QtCore[59620]
#define sipNameNr_Qt_5_13 59628
#define sipName_Qt_5_13 &sipStrings_QtCore[59628]
#define sipNameNr_Qt_5_14 59636
#define sipName_Qt_5_14 &sipStrings_QtCore[59636]
#define sipNameNr_Qt_5_15 59644
#define sipName_Qt_5_15 &sipStrings_QtCore[59644]
#define sipNameNr_Quechua 59652
#define sipName_Quechua &sipStrings_QtCore[59652]
#define sipNameNr_RegExp2 59660
#define sipName_RegExp2 &sipStrings_QtCore[59660]
#define sipNameNr_Reunion 59668
#define sipName_Reunion &sipStrings_QtCore[59668]
#define sipNameNr_Romania 59676
#define sipName_Romania &sipStrings_QtCore[59676]
#define sipNameNr_Romansh 59684
#define sipName_Romansh &sipStrings_QtCore[59684]
#define sipNameNr_Running 49794
#define sipName_Running &sipStrings_QtCore[49794]
#define sipNameNr_Russian 59692
#define sipName_Russian &sipStrings_QtCore[59692]
#define sipNameNr_Sabaean 59700
#define sipName_Sabaean &sipStrings_QtCore[59700]
#define sipNameNr_Samburu 59708
#define sipName_Samburu &sipStrings_QtCore[59708]
#define sipNameNr_Santali 59716
#define sipName_Santali &sipStrings_QtCore[59716]
#define sipNameNr_Saraiki 59724
#define sipName_Saraiki &sipStrings_QtCore[59724]
#define sipNameNr_Senegal 59732
#define sipName_Senegal &sipStrings_QtCore[59732]
#define sipNameNr_Serbian 59740
#define sipName_Serbian &sipStrings_QtCore[59740]
#define sipNameNr_Sinhala 59748
#define sipName_Sinhala &sipStrings_QtCore[59748]
#define sipNameNr_SockAct 59756
#define sipName_SockAct &sipStrings_QtCore[59756]
#define sipNameNr_Somalia 59764
#define sipName_Somalia &sipStrings_QtCore[59764]
#define sipNameNr_Spanish 59772
#define sipName_Spanish &sipStrings_QtCore[59772]
#define sipNameNr_Stopped 21298
#define sipName_Stopped &sipStrings_QtCore[21298]
#define sipNameNr_Swahili 39951
#define sipName_Swahili &sipStrings_QtCore[39951]
#define sipNameNr_Swedish 59780
#define sipName_Swedish &sipStrings_QtCore[59780]
#define sipNameNr_Sylheti 59788
#define sipName_Sylheti &sipStrings_QtCore[59788]
#define sipNameNr_Tagalog 59796
#define sipName_Tagalog &sipStrings_QtCore[59796]
#define sipNameNr_Tasawaq 59804
#define sipName_Tasawaq &sipStrings_QtCore[59804]
#define sipNameNr_Tibetan 59812
#define sipName_Tibetan &sipStrings_QtCore[59812]
#define sipNameNr_Tokelau 59820
#define sipName_Tokelau &sipStrings_QtCore[59820]
#define sipNameNr_ToolTip 3777
#define sipName_ToolTip &sipStrings_QtCore[3777]
#define sipNameNr_TopEdge 59828
#define sipName_TopEdge &sipStrings_QtCore[59828]
#define sipNameNr_Tuesday 59836
#define sipName_Tuesday &sipStrings_QtCore[59836]
#define sipNameNr_Tunisia 59844
#define sipName_Tunisia &sipStrings_QtCore[59844]
#define sipNameNr_Turkish 49827
#define sipName_Turkish &sipStrings_QtCore[49827]
#define sipNameNr_Turkmen 59852
#define sipName_Turkmen &sipStrings_QtCore[59852]
#define sipNameNr_Ukraine 59860
#define sipName_Ukraine &sipStrings_QtCore[59860]
#define sipNameNr_Unknown 50421
#define sipName_Unknown &sipStrings_QtCore[50421]
#define sipNameNr_UpArrow 59868
#define sipName_UpArrow &sipStrings_QtCore[59868]
#define sipNameNr_Uruguay 59876
#define sipName_Uruguay &sipStrings_QtCore[59876]
#define sipNameNr_Vanuatu 59884
#define sipName_Vanuatu &sipStrings_QtCore[59884]
#define sipNameNr_Variant 33276
#define sipName_Variant &sipStrings_QtCore[33276]
#define sipNameNr_Version 8720
#define sipName_Version &sipStrings_QtCore[8720]
#define sipNameNr_Vietnam 59892
#define sipName_Vietnam &sipStrings_QtCore[59892]
#define sipNameNr_Volapuk 59900
#define sipName_Volapuk &sipStrings_QtCore[59900]
#define sipNameNr_Walloon 59908
#define sipName_Walloon &sipStrings_QtCore[59908]
#define sipNameNr_WatchOS 59916
#define sipName_WatchOS &sipStrings_QtCore[59916]
#define sipNameNr_Windows 21820
#define sipName_Windows &sipStrings_QtCore[21820]
#define sipNameNr_Yangben 59924
#define sipName_Yangben &sipStrings_QtCore[59924]
#define sipNameNr_Yiddish 59932
#define sipName_Yiddish &sipStrings_QtCore[59932]
#define sipNameNr___add__ 59940
#define sipName___add__ &sipStrings_QtCore[59940]
#define sipNameNr___and__ 59948
#define sipName___and__ &sipStrings_QtCore[59948]
#define sipNameNr___int__ 59956
#define sipName___int__ &sipStrings_QtCore[59956]
#define sipNameNr___ior__ 59964
#define sipName___ior__ &sipStrings_QtCore[59964]
#define sipNameNr___len__ 59972
#define sipName___len__ &sipStrings_QtCore[59972]
#define sipNameNr___mul__ 59980
#define sipName___mul__ &sipStrings_QtCore[59980]
#define sipNameNr___neg__ 59988
#define sipName___neg__ &sipStrings_QtCore[59988]
#define sipNameNr___pos__ 59996
#define sipName___pos__ &sipStrings_QtCore[59996]
#define sipNameNr___str__ 60004
#define sipName___str__ &sipStrings_QtCore[60004]
#define sipNameNr___sub__ 60012
#define sipName___sub__ &sipStrings_QtCore[60012]
#define sipNameNr___xor__ 60020
#define sipName___xor__ &sipStrings_QtCore[60020]
#define sipNameNr_acquire 60028
#define sipName_acquire &sipStrings_QtCore[60028]
#define sipNameNr_addData 60036
#define sipName_addData &sipStrings_QtCore[60036]
#define sipNameNr_addDays 60044
#define sipName_addDays &sipStrings_QtCore[60044]
#define sipNameNr_addPath 60052
#define sipName_addPath &sipStrings_QtCore[60052]
#define sipNameNr_addSecs 60060
#define sipName_addSecs &sipStrings_QtCore[60060]
#define sipNameNr_aliases 60068
#define sipName_aliases &sipStrings_QtCore[60068]
#define sipNameNr_allKeys 60076
#define sipName_allKeys &sipStrings_QtCore[60076]
#define sipNameNr_angleTo 60084
#define sipName_angleTo &sipStrings_QtCore[60084]
#define sipNameNr_bounded 60092
#define sipName_bounded &sipStrings_QtCore[60092]
#define sipNameNr_caching 60100
#define sipName_caching &sipStrings_QtCore[60100]
#define sipNameNr_chopped 60108
#define sipName_chopped &sipStrings_QtCore[60108]
#define sipNameNr_comment 60116
#define sipName_comment &sipStrings_QtCore[60116]
#define sipNameNr_compare 60124
#define sipName_compare &sipStrings_QtCore[60124]
#define sipNameNr_convert 60132
#define sipName_convert &sipStrings_QtCore[60132]
#define sipNameNr_country 60140
#define sipName_country &sipStrings_QtCore[60140]
#define sipNameNr_created 60148
#define sipName_created &sipStrings_QtCore[60148]
#define sipNameNr_current 60156
#define sipName_current &sipStrings_QtCore[60156]
#define sipNameNr_darkRed 60164
#define sipName_darkRed &sipStrings_QtCore[60164]
#define sipNameNr_dayName 60172
#define sipName_dayName &sipStrings_QtCore[60172]
#define sipNameNr_decoded 60180
#define sipName_decoded &sipStrings_QtCore[60180]
#define sipNameNr_dirName 60188
#define sipName_dirName &sipStrings_QtCore[60188]
#define sipNameNr_discard 60196
#define sipName_discard &sipStrings_QtCore[60196]
#define sipNameNr_dtdName 60204
#define sipName_dtdName &sipStrings_QtCore[60204]
#define sipNameNr_elapsed 60212
#define sipName_elapsed &sipStrings_QtCore[60212]
#define sipNameNr_enabled 60220
#define sipName_enabled &sipStrings_QtCore[60220]
#define sipNameNr_entered 18673
#define sipName_entered &sipStrings_QtCore[18673]
#define sipNameNr_exclude 60228
#define sipName_exclude &sipStrings_QtCore[60228]
#define sipNameNr_execute 60236
#define sipName_execute &sipStrings_QtCore[60236]
#define sipNameNr_filters 60244
#define sipName_filters &sipStrings_QtCore[60244]
#define sipNameNr_formats 60252
#define sipName_formats &sipStrings_QtCore[60252]
#define sipNameNr_fromAce 60260
#define sipName_fromAce &sipStrings_QtCore[60260]
#define sipNameNr_fromHex 60268
#define sipName_fromHex &sipStrings_QtCore[60268]
#define sipNameNr_getChar 55310
#define sipName_getChar &sipStrings_QtCore[55310]
#define sipNameNr_getDate 60276
#define sipName_getDate &sipStrings_QtCore[60276]
#define sipNameNr_getRect 9008
#define sipName_getRect &sipStrings_QtCore[9008]
#define sipNameNr_global_ 60284
#define sipName_global_ &sipStrings_QtCore[60284]
#define sipNameNr_groupId 60292
#define sipName_groupId &sipStrings_QtCore[60292]
#define sipNameNr_grownBy 60300
#define sipName_grownBy &sipStrings_QtCore[60300]
#define sipNameNr_hasHtml 60308
#define sipName_hasHtml &sipStrings_QtCore[60308]
#define sipNameNr_hasNext 60316
#define sipName_hasNext &sipStrings_QtCore[60316]
#define sipNameNr_hasText 60324
#define sipName_hasText &sipStrings_QtCore[60324]
#define sipNameNr_hasUrls 60332
#define sipName_hasUrls &sipStrings_QtCore[60332]
#define sipNameNr_include 60340
#define sipName_include &sipStrings_QtCore[60340]
#define sipNameNr_indexIn 60348
#define sipName_indexIn &sipStrings_QtCore[60348]
#define sipNameNr_indexOf 60356
#define sipName_indexOf &sipStrings_QtCore[60356]
#define sipNameNr_indexes 60364
#define sipName_indexes &sipStrings_QtCore[60364]
#define sipNameNr_isArray 60372
#define sipName_isArray &sipStrings_QtCore[60372]
#define sipNameNr_isCDATA 60380
#define sipName_isCDATA &sipStrings_QtCore[60380]
#define sipNameNr_isEmpty 60388
#define sipName_isEmpty &sipStrings_QtCore[60388]
#define sipNameNr_isFalse 60396
#define sipName_isFalse &sipStrings_QtCore[60396]
#define sipNameNr_isFinal 60404
#define sipName_isFinal &sipStrings_QtCore[60404]
#define sipNameNr_isFloat 60412
#define sipName_isFloat &sipStrings_QtCore[60412]
#define sipNameNr_isLower 60420
#define sipName_isLower &sipStrings_QtCore[60420]
#define sipNameNr_isLunar 60428
#define sipName_isLunar &sipStrings_QtCore[60428]
#define sipNameNr_isReady 60436
#define sipName_isReady &sipStrings_QtCore[60436]
#define sipNameNr_isSolar 60444
#define sipName_isSolar &sipStrings_QtCore[60444]
#define sipNameNr_isUpper 60452
#define sipName_isUpper &sipStrings_QtCore[60452]
#define sipNameNr_isValid 60460
#define sipName_isValid &sipStrings_QtCore[60460]
#define sipNameNr_machine 60468
#define sipName_machine &sipStrings_QtCore[60468]
#define sipNameNr_magenta 60476
#define sipName_magenta &sipStrings_QtCore[60476]
#define sipNameNr_mapRoot 60484
#define sipName_mapRoot &sipStrings_QtCore[60484]
#define sipNameNr_mapping 60492
#define sipName_mapping &sipStrings_QtCore[60492]
#define sipNameNr_matches 60500
#define sipName_matches &sipStrings_QtCore[60500]
#define sipNameNr_message 60508
#define sipName_message &sipStrings_QtCore[60508]
#define sipNameNr_mibEnum 60516
#define sipName_mibEnum &sipStrings_QtCore[60516]
#define sipNameNr_moveRow 54880
#define sipName_moveRow &sipStrings_QtCore[54880]
#define sipNameNr_moveTop 60524
#define sipName_moveTop &sipStrings_QtCore[60524]
#define sipNameNr_msecsTo 60532
#define sipName_msecsTo &sipStrings_QtCore[60532]
#define sipNameNr_onEntry 60540
#define sipName_onEntry &sipStrings_QtCore[60540]
#define sipNameNr_options 60548
#define sipName_options &sipStrings_QtCore[60548]
#define sipNameNr_ownerId 60556
#define sipName_ownerId &sipStrings_QtCore[60556]
#define sipNameNr_padChar 60564
#define sipName_padChar &sipStrings_QtCore[60564]
#define sipNameNr_parents 60572
#define sipName_parents &sipStrings_QtCore[60572]
#define sipNameNr_pattern 60580
#define sipName_pattern &sipStrings_QtCore[60580]
#define sipNameNr_percent 60588
#define sipName_percent &sipStrings_QtCore[60588]
#define sipNameNr_pointAt 60596
#define sipName_pointAt &sipStrings_QtCore[60596]
#define sipNameNr_prepend 60604
#define sipName_prepend &sipStrings_QtCore[60604]
#define sipNameNr_process 60612
#define sipName_process &sipStrings_QtCore[60612]
#define sipNameNr_program 60620
#define sipName_program &sipStrings_QtCore[60620]
#define sipNameNr_putChar 60628
#define sipName_putChar &sipStrings_QtCore[60628]
#define sipNameNr_qIsNull 60636
#define sipName_qIsNull &sipStrings_QtCore[60636]
#define sipNameNr_qintptr 60644
#define sipName_qintptr &sipStrings_QtCore[60644]
#define sipNameNr_rawData 60652
#define sipName_rawData &sipStrings_QtCore[60652]
#define sipNameNr_readAll 60660
#define sipName_readAll &sipStrings_QtCore[60660]
#define sipNameNr_readInt 60668
#define sipName_readInt &sipStrings_QtCore[60668]
#define sipNameNr_reblock 60676
#define sipName_reblock &sipStrings_QtCore[60676]
#define sipNameNr_refresh 60684
#define sipName_refresh &sipStrings_QtCore[60684]
#define sipNameNr_release 60692
#define sipName_release &sipStrings_QtCore[60692]
#define sipNameNr_removed 60700
#define sipName_removed &sipStrings_QtCore[60700]
#define sipNameNr_reparse 60708
#define sipName_reparse &sipStrings_QtCore[60708]
#define sipNameNr_replace 60716
#define sipName_replace &sipStrings_QtCore[60716]
#define sipNameNr_reserve 60724
#define sipName_reserve &sipStrings_QtCore[60724]
#define sipNameNr_resolve 60732
#define sipName_resolve &sipStrings_QtCore[60732]
#define sipNameNr_restart 60740
#define sipName_restart &sipStrings_QtCore[60740]
#define sipNameNr_setData 12021
#define sipName_setData &sipStrings_QtCore[12021]
#define sipNameNr_setDate 60748
#define sipName_setDate &sipStrings_QtCore[60748]
#define sipNameNr_setFile 60756
#define sipName_setFile &sipStrings_QtCore[60756]
#define sipNameNr_setHost 60764
#define sipName_setHost &sipStrings_QtCore[60764]
#define sipNameNr_setHtml 60772
#define sipName_setHtml &sipStrings_QtCore[60772]
#define sipNameNr_setLeft 60780
#define sipName_setLeft &sipStrings_QtCore[60780]
#define sipNameNr_setLine 60788
#define sipName_setLine &sipStrings_QtCore[60788]
#define sipNameNr_setPath 60796
#define sipName_setPath &sipStrings_QtCore[60796]
#define sipNameNr_setPort 60804
#define sipName_setPort &sipStrings_QtCore[60804]
#define sipNameNr_setRect 60812
#define sipName_setRect &sipStrings_QtCore[60812]
#define sipNameNr_setSize 60820
#define sipName_setSize &sipStrings_QtCore[60820]
#define sipNameNr_setText 60828
#define sipName_setText &sipStrings_QtCore[60828]
#define sipNameNr_setTime 60836
#define sipName_setTime &sipStrings_QtCore[60836]
#define sipNameNr_setType 60844
#define sipName_setType &sipStrings_QtCore[60844]
#define sipNameNr_setUrls 60852
#define sipName_setUrls &sipStrings_QtCore[60852]
#define sipNameNr_sibling 60860
#define sipName_sibling &sipStrings_QtCore[60860]
#define sipNameNr_sortKey 60868
#define sipName_sortKey &sipStrings_QtCore[60868]
#define sipNameNr_sorting 60876
#define sipName_sorting &sipStrings_QtCore[60876]
#define sipNameNr_squeeze 60884
#define sipName_squeeze &sipStrings_QtCore[60884]
#define sipNameNr_started 60892
#define sipName_started &sipStrings_QtCore[60892]
#define sipNameNr_stopped 60900
#define sipName_stopped &sipStrings_QtCore[60900]
#define sipNameNr_testBit 60908
#define sipName_testBit &sipStrings_QtCore[60908]
#define sipNameNr_timeout 60916
#define sipName_timeout &sipStrings_QtCore[60916]
#define sipNameNr_timerId 60924
#define sipName_timerId &sipStrings_QtCore[60924]
#define sipNameNr_toArray 60932
#define sipName_toArray &sipStrings_QtCore[60932]
#define sipNameNr_toFloat 60940
#define sipName_toFloat &sipStrings_QtCore[60940]
#define sipNameNr_toLower 60948
#define sipName_toLower &sipStrings_QtCore[60948]
#define sipNameNr_toPoint 60956
#define sipName_toPoint &sipStrings_QtCore[60956]
#define sipNameNr_toShort 60964
#define sipName_toShort &sipStrings_QtCore[60964]
#define sipNameNr_toStart 60972
#define sipName_toStart &sipStrings_QtCore[60972]
#define sipNameNr_toULong 60980
#define sipName_toULong &sipStrings_QtCore[60980]
#define sipNameNr_toUpper 60988
#define sipName_toUpper &sipStrings_QtCore[60988]
#define sipNameNr_topLeft 60996
#define sipName_topLeft &sipStrings_QtCore[60996]
#define sipNameNr_trimmed 61004
#define sipName_trimmed &sipStrings_QtCore[61004]
#define sipNameNr_tryLock 61012
#define sipName_tryLock &sipStrings_QtCore[61012]
#define sipNameNr_tryTake 61020
#define sipName_tryTake &sipStrings_QtCore[61020]
#define sipNameNr_unblock 61028
#define sipName_unblock &sipStrings_QtCore[61028]
#define sipNameNr_variant 61036
#define sipName_variant &sipStrings_QtCore[61036]
#define sipNameNr_version 18825
#define sipName_version &sipStrings_QtCore[18825]
#define sipNameNr_wakeAll 61044
#define sipName_wakeAll &sipStrings_QtCore[61044]
#define sipNameNr_wakeOne 61052
#define sipName_wakeOne &sipStrings_QtCore[61052]
#define sipNameNr_warning 61060
#define sipName_warning &sipStrings_QtCore[61060]
#define sipNameNr_Access 16452
#define sipName_Access &sipStrings_QtCore[16452]
#define sipNameNr_Akoose 61068
#define sipName_Akoose &sipStrings_QtCore[61068]
#define sipNameNr_Angola 61075
#define sipName_Angola &sipStrings_QtCore[61075]
#define sipNameNr_Append 61082
#define sipName_Append &sipStrings_QtCore[61082]
#define sipNameNr_Arabic 61089
#define sipName_Arabic &sipStrings_QtCore[61089]
#define sipNameNr_Avaric 61096
#define sipName_Avaric &sipStrings_QtCore[61096]
#define sipNameNr_Aymara 61103
#define sipName_Aymara &sipStrings_QtCore[61103]
#define sipNameNr_BGMode 50103
#define sipName_BGMode &sipStrings_QtCore[50103]
#define sipNameNr_Base64 31762
#define sipName_Base64 &sipStrings_QtCore[31762]
#define sipNameNr_Basque 61110
#define sipName_Basque &sipStrings_QtCore[61110]
#define sipNameNr_Belize 61117
#define sipName_Belize &sipStrings_QtCore[61117]
#define sipNameNr_Bhutan 61124
#define sipName_Bhutan &sipStrings_QtCore[61124]
#define sipNameNr_Bihari 61131
#define sipName_Bihari &sipStrings_QtCore[61131]
#define sipNameNr_Bitmap 59493
#define sipName_Bitmap &sipStrings_QtCore[59493]
#define sipNameNr_Brazil 61138
#define sipName_Brazil &sipStrings_QtCore[61138]
#define sipNameNr_Breton 61145
#define sipName_Breton &sipStrings_QtCore[61145]
#define sipNameNr_Brunei 61152
#define sipName_Brunei &sipStrings_QtCore[61152]
#define sipNameNr_Canada 61159
#define sipName_Canada &sipStrings_QtCore[61159]
#define sipNameNr_Carian 61166
#define sipName_Carian &sipStrings_QtCore[61166]
#define sipNameNr_Chakma 61173
#define sipName_Chakma &sipStrings_QtCore[61173]
#define sipNameNr_Church 61180
#define sipName_Church &sipStrings_QtCore[61180]
#define sipNameNr_Coptic 61187
#define sipName_Coptic &sipStrings_QtCore[61187]
#define sipNameNr_Corner 21173
#define sipName_Corner &sipStrings_QtCore[21173]
#define sipNameNr_Create 61194
#define sipName_Create &sipStrings_QtCore[61194]
#define sipNameNr_Cursor 18389
#define sipName_Cursor &sipStrings_QtCore[18389]
#define sipNameNr_Custom 61201
#define sipName_Custom &sipStrings_QtCore[61201]
#define sipNameNr_Cyprus 61208
#define sipName_Cyprus &sipStrings_QtCore[61208]
#define sipNameNr_Danish 61215
#define sipName_Danish &sipStrings_QtCore[61215]
#define sipNameNr_Dialog 4538
#define sipName_Dialog &sipStrings_QtCore[4538]
#define sipNameNr_Divehi 61222
#define sipName_Divehi &sipStrings_QtCore[61222]
#define sipNameNr_Double 34552
#define sipName_Double &sipStrings_QtCore[34552]
#define sipNameNr_Drawer 61229
#define sipName_Drawer &sipStrings_QtCore[61229]
#define sipNameNr_Drives 61236
#define sipName_Drives &sipStrings_QtCore[61236]
#define sipNameNr_Endian 25484
#define sipName_Endian &sipStrings_QtCore[25484]
#define sipNameNr_Europe 61243
#define sipName_Europe &sipStrings_QtCore[61243]
#define sipNameNr_Ewondo 61250
#define sipName_Ewondo &sipStrings_QtCore[61250]
#define sipNameNr_Expose 61257
#define sipName_Expose &sipStrings_QtCore[61257]
#define sipNameNr_False_ 61264
#define sipName_False_ &sipStrings_QtCore[61264]
#define sipNameNr_Fijian 61271
#define sipName_Fijian &sipStrings_QtCore[61271]
#define sipNameNr_Filter 5138
#define sipName_Filter &sipStrings_QtCore[5138]
#define sipNameNr_Format 2989
#define sipName_Format &sipStrings_QtCore[2989]
#define sipNameNr_France 61278
#define sipName_France &sipStrings_QtCore[61278]
#define sipNameNr_French 61285
#define sipName_French &sipStrings_QtCore[61285]
#define sipNameNr_Friday 61292
#define sipName_Friday &sipStrings_QtCore[61292]
#define sipNameNr_Gaelic 61299
#define sipName_Gaelic &sipStrings_QtCore[61299]
#define sipNameNr_Gambia 61306
#define sipName_Gambia &sipStrings_QtCore[61306]
#define sipNameNr_German 46326
#define sipName_German &sipStrings_QtCore[46326]
#define sipNameNr_Gothic 61313
#define sipName_Gothic &sipStrings_QtCore[61313]
#define sipNameNr_Greece 61320
#define sipName_Greece &sipStrings_QtCore[61320]
#define sipNameNr_Guinea 24464
#define sipName_Guinea &sipStrings_QtCore[24464]
#define sipNameNr_Guyana 61327
#define sipName_Guyana &sipStrings_QtCore[61327]
#define sipNameNr_Hebrew 61334
#define sipName_Hebrew &sipStrings_QtCore[61334]
#define sipNameNr_Herero 61341
#define sipName_Herero &sipStrings_QtCore[61341]
#define sipNameNr_Hidden 21119
#define sipName_Hidden &sipStrings_QtCore[21119]
#define sipNameNr_ImFont 61348
#define sipName_ImFont &sipStrings_QtCore[61348]
#define sipNameNr_InBack 53271
#define sipName_InBack &sipStrings_QtCore[53271]
#define sipNameNr_InCirc 53281
#define sipName_InCirc &sipStrings_QtCore[53281]
#define sipNameNr_InExpo 53291
#define sipName_InExpo &sipStrings_QtCore[53291]
#define sipNameNr_InQuad 53301
#define sipName_InQuad &sipStrings_QtCore[53301]
#define sipNameNr_InSine 53311
#define sipName_InSine &sipStrings_QtCore[53311]
#define sipNameNr_Ingush 61355
#define sipName_Ingush &sipStrings_QtCore[61355]
#define sipNameNr_Israel 61362
#define sipName_Israel &sipStrings_QtCore[61362]
#define sipNameNr_Jalali 61369
#define sipName_Jalali &sipStrings_QtCore[61369]
#define sipNameNr_Jersey 61376
#define sipName_Jersey &sipStrings_QtCore[61376]
#define sipNameNr_Jordan 61383
#define sipName_Jordan &sipStrings_QtCore[61383]
#define sipNameNr_Julian 61390
#define sipName_Julian &sipStrings_QtCore[61390]
#define sipNameNr_Kabyle 61397
#define sipName_Kabyle &sipStrings_QtCore[61397]
#define sipNameNr_Kanuri 61404
#define sipName_Kanuri &sipStrings_QtCore[61404]
#define sipNameNr_Kazakh 61411
#define sipName_Kazakh &sipStrings_QtCore[61411]
#define sipNameNr_Key_AE 61418
#define sipName_Key_AE &sipStrings_QtCore[61418]
#define sipNameNr_Key_At 61425
#define sipName_Key_At &sipStrings_QtCore[61425]
#define sipNameNr_Key_CD 61432
#define sipName_Key_CD &sipStrings_QtCore[61432]
#define sipNameNr_Key_F1 61439
#define sipName_Key_F1 &sipStrings_QtCore[61439]
#define sipNameNr_Key_F2 61446
#define sipName_Key_F2 &sipStrings_QtCore[61446]
#define sipNameNr_Key_F3 61453
#define sipName_Key_F3 &sipStrings_QtCore[61453]
#define sipNameNr_Key_F4 61460
#define sipName_Key_F4 &sipStrings_QtCore[61460]
#define sipNameNr_Key_F5 61467
#define sipName_Key_F5 &sipStrings_QtCore[61467]
#define sipNameNr_Key_F6 61474
#define sipName_Key_F6 &sipStrings_QtCore[61474]
#define sipNameNr_Key_F7 61481
#define sipName_Key_F7 &sipStrings_QtCore[61481]
#define sipNameNr_Key_F8 61488
#define sipName_Key_F8 &sipStrings_QtCore[61488]
#define sipNameNr_Key_F9 61495
#define sipName_Key_F9 &sipStrings_QtCore[61495]
#define sipNameNr_Key_Go 61502
#define sipName_Key_Go &sipStrings_QtCore[61502]
#define sipNameNr_Key_No 61509
#define sipName_Key_No &sipStrings_QtCore[61509]
#define sipNameNr_Key_Up 61516
#define sipName_Key_Up &sipStrings_QtCore[61516]
#define sipNameNr_Key_mu 61523
#define sipName_Key_mu &sipStrings_QtCore[61523]
#define sipNameNr_Kikuyu 61530
#define sipName_Kikuyu &sipStrings_QtCore[61530]
#define sipNameNr_Korean 61537
#define sipName_Korean &sipStrings_QtCore[61537]
#define sipNameNr_Kosovo 61544
#define sipName_Kosovo &sipStrings_QtCore[61544]
#define sipNameNr_Kpelle 61551
#define sipName_Kpelle &sipStrings_QtCore[61551]
#define sipNameNr_Kuwait 61558
#define sipName_Kuwait &sipStrings_QtCore[61558]
#define sipNameNr_Kwasio 61565
#define sipName_Kwasio &sipStrings_QtCore[61565]
#define sipNameNr_Lakota 61572
#define sipName_Lakota &sipStrings_QtCore[61572]
#define sipNameNr_Latvia 61579
#define sipName_Latvia &sipStrings_QtCore[61579]
#define sipNameNr_Lepcha 61586
#define sipName_Lepcha &sipStrings_QtCore[61586]
#define sipNameNr_Linear 61593
#define sipName_Linear &sipStrings_QtCore[61593]
#define sipNameNr_Locale 23657
#define sipName_Locale &sipStrings_QtCore[23657]
#define sipNameNr_Lojban 61600
#define sipName_Lojban &sipStrings_QtCore[61600]
#define sipNameNr_Lycian 61607
#define sipName_Lycian &sipStrings_QtCore[61607]
#define sipNameNr_Lydian 61614
#define sipName_Lydian &sipStrings_QtCore[61614]
#define sipNameNr_Malawi 61621
#define sipName_Malawi &sipStrings_QtCore[61621]
#define sipNameNr_Matrix 59525
#define sipName_Matrix &sipStrings_QtCore[59525]
#define sipNameNr_Method 38757
#define sipName_Method &sipStrings_QtCore[38757]
#define sipNameNr_Mexico 61628
#define sipName_Mexico &sipStrings_QtCore[61628]
#define sipNameNr_Mohawk 61635
#define sipName_Mohawk &sipStrings_QtCore[61635]
#define sipNameNr_Monaco 61642
#define sipName_Monaco &sipStrings_QtCore[61642]
#define sipNameNr_Monday 61649
#define sipName_Monday &sipStrings_QtCore[61649]
#define sipNameNr_Navaho 61656
#define sipName_Navaho &sipStrings_QtCore[61656]
#define sipNameNr_Ndonga 61663
#define sipName_Ndonga &sipStrings_QtCore[61663]
#define sipNameNr_Nepali 61670
#define sipName_Nepali &sipStrings_QtCore[61670]
#define sipNameNr_Newari 61677
#define sipName_Newari &sipStrings_QtCore[61677]
#define sipNameNr_Ngomba 61684
#define sipName_Ngomba &sipStrings_QtCore[61684]
#define sipNameNr_NoClip 61691
#define sipName_NoClip &sipStrings_QtCore[61691]
#define sipNameNr_NoSort 61698
#define sipName_NoSort &sipStrings_QtCore[61698]
#define sipNameNr_Norway 61705
#define sipName_Norway &sipStrings_QtCore[61705]
#define sipNameNr_Nyanja 61712
#define sipName_Nyanja &sipStrings_QtCore[61712]
#define sipNameNr_OSType 2311
#define sipName_OSType &sipStrings_QtCore[2311]
#define sipNameNr_Object 19700
#define sipName_Object &sipStrings_QtCore[19700]
#define sipNameNr_Ojibwa 61719
#define sipName_Ojibwa &sipStrings_QtCore[61719]
#define sipNameNr_Panama 61726
#define sipName_Panama &sipStrings_QtCore[61726]
#define sipNameNr_Pashto 61733
#define sipName_Pashto &sipStrings_QtCore[61733]
#define sipNameNr_Paused 55071
#define sipName_Paused &sipStrings_QtCore[55071]
#define sipNameNr_Pixmap 59533
#define sipName_Pixmap &sipStrings_QtCore[59533]
#define sipNameNr_PointF 59541
#define sipName_PointF &sipStrings_QtCore[59541]
#define sipNameNr_Poland 61740
#define sipName_Poland &sipStrings_QtCore[61740]
#define sipNameNr_Polish 61747
#define sipName_Polish &sipStrings_QtCore[61747]
#define sipNameNr_Public 61754
#define sipName_Public &sipStrings_QtCore[61754]
#define sipNameNr_QBrush 61761
#define sipName_QBrush &sipStrings_QtCore[61761]
#define sipNameNr_QColor 61768
#define sipName_QColor &sipStrings_QtCore[61768]
#define sipNameNr_QEvent 61775
#define sipName_QEvent &sipStrings_QtCore[61775]
#define sipNameNr_QFlags 61782
#define sipName_QFlags &sipStrings_QtCore[61782]
#define sipNameNr_QImage 61789
#define sipName_QImage &sipStrings_QtCore[61789]
#define sipNameNr_QLineF 61796
#define sipName_QLineF &sipStrings_QtCore[61796]
#define sipNameNr_QMutex 61803
#define sipName_QMutex &sipStrings_QtCore[61803]
#define sipNameNr_QPoint 61810
#define sipName_QPoint &sipStrings_QtCore[61810]
#define sipNameNr_QRectF 61817
#define sipName_QRectF &sipStrings_QtCore[61817]
#define sipNameNr_QSizeF 61824
#define sipName_QSizeF &sipStrings_QtCore[61824]
#define sipNameNr_QState 61831
#define sipName_QState &sipStrings_QtCore[61831]
#define sipNameNr_QTimer 61838
#define sipName_QTimer &sipStrings_QtCore[61838]
#define sipNameNr_Q_ENUM 61845
#define sipName_Q_ENUM &sipStrings_QtCore[61845]
#define sipNameNr_Q_FLAG 61852
#define sipName_Q_FLAG &sipStrings_QtCore[61852]
#define sipNameNr_Qt_1_0 61859
#define sipName_Qt_1_0 &sipStrings_QtCore[61859]
#define sipNameNr_Qt_2_0 61866
#define sipName_Qt_2_0 &sipStrings_QtCore[61866]
#define sipNameNr_Qt_2_1 61873
#define sipName_Qt_2_1 &sipStrings_QtCore[61873]
#define sipNameNr_Qt_3_0 61880
#define sipName_Qt_3_0 &sipStrings_QtCore[61880]
#define sipNameNr_Qt_3_1 61887
#define sipName_Qt_3_1 &sipStrings_QtCore[61887]
#define sipNameNr_Qt_3_3 61894
#define sipName_Qt_3_3 &sipStrings_QtCore[61894]
#define sipNameNr_Qt_4_0 61901
#define sipName_Qt_4_0 &sipStrings_QtCore[61901]
#define sipNameNr_Qt_4_1 61908
#define sipName_Qt_4_1 &sipStrings_QtCore[61908]
#define sipNameNr_Qt_4_2 61915
#define sipName_Qt_4_2 &sipStrings_QtCore[61915]
#define sipNameNr_Qt_4_3 61922
#define sipName_Qt_4_3 &sipStrings_QtCore[61922]
#define sipNameNr_Qt_4_4 61929
#define sipName_Qt_4_4 &sipStrings_QtCore[61929]
#define sipNameNr_Qt_4_5 61936
#define sipName_Qt_4_5 &sipStrings_QtCore[61936]
#define sipNameNr_Qt_4_6 61943
#define sipName_Qt_4_6 &sipStrings_QtCore[61943]
#define sipNameNr_Qt_4_7 61950
#define sipName_Qt_4_7 &sipStrings_QtCore[61950]
#define sipNameNr_Qt_4_8 61957
#define sipName_Qt_4_8 &sipStrings_QtCore[61957]
#define sipNameNr_Qt_4_9 61964
#define sipName_Qt_4_9 &sipStrings_QtCore[61964]
#define sipNameNr_Qt_5_0 61971
#define sipName_Qt_5_0 &sipStrings_QtCore[61971]
#define sipNameNr_Qt_5_1 61978
#define sipName_Qt_5_1 &sipStrings_QtCore[61978]
#define sipNameNr_Qt_5_2 61985
#define sipName_Qt_5_2 &sipStrings_QtCore[61985]
#define sipNameNr_Qt_5_3 61992
#define sipName_Qt_5_3 &sipStrings_QtCore[61992]
#define sipNameNr_Qt_5_4 61999
#define sipName_Qt_5_4 &sipStrings_QtCore[61999]
#define sipNameNr_Qt_5_5 62006
#define sipName_Qt_5_5 &sipStrings_QtCore[62006]
#define sipNameNr_Qt_5_6 62013
#define sipName_Qt_5_6 &sipStrings_QtCore[62013]
#define sipNameNr_Qt_5_7 62020
#define sipName_Qt_5_7 &sipStrings_QtCore[62020]
#define sipNameNr_Qt_5_8 62027
#define sipName_Qt_5_8 &sipStrings_QtCore[62027]
#define sipNameNr_Qt_5_9 62034
#define sipName_Qt_5_9 &sipStrings_QtCore[62034]
#define sipNameNr_Random 62041
#define sipName_Random &sipStrings_QtCore[62041]
#define sipNameNr_RegExp 30855
#define sipName_RegExp &sipStrings_QtCore[30855]
#define sipNameNr_Region 59557
#define sipName_Region &sipStrings_QtCore[59557]
#define sipNameNr_Rejang 62048
#define sipName_Rejang &sipStrings_QtCore[62048]
#define sipNameNr_Resize 15732
#define sipName_Resize &sipStrings_QtCore[15732]
#define sipNameNr_Russia 62055
#define sipName_Russia &sipStrings_QtCore[62055]
#define sipNameNr_Rwanda 62062
#define sipName_Rwanda &sipStrings_QtCore[62062]
#define sipNameNr_Samoan 62069
#define sipName_Samoan &sipStrings_QtCore[62069]
#define sipNameNr_Script 4034
#define sipName_Script &sipStrings_QtCore[4034]
#define sipNameNr_Scroll 62076
#define sipName_Scroll &sipStrings_QtCore[62076]
#define sipNameNr_Select 31447
#define sipName_Select &sipStrings_QtCore[31447]
#define sipNameNr_Serbia 62083
#define sipName_Serbia &sipStrings_QtCore[62083]
#define sipNameNr_Sha224 62090
#define sipName_Sha224 &sipStrings_QtCore[62090]
#define sipNameNr_Sha256 62097
#define sipName_Sha256 &sipStrings_QtCore[62097]
#define sipNameNr_Sha384 62104
#define sipName_Sha384 &sipStrings_QtCore[62104]
#define sipNameNr_Sha512 62111
#define sipName_Sha512 &sipStrings_QtCore[62111]
#define sipNameNr_Sidamo 62118
#define sipName_Sidamo &sipStrings_QtCore[62118]
#define sipNameNr_Signal 19548
#define sipName_Signal &sipStrings_QtCore[19548]
#define sipNameNr_Sindhi 62125
#define sipName_Sindhi &sipStrings_QtCore[62125]
#define sipNameNr_Slovak 62132
#define sipName_Slovak &sipStrings_QtCore[62132]
#define sipNameNr_Somali 62139
#define sipName_Somali &sipStrings_QtCore[62139]
#define sipNameNr_Status 1888
#define sipName_Status &sipStrings_QtCore[1888]
#define sipNameNr_String 12748
#define sipName_String &sipStrings_QtCore[12748]
#define sipNameNr_Sunday 62146
#define sipName_Sunday &sipStrings_QtCore[62146]
#define sipNameNr_Sweden 62153
#define sipName_Sweden &sipStrings_QtCore[62153]
#define sipNameNr_Syriac 62160
#define sipName_Syriac &sipStrings_QtCore[62160]
#define sipNameNr_System 2779
#define sipName_System &sipStrings_QtCore[2779]
#define sipNameNr_TaiDam 62167
#define sipName_TaiDam &sipStrings_QtCore[62167]
#define sipNameNr_TaiNua 62174
#define sipName_TaiNua &sipStrings_QtCore[62174]
#define sipNameNr_Taiwan 62181
#define sipName_Taiwan &sipStrings_QtCore[62181]
#define sipNameNr_Tangut 62188
#define sipName_Tangut &sipStrings_QtCore[62188]
#define sipNameNr_Taroko 62195
#define sipName_Taroko &sipStrings_QtCore[62195]
#define sipNameNr_Telugu 62202
#define sipName_Telugu &sipStrings_QtCore[62202]
#define sipNameNr_Toggle 18636
#define sipName_Toggle &sipStrings_QtCore[18636]
#define sipNameNr_Tongan 62209
#define sipName_Tongan &sipStrings_QtCore[62209]
#define sipNameNr_Tsonga 62216
#define sipName_Tsonga &sipStrings_QtCore[62216]
#define sipNameNr_Tswana 62223
#define sipName_Tswana &sipStrings_QtCore[62223]
#define sipNameNr_Turkey 62230
#define sipName_Turkey &sipStrings_QtCore[62230]
#define sipNameNr_Tuvalu 62237
#define sipName_Tuvalu &sipStrings_QtCore[62237]
#define sipNameNr_UShort 58259
#define sipName_UShort &sipStrings_QtCore[58259]
#define sipNameNr_Uganda 62244
#define sipName_Uganda &sipStrings_QtCore[62244]
#define sipNameNr_Uighur 62251
#define sipName_Uighur &sipStrings_QtCore[62251]
#define sipNameNr_Walamo 62258
#define sipName_Walamo &sipStrings_QtCore[62258]
#define sipNameNr_Walser 62265
#define sipName_Walser &sipStrings_QtCore[62265]
#define sipNameNr_Widget 5890
#define sipName_Widget &sipStrings_QtCore[5890]
#define sipNameNr_Window 5516
#define sipName_Window &sipStrings_QtCore[5516]
#define sipNameNr_Yoruba 62272
#define sipName_Yoruba &sipStrings_QtCore[62272]
#define sipNameNr_Zambia 62279
#define sipName_Zambia &sipStrings_QtCore[62279]
#define sipNameNr_Zhuang 62286
#define sipName_Zhuang &sipStrings_QtCore[62286]
#define sipNameNr___eq__ 62293
#define sipName___eq__ &sipStrings_QtCore[62293]
#define sipNameNr___ge__ 62300
#define sipName___ge__ &sipStrings_QtCore[62300]
#define sipNameNr___gt__ 62307
#define sipName___gt__ &sipStrings_QtCore[62307]
#define sipNameNr___le__ 62314
#define sipName___le__ &sipStrings_QtCore[62314]
#define sipNameNr___lt__ 62321
#define sipName___lt__ &sipStrings_QtCore[62321]
#define sipNameNr___ne__ 62328
#define sipName___ne__ &sipStrings_QtCore[62328]
#define sipNameNr___or__ 62335
#define sipName___or__ &sipStrings_QtCore[62335]
#define sipNameNr_accept 62342
#define sipName_accept &sipStrings_QtCore[62342]
#define sipNameNr_access 62349
#define sipName_access &sipStrings_QtCore[62349]
#define sipNameNr_active 15532
#define sipName_active &sipStrings_QtCore[15532]
#define sipNameNr_adjust 62356
#define sipName_adjust &sipStrings_QtCore[62356]
#define sipNameNr_amText 62363
#define sipName_amText &sipStrings_QtCore[62363]
#define sipNameNr_append 62370
#define sipName_append &sipStrings_QtCore[62370]
#define sipNameNr_attach 62377
#define sipName_attach &sipStrings_QtCore[62377]
#define sipNameNr_bottom 62384
#define sipName_bottom &sipStrings_QtCore[62384]
#define sipNameNr_buffer 62391
#define sipName_buffer &sipStrings_QtCore[62391]
#define sipNameNr_cancel 62398
#define sipName_cancel &sipStrings_QtCore[62398]
#define sipNameNr_center 62405
#define sipName_center &sipStrings_QtCore[62405]
#define sipNameNr_color0 62412
#define sipName_color0 &sipStrings_QtCore[62412]
#define sipNameNr_color1 62419
#define sipName_color1 &sipStrings_QtCore[62419]
#define sipNameNr_column 62426
#define sipName_column &sipStrings_QtCore[62426]
#define sipNameNr_commit 62433
#define sipName_commit &sipStrings_QtCore[62433]
#define sipNameNr_create 62440
#define sipName_create &sipStrings_QtCore[62440]
#define sipNameNr_daysTo 62447
#define sipName_daysTo &sipStrings_QtCore[62447]
#define sipNameNr_detach 62454
#define sipName_detach &sipStrings_QtCore[62454]
#define sipNameNr_device 62461
#define sipName_device &sipStrings_QtCore[62461]
#define sipNameNr_drives 62468
#define sipName_drives &sipStrings_QtCore[62468]
#define sipNameNr_endMap 62475
#define sipName_endMap &sipStrings_QtCore[62475]
#define sipNameNr_escape 62482
#define sipName_escape &sipStrings_QtCore[62482]
#define sipNameNr_exists 62489
#define sipName_exists &sipStrings_QtCore[62489]
#define sipNameNr_exited 62496
#define sipName_exited &sipStrings_QtCore[62496]
#define sipNameNr_filter 62503
#define sipName_filter &sipStrings_QtCore[62503]
#define sipNameNr_format 62510
#define sipName_format &sipStrings_QtCore[62510]
#define sipNameNr_handle 62517
#define sipName_handle &sipStrings_QtCore[62517]
#define sipNameNr_height 62524
#define sipName_height &sipStrings_QtCore[62524]
#define sipNameNr_ignore 62531
#define sipName_ignore &sipStrings_QtCore[62531]
#define sipNameNr_insert 62538
#define sipName_insert &sipStrings_QtCore[62538]
#define sipNameNr_invoke 62545
#define sipName_invoke &sipStrings_QtCore[62545]
#define sipNameNr_isBool 62552
#define sipName_isBool &sipStrings_QtCore[62552]
#define sipNameNr_isFile 62559
#define sipName_isFile &sipStrings_QtCore[62559]
#define sipNameNr_isFlag 62566
#define sipName_isFlag &sipStrings_QtCore[62566]
#define sipNameNr_isNull 62573
#define sipName_isNull &sipStrings_QtCore[62573]
#define sipNameNr_isOpen 62580
#define sipName_isOpen &sipStrings_QtCore[62580]
#define sipNameNr_isRoot 62587
#define sipName_isRoot &sipStrings_QtCore[62587]
#define sipNameNr_isTrue 62594
#define sipName_isTrue &sipStrings_QtCore[62594]
#define sipNameNr_isUser 62601
#define sipName_isUser &sipStrings_QtCore[62601]
#define sipNameNr_length 62608
#define sipName_length &sipStrings_QtCore[62608]
#define sipNameNr_locale 62615
#define sipName_locale &sipStrings_QtCore[62615]
#define sipNameNr_locate 62622
#define sipName_locate &sipStrings_QtCore[62622]
#define sipNameNr_mapped 62629
#define sipName_mapped &sipStrings_QtCore[62629]
#define sipNameNr_maxlen 62636
#define sipName_maxlen &sipStrings_QtCore[62636]
#define sipNameNr_method 62643
#define sipName_method &sipStrings_QtCore[62643]
#define sipNameNr_minute 62650
#define sipName_minute &sipStrings_QtCore[62650]
#define sipNameNr_mkpath 62657
#define sipName_mkpath &sipStrings_QtCore[62657]
#define sipNameNr_moveTo 62664
#define sipName_moveTo &sipStrings_QtCore[62664]
#define sipNameNr_msleep 62671
#define sipName_msleep &sipStrings_QtCore[62671]
#define sipNameNr_notify 62678
#define sipName_notify &sipStrings_QtCore[62678]
#define sipNameNr_number 62685
#define sipName_number &sipStrings_QtCore[62685]
#define sipNameNr_object 62692
#define sipName_object &sipStrings_QtCore[62692]
#define sipNameNr_offset 62699
#define sipName_offset &sipStrings_QtCore[62699]
#define sipNameNr_onExit 62706
#define sipName_onExit &sipStrings_QtCore[62706]
#define sipNameNr_parent 6540
#define sipName_parent &sipStrings_QtCore[6540]
#define sipNameNr_period 62713
#define sipName_period &sipStrings_QtCore[62713]
#define sipNameNr_pmText 62720
#define sipName_pmText &sipStrings_QtCore[62720]
#define sipNameNr_policy 62727
#define sipName_policy &sipStrings_QtCore[62727]
#define sipNameNr_prefix 62734
#define sipName_prefix &sipStrings_QtCore[62734]
#define sipNameNr_proper 62741
#define sipName_proper &sipStrings_QtCore[62741]
#define sipNameNr_qDebug 62748
#define sipName_qDebug &sipStrings_QtCore[62748]
#define sipNameNr_qFatal 62755
#define sipName_qFatal &sipStrings_QtCore[62755]
#define sipNameNr_qIsInf 62762
#define sipName_qIsInf &sipStrings_QtCore[62762]
#define sipNameNr_qIsNaN 62769
#define sipName_qIsNaN &sipStrings_QtCore[62769]
#define sipNameNr_qRound 62776
#define sipName_qRound &sipStrings_QtCore[62776]
#define sipNameNr_qsrand 62783
#define sipName_qsrand &sipStrings_QtCore[62783]
#define sipNameNr_relock 62790
#define sipName_relock &sipStrings_QtCore[62790]
#define sipNameNr_remove 62797
#define sipName_remove &sipStrings_QtCore[62797]
#define sipNameNr_rename 62804
#define sipName_rename &sipStrings_QtCore[62804]
#define sipNameNr_resize 62811
#define sipName_resize &sipStrings_QtCore[62811]
#define sipNameNr_result 62818
#define sipName_result &sipStrings_QtCore[62818]
#define sipNameNr_resume 62825
#define sipName_resume &sipStrings_QtCore[62825]
#define sipNameNr_revert 62832
#define sipName_revert &sipStrings_QtCore[62832]
#define sipNameNr_rmpath 62839
#define sipName_rmpath &sipStrings_QtCore[62839]
#define sipNameNr_scaled 62846
#define sipName_scaled &sipStrings_QtCore[62846]
#define sipNameNr_scheme 62853
#define sipName_scheme &sipStrings_QtCore[62853]
#define sipNameNr_script 62860
#define sipName_script &sipStrings_QtCore[62860]
#define sipNameNr_second 62867
#define sipName_second &sipStrings_QtCore[62867]
#define sipNameNr_secsTo 60533
#define sipName_secsTo &sipStrings_QtCore[60533]
#define sipNameNr_select 55577
#define sipName_select &sipStrings_QtCore[55577]
#define sipNameNr_sender 62874
#define sipName_sender &sipStrings_QtCore[62874]
#define sipNameNr_setBit 62881
#define sipName_setBit &sipStrings_QtCore[62881]
#define sipNameNr_setHMS 62888
#define sipName_setHMS &sipStrings_QtCore[62888]
#define sipNameNr_setKey 62895
#define sipName_setKey &sipStrings_QtCore[62895]
#define sipNameNr_setNum 62902
#define sipName_setNum &sipStrings_QtCore[62902]
#define sipNameNr_setTop 62909
#define sipName_setTop &sipStrings_QtCore[62909]
#define sipNameNr_setUrl 62916
#define sipName_setUrl &sipStrings_QtCore[62916]
#define sipNameNr_signal 62923
#define sipName_signal &sipStrings_QtCore[62923]
#define sipNameNr_socket 62930
#define sipName_socket &sipStrings_QtCore[62930]
#define sipNameNr_status 62937
#define sipName_status &sipStrings_QtCore[62937]
#define sipNameNr_string 62944
#define sipName_string &sipStrings_QtCore[62944]
#define sipNameNr_submit 62951
#define sipName_submit &sipStrings_QtCore[62951]
#define sipNameNr_suffix 62958
#define sipName_suffix &sipStrings_QtCore[62958]
#define sipNameNr_symbol 62965
#define sipName_symbol &sipStrings_QtCore[62965]
#define sipNameNr_syntax 62972
#define sipName_syntax &sipStrings_QtCore[62972]
#define sipNameNr_system 62979
#define sipName_system &sipStrings_QtCore[62979]
#define sipNameNr_takeAt 62986
#define sipName_takeAt &sipStrings_QtCore[62986]
#define sipNameNr_thread 62993
#define sipName_thread &sipStrings_QtCore[62993]
#define sipNameNr_toBool 63000
#define sipName_toBool &sipStrings_QtCore[63000]
#define sipNameNr_toDate 63007
#define sipName_toDate &sipStrings_QtCore[63007]
#define sipNameNr_toJson 63014
#define sipName_toJson &sipStrings_QtCore[63014]
#define sipNameNr_toLine 63021
#define sipName_toLine &sipStrings_QtCore[63021]
#define sipNameNr_toLong 63028
#define sipName_toLong &sipStrings_QtCore[63028]
#define sipNameNr_toRect 63035
#define sipName_toRect &sipStrings_QtCore[63035]
#define sipNameNr_toSize 63042
#define sipName_toSize &sipStrings_QtCore[63042]
#define sipNameNr_toTime 63049
#define sipName_toTime &sipStrings_QtCore[63049]
#define sipNameNr_toUInt 63056
#define sipName_toUInt &sipStrings_QtCore[63056]
#define sipNameNr_united 63063
#define sipName_united &sipStrings_QtCore[63063]
#define sipNameNr_unload 63070
#define sipName_unload &sipStrings_QtCore[63070]
#define sipNameNr_unlock 63077
#define sipName_unlock &sipStrings_QtCore[63077]
#define sipNameNr_usleep 63084
#define sipName_usleep &sipStrings_QtCore[63084]
#define sipNameNr_value0 63091
#define sipName_value0 &sipStrings_QtCore[63091]
#define sipNameNr_value1 63098
#define sipName_value1 &sipStrings_QtCore[63098]
#define sipNameNr_value2 63105
#define sipName_value2 &sipStrings_QtCore[63105]
#define sipNameNr_value3 63112
#define sipName_value3 &sipStrings_QtCore[63112]
#define sipNameNr_value4 63119
#define sipName_value4 &sipStrings_QtCore[63119]
#define sipNameNr_value5 63126
#define sipName_value5 &sipStrings_QtCore[63126]
#define sipNameNr_value6 63133
#define sipName_value6 &sipStrings_QtCore[63133]
#define sipNameNr_value7 63140
#define sipName_value7 &sipStrings_QtCore[63140]
#define sipNameNr_value8 63147
#define sipName_value8 &sipStrings_QtCore[63147]
#define sipNameNr_value9 63154
#define sipName_value9 &sipStrings_QtCore[63154]
#define sipNameNr_values 63161
#define sipName_values &sipStrings_QtCore[63161]
#define sipNameNr_vmicro 63168
#define sipName_vmicro &sipStrings_QtCore[63168]
#define sipNameNr_vminor 63175
#define sipName_vminor &sipStrings_QtCore[63175]
#define sipNameNr_wakeUp 63182
#define sipName_wakeUp &sipStrings_QtCore[63182]
#define sipNameNr_yellow 63189
#define sipName_yellow &sipStrings_QtCore[63189]
#define sipNameNr_Aghem 63196
#define sipName_Aghem &sipStrings_QtCore[63196]
#define sipNameNr_Array 22614
#define sipName_Array &sipStrings_QtCore[22614]
#define sipNameNr_Aruba 63202
#define sipName_Aruba &sipStrings_QtCore[63202]
#define sipNameNr_Atsam 63208
#define sipName_Atsam &sipStrings_QtCore[63208]
#define sipNameNr_Bafia 63214
#define sipName_Bafia &sipStrings_QtCore[63214]
#define sipNameNr_Bamun 63220
#define sipName_Bamun &sipStrings_QtCore[63220]
#define sipNameNr_Basaa 63226
#define sipName_Basaa &sipStrings_QtCore[63226]
#define sipNameNr_Bassa 63232
#define sipName_Bassa &sipStrings_QtCore[63232]
#define sipNameNr_Bemba 63238
#define sipName_Bemba &sipStrings_QtCore[63238]
#define sipNameNr_Benin 63244
#define sipName_Benin &sipStrings_QtCore[63244]
#define sipNameNr_Brush 59398
#define sipName_Brush &sipStrings_QtCore[59398]
#define sipNameNr_Buhid 63250
#define sipName_Buhid &sipStrings_QtCore[63250]
#define sipNameNr_Chewa 63256
#define sipName_Chewa &sipStrings_QtCore[63256]
#define sipNameNr_Chiga 63262
#define sipName_Chiga &sipStrings_QtCore[63262]
#define sipNameNr_Chile 63268
#define sipName_Chile &sipStrings_QtCore[63268]
#define sipNameNr_China 63274
#define sipName_China &sipStrings_QtCore[63274]
#define sipNameNr_Clear 52762
#define sipName_Clear &sipStrings_QtCore[52762]
#define sipNameNr_Close 26114
#define sipName_Close &sipStrings_QtCore[26114]
#define sipNameNr_Color 29336
#define sipName_Color &sipStrings_QtCore[29336]
#define sipNameNr_Czech 63280
#define sipName_Czech &sipStrings_QtCore[63280]
#define sipNameNr_Dogri 63286
#define sipName_Dogri &sipStrings_QtCore[63286]
#define sipNameNr_Duala 63292
#define sipName_Duala &sipStrings_QtCore[63292]
#define sipNameNr_Dutch 63298
#define sipName_Dutch &sipStrings_QtCore[63298]
#define sipNameNr_Edges 53572
#define sipName_Edges &sipStrings_QtCore[53572]
#define sipNameNr_Egypt 63304
#define sipName_Egypt &sipStrings_QtCore[63304]
#define sipNameNr_Enter 8314
#define sipName_Enter &sipStrings_QtCore[8314]
#define sipNameNr_Error 470
#define sipName_Error &sipStrings_QtCore[470]
#define sipNameNr_Erzya 63310
#define sipName_Erzya &sipStrings_QtCore[63310]
#define sipNameNr_Files 63316
#define sipName_Files &sipStrings_QtCore[63316]
#define sipNameNr_First 52442
#define sipName_First &sipStrings_QtCore[52442]
#define sipNameNr_Flags 1103
#define sipName_Flags &sipStrings_QtCore[1103]
#define sipNameNr_Float 52117
#define sipName_Float &sipStrings_QtCore[52117]
#define sipNameNr_Floor 25808
#define sipName_Floor &sipStrings_QtCore[25808]
#define sipNameNr_Fulah 63322
#define sipName_Fulah &sipStrings_QtCore[63322]
#define sipNameNr_Gabon 63328
#define sipName_Gabon &sipStrings_QtCore[63328]
#define sipNameNr_Ganda 63334
#define sipName_Ganda &sipStrings_QtCore[63334]
#define sipNameNr_Ghana 63340
#define sipName_Ghana &sipStrings_QtCore[63340]
#define sipNameNr_Greek 32228
#define sipName_Greek &sipStrings_QtCore[32228]
#define sipNameNr_Gusii 63346
#define sipName_Gusii &sipStrings_QtCore[63346]
#define sipNameNr_Haiti 63352
#define sipName_Haiti &sipStrings_QtCore[63352]
#define sipNameNr_Hausa 63358
#define sipName_Hausa &sipStrings_QtCore[63358]
#define sipNameNr_Hindi 63364
#define sipName_Hindi &sipStrings_QtCore[63364]
#define sipNameNr_Id128 63370
#define sipName_Id128 &sipStrings_QtCore[63370]
#define sipNameNr_Image 57522
#define sipName_Image &sipStrings_QtCore[57522]
#define sipNameNr_India 63376
#define sipName_India &sipStrings_QtCore[63376]
#define sipNameNr_Irish 56460
#define sipName_Irish &sipStrings_QtCore[56460]
#define sipNameNr_Italy 63382
#define sipName_Italy &sipStrings_QtCore[63382]
#define sipNameNr_Japan 63388
#define sipName_Japan &sipStrings_QtCore[63388]
#define sipNameNr_Kamba 63394
#define sipName_Kamba &sipStrings_QtCore[63394]
#define sipNameNr_Kenya 63400
#define sipName_Kenya &sipStrings_QtCore[63400]
#define sipNameNr_Key_0 63406
#define sipName_Key_0 &sipStrings_QtCore[63406]
#define sipNameNr_Key_1 63412
#define sipName_Key_1 &sipStrings_QtCore[63412]
#define sipNameNr_Key_2 63418
#define sipName_Key_2 &sipStrings_QtCore[63418]
#define sipNameNr_Key_3 63424
#define sipName_Key_3 &sipStrings_QtCore[63424]
#define sipNameNr_Key_4 63430
#define sipName_Key_4 &sipStrings_QtCore[63430]
#define sipNameNr_Key_5 63436
#define sipName_Key_5 &sipStrings_QtCore[63436]
#define sipNameNr_Key_6 63442
#define sipName_Key_6 &sipStrings_QtCore[63442]
#define sipNameNr_Key_7 63448
#define sipName_Key_7 &sipStrings_QtCore[63448]
#define sipNameNr_Key_8 63454
#define sipName_Key_8 &sipStrings_QtCore[63454]
#define sipNameNr_Key_9 63460
#define sipName_Key_9 &sipStrings_QtCore[63460]
#define sipNameNr_Key_A 63466
#define sipName_Key_A &sipStrings_QtCore[63466]
#define sipNameNr_Key_B 63472
#define sipName_Key_B &sipStrings_QtCore[63472]
#define sipNameNr_Key_C 63478
#define sipName_Key_C &sipStrings_QtCore[63478]
#define sipNameNr_Key_D 63484
#define sipName_Key_D &sipStrings_QtCore[63484]
#define sipNameNr_Key_E 63490
#define sipName_Key_E &sipStrings_QtCore[63490]
#define sipNameNr_Key_F 63496
#define sipName_Key_F &sipStrings_QtCore[63496]
#define sipNameNr_Key_G 63502
#define sipName_Key_G &sipStrings_QtCore[63502]
#define sipNameNr_Key_H 63508
#define sipName_Key_H &sipStrings_QtCore[63508]
#define sipNameNr_Key_I 63514
#define sipName_Key_I &sipStrings_QtCore[63514]
#define sipNameNr_Key_J 63520
#define sipName_Key_J &sipStrings_QtCore[63520]
#define sipNameNr_Key_K 63526
#define sipName_Key_K &sipStrings_QtCore[63526]
#define sipNameNr_Key_L 63532
#define sipName_Key_L &sipStrings_QtCore[63532]
#define sipNameNr_Key_M 63538
#define sipName_Key_M &sipStrings_QtCore[63538]
#define sipNameNr_Key_N 63544
#define sipName_Key_N &sipStrings_QtCore[63544]
#define sipNameNr_Key_O 63550
#define sipName_Key_O &sipStrings_QtCore[63550]
#define sipNameNr_Key_P 63556
#define sipName_Key_P &sipStrings_QtCore[63556]
#define sipNameNr_Key_Q 63562
#define sipName_Key_Q &sipStrings_QtCore[63562]
#define sipNameNr_Key_R 63568
#define sipName_Key_R &sipStrings_QtCore[63568]
#define sipNameNr_Key_S 63574
#define sipName_Key_S &sipStrings_QtCore[63574]
#define sipNameNr_Key_T 63580
#define sipName_Key_T &sipStrings_QtCore[63580]
#define sipNameNr_Key_U 63586
#define sipName_Key_U &sipStrings_QtCore[63586]
#define sipNameNr_Key_V 63592
#define sipName_Key_V &sipStrings_QtCore[63592]
#define sipNameNr_Key_W 63598
#define sipName_Key_W &sipStrings_QtCore[63598]
#define sipNameNr_Key_X 63604
#define sipName_Key_X &sipStrings_QtCore[63604]
#define sipNameNr_Key_Y 63610
#define sipName_Key_Y &sipStrings_QtCore[63610]
#define sipNameNr_Key_Z 63616
#define sipName_Key_Z &sipStrings_QtCore[63616]
#define sipNameNr_Khmer 63622
#define sipName_Khmer &sipStrings_QtCore[63622]
#define sipNameNr_Kiche 63628
#define sipName_Kiche &sipStrings_QtCore[63628]
#define sipNameNr_Kongo 63634
#define sipName_Kongo &sipStrings_QtCore[63634]
#define sipNameNr_Langi 63640
#define sipName_Langi &sipStrings_QtCore[63640]
#define sipNameNr_Latin 31988
#define sipName_Latin &sipStrings_QtCore[31988]
#define sipNameNr_Leave 8338
#define sipName_Leave &sipStrings_QtCore[8338]
#define sipNameNr_Libya 63646
#define sipName_Libya &sipStrings_QtCore[63646]
#define sipNameNr_Limbu 63652
#define sipName_Limbu &sipStrings_QtCore[63652]
#define sipNameNr_LineF 61797
#define sipName_LineF &sipStrings_QtCore[61797]
#define sipNameNr_Luyia 63658
#define sipName_Luyia &sipStrings_QtCore[63658]
#define sipNameNr_MacOS 63664
#define sipName_MacOS &sipStrings_QtCore[63664]
#define sipNameNr_Macau 63670
#define sipName_Macau &sipStrings_QtCore[63670]
#define sipNameNr_Malay 63676
#define sipName_Malay &sipStrings_QtCore[63676]
#define sipNameNr_Malta 63682
#define sipName_Malta &sipStrings_QtCore[63682]
#define sipNameNr_Maori 63688
#define sipName_Maori &sipStrings_QtCore[63688]
#define sipNameNr_Masai 63694
#define sipName_Masai &sipStrings_QtCore[63694]
#define sipNameNr_Mende 63700
#define sipName_Mende &sipStrings_QtCore[63700]
#define sipNameNr_Nepal 63706
#define sipName_Nepal &sipStrings_QtCore[63706]
#define sipNameNr_Niger 63712
#define sipName_Niger &sipStrings_QtCore[63712]
#define sipNameNr_NoDot 63718
#define sipName_NoDot &sipStrings_QtCore[63718]
#define sipNameNr_NoPen 63724
#define sipName_NoPen &sipStrings_QtCore[63724]
#define sipNameNr_None_ 63730
#define sipName_None_ &sipStrings_QtCore[63730]
#define sipNameNr_Oriya 63736
#define sipName_Oriya &sipStrings_QtCore[63736]
#define sipNameNr_Oromo 63742
#define sipName_Oromo &sipStrings_QtCore[63742]
#define sipNameNr_Osage 63748
#define sipName_Osage &sipStrings_QtCore[63748]
#define sipNameNr_Paint 63754
#define sipName_Paint &sipStrings_QtCore[63754]
#define sipNameNr_Palau 63760
#define sipName_Palau &sipStrings_QtCore[63760]
#define sipNameNr_Point 29224
#define sipName_Point &sipStrings_QtCore[29224]
#define sipNameNr_Popup 63766
#define sipName_Popup &sipStrings_QtCore[63766]
#define sipNameNr_QChar 63772
#define sipName_QChar &sipStrings_QtCore[63772]
#define sipNameNr_QDate 63778
#define sipName_QDate &sipStrings_QtCore[63778]
#define sipNameNr_QFile 63784
#define sipName_QFile &sipStrings_QtCore[63784]
#define sipNameNr_QFont 63790
#define sipName_QFont &sipStrings_QtCore[63790]
#define sipNameNr_QIcon 63796
#define sipName_QIcon &sipStrings_QtCore[63796]
#define sipNameNr_QLine 63802
#define sipName_QLine &sipStrings_QtCore[63802]
#define sipNameNr_QRect 63808
#define sipName_QRect &sipStrings_QtCore[63808]
#define sipNameNr_QSize 63814
#define sipName_QSize &sipStrings_QtCore[63814]
#define sipNameNr_QTime 63820
#define sipName_QTime &sipStrings_QtCore[63820]
#define sipNameNr_QUuid 63826
#define sipName_QUuid &sipStrings_QtCore[63826]
#define sipNameNr_Q_ARG 63832
#define sipName_Q_ARG &sipStrings_QtCore[63832]
#define sipNameNr_Qatar 63838
#define sipName_Qatar &sipStrings_QtCore[63838]
#define sipNameNr_RectF 61818
#define sipName_RectF &sipStrings_QtCore[61818]
#define sipNameNr_Rombo 63844
#define sipName_Rombo &sipStrings_QtCore[63844]
#define sipNameNr_Round 62777
#define sipName_Round &sipStrings_QtCore[62777]
#define sipNameNr_Rundi 63850
#define sipName_Rundi &sipStrings_QtCore[63850]
#define sipNameNr_SChar 63856
#define sipName_SChar &sipStrings_QtCore[63856]
#define sipNameNr_SHIFT 63862
#define sipName_SHIFT &sipStrings_QtCore[63862]
#define sipNameNr_Sakha 63868
#define sipName_Sakha &sipStrings_QtCore[63868]
#define sipNameNr_Samoa 35580
#define sipName_Samoa &sipStrings_QtCore[35580]
#define sipNameNr_Sango 63874
#define sipName_Sango &sipStrings_QtCore[63874]
#define sipNameNr_Sangu 63880
#define sipName_Sangu &sipStrings_QtCore[63880]
#define sipNameNr_Scope 25451
#define sipName_Scope &sipStrings_QtCore[25451]
#define sipNameNr_Sheet 38268
#define sipName_Sheet &sipStrings_QtCore[38268]
#define sipNameNr_Shona 63886
#define sipName_Shona &sipStrings_QtCore[63886]
#define sipNameNr_Short 58260
#define sipName_Short &sipStrings_QtCore[58260]
#define sipNameNr_SizeF 61825
#define sipName_SizeF &sipStrings_QtCore[61825]
#define sipNameNr_Sizes 29176
#define sipName_Sizes &sipStrings_QtCore[29176]
#define sipNameNr_Spain 63892
#define sipName_Spain &sipStrings_QtCore[63892]
#define sipNameNr_State 5409
#define sipName_State &sipStrings_QtCore[5409]
#define sipNameNr_Sudan 50258
#define sipName_Sudan &sipStrings_QtCore[50258]
#define sipNameNr_Swati 63898
#define sipName_Swati &sipStrings_QtCore[63898]
#define sipNameNr_Syria 63904
#define sipName_Syria &sipStrings_QtCore[63904]
#define sipNameNr_Taita 63910
#define sipName_Taita &sipStrings_QtCore[63910]
#define sipNameNr_Tajik 63916
#define sipName_Tajik &sipStrings_QtCore[63916]
#define sipNameNr_Tamil 63922
#define sipName_Tamil &sipStrings_QtCore[63922]
#define sipNameNr_Tatar 63928
#define sipName_Tatar &sipStrings_QtCore[63928]
#define sipNameNr_Tigre 63934
#define sipName_Tigre &sipStrings_QtCore[63934]
#define sipNameNr_Timer 29768
#define sipName_Timer &sipStrings_QtCore[29768]
#define sipNameNr_Tonga 63940
#define sipName_Tonga &sipStrings_QtCore[63940]
#define sipNameNr_True_ 63946
#define sipName_True_ &sipStrings_QtCore[63946]
#define sipNameNr_UChar 63952
#define sipName_UChar &sipStrings_QtCore[63952]
#define sipNameNr_ULong 60982
#define sipName_ULong &sipStrings_QtCore[60982]
#define sipNameNr_Uigur 63958
#define sipName_Uigur &sipStrings_QtCore[63958]
#define sipNameNr_Uzbek 63964
#define sipName_Uzbek &sipStrings_QtCore[63964]
#define sipNameNr_Venda 63970
#define sipName_Venda &sipStrings_QtCore[63970]
#define sipNameNr_Vunjo 63976
#define sipName_Vunjo &sipStrings_QtCore[63976]
#define sipNameNr_Welsh 63982
#define sipName_Welsh &sipStrings_QtCore[63982]
#define sipNameNr_Wheel 18276
#define sipName_Wheel &sipStrings_QtCore[18276]
#define sipNameNr_Wolof 63988
#define sipName_Wolof &sipStrings_QtCore[63988]
#define sipNameNr_World 63994
#define sipName_World &sipStrings_QtCore[63994]
#define sipNameNr_Write 31096
#define sipName_Write &sipStrings_QtCore[31096]
#define sipNameNr_XAxis 64000
#define sipName_XAxis &sipStrings_QtCore[64000]
#define sipNameNr_Xhosa 64006
#define sipName_Xhosa &sipStrings_QtCore[64006]
#define sipNameNr_YAxis 64012
#define sipName_YAxis &sipStrings_QtCore[64012]
#define sipNameNr_Yemen 64018
#define sipName_Yemen &sipStrings_QtCore[64018]
#define sipNameNr_ZAxis 64024
#define sipName_ZAxis &sipStrings_QtCore[64024]
#define sipNameNr_Zarma 64030
#define sipName_Zarma &sipStrings_QtCore[64030]
#define sipNameNr_added 64036
#define sipName_added &sipStrings_QtCore[64036]
#define sipNameNr_angle 7026
#define sipName_angle &sipStrings_QtCore[7026]
#define sipNameNr_array 64042
#define sipName_array &sipStrings_QtCore[64042]
#define sipNameNr_atEnd 64048
#define sipName_atEnd &sipStrings_QtCore[64048]
#define sipNameNr_atUtc 64054
#define sipName_atUtc &sipStrings_QtCore[64054]
#define sipNameNr_awake 64060
#define sipName_awake &sipStrings_QtCore[64060]
#define sipNameNr_black 64066
#define sipName_black &sipStrings_QtCore[64066]
#define sipNameNr_buddy 64072
#define sipName_buddy &sipStrings_QtCore[64072]
#define sipNameNr_child 64078
#define sipName_child &sipStrings_QtCore[64078]
#define sipNameNr_clear 64084
#define sipName_clear &sipStrings_QtCore[64084]
#define sipNameNr_close 64090
#define sipName_close &sipStrings_QtCore[64090]
#define sipNameNr_codec 64096
#define sipName_codec &sipStrings_QtCore[64096]
#define sipNameNr_count 64102
#define sipName_count &sipStrings_QtCore[64102]
#define sipNameNr_debug 64108
#define sipName_debug &sipStrings_QtCore[64108]
#define sipNameNr_error 64114
#define sipName_error &sipStrings_QtCore[64114]
#define sipNameNr_event 64120
#define sipName_event &sipStrings_QtCore[64120]
#define sipNameNr_exec_ 64126
#define sipName_exec_ &sipStrings_QtCore[64126]
#define sipNameNr_fatal 64132
#define sipName_fatal &sipStrings_QtCore[64132]
#define sipNameNr_files 64138
#define sipName_files &sipStrings_QtCore[64138]
#define sipNameNr_first 64144
#define sipName_first &sipStrings_QtCore[64144]
#define sipNameNr_fixed 64150
#define sipName_fixed &sipStrings_QtCore[64150]
#define sipNameNr_flags 64156
#define sipName_flags &sipStrings_QtCore[64156]
#define sipNameNr_flush 64162
#define sipName_flush &sipStrings_QtCore[64162]
#define sipNameNr_green 64168
#define sipName_green &sipStrings_QtCore[64168]
#define sipNameNr_group 64174
#define sipName_group &sipStrings_QtCore[64174]
#define sipNameNr_index 64180
#define sipName_index &sipStrings_QtCore[64180]
#define sipNameNr_isDTD 64186
#define sipName_isDTD &sipStrings_QtCore[64186]
#define sipNameNr_isDir 64192
#define sipName_isDir &sipStrings_QtCore[64192]
#define sipNameNr_isMap 64198
#define sipName_isMap &sipStrings_QtCore[64198]
#define sipNameNr_isSet 64204
#define sipName_isSet &sipStrings_QtCore[64204]
#define sipNameNr_isTag 64210
#define sipName_isTag &sipStrings_QtCore[64210]
#define sipNameNr_match 64216
#define sipName_match &sipStrings_QtCore[64216]
#define sipNameNr_merge 64222
#define sipName_merge &sipStrings_QtCore[64222]
#define sipNameNr_mkdir 64228
#define sipName_mkdir &sipStrings_QtCore[64228]
#define sipNameNr_model 64234
#define sipName_model &sipStrings_QtCore[64234]
#define sipNameNr_month 64240
#define sipName_month &sipStrings_QtCore[64240]
#define sipNameNr_msecs 64246
#define sipName_msecs &sipStrings_QtCore[64246]
#define sipNameNr_mutex 64252
#define sipName_mutex &sipStrings_QtCore[64252]
#define sipNameNr_names 64258
#define sipName_names &sipStrings_QtCore[64258]
#define sipNameNr_nsecs 64264
#define sipName_nsecs &sipStrings_QtCore[64264]
#define sipNameNr_order 64270
#define sipName_order &sipStrings_QtCore[64270]
#define sipNameNr_owner 64276
#define sipName_owner &sipStrings_QtCore[64276]
#define sipNameNr_parse 60710
#define sipName_parse &sipStrings_QtCore[60710]
#define sipNameNr_paths 64282
#define sipName_paths &sipStrings_QtCore[64282]
#define sipNameNr_pause 64288
#define sipName_pause &sipStrings_QtCore[64288]
#define sipNameNr_qInfo 64294
#define sipName_qInfo &sipStrings_QtCore[64294]
#define sipNameNr_qQNaN 64300
#define sipName_qQNaN &sipStrings_QtCore[64300]
#define sipNameNr_qSNaN 64306
#define sipName_qSNaN &sipStrings_QtCore[64306]
#define sipNameNr_qrand 64312
#define sipName_qrand &sipStrings_QtCore[64312]
#define sipNameNr_query 64318
#define sipName_query &sipStrings_QtCore[64318]
#define sipNameNr_reset 64324
#define sipName_reset &sipStrings_QtCore[64324]
#define sipNameNr_right 18656
#define sipName_right &sipStrings_QtCore[18656]
#define sipNameNr_rmdir 64330
#define sipName_rmdir &sipStrings_QtCore[64330]
#define sipNameNr_roles 64336
#define sipName_roles &sipStrings_QtCore[64336]
#define sipNameNr_scale 64342
#define sipName_scale &sipStrings_QtCore[64342]
#define sipNameNr_scope 64348
#define sipName_scope &sipStrings_QtCore[64348]
#define sipNameNr_setP1 64354
#define sipName_setP1 &sipStrings_QtCore[64354]
#define sipNameNr_setP2 64360
#define sipName_setP2 &sipStrings_QtCore[64360]
#define sipNameNr_sleep 62672
#define sipName_sleep &sipStrings_QtCore[62672]
#define sipNameNr_split 64366
#define sipName_split &sipStrings_QtCore[64366]
#define sipNameNr_start 60742
#define sipName_start &sipStrings_QtCore[60742]
#define sipNameNr_state 18485
#define sipName_state &sipStrings_QtCore[18485]
#define sipNameNr_style 64372
#define sipName_style &sipStrings_QtCore[64372]
#define sipNameNr_toAce 64378
#define sipName_toAce &sipStrings_QtCore[64378]
#define sipNameNr_toEnd 64384
#define sipName_toEnd &sipStrings_QtCore[64384]
#define sipNameNr_toHex 64390
#define sipName_toHex &sipStrings_QtCore[64390]
#define sipNameNr_toInt 64396
#define sipName_toInt &sipStrings_QtCore[64396]
#define sipNameNr_toUTC 64402
#define sipName_toUTC &sipStrings_QtCore[64402]
#define sipNameNr_unmap 64408
#define sipName_unmap &sipStrings_QtCore[64408]
#define sipNameNr_value 64414
#define sipName_value &sipStrings_QtCore[64414]
#define sipNameNr_white 64420
#define sipName_white &sipStrings_QtCore[64420]
#define sipNameNr_width 64426
#define sipName_width &sipStrings_QtCore[64426]
#define sipNameNr_write 64432
#define sipName_write &sipStrings_QtCore[64432]
#define sipNameNr_Afan 64438
#define sipName_Afan &sipStrings_QtCore[64438]
#define sipNameNr_Afar 64443
#define sipName_Afar &sipStrings_QtCore[64443]
#define sipNameNr_Ahom 64448
#define sipName_Ahom &sipStrings_QtCore[64448]
#define sipNameNr_Akan 64453
#define sipName_Akan &sipStrings_QtCore[64453]
#define sipNameNr_Axis 56596
#define sipName_Axis &sipStrings_QtCore[56596]
#define sipNameNr_Bena 64458
#define sipName_Bena &sipStrings_QtCore[64458]
#define sipNameNr_Blin 64463
#define sipName_Blin &sipStrings_QtCore[64463]
#define sipNameNr_Bodo 64468
#define sipName_Bodo &sipStrings_QtCore[64468]
#define sipNameNr_Bool 55333
#define sipName_Bool &sipStrings_QtCore[55333]
#define sipNameNr_CTRL 64473
#define sipName_CTRL &sipStrings_QtCore[64473]
#define sipNameNr_Ceil 64478
#define sipName_Ceil &sipStrings_QtCore[64478]
#define sipNameNr_Chad 64483
#define sipName_Chad &sipStrings_QtCore[64483]
#define sipNameNr_Char 47648
#define sipName_Char &sipStrings_QtCore[47648]
#define sipNameNr_Code 1032
#define sipName_Code &sipStrings_QtCore[1032]
#define sipNameNr_Cree 64488
#define sipName_Cree &sipStrings_QtCore[64488]
#define sipNameNr_Cuba 64493
#define sipName_Cuba &sipStrings_QtCore[64493]
#define sipNameNr_Date 9628
#define sipName_Date &sipStrings_QtCore[9628]
#define sipNameNr_Dirs 58375
#define sipName_Dirs &sipStrings_QtCore[58375]
#define sipNameNr_Drop 21445
#define sipName_Drop &sipStrings_QtCore[21445]
#define sipNameNr_Edge 48532
#define sipName_Edge &sipStrings_QtCore[48532]
#define sipNameNr_Embu 64498
#define sipName_Embu &sipStrings_QtCore[64498]
#define sipNameNr_Fiji 64503
#define sipName_Fiji &sipStrings_QtCore[64503]
#define sipNameNr_Flag 1315
#define sipName_Flag &sipStrings_QtCore[1315]
#define sipNameNr_Font 50490
#define sipName_Font &sipStrings_QtCore[50490]
#define sipNameNr_Geez 64508
#define sipName_Geez &sipStrings_QtCore[64508]
#define sipNameNr_Guam 64513
#define sipName_Guam &sipStrings_QtCore[64513]
#define sipNameNr_Hash 19151
#define sipName_Hash &sipStrings_QtCore[19151]
#define sipNameNr_Hide 5545
#define sipName_Hide &sipStrings_QtCore[5545]
#define sipNameNr_Icon 7552
#define sipName_Icon &sipStrings_QtCore[7552]
#define sipNameNr_Igbo 64518
#define sipName_Igbo &sipStrings_QtCore[64518]
#define sipNameNr_Iran 64523
#define sipName_Iran &sipStrings_QtCore[64523]
#define sipNameNr_Iraq 64528
#define sipName_Iraq &sipStrings_QtCore[64528]
#define sipNameNr_Kako 64533
#define sipName_Kako &sipStrings_QtCore[64533]
#define sipNameNr_Komi 64538
#define sipName_Komi &sipStrings_QtCore[64538]
#define sipNameNr_Koro 64543
#define sipName_Koro &sipStrings_QtCore[64543]
#define sipNameNr_Laos 64548
#define sipName_Laos &sipStrings_QtCore[64548]
#define sipNameNr_Last 36729
#define sipName_Last &sipStrings_QtCore[36729]
#define sipNameNr_Line 31479
#define sipName_Line &sipStrings_QtCore[31479]
#define sipNameNr_List 6672
#define sipName_List &sipStrings_QtCore[6672]
#define sipNameNr_Lisu 64553
#define sipName_Lisu &sipStrings_QtCore[64553]
#define sipNameNr_Long 48200
#define sipName_Long &sipStrings_QtCore[48200]
#define sipNameNr_META 64558
#define sipName_META &sipStrings_QtCore[64558]
#define sipNameNr_Mali 64563
#define sipName_Mali &sipStrings_QtCore[64563]
#define sipNameNr_Manx 64568
#define sipName_Manx &sipStrings_QtCore[64568]
#define sipNameNr_Meru 64573
#define sipName_Meru &sipStrings_QtCore[64573]
#define sipNameNr_Meta 5840
#define sipName_Meta &sipStrings_QtCore[5840]
#define sipNameNr_Mono 64578
#define sipName_Mono &sipStrings_QtCore[64578]
#define sipNameNr_Move 9812
#define sipName_Move &sipStrings_QtCore[9812]
#define sipNameNr_Nama 64583
#define sipName_Nama &sipStrings_QtCore[64583]
#define sipNameNr_Name 13124
#define sipName_Name &sipStrings_QtCore[13124]
#define sipNameNr_Niue 64588
#define sipName_Niue &sipStrings_QtCore[64588]
#define sipNameNr_Nuer 64593
#define sipName_Nuer &sipStrings_QtCore[64593]
#define sipNameNr_Null 13503
#define sipName_Null &sipStrings_QtCore[13503]
#define sipNameNr_Oman 64598
#define sipName_Oman &sipStrings_QtCore[64598]
#define sipNameNr_Open 55696
#define sipName_Open &sipStrings_QtCore[55696]
#define sipNameNr_Pali 64603
#define sipName_Pali &sipStrings_QtCore[64603]
#define sipNameNr_Peru 64608
#define sipName_Peru &sipStrings_QtCore[64608]
#define sipNameNr_QDir 64613
#define sipName_QDir &sipStrings_QtCore[64613]
#define sipNameNr_QPen 64618
#define sipName_QPen &sipStrings_QtCore[64618]
#define sipNameNr_QUrl 64623
#define sipName_QUrl &sipStrings_QtCore[64623]
#define sipNameNr_Read 26455
#define sipName_Read &sipStrings_QtCore[26455]
#define sipNameNr_Rect 4897
#define sipName_Rect &sipStrings_QtCore[4897]
#define sipNameNr_Rows 30025
#define sipName_Rows &sipStrings_QtCore[30025]
#define sipNameNr_Saho 64628
#define sipName_Saho &sipStrings_QtCore[64628]
#define sipNameNr_Sena 64633
#define sipName_Sena &sipStrings_QtCore[64633]
#define sipNameNr_Sha1 64638
#define sipName_Sha1 &sipStrings_QtCore[64638]
#define sipNameNr_Show 64643
#define sipName_Show &sipStrings_QtCore[64643]
#define sipNameNr_Size 19816
#define sipName_Size &sipStrings_QtCore[19816]
#define sipNameNr_Slot 47228
#define sipName_Slot &sipStrings_QtCore[47228]
#define sipNameNr_Soga 64648
#define sipName_Soga &sipStrings_QtCore[64648]
#define sipNameNr_Sora 64653
#define sipName_Sora &sipStrings_QtCore[64653]
#define sipNameNr_Teso 64658
#define sipName_Teso &sipStrings_QtCore[64658]
#define sipNameNr_Text 15814
#define sipName_Text &sipStrings_QtCore[15814]
#define sipNameNr_Thai 41423
#define sipName_Thai &sipStrings_QtCore[41423]
#define sipNameNr_Time 9467
#define sipName_Time &sipStrings_QtCore[9467]
#define sipNameNr_Togo 64663
#define sipName_Togo &sipStrings_QtCore[64663]
#define sipNameNr_Tool 64668
#define sipName_Tool &sipStrings_QtCore[64668]
#define sipNameNr_TvOS 64673
#define sipName_TvOS &sipStrings_QtCore[64673]
#define sipNameNr_Tyap 64678
#define sipName_Tyap &sipStrings_QtCore[64678]
#define sipNameNr_Type 996
#define sipName_Type &sipStrings_QtCore[996]
#define sipNameNr_UInt 63058
#define sipName_UInt &sipStrings_QtCore[63058]
#define sipNameNr_Urdu 64683
#define sipName_Urdu &sipStrings_QtCore[64683]
#define sipNameNr_User 53973
#define sipName_User &sipStrings_QtCore[53973]
#define sipNameNr_Uuid 50787
#define sipName_Uuid &sipStrings_QtCore[50787]
#define sipNameNr_Void 64688
#define sipName_Void &sipStrings_QtCore[64688]
#define sipNameNr_Word 56191
#define sipName_Word &sipStrings_QtCore[56191]
#define sipNameNr_Zulu 64693
#define sipName_Zulu &sipStrings_QtCore[64693]
#define sipNameNr_base 37597
#define sipName_base &sipStrings_QtCore[37597]
#define sipNameNr_bin_ 64698
#define sipName_bin_ &sipStrings_QtCore[64698]
#define sipNameNr_bits 64703
#define sipName_bits &sipStrings_QtCore[64703]
#define sipNameNr_blue 64708
#define sipName_blue &sipStrings_QtCore[64708]
#define sipNameNr_cdUp 64713
#define sipName_cdUp &sipStrings_QtCore[64713]
#define sipNameNr_chop 64718
#define sipName_chop &sipStrings_QtCore[64718]
#define sipNameNr_code 15204
#define sipName_code &sipStrings_QtCore[15204]
#define sipNameNr_copy 64723
#define sipName_copy &sipStrings_QtCore[64723]
#define sipNameNr_cyan 64728
#define sipName_cyan &sipStrings_QtCore[64728]
#define sipNameNr_data 64733
#define sipName_data &sipStrings_QtCore[64733]
#define sipNameNr_date 11540
#define sipName_date &sipStrings_QtCore[11540]
#define sipNameNr_endl 64738
#define sipName_endl &sipStrings_QtCore[64738]
#define sipNameNr_exec 64743
#define sipName_exec &sipStrings_QtCore[64743]
#define sipNameNr_exit 64748
#define sipName_exit &sipStrings_QtCore[64748]
#define sipNameNr_file 64753
#define sipName_file &sipStrings_QtCore[64753]
#define sipNameNr_fill 64758
#define sipName_fill &sipStrings_QtCore[64758]
#define sipNameNr_from 64763
#define sipName_from &sipStrings_QtCore[64763]
#define sipNameNr_gray 64768
#define sipName_gray &sipStrings_QtCore[64768]
#define sipNameNr_hash 64773
#define sipName_hash &sipStrings_QtCore[64773]
#define sipNameNr_hex_ 64778
#define sipName_hex_ &sipStrings_QtCore[64778]
#define sipNameNr_hint 64783
#define sipName_hint &sipStrings_QtCore[64783]
#define sipNameNr_hits 64788
#define sipName_hits &sipStrings_QtCore[64788]
#define sipNameNr_home 64793
#define sipName_home &sipStrings_QtCore[64793]
#define sipNameNr_host 64798
#define sipName_host &sipStrings_QtCore[64798]
#define sipNameNr_hour 64803
#define sipName_hour &sipStrings_QtCore[64803]
#define sipNameNr_html 64808
#define sipName_html &sipStrings_QtCore[64808]
#define sipNameNr_info 64813
#define sipName_info &sipStrings_QtCore[64813]
#define sipNameNr_keys 64818
#define sipName_keys &sipStrings_QtCore[64818]
#define sipNameNr_kill 64823
#define sipName_kill &sipStrings_QtCore[64823]
#define sipNameNr_last 64828
#define sipName_last &sipStrings_QtCore[64828]
#define sipNameNr_left 21841
#define sipName_left &sipStrings_QtCore[21841]
#define sipNameNr_line 4951
#define sipName_line &sipStrings_QtCore[4951]
#define sipNameNr_link 64833
#define sipName_link &sipStrings_QtCore[64833]
#define sipNameNr_load 49302
#define sipName_load &sipStrings_QtCore[49302]
#define sipNameNr_lock 32844
#define sipName_lock &sipStrings_QtCore[32844]
#define sipNameNr_mode 64838
#define sipName_mode &sipStrings_QtCore[64838]
#define sipNameNr_move 39277
#define sipName_move &sipStrings_QtCore[39277]
#define sipNameNr_msec 64843
#define sipName_msec &sipStrings_QtCore[64843]
#define sipNameNr_name 33489
#define sipName_name &sipStrings_QtCore[33489]
#define sipNameNr_next 64848
#define sipName_next &sipStrings_QtCore[64848]
#define sipNameNr_oct_ 64853
#define sipName_oct_ &sipStrings_QtCore[64853]
#define sipNameNr_open 64858
#define sipName_open &sipStrings_QtCore[64858]
#define sipNameNr_path 62659
#define sipName_path &sipStrings_QtCore[62659]
#define sipNameNr_peek 64863
#define sipName_peek &sipStrings_QtCore[64863]
#define sipNameNr_port 45260
#define sipName_port &sipStrings_QtCore[45260]
#define sipNameNr_qAbs 64868
#define sipName_qAbs &sipStrings_QtCore[64868]
#define sipNameNr_qInf 64873
#define sipName_qInf &sipStrings_QtCore[64873]
#define sipNameNr_quit 64878
#define sipName_quit &sipStrings_QtCore[64878]
#define sipNameNr_read 21013
#define sipName_read &sipStrings_QtCore[21013]
#define sipNameNr_role 64883
#define sipName_role &sipStrings_QtCore[64883]
#define sipNameNr_root 64888
#define sipName_root &sipStrings_QtCore[64888]
#define sipNameNr_save 64893
#define sipName_save &sipStrings_QtCore[64893]
#define sipNameNr_seed 64898
#define sipName_seed &sipStrings_QtCore[64898]
#define sipNameNr_seek 64903
#define sipName_seek &sipStrings_QtCore[64903]
#define sipNameNr_setX 64908
#define sipName_setX &sipStrings_QtCore[64908]
#define sipNameNr_setY 64913
#define sipName_setY &sipStrings_QtCore[64913]
#define sipNameNr_size 15734
#define sipName_size &sipStrings_QtCore[15734]
#define sipNameNr_skip 64918
#define sipName_skip &sipStrings_QtCore[64918]
#define sipNameNr_sort 64923
#define sipName_sort &sipStrings_QtCore[64923]
#define sipNameNr_span 64928
#define sipName_span &sipStrings_QtCore[64928]
#define sipNameNr_spec 64933
#define sipName_spec &sipStrings_QtCore[64933]
#define sipNameNr_stop 64938
#define sipName_stop &sipStrings_QtCore[64938]
#define sipNameNr_swap 64943
#define sipName_swap &sipStrings_QtCore[64943]
#define sipNameNr_sync 64948
#define sipName_sync &sipStrings_QtCore[64948]
#define sipNameNr_temp 64953
#define sipName_temp &sipStrings_QtCore[64953]
#define sipNameNr_text 16834
#define sipName_text &sipStrings_QtCore[16834]
#define sipNameNr_time 64958
#define sipName_time &sipStrings_QtCore[64958]
#define sipNameNr_type 64963
#define sipName_type &sipStrings_QtCore[64963]
#define sipNameNr_urls 64968
#define sipName_urls &sipStrings_QtCore[64968]
#define sipNameNr_wait 61560
#define sipName_wait &sipStrings_QtCore[61560]
#define sipNameNr_year 64973
#define sipName_year &sipStrings_QtCore[64973]
#define sipNameNr_ALT 64978
#define sipName_ALT &sipStrings_QtCore[64978]
#define sipNameNr_Asu 64982
#define sipName_Asu &sipStrings_QtCore[64982]
#define sipNameNr_DCE 64986
#define sipName_DCE &sipStrings_QtCore[64986]
#define sipNameNr_DTD 58343
#define sipName_DTD &sipStrings_QtCore[58343]
#define sipNameNr_Ewe 64990
#define sipName_Ewe &sipStrings_QtCore[64990]
#define sipNameNr_IOS 64994
#define sipName_IOS &sipStrings_QtCore[64994]
#define sipNameNr_Ido 64998
#define sipName_Ido &sipStrings_QtCore[64998]
#define sipNameNr_Int 54634
#define sipName_Int &sipStrings_QtCore[54634]
#define sipNameNr_Jju 65002
#define sipName_Jju &sipStrings_QtCore[65002]
#define sipNameNr_Key 25266
#define sipName_Key &sipStrings_QtCore[25266]
#define sipNameNr_Lao 65006
#define sipName_Lao &sipStrings_QtCore[65006]
#define sipNameNr_Luo 65010
#define sipName_Luo &sipStrings_QtCore[65010]
#define sipNameNr_Map 27561
#define sipName_Map &sipStrings_QtCore[27561]
#define sipNameNr_Md4 65014
#define sipName_Md4 &sipStrings_QtCore[65014]
#define sipNameNr_Md5 65018
#define sipName_Md5 &sipStrings_QtCore[65018]
#define sipNameNr_Mru 65022
#define sipName_Mru &sipStrings_QtCore[65022]
#define sipNameNr_NCS 65026
#define sipName_NCS &sipStrings_QtCore[65026]
#define sipNameNr_Nko 65030
#define sipName_Nko &sipStrings_QtCore[65030]
#define sipNameNr_Pen 63726
#define sipName_Pen &sipStrings_QtCore[63726]
#define sipNameNr_Rwa 65034
#define sipName_Rwa &sipStrings_QtCore[65034]
#define sipNameNr_Tag 64212
#define sipName_Tag &sipStrings_QtCore[64212]
#define sipNameNr_Twi 65038
#define sipName_Twi &sipStrings_QtCore[65038]
#define sipNameNr_UTC 37374
#define sipName_UTC &sipStrings_QtCore[37374]
#define sipNameNr_Url 34750
#define sipName_Url &sipStrings_QtCore[34750]
#define sipNameNr_Vai 65042
#define sipName_Vai &sipStrings_QtCore[65042]
#define sipNameNr_add 65046
#define sipName_add &sipStrings_QtCore[65046]
#define sipNameNr_bom 65050
#define sipName_bom &sipStrings_QtCore[65050]
#define sipNameNr_cap 65054
#define sipName_cap &sipStrings_QtCore[65054]
#define sipNameNr_day 53944
#define sipName_day &sipStrings_QtCore[53944]
#define sipNameNr_dec 47889
#define sipName_dec &sipStrings_QtCore[47889]
#define sipNameNr_dir 64230
#define sipName_dir &sipStrings_QtCore[64230]
#define sipNameNr_key 36800
#define sipName_key &sipStrings_QtCore[36800]
#define sipNameNr_map 59496
#define sipName_map &sipStrings_QtCore[59496]
#define sipNameNr_max 65058
#define sipName_max &sipStrings_QtCore[65058]
#define sipNameNr_mid 65062
#define sipName_mid &sipStrings_QtCore[65062]
#define sipNameNr_min 65066
#define sipName_min &sipStrings_QtCore[65066]
#define sipNameNr_nth 20235
#define sipName_nth &sipStrings_QtCore[20235]
#define sipNameNr_pid 65070
#define sipName_pid &sipStrings_QtCore[65070]
#define sipNameNr_pos 65074
#define sipName_pos &sipStrings_QtCore[65074]
#define sipNameNr_red 12927
#define sipName_red &sipStrings_QtCore[12927]
#define sipNameNr_row 50183
#define sipName_row &sipStrings_QtCore[50183]
#define sipNameNr_run 65078
#define sipName_run &sipStrings_QtCore[65078]
#define sipNameNr_tag 65082
#define sipName_tag &sipStrings_QtCore[65082]
#define sipNameNr_top 3723
#define sipName_top &sipStrings_QtCore[3723]
#define sipNameNr_url 21410
#define sipName_url &sipStrings_QtCore[21410]
#define sipNameNr_utc 65086
#define sipName_utc &sipStrings_QtCore[65086]
#define sipNameNr_Ga 65090
#define sipName_Ga &sipStrings_QtCore[65090]
#define sipNameNr_Ho 65093
#define sipName_Ho &sipStrings_QtCore[65093]
#define sipNameNr_Lu 65096
#define sipName_Lu &sipStrings_QtCore[65096]
#define sipNameNr_Ok 65099
#define sipName_Ok &sipStrings_QtCore[65099]
#define sipNameNr_Qt 6180
#define sipName_Qt &sipStrings_QtCore[6180]
#define sipNameNr_at 2993
#define sipName_at &sipStrings_QtCore[2993]
#define sipNameNr_cd 65102
#define sipName_cd &sipStrings_QtCore[65102]
#define sipNameNr_cs 20540
#define sipName_cs &sipStrings_QtCore[20540]
#define sipNameNr_dx 65105
#define sipName_dx &sipStrings_QtCore[65105]
#define sipNameNr_dy 60441
#define sipName_dy &sipStrings_QtCore[60441]
#define sipNameNr_id 28907
#define sipName_id &sipStrings_QtCore[28907]
#define sipNameNr_ok 15101
#define sipName_ok &sipStrings_QtCore[15101]
#define sipNameNr_on 705
#define sipName_on &sipStrings_QtCore[705]
#define sipNameNr_p1 65108
#define sipName_p1 &sipStrings_QtCore[65108]
#define sipNameNr_p2 59665
#define sipName_p2 &sipStrings_QtCore[59665]
#define sipNameNr_tr 57921
#define sipName_tr &sipStrings_QtCore[57921]
#define sipNameNr_ws 21825
#define sipName_ws &sipStrings_QtCore[21825]
#define sipNameNr_x1 65111
#define sipName_x1 &sipStrings_QtCore[65111]
#define sipNameNr_x2 65114
#define sipName_x2 &sipStrings_QtCore[65114]
#define sipNameNr_y1 65117
#define sipName_y1 &sipStrings_QtCore[65117]
#define sipNameNr_y2 65120
#define sipName_y2 &sipStrings_QtCore[65120]
#define sipNameNr_C 32697
#define sipName_C &sipStrings_QtCore[32697]
#define sipNameNr_c 9585
#define sipName_c &sipStrings_QtCore[9585]
#define sipNameNr_n 706
#define sipName_n &sipStrings_QtCore[706]
#define sipNameNr_x 7080
#define sipName_x &sipStrings_QtCore[7080]
#define sipNameNr_y 394
#define sipName_y &sipStrings_QtCore[394]

#define sipMalloc                   sipAPI_QtCore->api_malloc
#define sipFree                     sipAPI_QtCore->api_free
#define sipBuildResult              sipAPI_QtCore->api_build_result
#define sipCallMethod               sipAPI_QtCore->api_call_method
#define sipCallProcedureMethod      sipAPI_QtCore->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtCore->api_call_error_handler
#define sipParseResultEx            sipAPI_QtCore->api_parse_result_ex
#define sipParseResult              sipAPI_QtCore->api_parse_result
#define sipParseArgs                sipAPI_QtCore->api_parse_args
#define sipParseKwdArgs             sipAPI_QtCore->api_parse_kwd_args
#define sipParsePair                sipAPI_QtCore->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtCore->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtCore->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtCore->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtCore->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtCore->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtCore->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtCore->api_add_exception
#define sipNoFunction               sipAPI_QtCore->api_no_function
#define sipNoMethod                 sipAPI_QtCore->api_no_method
#define sipAbstractMethod           sipAPI_QtCore->api_abstract_method
#define sipBadClass                 sipAPI_QtCore->api_bad_class
#define sipBadCatcherResult         sipAPI_QtCore->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtCore->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtCore->api_bad_operator_arg
#define sipTrace                    sipAPI_QtCore->api_trace
#define sipTransferBack             sipAPI_QtCore->api_transfer_back
#define sipTransferTo               sipAPI_QtCore->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtCore->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtCore->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtCore->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtCore->api_voidptr_type
#define sipGetPyObject              sipAPI_QtCore->api_get_pyobject
#define sipGetAddress               sipAPI_QtCore->api_get_address
#define sipGetMixinAddress          sipAPI_QtCore->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtCore->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtCore->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtCore->api_call_hook
#define sipEndThread                sipAPI_QtCore->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtCore->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtCore->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtCore->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtCore->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtCore->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtCore->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtCore->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtCore->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtCore->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtCore->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtCore->api_convert_to_bool
#define sipReleaseType              sipAPI_QtCore->api_release_type
#define sipConvertFromType          sipAPI_QtCore->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtCore->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtCore->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtCore->api_convert_from_enum
#define sipGetState                 sipAPI_QtCore->api_get_state
#define sipExportSymbol             sipAPI_QtCore->api_export_symbol
#define sipImportSymbol             sipAPI_QtCore->api_import_symbol
#define sipFindType                 sipAPI_QtCore->api_find_type
#define sipBytes_AsChar             sipAPI_QtCore->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtCore->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtCore->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtCore->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtCore->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtCore->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtCore->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtCore->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtCore->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtCore->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtCore->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtCore->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtCore->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtCore->api_deprecated
#define sipGetReference             sipAPI_QtCore->api_get_reference
#define sipKeepReference            sipAPI_QtCore->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtCore->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtCore->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtCore->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtCore->api_type_scope
#define sipResolveTypedef           sipAPI_QtCore->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtCore->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtCore->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtCore->api_init_mixin
#define sipExportModule             sipAPI_QtCore->api_export_module
#define sipInitModule               sipAPI_QtCore->api_init_module
#define sipGetInterpreter           sipAPI_QtCore->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtCore->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtCore->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtCore->api_py_type_dict
#define sipPyTypeName               sipAPI_QtCore->api_py_type_name
#define sipGetCFunction             sipAPI_QtCore->api_get_c_function
#define sipGetMethod                sipAPI_QtCore->api_get_method
#define sipFromMethod               sipAPI_QtCore->api_from_method
#define sipGetDate                  sipAPI_QtCore->api_get_date
#define sipFromDate                 sipAPI_QtCore->api_from_date
#define sipGetDateTime              sipAPI_QtCore->api_get_datetime
#define sipFromDateTime             sipAPI_QtCore->api_from_datetime
#define sipGetTime                  sipAPI_QtCore->api_get_time
#define sipFromTime                 sipAPI_QtCore->api_from_time
#define sipIsUserType               sipAPI_QtCore->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtCore->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtCore->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtCore->api_unicode_write
#define sipUnicodeData              sipAPI_QtCore->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtCore->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtCore->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtCore->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtCore->api_is_derived_class
#define sipGetUserObject            sipAPI_QtCore->api_get_user_object
#define sipSetUserObject            sipAPI_QtCore->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtCore->api_register_event_handler
#define sipConvertToArray           sipAPI_QtCore->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtCore->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtCore->api_enable_gc
#define sipPrintObject              sipAPI_QtCore->api_print_object
#define sipLong_AsChar              sipAPI_QtCore->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtCore->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtCore->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtCore->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtCore->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtCore->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtCore->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtCore->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtCore->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtCore->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtCore->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtCore->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtCore->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtCore->api_register_exit_notifier
#define sipPyTypeDictRef            sipAPI_QtCore->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtCore->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtCore->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtCore->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtCore->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtCore->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtCore->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtCore->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtCore->api_connect_rx
#define sipConvertRx                sipAPI_QtCore->api_convert_rx
#define sipDisconnectRx             sipAPI_QtCore->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtCore->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtCore->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtCore->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtCore->api_same_slot
#define sipSaveSlot                 sipAPI_QtCore->api_save_slot
#define sipVisitSlot                sipAPI_QtCore->api_visit_slot
#define sipIsPyMethod               sipAPI_QtCore->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtCore[];

#define sipType_Qt sipExportedTypes_QtCore[350]

#define sipType_Qt_HighDpiScaleFactorRoundingPolicy sipExportedTypes_QtCore[392]

#define sipType_Qt_ChecksumType sipExportedTypes_QtCore[364]

#define sipType_Qt_EnterKeyType sipExportedTypes_QtCore[380]

#define sipType_Qt_ItemSelectionOperation sipExportedTypes_QtCore[404]

#define sipType_Qt_TabFocusBehavior sipExportedTypes_QtCore[433]

#define sipType_Qt_MouseEventFlag sipExportedTypes_QtCore[415]

#define sipType_Qt_MouseEventSource sipExportedTypes_QtCore[417]

#define sipType_Qt_ScrollPhase sipExportedTypes_QtCore[428]

#define sipType_Qt_NativeGestureType sipExportedTypes_QtCore[418]

#define sipType_Qt_Edge sipExportedTypes_QtCore[378]

#define sipType_Qt_ApplicationState sipExportedTypes_QtCore[355]

#define sipType_Qt_HitTestAccuracy sipExportedTypes_QtCore[393]

#define sipType_Qt_WhiteSpaceMode sipExportedTypes_QtCore[449]

#define sipType_Qt_FindChildOption sipExportedTypes_QtCore[383]

#define sipType_Qt_ScreenOrientation sipExportedTypes_QtCore[425]

#define sipType_Qt_CursorMoveStyle sipExportedTypes_QtCore[370]

#define sipType_Qt_NavigationMode sipExportedTypes_QtCore[419]

#define sipType_Qt_GestureFlag sipExportedTypes_QtCore[387]

#define sipType_Qt_GestureType sipExportedTypes_QtCore[390]

#define sipType_Qt_GestureState sipExportedTypes_QtCore[389]

#define sipType_Qt_TouchPointState sipExportedTypes_QtCore[445]

#define sipType_Qt_CoordinateSystem sipExportedTypes_QtCore[368]

#define sipType_Qt_AnchorPoint sipExportedTypes_QtCore[353]

#define sipType_Qt_InputMethodHint sipExportedTypes_QtCore[396]

#define sipType_Qt_TileRule sipExportedTypes_QtCore[439]

#define sipType_Qt_WindowFrameSection sipExportedTypes_QtCore[452]

#define sipType_Qt_SizeHint sipExportedTypes_QtCore[430]

#define sipType_Qt_SizeMode sipExportedTypes_QtCore[431]

#define sipType_Qt_EventPriority sipExportedTypes_QtCore[381]

#define sipType_Qt_Axis sipExportedTypes_QtCore[359]

#define sipType_Qt_MaskMode sipExportedTypes_QtCore[409]

#define sipType_Qt_TextInteractionFlag sipExportedTypes_QtCore[437]

#define sipType_Qt_ItemSelectionMode sipExportedTypes_QtCore[403]

#define sipType_Qt_ApplicationAttribute sipExportedTypes_QtCore[354]

#define sipType_Qt_WindowModality sipExportedTypes_QtCore[453]

#define sipType_Qt_MatchFlag sipExportedTypes_QtCore[410]

#define sipType_Qt_ItemFlag sipExportedTypes_QtCore[401]

#define sipType_Qt_ItemDataRole sipExportedTypes_QtCore[400]

#define sipType_Qt_CheckState sipExportedTypes_QtCore[363]

#define sipType_Qt_DropAction sipExportedTypes_QtCore[376]

#define sipType_Qt_LayoutDirection sipExportedTypes_QtCore[408]

#define sipType_Qt_ToolButtonStyle sipExportedTypes_QtCore[444]

#define sipType_Qt_InputMethodQuery sipExportedTypes_QtCore[399]

#define sipType_Qt_ContextMenuPolicy sipExportedTypes_QtCore[367]

#define sipType_Qt_FocusReason sipExportedTypes_QtCore[386]

#define sipType_Qt_TransformationMode sipExportedTypes_QtCore[447]

#define sipType_Qt_ClipOperation sipExportedTypes_QtCore[365]

#define sipType_Qt_FillRule sipExportedTypes_QtCore[382]

#define sipType_Qt_ShortcutContext sipExportedTypes_QtCore[429]

#define sipType_Qt_ConnectionType sipExportedTypes_QtCore[366]

#define sipType_Qt_Corner sipExportedTypes_QtCore[369]

#define sipType_Qt_CaseSensitivity sipExportedTypes_QtCore[362]

#define sipType_Qt_ScrollBarPolicy sipExportedTypes_QtCore[427]

#define sipType_Qt_DayOfWeek sipExportedTypes_QtCore[373]

#define sipType_Qt_TimeSpec sipExportedTypes_QtCore[440]

#define sipType_Qt_DateFormat sipExportedTypes_QtCore[372]

#define sipType_Qt_ToolBarArea sipExportedTypes_QtCore[442]

#define sipType_Qt_TimerType sipExportedTypes_QtCore[441]

#define sipType_Qt_DockWidgetArea sipExportedTypes_QtCore[374]

#define sipType_Qt_AspectRatioMode sipExportedTypes_QtCore[358]

#define sipType_Qt_TextFormat sipExportedTypes_QtCore[436]

#define sipType_Qt_CursorShape sipExportedTypes_QtCore[371]

#define sipType_Qt_UIEffect sipExportedTypes_QtCore[448]

#define sipType_Qt_BrushStyle sipExportedTypes_QtCore[361]

#define sipType_Qt_PenJoinStyle sipExportedTypes_QtCore[423]

#define sipType_Qt_PenCapStyle sipExportedTypes_QtCore[422]

#define sipType_Qt_PenStyle sipExportedTypes_QtCore[424]

#define sipType_Qt_ArrowType sipExportedTypes_QtCore[357]

#define sipType_Qt_Key sipExportedTypes_QtCore[405]

#define sipType_Qt_BGMode sipExportedTypes_QtCore[360]

#define sipType_Qt_ImageConversionFlag sipExportedTypes_QtCore[394]

#define sipType_Qt_WidgetAttribute sipExportedTypes_QtCore[450]

#define sipType_Qt_WindowState sipExportedTypes_QtCore[454]

#define sipType_Qt_WindowType sipExportedTypes_QtCore[456]

#define sipType_Qt_TextElideMode sipExportedTypes_QtCore[434]

#define sipType_Qt_TextFlag sipExportedTypes_QtCore[435]

#define sipType_Qt_AlignmentFlag sipExportedTypes_QtCore[352]

#define sipType_Qt_SortOrder sipExportedTypes_QtCore[432]

#define sipType_Qt_FocusPolicy sipExportedTypes_QtCore[385]

#define sipType_Qt_Orientation sipExportedTypes_QtCore[420]

#define sipType_Qt_MouseButton sipExportedTypes_QtCore[413]

#define sipType_Qt_Modifier sipExportedTypes_QtCore[412]

#define sipType_Qt_KeyboardModifier sipExportedTypes_QtCore[406]

#define sipType_Qt_GlobalColor sipExportedTypes_QtCore[391]

extern sipClassTypeDef sipTypeDef_QtCore_Qt;

#define sipType_Qt_KeyboardModifiers sipExportedTypes_QtCore[407]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_KeyboardModifiers;

#define sipType_Qt_MouseButtons sipExportedTypes_QtCore[414]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_MouseButtons;

#define sipType_Qt_Orientations sipExportedTypes_QtCore[421]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_Orientations;

#define sipType_Qt_Alignment sipExportedTypes_QtCore[351]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_Alignment;

#define sipType_Qt_WindowFlags sipExportedTypes_QtCore[451]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_WindowFlags;

#define sipType_Qt_WindowStates sipExportedTypes_QtCore[455]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_WindowStates;

#define sipType_Qt_ImageConversionFlags sipExportedTypes_QtCore[395]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_ImageConversionFlags;

#define sipType_Qt_DockWidgetAreas sipExportedTypes_QtCore[375]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_DockWidgetAreas;

#define sipType_Qt_ToolBarAreas sipExportedTypes_QtCore[443]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_ToolBarAreas;

#define sipType_Qt_InputMethodQueries sipExportedTypes_QtCore[398]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_InputMethodQueries;

#define sipType_Qt_DropActions sipExportedTypes_QtCore[377]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_DropActions;

#define sipType_Qt_ItemFlags sipExportedTypes_QtCore[402]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_ItemFlags;

#define sipType_Qt_MatchFlags sipExportedTypes_QtCore[411]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_MatchFlags;

#define sipType_Qt_TextInteractionFlags sipExportedTypes_QtCore[438]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_TextInteractionFlags;

#define sipType_Qt_InputMethodHints sipExportedTypes_QtCore[397]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_InputMethodHints;

#define sipType_Qt_TouchPointStates sipExportedTypes_QtCore[446]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_TouchPointStates;

#define sipType_Qt_GestureFlags sipExportedTypes_QtCore[388]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_GestureFlags;

#define sipType_Qt_ScreenOrientations sipExportedTypes_QtCore[426]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_ScreenOrientations;

#define sipType_Qt_FindChildOptions sipExportedTypes_QtCore[384]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_FindChildOptions;

#define sipType_Qt_ApplicationStates sipExportedTypes_QtCore[356]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_ApplicationStates;

#define sipType_Qt_Edges sipExportedTypes_QtCore[379]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_Edges;

#define sipType_Qt_MouseEventFlags sipExportedTypes_QtCore[416]

extern sipClassTypeDef sipTypeDef_QtCore_Qt_MouseEventFlags;

#define sipType_QObject sipExportedTypes_QtCore[191]

extern sipClassTypeDef sipTypeDef_QtCore_QObject;

#define sipType_QAbstractAnimation sipExportedTypes_QtCore[0]

#define sipType_QAbstractAnimation_DeletionPolicy sipExportedTypes_QtCore[1]

#define sipType_QAbstractAnimation_State sipExportedTypes_QtCore[3]

#define sipType_QAbstractAnimation_Direction sipExportedTypes_QtCore[2]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractAnimation;

#define sipType_QAbstractEventDispatcher sipExportedTypes_QtCore[4]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractEventDispatcher;

#define sipType_QAbstractEventDispatcher_TimerInfo sipExportedTypes_QtCore[5]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractEventDispatcher_TimerInfo;

#define sipType_QModelIndex sipExportedTypes_QtCore[187]

extern sipClassTypeDef sipTypeDef_QtCore_QModelIndex;

#define sipType_QPersistentModelIndex sipExportedTypes_QtCore[198]

extern sipClassTypeDef sipTypeDef_QtCore_QPersistentModelIndex;

#define sipType_QAbstractItemModel sipExportedTypes_QtCore[6]

#define sipType_QAbstractItemModel_CheckIndexOption sipExportedTypes_QtCore[7]

#define sipType_QAbstractItemModel_LayoutChangeHint sipExportedTypes_QtCore[9]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractItemModel;

#define sipType_QAbstractItemModel_CheckIndexOptions sipExportedTypes_QtCore[8]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractItemModel_CheckIndexOptions;

#define sipType_QAbstractTableModel sipExportedTypes_QtCore[14]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractTableModel;

#define sipType_QAbstractListModel sipExportedTypes_QtCore[10]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractListModel;

#define sipType_QAbstractNativeEventFilter sipExportedTypes_QtCore[11]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractNativeEventFilter;

#define sipType_QAbstractProxyModel sipExportedTypes_QtCore[12]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractProxyModel;

#define sipType_QAbstractState sipExportedTypes_QtCore[13]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractState;

#define sipType_QAbstractTransition sipExportedTypes_QtCore[15]

#define sipType_QAbstractTransition_TransitionType sipExportedTypes_QtCore[16]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractTransition;

#define sipType_QAnimationGroup sipExportedTypes_QtCore[17]

extern sipClassTypeDef sipTypeDef_QtCore_QAnimationGroup;

#define sipType_QBasicTimer sipExportedTypes_QtCore[18]

extern sipClassTypeDef sipTypeDef_QtCore_QBasicTimer;

#define sipType_QBitArray sipExportedTypes_QtCore[19]

extern sipClassTypeDef sipTypeDef_QtCore_QBitArray;

#define sipType_QIODevice sipExportedTypes_QtCore[102]

#define sipType_QIODevice_OpenModeFlag sipExportedTypes_QtCore[104]

extern sipClassTypeDef sipTypeDef_QtCore_QIODevice;

#define sipType_QBuffer sipExportedTypes_QtCore[20]

extern sipClassTypeDef sipTypeDef_QtCore_QBuffer;

#define sipType_QByteArray sipExportedTypes_QtCore[21]

#define sipType_QByteArray_Base64DecodingStatus sipExportedTypes_QtCore[22]

#define sipType_QByteArray_Base64Option sipExportedTypes_QtCore[23]

extern sipClassTypeDef sipTypeDef_QtCore_QByteArray;

#define sipType_QByteArray_Base64Options sipExportedTypes_QtCore[24]

extern sipClassTypeDef sipTypeDef_QtCore_QByteArray_Base64Options;

#define sipType_QByteArray_FromBase64Result sipExportedTypes_QtCore[25]

extern sipClassTypeDef sipTypeDef_QtCore_QByteArray_FromBase64Result;

#define sipType_QByteArrayMatcher sipExportedTypes_QtCore[26]

extern sipClassTypeDef sipTypeDef_QtCore_QByteArrayMatcher;

#define sipType_QCalendar sipExportedTypes_QtCore[27]

#define sipType_QCalendar_System sipExportedTypes_QtCore[28]

extern sipClassTypeDef sipTypeDef_QtCore_QCalendar;

#define sipType_QCalendar_YearMonthDay sipExportedTypes_QtCore[29]

extern sipClassTypeDef sipTypeDef_QtCore_QCalendar_YearMonthDay;

#define sipType_QCborError sipExportedTypes_QtCore[30]

#define sipType_QCborError_Code sipExportedTypes_QtCore[31]

extern sipClassTypeDef sipTypeDef_QtCore_QCborError;

#define sipType_QCborStreamWriter sipExportedTypes_QtCore[37]

extern sipClassTypeDef sipTypeDef_QtCore_QCborStreamWriter;

#define sipType_QCborStreamReader sipExportedTypes_QtCore[34]

#define sipType_QCborStreamReader_StringResultCode sipExportedTypes_QtCore[35]

#define sipType_QCborStreamReader_Type sipExportedTypes_QtCore[36]

extern sipClassTypeDef sipTypeDef_QtCore_QCborStreamReader;

#define sipType_QCollatorSortKey sipExportedTypes_QtCore[41]

extern sipClassTypeDef sipTypeDef_QtCore_QCollatorSortKey;

#define sipType_QCollator sipExportedTypes_QtCore[40]

extern sipClassTypeDef sipTypeDef_QtCore_QCollator;

#define sipType_QCommandLineOption sipExportedTypes_QtCore[42]

#define sipType_QCommandLineOption_Flag sipExportedTypes_QtCore[43]

extern sipClassTypeDef sipTypeDef_QtCore_QCommandLineOption;

#define sipType_QCommandLineOption_Flags sipExportedTypes_QtCore[44]

extern sipClassTypeDef sipTypeDef_QtCore_QCommandLineOption_Flags;

#define sipType_QCommandLineParser sipExportedTypes_QtCore[45]

#define sipType_QCommandLineParser_OptionsAfterPositionalArgumentsMode sipExportedTypes_QtCore[46]

#define sipType_QCommandLineParser_SingleDashWordOptionMode sipExportedTypes_QtCore[47]

extern sipClassTypeDef sipTypeDef_QtCore_QCommandLineParser;

#define sipType_QConcatenateTablesProxyModel sipExportedTypes_QtCore[48]

extern sipClassTypeDef sipTypeDef_QtCore_QConcatenateTablesProxyModel;

#define sipType_QCoreApplication sipExportedTypes_QtCore[49]

extern sipClassTypeDef sipTypeDef_QtCore_QCoreApplication;

#define sipType_QEvent sipExportedTypes_QtCore[76]

#define sipType_QEvent_Type sipExportedTypes_QtCore[77]

extern sipClassTypeDef sipTypeDef_QtCore_QEvent;

#define sipType_QTimerEvent sipExportedTypes_QtCore[307]

extern sipClassTypeDef sipTypeDef_QtCore_QTimerEvent;

#define sipType_QChildEvent sipExportedTypes_QtCore[39]

extern sipClassTypeDef sipTypeDef_QtCore_QChildEvent;

#define sipType_QDynamicPropertyChangeEvent sipExportedTypes_QtCore[71]

extern sipClassTypeDef sipTypeDef_QtCore_QDynamicPropertyChangeEvent;

#define sipType_QCryptographicHash sipExportedTypes_QtCore[50]

#define sipType_QCryptographicHash_Algorithm sipExportedTypes_QtCore[51]

extern sipClassTypeDef sipTypeDef_QtCore_QCryptographicHash;

#define sipType_QDataStream sipExportedTypes_QtCore[52]

#define sipType_QDataStream_FloatingPointPrecision sipExportedTypes_QtCore[54]

#define sipType_QDataStream_Status sipExportedTypes_QtCore[55]

#define sipType_QDataStream_ByteOrder sipExportedTypes_QtCore[53]

#define sipType_QDataStream_Version sipExportedTypes_QtCore[56]

extern sipClassTypeDef sipTypeDef_QtCore_QDataStream;

#define sipType_QDate sipExportedTypes_QtCore[57]

#define sipType_QDate_MonthNameType sipExportedTypes_QtCore[58]

extern sipClassTypeDef sipTypeDef_QtCore_QDate;

#define sipType_QTime sipExportedTypes_QtCore[297]

extern sipClassTypeDef sipTypeDef_QtCore_QTime;

#define sipType_QDateTime sipExportedTypes_QtCore[59]

#define sipType_QDateTime_YearRange sipExportedTypes_QtCore[60]

extern sipClassTypeDef sipTypeDef_QtCore_QDateTime;

#define sipType_QDeadlineTimer sipExportedTypes_QtCore[61]

#define sipType_QDeadlineTimer_ForeverConstant sipExportedTypes_QtCore[62]

extern sipClassTypeDef sipTypeDef_QtCore_QDeadlineTimer;

#define sipType_QDir sipExportedTypes_QtCore[63]

#define sipType_QDir_SortFlag sipExportedTypes_QtCore[66]

#define sipType_QDir_Filter sipExportedTypes_QtCore[64]

extern sipClassTypeDef sipTypeDef_QtCore_QDir;

#define sipType_QDir_Filters sipExportedTypes_QtCore[65]

extern sipClassTypeDef sipTypeDef_QtCore_QDir_Filters;

#define sipType_QDir_SortFlags sipExportedTypes_QtCore[67]

extern sipClassTypeDef sipTypeDef_QtCore_QDir_SortFlags;

#define sipType_QDirIterator sipExportedTypes_QtCore[68]

#define sipType_QDirIterator_IteratorFlag sipExportedTypes_QtCore[69]

extern sipClassTypeDef sipTypeDef_QtCore_QDirIterator;

#define sipType_QDirIterator_IteratorFlags sipExportedTypes_QtCore[70]

extern sipClassTypeDef sipTypeDef_QtCore_QDirIterator_IteratorFlags;

#define sipType_QEasingCurve sipExportedTypes_QtCore[72]

#define sipType_QEasingCurve_Type sipExportedTypes_QtCore[73]

extern sipClassTypeDef sipTypeDef_QtCore_QEasingCurve;

#define sipType_QElapsedTimer sipExportedTypes_QtCore[74]

#define sipType_QElapsedTimer_ClockType sipExportedTypes_QtCore[75]

extern sipClassTypeDef sipTypeDef_QtCore_QElapsedTimer;

#define sipType_QEventLoop sipExportedTypes_QtCore[78]

#define sipType_QEventLoop_ProcessEventsFlag sipExportedTypes_QtCore[79]

extern sipClassTypeDef sipTypeDef_QtCore_QEventLoop;

#define sipType_QEventLoop_ProcessEventsFlags sipExportedTypes_QtCore[80]

extern sipClassTypeDef sipTypeDef_QtCore_QEventLoop_ProcessEventsFlags;

#define sipType_QEventLoopLocker sipExportedTypes_QtCore[81]

extern sipClassTypeDef sipTypeDef_QtCore_QEventLoopLocker;

#define sipType_QEventTransition sipExportedTypes_QtCore[82]

extern sipClassTypeDef sipTypeDef_QtCore_QEventTransition;

#define sipType_QFileDevice sipExportedTypes_QtCore[84]

#define sipType_QFileDevice_FileTime sipExportedTypes_QtCore[88]

#define sipType_QFileDevice_MemoryMapFlags sipExportedTypes_QtCore[89]

#define sipType_QFileDevice_FileHandleFlag sipExportedTypes_QtCore[86]

#define sipType_QFileDevice_Permission sipExportedTypes_QtCore[90]

#define sipType_QFileDevice_FileError sipExportedTypes_QtCore[85]

extern sipClassTypeDef sipTypeDef_QtCore_QFileDevice;

#define sipType_QFile sipExportedTypes_QtCore[83]

extern sipClassTypeDef sipTypeDef_QtCore_QFile;

#define sipType_QFileDevice_Permissions sipExportedTypes_QtCore[91]

extern sipClassTypeDef sipTypeDef_QtCore_QFileDevice_Permissions;

#define sipType_QFileDevice_FileHandleFlags sipExportedTypes_QtCore[87]

extern sipClassTypeDef sipTypeDef_QtCore_QFileDevice_FileHandleFlags;

#define sipType_QFileInfo sipExportedTypes_QtCore[92]

extern sipClassTypeDef sipTypeDef_QtCore_QFileInfo;

#define sipType_QFileSelector sipExportedTypes_QtCore[93]

extern sipClassTypeDef sipTypeDef_QtCore_QFileSelector;

#define sipType_QFileSystemWatcher sipExportedTypes_QtCore[94]

extern sipClassTypeDef sipTypeDef_QtCore_QFileSystemWatcher;

#define sipType_QFinalState sipExportedTypes_QtCore[95]

extern sipClassTypeDef sipTypeDef_QtCore_QFinalState;

#define sipType_QHistoryState sipExportedTypes_QtCore[100]

#define sipType_QHistoryState_HistoryType sipExportedTypes_QtCore[101]

extern sipClassTypeDef sipTypeDef_QtCore_QHistoryState;

#define sipType_QIdentityProxyModel sipExportedTypes_QtCore[105]

extern sipClassTypeDef sipTypeDef_QtCore_QIdentityProxyModel;

#define sipType_QIODevice_OpenMode sipExportedTypes_QtCore[103]

extern sipClassTypeDef sipTypeDef_QtCore_QIODevice_OpenMode;

#define sipType_QItemSelectionRange sipExportedTypes_QtCore[110]

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelectionRange;

#define sipType_QItemSelectionModel sipExportedTypes_QtCore[107]

#define sipType_QItemSelectionModel_SelectionFlag sipExportedTypes_QtCore[108]

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelectionModel;

#define sipType_QItemSelectionModel_SelectionFlags sipExportedTypes_QtCore[109]

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelectionModel_SelectionFlags;

#define sipType_QItemSelection sipExportedTypes_QtCore[106]

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelection;

#define sipType_QJsonParseError sipExportedTypes_QtCore[116]

#define sipType_QJsonParseError_ParseError sipExportedTypes_QtCore[117]

extern sipClassTypeDef sipTypeDef_QtCore_QJsonParseError;

#define sipType_QJsonDocument sipExportedTypes_QtCore[112]

#define sipType_QJsonDocument_JsonFormat sipExportedTypes_QtCore[114]

#define sipType_QJsonDocument_DataValidation sipExportedTypes_QtCore[113]

extern sipClassTypeDef sipTypeDef_QtCore_QJsonDocument;

#define sipType_QJsonValue sipExportedTypes_QtCore[118]

#define sipType_QJsonValue_Type sipExportedTypes_QtCore[119]

extern sipClassTypeDef sipTypeDef_QtCore_QJsonValue;

#define sipType_QLibrary sipExportedTypes_QtCore[120]

#define sipType_QLibrary_LoadHint sipExportedTypes_QtCore[121]

extern sipClassTypeDef sipTypeDef_QtCore_QLibrary;

#define sipType_QLibrary_LoadHints sipExportedTypes_QtCore[122]

extern sipClassTypeDef sipTypeDef_QtCore_QLibrary_LoadHints;

#define sipType_QLibraryInfo sipExportedTypes_QtCore[123]

#define sipType_QLibraryInfo_LibraryLocation sipExportedTypes_QtCore[124]

extern sipClassTypeDef sipTypeDef_QtCore_QLibraryInfo;

#define sipType_QLine sipExportedTypes_QtCore[125]

extern sipClassTypeDef sipTypeDef_QtCore_QLine;

#define sipType_QLineF sipExportedTypes_QtCore[126]

#define sipType_QLineF_IntersectType sipExportedTypes_QtCore[127]

extern sipClassTypeDef sipTypeDef_QtCore_QLineF;

#define sipType_QLocale sipExportedTypes_QtCore[149]

#define sipType_QLocale_DataSizeFormat sipExportedTypes_QtCore[152]

#define sipType_QLocale_FloatingPointPrecisionOption sipExportedTypes_QtCore[154]

#define sipType_QLocale_QuotationStyle sipExportedTypes_QtCore[160]

#define sipType_QLocale_CurrencySymbolFormat sipExportedTypes_QtCore[151]

#define sipType_QLocale_Script sipExportedTypes_QtCore[161]

#define sipType_QLocale_MeasurementSystem sipExportedTypes_QtCore[157]

#define sipType_QLocale_FormatType sipExportedTypes_QtCore[155]

#define sipType_QLocale_NumberOption sipExportedTypes_QtCore[158]

#define sipType_QLocale_Country sipExportedTypes_QtCore[150]

#define sipType_QLocale_Language sipExportedTypes_QtCore[156]

extern sipClassTypeDef sipTypeDef_QtCore_QLocale;

#define sipType_QLocale_NumberOptions sipExportedTypes_QtCore[159]

extern sipClassTypeDef sipTypeDef_QtCore_QLocale_NumberOptions;

#define sipType_QLocale_DataSizeFormats sipExportedTypes_QtCore[153]

extern sipClassTypeDef sipTypeDef_QtCore_QLocale_DataSizeFormats;

#define sipType_QLockFile sipExportedTypes_QtCore[162]

#define sipType_QLockFile_LockError sipExportedTypes_QtCore[163]

extern sipClassTypeDef sipTypeDef_QtCore_QLockFile;

#define sipType_QMessageLogContext sipExportedTypes_QtCore[169]

extern sipClassTypeDef sipTypeDef_QtCore_QMessageLogContext;

#define sipType_QMessageLogger sipExportedTypes_QtCore[170]

extern sipClassTypeDef sipTypeDef_QtCore_QMessageLogger;

#define sipType_QLoggingCategory sipExportedTypes_QtCore[164]

extern sipClassTypeDef sipTypeDef_QtCore_QLoggingCategory;

#define sipType_QMargins sipExportedTypes_QtCore[166]

extern sipClassTypeDef sipTypeDef_QtCore_QMargins;

#define sipType_QMarginsF sipExportedTypes_QtCore[167]

extern sipClassTypeDef sipTypeDef_QtCore_QMarginsF;

#define sipType_QMessageAuthenticationCode sipExportedTypes_QtCore[168]

extern sipClassTypeDef sipTypeDef_QtCore_QMessageAuthenticationCode;

#define sipType_QMetaMethod sipExportedTypes_QtCore[173]

#define sipType_QMetaMethod_MethodType sipExportedTypes_QtCore[175]

#define sipType_QMetaMethod_Access sipExportedTypes_QtCore[174]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaMethod;

#define sipType_QMetaEnum sipExportedTypes_QtCore[172]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaEnum;

#define sipType_QMetaProperty sipExportedTypes_QtCore[178]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaProperty;

#define sipType_QMetaClassInfo sipExportedTypes_QtCore[171]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaClassInfo;

#define sipType_QMetaType sipExportedTypes_QtCore[179]

#define sipType_QMetaType_TypeFlag sipExportedTypes_QtCore[181]

#define sipType_QMetaType_Type sipExportedTypes_QtCore[180]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaType;

#define sipType_QMetaType_TypeFlags sipExportedTypes_QtCore[182]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaType_TypeFlags;

#define sipType_QMimeData sipExportedTypes_QtCore[183]

extern sipClassTypeDef sipTypeDef_QtCore_QMimeData;

#define sipType_QMimeDatabase sipExportedTypes_QtCore[184]

#define sipType_QMimeDatabase_MatchMode sipExportedTypes_QtCore[185]

extern sipClassTypeDef sipTypeDef_QtCore_QMimeDatabase;

#define sipType_QMimeType sipExportedTypes_QtCore[186]

extern sipClassTypeDef sipTypeDef_QtCore_QMimeType;

#define sipType_QMutexLocker sipExportedTypes_QtCore[190]

extern sipClassTypeDef sipTypeDef_QtCore_QMutexLocker;

#define sipType_QMutex sipExportedTypes_QtCore[188]

#define sipType_QMutex_RecursionMode sipExportedTypes_QtCore[189]

extern sipClassTypeDef sipTypeDef_QtCore_QMutex;

#define sipType_QRecursiveMutex sipExportedTypes_QtCore[217]

extern sipClassTypeDef sipTypeDef_QtCore_QRecursiveMutex;

#define sipType_QSignalBlocker sipExportedTypes_QtCore[244]

extern sipClassTypeDef sipTypeDef_QtCore_QSignalBlocker;

#define sipType_QObjectCleanupHandler sipExportedTypes_QtCore[192]

extern sipClassTypeDef sipTypeDef_QtCore_QObjectCleanupHandler;

#define sipType_QMetaObject sipExportedTypes_QtCore[176]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaObject;

#define sipType_QMetaObject_Connection sipExportedTypes_QtCore[177]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaObject_Connection;

#define sipType_QGenericArgument sipExportedTypes_QtCore[96]

extern sipClassTypeDef sipTypeDef_QtCore_QGenericArgument;

#define sipType_QGenericReturnArgument sipExportedTypes_QtCore[97]

extern sipClassTypeDef sipTypeDef_QtCore_QGenericReturnArgument;

#define sipType_QOperatingSystemVersion sipExportedTypes_QtCore[193]

#define sipType_QOperatingSystemVersion_OSType sipExportedTypes_QtCore[194]

extern sipClassTypeDef sipTypeDef_QtCore_QOperatingSystemVersion;

#define sipType_QParallelAnimationGroup sipExportedTypes_QtCore[196]

extern sipClassTypeDef sipTypeDef_QtCore_QParallelAnimationGroup;

#define sipType_QPauseAnimation sipExportedTypes_QtCore[197]

extern sipClassTypeDef sipTypeDef_QtCore_QPauseAnimation;

#define sipType_QVariantAnimation sipExportedTypes_QtCore[325]

extern sipClassTypeDef sipTypeDef_QtCore_QVariantAnimation;

#define sipType_QPropertyAnimation sipExportedTypes_QtCore[210]

extern sipClassTypeDef sipTypeDef_QtCore_QPropertyAnimation;

#define sipType_QPluginLoader sipExportedTypes_QtCore[199]

extern sipClassTypeDef sipTypeDef_QtCore_QPluginLoader;

#define sipType_QPoint sipExportedTypes_QtCore[200]

extern sipClassTypeDef sipTypeDef_QtCore_QPoint;

#define sipType_QPointF sipExportedTypes_QtCore[201]

extern sipClassTypeDef sipTypeDef_QtCore_QPointF;

#define sipType_QProcess sipExportedTypes_QtCore[202]

#define sipType_QProcess_InputChannelMode sipExportedTypes_QtCore[204]

#define sipType_QProcess_ProcessChannelMode sipExportedTypes_QtCore[206]

#define sipType_QProcess_ProcessChannel sipExportedTypes_QtCore[205]

#define sipType_QProcess_ProcessState sipExportedTypes_QtCore[208]

#define sipType_QProcess_ProcessError sipExportedTypes_QtCore[207]

#define sipType_QProcess_ExitStatus sipExportedTypes_QtCore[203]

extern sipClassTypeDef sipTypeDef_QtCore_QProcess;

#define sipType_QProcessEnvironment sipExportedTypes_QtCore[209]

extern sipClassTypeDef sipTypeDef_QtCore_QProcessEnvironment;

#define sipType_QRandomGenerator sipExportedTypes_QtCore[211]

extern sipClassTypeDef sipTypeDef_QtCore_QRandomGenerator;

#define sipType_QReadWriteLock sipExportedTypes_QtCore[213]

#define sipType_QReadWriteLock_RecursionMode sipExportedTypes_QtCore[214]

extern sipClassTypeDef sipTypeDef_QtCore_QReadWriteLock;

#define sipType_QReadLocker sipExportedTypes_QtCore[212]

extern sipClassTypeDef sipTypeDef_QtCore_QReadLocker;

#define sipType_QWriteLocker sipExportedTypes_QtCore[338]

extern sipClassTypeDef sipTypeDef_QtCore_QWriteLocker;

#define sipType_QRect sipExportedTypes_QtCore[215]

extern sipClassTypeDef sipTypeDef_QtCore_QRect;

#define sipType_QRectF sipExportedTypes_QtCore[216]

extern sipClassTypeDef sipTypeDef_QtCore_QRectF;

#define sipType_QRegExp sipExportedTypes_QtCore[218]

#define sipType_QRegExp_CaretMode sipExportedTypes_QtCore[219]

#define sipType_QRegExp_PatternSyntax sipExportedTypes_QtCore[220]

extern sipClassTypeDef sipTypeDef_QtCore_QRegExp;

#define sipType_QRegularExpression sipExportedTypes_QtCore[221]

#define sipType_QRegularExpression_MatchOption sipExportedTypes_QtCore[222]

#define sipType_QRegularExpression_MatchType sipExportedTypes_QtCore[224]

#define sipType_QRegularExpression_PatternOption sipExportedTypes_QtCore[225]

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpression;

#define sipType_QRegularExpression_PatternOptions sipExportedTypes_QtCore[226]

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpression_PatternOptions;

#define sipType_QRegularExpression_MatchOptions sipExportedTypes_QtCore[223]

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpression_MatchOptions;

#define sipType_QRegularExpressionMatch sipExportedTypes_QtCore[227]

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpressionMatch;

#define sipType_QRegularExpressionMatchIterator sipExportedTypes_QtCore[228]

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpressionMatchIterator;

#define sipType_QResource sipExportedTypes_QtCore[229]

#define sipType_QResource_Compression sipExportedTypes_QtCore[230]

extern sipClassTypeDef sipTypeDef_QtCore_QResource;

#define sipType_QRunnable sipExportedTypes_QtCore[231]

extern sipClassTypeDef sipTypeDef_QtCore_QRunnable;

#define sipType_QSaveFile sipExportedTypes_QtCore[232]

extern sipClassTypeDef sipTypeDef_QtCore_QSaveFile;

#define sipType_QSemaphore sipExportedTypes_QtCore[233]

extern sipClassTypeDef sipTypeDef_QtCore_QSemaphore;

#define sipType_QSemaphoreReleaser sipExportedTypes_QtCore[234]

extern sipClassTypeDef sipTypeDef_QtCore_QSemaphoreReleaser;

#define sipType_QSequentialAnimationGroup sipExportedTypes_QtCore[235]

extern sipClassTypeDef sipTypeDef_QtCore_QSequentialAnimationGroup;

#define sipType_QSettings sipExportedTypes_QtCore[237]

#define sipType_QSettings_Scope sipExportedTypes_QtCore[239]

#define sipType_QSettings_Format sipExportedTypes_QtCore[238]

#define sipType_QSettings_Status sipExportedTypes_QtCore[240]

extern sipClassTypeDef sipTypeDef_QtCore_QSettings;

#define sipType_QSharedMemory sipExportedTypes_QtCore[241]

#define sipType_QSharedMemory_SharedMemoryError sipExportedTypes_QtCore[243]

#define sipType_QSharedMemory_AccessMode sipExportedTypes_QtCore[242]

extern sipClassTypeDef sipTypeDef_QtCore_QSharedMemory;

#define sipType_QWidget sipExportedTypes_QtCore[337]

#define sipType_QSignalMapper sipExportedTypes_QtCore[245]

extern sipClassTypeDef sipTypeDef_QtCore_QSignalMapper;

#define sipType_QSignalTransition sipExportedTypes_QtCore[246]

extern sipClassTypeDef sipTypeDef_QtCore_QSignalTransition;

#define sipType_QSize sipExportedTypes_QtCore[247]

extern sipClassTypeDef sipTypeDef_QtCore_QSize;

#define sipType_QSizeF sipExportedTypes_QtCore[248]

extern sipClassTypeDef sipTypeDef_QtCore_QSizeF;

#define sipType_QSocketNotifier sipExportedTypes_QtCore[249]

#define sipType_QSocketNotifier_Type sipExportedTypes_QtCore[250]

extern sipClassTypeDef sipTypeDef_QtCore_QSocketNotifier;

#define sipType_QSortFilterProxyModel sipExportedTypes_QtCore[251]

extern sipClassTypeDef sipTypeDef_QtCore_QSortFilterProxyModel;

#define sipType_QStandardPaths sipExportedTypes_QtCore[252]

#define sipType_QStandardPaths_LocateOption sipExportedTypes_QtCore[253]

#define sipType_QStandardPaths_StandardLocation sipExportedTypes_QtCore[255]

extern sipClassTypeDef sipTypeDef_QtCore_QStandardPaths;

#define sipType_QStandardPaths_LocateOptions sipExportedTypes_QtCore[254]

extern sipClassTypeDef sipTypeDef_QtCore_QStandardPaths_LocateOptions;

#define sipType_QState sipExportedTypes_QtCore[256]

#define sipType_QState_RestorePolicy sipExportedTypes_QtCore[258]

#define sipType_QState_ChildMode sipExportedTypes_QtCore[257]

extern sipClassTypeDef sipTypeDef_QtCore_QState;

#define sipType_QStateMachine sipExportedTypes_QtCore[259]

#define sipType_QStateMachine_Error sipExportedTypes_QtCore[260]

#define sipType_QStateMachine_EventPriority sipExportedTypes_QtCore[261]

extern sipClassTypeDef sipTypeDef_QtCore_QStateMachine;

#define sipType_QStateMachine_SignalEvent sipExportedTypes_QtCore[262]

extern sipClassTypeDef sipTypeDef_QtCore_QStateMachine_SignalEvent;

#define sipType_QStateMachine_WrappedEvent sipExportedTypes_QtCore[263]

extern sipClassTypeDef sipTypeDef_QtCore_QStateMachine_WrappedEvent;

#define sipType_QStorageInfo sipExportedTypes_QtCore[264]

extern sipClassTypeDef sipTypeDef_QtCore_QStorageInfo;

#define sipType_QStringListModel sipExportedTypes_QtCore[267]

extern sipClassTypeDef sipTypeDef_QtCore_QStringListModel;

#define sipType_QSystemSemaphore sipExportedTypes_QtCore[272]

#define sipType_QSystemSemaphore_SystemSemaphoreError sipExportedTypes_QtCore[274]

#define sipType_QSystemSemaphore_AccessMode sipExportedTypes_QtCore[273]

extern sipClassTypeDef sipTypeDef_QtCore_QSystemSemaphore;

#define sipType_QTemporaryDir sipExportedTypes_QtCore[275]

extern sipClassTypeDef sipTypeDef_QtCore_QTemporaryDir;

#define sipType_QTemporaryFile sipExportedTypes_QtCore[276]

extern sipClassTypeDef sipTypeDef_QtCore_QTemporaryFile;

#define sipType_QTextBoundaryFinder sipExportedTypes_QtCore[277]

#define sipType_QTextBoundaryFinder_BoundaryType sipExportedTypes_QtCore[280]

#define sipType_QTextBoundaryFinder_BoundaryReason sipExportedTypes_QtCore[278]

extern sipClassTypeDef sipTypeDef_QtCore_QTextBoundaryFinder;

#define sipType_QTextBoundaryFinder_BoundaryReasons sipExportedTypes_QtCore[279]

extern sipClassTypeDef sipTypeDef_QtCore_QTextBoundaryFinder_BoundaryReasons;

#define sipType_QTextCodec sipExportedTypes_QtCore[281]

#define sipType_QTextCodec_ConversionFlag sipExportedTypes_QtCore[282]

extern sipClassTypeDef sipTypeDef_QtCore_QTextCodec;

#define sipType_QTextCodec_ConversionFlags sipExportedTypes_QtCore[283]

extern sipClassTypeDef sipTypeDef_QtCore_QTextCodec_ConversionFlags;

#define sipType_QTextCodec_ConverterState sipExportedTypes_QtCore[284]

extern sipClassTypeDef sipTypeDef_QtCore_QTextCodec_ConverterState;

#define sipType_QTextEncoder sipExportedTypes_QtCore[286]

extern sipClassTypeDef sipTypeDef_QtCore_QTextEncoder;

#define sipType_QTextDecoder sipExportedTypes_QtCore[285]

extern sipClassTypeDef sipTypeDef_QtCore_QTextDecoder;

#define sipType_QTextStream sipExportedTypes_QtCore[287]

#define sipType_QTextStream_Status sipExportedTypes_QtCore[292]

#define sipType_QTextStream_NumberFlag sipExportedTypes_QtCore[289]

#define sipType_QTextStream_FieldAlignment sipExportedTypes_QtCore[288]

#define sipType_QTextStream_RealNumberNotation sipExportedTypes_QtCore[291]

extern sipClassTypeDef sipTypeDef_QtCore_QTextStream;

#define sipType_QTextStream_NumberFlags sipExportedTypes_QtCore[290]

extern sipClassTypeDef sipTypeDef_QtCore_QTextStream_NumberFlags;

#define sipType_QTextStreamManipulator sipExportedTypes_QtCore[293]

extern sipClassTypeDef sipTypeDef_QtCore_QTextStreamManipulator;

#define sipType_QThread sipExportedTypes_QtCore[294]

#define sipType_QThread_Priority sipExportedTypes_QtCore[295]

extern sipClassTypeDef sipTypeDef_QtCore_QThread;

#define sipType_QThreadPool sipExportedTypes_QtCore[296]

extern sipClassTypeDef sipTypeDef_QtCore_QThreadPool;

#define sipType_QTimeLine sipExportedTypes_QtCore[298]

#define sipType_QTimeLine_State sipExportedTypes_QtCore[301]

#define sipType_QTimeLine_Direction sipExportedTypes_QtCore[300]

#define sipType_QTimeLine_CurveShape sipExportedTypes_QtCore[299]

extern sipClassTypeDef sipTypeDef_QtCore_QTimeLine;

#define sipType_QTimer sipExportedTypes_QtCore[306]

extern sipClassTypeDef sipTypeDef_QtCore_QTimer;

#define sipType_QTimeZone sipExportedTypes_QtCore[302]

#define sipType_QTimeZone_NameType sipExportedTypes_QtCore[303]

#define sipType_QTimeZone_TimeType sipExportedTypes_QtCore[305]

extern sipClassTypeDef sipTypeDef_QtCore_QTimeZone;

#define sipType_QTimeZone_OffsetData sipExportedTypes_QtCore[304]

extern sipClassTypeDef sipTypeDef_QtCore_QTimeZone_OffsetData;

#define sipType_QTranslator sipExportedTypes_QtCore[308]

extern sipClassTypeDef sipTypeDef_QtCore_QTranslator;

#define sipType_QTransposeProxyModel sipExportedTypes_QtCore[309]

extern sipClassTypeDef sipTypeDef_QtCore_QTransposeProxyModel;

#define sipType_QUrl sipExportedTypes_QtCore[310]

#define sipType_QUrl_UserInputResolutionOption sipExportedTypes_QtCore[316]

#define sipType_QUrl_ComponentFormattingOption sipExportedTypes_QtCore[311]

#define sipType_QUrl_UrlFormattingOption sipExportedTypes_QtCore[315]

#define sipType_QUrl_ParsingMode sipExportedTypes_QtCore[314]

extern sipClassTypeDef sipTypeDef_QtCore_QUrl;

#define sipType_QUrl_FormattingOptions sipExportedTypes_QtCore[313]

extern sipClassTypeDef sipTypeDef_QtCore_QUrl_FormattingOptions;

#define sipType_QUrl_ComponentFormattingOptions sipExportedTypes_QtCore[312]

extern sipClassTypeDef sipTypeDef_QtCore_QUrl_ComponentFormattingOptions;

#define sipType_QUrl_UserInputResolutionOptions sipExportedTypes_QtCore[317]

extern sipClassTypeDef sipTypeDef_QtCore_QUrl_UserInputResolutionOptions;

#define sipType_QUrlQuery sipExportedTypes_QtCore[318]

extern sipClassTypeDef sipTypeDef_QtCore_QUrlQuery;

#define sipType_QUuid sipExportedTypes_QtCore[319]

#define sipType_QUuid_StringFormat sipExportedTypes_QtCore[320]

#define sipType_QUuid_Version sipExportedTypes_QtCore[322]

#define sipType_QUuid_Variant sipExportedTypes_QtCore[321]

extern sipClassTypeDef sipTypeDef_QtCore_QUuid;

#define sipType_QVariant sipExportedTypes_QtCore[323]

#define sipType_QVariant_Type sipExportedTypes_QtCore[324]

extern sipClassTypeDef sipTypeDef_QtCore_QVariant;

#define sipType_QVersionNumber sipExportedTypes_QtCore[335]

extern sipClassTypeDef sipTypeDef_QtCore_QVersionNumber;

#define sipType_QWaitCondition sipExportedTypes_QtCore[336]

extern sipClassTypeDef sipTypeDef_QtCore_QWaitCondition;

#define sipType_QXmlStreamAttribute sipExportedTypes_QtCore[339]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamAttribute;

#define sipType_QXmlStreamAttributes sipExportedTypes_QtCore[340]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamAttributes;

#define sipType_QXmlStreamNamespaceDeclaration sipExportedTypes_QtCore[343]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamNamespaceDeclaration;

#define sipType_QXmlStreamNotationDeclaration sipExportedTypes_QtCore[344]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamNotationDeclaration;

#define sipType_QXmlStreamEntityDeclaration sipExportedTypes_QtCore[341]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamEntityDeclaration;

#define sipType_QXmlStreamEntityResolver sipExportedTypes_QtCore[342]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamEntityResolver;

#define sipType_QXmlStreamReader sipExportedTypes_QtCore[345]

#define sipType_QXmlStreamReader_Error sipExportedTypes_QtCore[346]

#define sipType_QXmlStreamReader_ReadElementTextBehaviour sipExportedTypes_QtCore[347]

#define sipType_QXmlStreamReader_TokenType sipExportedTypes_QtCore[348]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamReader;

#define sipType_QXmlStreamWriter sipExportedTypes_QtCore[349]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamWriter;

#define sipType_QSysInfo sipExportedTypes_QtCore[269]

#define sipType_QSysInfo_Endian sipExportedTypes_QtCore[270]

#define sipType_QSysInfo_Sizes sipExportedTypes_QtCore[271]

extern sipClassTypeDef sipTypeDef_QtCore_QSysInfo;

#define sipType_QList_0600QPair_0100QString_0100QString sipExportedTypes_QtCore[140]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0600QPair_0100QString_0100QString;

#define sipType_QList_0100QStorageInfo sipExportedTypes_QtCore[143]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QStorageInfo;

#define sipType_QSet_0101QAbstractState sipExportedTypes_QtCore[236]

extern sipMappedTypeDef sipTypeDef_QtCore_QSet_0101QAbstractState;

#define sipType_QList_0101QAbstractTransition sipExportedTypes_QtCore[132]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QAbstractTransition;

#define sipType_QList_0100QMimeType sipExportedTypes_QtCore[137]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QMimeType;

#define sipType_QList_0100QUrl sipExportedTypes_QtCore[144]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QUrl;

#define sipType_QList_0100QLocale sipExportedTypes_QtCore[136]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QLocale;

#define sipType_QVector_0100QPointF sipExportedTypes_QtCore[328]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0100QPointF;

#define sipType_QList_0101QAbstractItemModel sipExportedTypes_QtCore[130]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QAbstractItemModel;

#define sipType_QList_0100QCommandLineOption sipExportedTypes_QtCore[134]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QCommandLineOption;

#define sipType_QList_0101QAbstractAnimation sipExportedTypes_QtCore[128]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QAbstractAnimation;

#define sipType_QList_0101QAbstractState sipExportedTypes_QtCore[131]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QAbstractState;

#define sipType_QHash_1800_0100QByteArray sipExportedTypes_QtCore[99]

extern sipMappedTypeDef sipTypeDef_QtCore_QHash_1800_0100QByteArray;

#define sipType_QList_0100QPersistentModelIndex sipExportedTypes_QtCore[142]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QPersistentModelIndex;

#define sipType_QMap_1800_0100QVariant sipExportedTypes_QtCore[165]

extern sipMappedTypeDef sipTypeDef_QtCore_QMap_1800_0100QVariant;

#define sipType_QList_0100QAbstractEventDispatcher_TimerInfo sipExportedTypes_QtCore[129]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QAbstractEventDispatcher_TimerInfo;

#define sipType_QList_0100QByteArray sipExportedTypes_QtCore[133]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QByteArray;

#define sipType_QVector_0100QXmlStreamNotationDeclaration sipExportedTypes_QtCore[332]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0100QXmlStreamNotationDeclaration;

#define sipType_QVector_0100QXmlStreamNamespaceDeclaration sipExportedTypes_QtCore[331]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0100QXmlStreamNamespaceDeclaration;

#define sipType_QVector_0100QXmlStreamEntityDeclaration sipExportedTypes_QtCore[330]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0100QXmlStreamEntityDeclaration;

#define sipType_QList_0100QVariant sipExportedTypes_QtCore[145]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QVariant;

#define sipType_QHash_0100QString_0100QVariant sipExportedTypes_QtCore[98]

extern sipMappedTypeDef sipTypeDef_QtCore_QHash_0100QString_0100QVariant;

#define sipType_QVector_0600QPair_2400_0100QVariant sipExportedTypes_QtCore[327]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0600QPair_2400_0100QVariant;

#define sipType_QVector_0100QTimeZone_OffsetData sipExportedTypes_QtCore[329]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0100QTimeZone_OffsetData;

#define sipType_QList_0101QObject sipExportedTypes_QtCore[139]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QObject;

#define sipType_QList_0100QModelIndex sipExportedTypes_QtCore[138]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QModelIndex;

#define sipType_QList_0100QFileInfo sipExportedTypes_QtCore[135]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QFileInfo;

#define sipType_QVector_1600 sipExportedTypes_QtCore[334]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_1600;

#define sipType_QVector_1800 sipExportedTypes_QtCore[333]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_1800;

#define sipType_QPair_1800_1800 sipExportedTypes_QtCore[195]

extern sipMappedTypeDef sipTypeDef_QtCore_QPair_1800_1800;

#define sipType_QVariantMap sipExportedTypes_QtCore[326]

extern sipMappedTypeDef sipTypeDef_QtCore_QVariantMap;

#define sipType_QJsonArray sipExportedTypes_QtCore[111]

extern sipMappedTypeDef sipTypeDef_QtCore_QJsonArray;

#define sipType_QStringList sipExportedTypes_QtCore[266]

extern sipMappedTypeDef sipTypeDef_QtCore_QStringList;

#define sipType_QList_0100Qt_DayOfWeek sipExportedTypes_QtCore[146]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100Qt_DayOfWeek;

#define sipType_QList_2400 sipExportedTypes_QtCore[148]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_2400;

#define sipType_QList_1800 sipExportedTypes_QtCore[147]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_1800;

#define sipType_QList_0600QPair_1800_1800 sipExportedTypes_QtCore[141]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0600QPair_1800_1800;

#define sipType_QJsonObject sipExportedTypes_QtCore[115]

extern sipMappedTypeDef sipTypeDef_QtCore_QJsonObject;

#define sipType_QStringRef sipExportedTypes_QtCore[268]

extern sipMappedTypeDef sipTypeDef_QtCore_QStringRef;

#define sipType_QString sipExportedTypes_QtCore[265]

extern sipMappedTypeDef sipTypeDef_QtCore_QString;

#define sipType_QChar sipExportedTypes_QtCore[38]

extern sipMappedTypeDef sipTypeDef_QtCore_QChar;

#define sipType_quintptr sipExportedTypes_QtCore[459]

extern sipMappedTypeDef sipTypeDef_QtCore_quintptr;

#define sipType_qintptr sipExportedTypes_QtCore[458]

extern sipMappedTypeDef sipTypeDef_QtCore_qintptr;

#define sipType_QtMsgType sipExportedTypes_QtCore[457]

#define sipType_QCborKnownTags sipExportedTypes_QtCore[32]

#define sipType_QCborSimpleType sipExportedTypes_QtCore[33]

void sipVEH_QtCore_PyQt5(sipSimpleWrapper *, sip_gilstate_t);

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtCore;
extern sipExportedModuleDef sipModuleAPI_QtCore;
extern sipTypeDef *sipExportedTypes_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtCore_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtCore_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtCore_qt_metacast;
#line 742 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include "qpycore_api.h"
#line 12306 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipAPIQtCore.h"

#endif
